/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayoutitem.sip"
#include <qlayoutitem.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayoutitem.sip"
#include <qlayoutitem.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"


class sipQLayout : public  ::QLayout
{
public:
    sipQLayout( ::QWidget*);
    sipQLayout();
    virtual ~sipQLayout();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    int count() const SIP_OVERRIDE;
    int indexOf( ::QWidget*) const SIP_OVERRIDE;
     ::QLayoutItem* takeAt(int) SIP_OVERRIDE;
     ::QLayoutItem* itemAt(int) const SIP_OVERRIDE;
    void addItem( ::QLayoutItem*) SIP_OVERRIDE;
     ::QSize sizeHint() const SIP_OVERRIDE;
     ::QSize minimumSize() const SIP_OVERRIDE;
     ::QSize maximumSize() const SIP_OVERRIDE;
     ::Qt::Orientations expandingDirections() const SIP_OVERRIDE;
    void setGeometry(const  ::QRect&) SIP_OVERRIDE;
     ::QRect geometry() const SIP_OVERRIDE;
    bool isEmpty() const SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    int minimumHeightForWidth(int) const SIP_OVERRIDE;
    void invalidate() SIP_OVERRIDE;
     ::QWidget* widget() SIP_OVERRIDE;
     ::QLayout* layout() SIP_OVERRIDE;
     ::QSpacerItem* spacerItem() SIP_OVERRIDE;
     ::QSizePolicy::ControlTypes controlTypes() const SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQLayout(const sipQLayout &);
    sipQLayout &operator = (const sipQLayout &);

    char sipPyMethods[27];
};

sipQLayout::sipQLayout( ::QWidget*a0):  ::QLayout(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLayout::sipQLayout():  ::QLayout(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLayout::~sipQLayout()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQLayout::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf,sipType_QLayout);

    return  ::QLayout::metaObject();
}

int sipQLayout::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QLayout::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf,sipType_QLayout,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQLayout::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QLayout, _clname, &sipCpp) ? sipCpp :  ::QLayout::qt_metacast(_clname));
}

int sipQLayout::count() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,sipName_QLayout,sipName_count);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQLayout::indexOf( ::QWidget*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,SIP_NULLPTR,sipName_indexOf);

    if (!sipMeth)
        return  ::QLayout::indexOf(a0);

    extern int sipVH_QtWidgets_85(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QWidget*);

    return sipVH_QtWidgets_85(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QLayoutItem* sipQLayout::takeAt(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,sipName_QLayout,sipName_takeAt);

    if (!sipMeth)
        return 0;

    extern  ::QLayoutItem* sipVH_QtWidgets_84(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_84(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QLayoutItem* sipQLayout::itemAt(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,sipName_QLayout,sipName_itemAt);

    if (!sipMeth)
        return 0;

    extern  ::QLayoutItem* sipVH_QtWidgets_83(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_83(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::addItem( ::QLayoutItem*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,sipName_QLayout,sipName_addItem);

    if (!sipMeth)
        return;

    extern void sipVH_QtWidgets_82(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QLayoutItem*);

    sipVH_QtWidgets_82(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QSize sipQLayout::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,sipName_QLayout,sipName_sizeHint);

    if (!sipMeth)
        return  ::QSize();

    extern  ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSize sipQLayout::minimumSize() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[6]),sipPySelf,SIP_NULLPTR,sipName_minimumSize);

    if (!sipMeth)
        return  ::QLayout::minimumSize();

    extern  ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSize sipQLayout::maximumSize() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[7]),sipPySelf,SIP_NULLPTR,sipName_maximumSize);

    if (!sipMeth)
        return  ::QLayout::maximumSize();

    extern  ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::Qt::Orientations sipQLayout::expandingDirections() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[8]),sipPySelf,SIP_NULLPTR,sipName_expandingDirections);

    if (!sipMeth)
        return  ::QLayout::expandingDirections();

    extern  ::Qt::Orientations sipVH_QtWidgets_75(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_75(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQLayout::setGeometry(const  ::QRect& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_setGeometry);

    if (!sipMeth)
    {
         ::QLayout::setGeometry(a0);
        return;
    }

    extern void sipVH_QtWidgets_76(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QRect&);

    sipVH_QtWidgets_76(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QRect sipQLayout::geometry() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[10]),sipPySelf,SIP_NULLPTR,sipName_geometry);

    if (!sipMeth)
        return  ::QLayout::geometry();

    extern  ::QRect sipVH_QtWidgets_77(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_77(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLayout::isEmpty() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[11]),sipPySelf,SIP_NULLPTR,sipName_isEmpty);

    if (!sipMeth)
        return  ::QLayout::isEmpty();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLayout::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[12]),sipPySelf,SIP_NULLPTR,sipName_hasHeightForWidth);

    if (!sipMeth)
        return  ::QLayout::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQLayout::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[13]),sipPySelf,SIP_NULLPTR,sipName_heightForWidth);

    if (!sipMeth)
        return  ::QLayout::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQLayout::minimumHeightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[14]),sipPySelf,SIP_NULLPTR,sipName_minimumHeightForWidth);

    if (!sipMeth)
        return  ::QLayout::minimumHeightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::invalidate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_invalidate);

    if (!sipMeth)
    {
         ::QLayout::invalidate();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QWidget* sipQLayout::widget()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_widget);

    if (!sipMeth)
        return  ::QLayout::widget();

    extern  ::QWidget* sipVH_QtWidgets_78(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_78(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QLayout* sipQLayout::layout()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[17],sipPySelf,SIP_NULLPTR,sipName_layout);

    if (!sipMeth)
        return  ::QLayout::layout();

    extern  ::QLayout* sipVH_QtWidgets_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_79(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSpacerItem* sipQLayout::spacerItem()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_spacerItem);

    if (!sipMeth)
        return  ::QLayout::spacerItem();

    extern  ::QSpacerItem* sipVH_QtWidgets_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_80(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSizePolicy::ControlTypes sipQLayout::controlTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[19]),sipPySelf,SIP_NULLPTR,sipName_controlTypes);

    if (!sipMeth)
        return  ::QLayout::controlTypes();

    extern  ::QSizePolicy::ControlTypes sipVH_QtWidgets_81(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_81(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLayout::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QLayout::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQLayout::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[21],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QLayout::eventFilter(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQLayout::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[22],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QLayout::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QLayout::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QLayout::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QLayout::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLayout::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QLayout::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QLayout_spacing, "spacing(self) -> int");

extern "C" {static PyObject *meth_QLayout_spacing(PyObject *, PyObject *);}
static PyObject *meth_QLayout_spacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->spacing();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_spacing, doc_QLayout_spacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setSpacing, "setSpacing(self, int)");

extern "C" {static PyObject *meth_QLayout_setSpacing(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLayout, &sipCpp, &a0))
        {
            sipCpp->setSpacing(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setSpacing, doc_QLayout_setSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setAlignment, "setAlignment(self, QWidget, Union[Qt.Alignment, Qt.AlignmentFlag]) -> bool\n"
"setAlignment(self, QLayout, Union[Qt.Alignment, Qt.AlignmentFlag]) -> bool\n"
"setAlignment(self, Union[Qt.Alignment, Qt.AlignmentFlag])");

extern "C" {static PyObject *meth_QLayout_setAlignment(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
         ::Qt::Alignment* a1;
        int a1State = 0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QLayout, &sipCpp, sipType_QWidget, &a0, sipType_Qt_Alignment, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->setAlignment(a0,*a1);
            sipReleaseType(a1,sipType_Qt_Alignment,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
         ::QLayout* a0;
         ::Qt::Alignment* a1;
        int a1State = 0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayout, &a0, sipType_Qt_Alignment, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->setAlignment(a0,*a1);
            sipReleaseType(a1,sipType_Qt_Alignment,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
         ::Qt::Alignment* a0;
        int a0State = 0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLayout, &sipCpp, sipType_Qt_Alignment, &a0, &a0State))
        {
            sipCpp->setAlignment(*a0);
            sipReleaseType(a0,sipType_Qt_Alignment,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setAlignment, doc_QLayout_setAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setSizeConstraint, "setSizeConstraint(self, QLayout.SizeConstraint)");

extern "C" {static PyObject *meth_QLayout_setSizeConstraint(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setSizeConstraint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayout::SizeConstraint a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayout_SizeConstraint, &a0))
        {
            sipCpp->setSizeConstraint(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setSizeConstraint, doc_QLayout_setSizeConstraint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_sizeConstraint, "sizeConstraint(self) -> QLayout.SizeConstraint");

extern "C" {static PyObject *meth_QLayout_sizeConstraint(PyObject *, PyObject *);}
static PyObject *meth_QLayout_sizeConstraint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QLayout::SizeConstraint sipRes;

            sipRes = sipCpp->sizeConstraint();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLayout_SizeConstraint);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_sizeConstraint, doc_QLayout_sizeConstraint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setMenuBar, "setMenuBar(self, QWidget)");

extern "C" {static PyObject *meth_QLayout_setMenuBar(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setMenuBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        PyObject *a0Wrapper;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QLayout, &sipCpp, &a0Wrapper, sipType_QWidget, &a0))
        {
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayout.sip"
        Py_BEGIN_ALLOW_THREADS
        sipCpp->setMenuBar(a0);
        Py_END_ALLOW_THREADS
        
        // The layout's parent widget (if there is one) will now have ownership.
        QWidget *parent = sipCpp->parentWidget();
        
        if (a0 && parent)
        {
            PyObject *py_parent = sipGetPyObject(parent, sipType_QWidget);
        
            if (py_parent)
                sipTransferTo(a0Wrapper, py_parent);
        }
        else
        {
            // For now give the Python ownership to the layout.  This maintains
            // compatibility with previous versions and allows setMenuBar(QWidget()).
            sipTransferTo(a0Wrapper, sipSelf);
        }
#line 849 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setMenuBar, doc_QLayout_setMenuBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_menuBar, "menuBar(self) -> QWidget");

extern "C" {static PyObject *meth_QLayout_menuBar(PyObject *, PyObject *);}
static PyObject *meth_QLayout_menuBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->menuBar();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_menuBar, doc_QLayout_menuBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_parentWidget, "parentWidget(self) -> QWidget");

extern "C" {static PyObject *meth_QLayout_parentWidget(PyObject *, PyObject *);}
static PyObject *meth_QLayout_parentWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->parentWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_parentWidget, doc_QLayout_parentWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_invalidate, "invalidate(self)");

extern "C" {static PyObject *meth_QLayout_invalidate(PyObject *, PyObject *);}
static PyObject *meth_QLayout_invalidate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QLayout::invalidate() : sipCpp->invalidate());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_invalidate, doc_QLayout_invalidate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_geometry, "geometry(self) -> QRect");

extern "C" {static PyObject *meth_QLayout_geometry(PyObject *, PyObject *);}
static PyObject *meth_QLayout_geometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect((sipSelfWasArg ? sipCpp-> ::QLayout::geometry() : sipCpp->geometry()));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_geometry, doc_QLayout_geometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_activate, "activate(self) -> bool");

extern "C" {static PyObject *meth_QLayout_activate(PyObject *, PyObject *);}
static PyObject *meth_QLayout_activate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->activate();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_activate, doc_QLayout_activate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_update, "update(self)");

extern "C" {static PyObject *meth_QLayout_update(PyObject *, PyObject *);}
static PyObject *meth_QLayout_update(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            sipCpp->update();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_update, doc_QLayout_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_addWidget, "addWidget(self, QWidget)");

extern "C" {static PyObject *meth_QLayout_addWidget(PyObject *, PyObject *);}
static PyObject *meth_QLayout_addWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        PyObject *a0Wrapper;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QLayout, &sipCpp, &a0Wrapper, sipType_QWidget, &a0))
        {
#line 82 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayout.sip"
        Py_BEGIN_ALLOW_THREADS
        sipCpp->addWidget(a0);
        Py_END_ALLOW_THREADS
        
        // The layout's parent widget (if there is one) will now have ownership.
        QWidget *parent = sipCpp->parentWidget();
        
        if (parent)
        {
            PyObject *py_parent = sipGetPyObject(parent, sipType_QWidget);
        
            if (py_parent)
                sipTransferTo(a0Wrapper, py_parent);
        }
        else
        {
            // For now give the Python ownership to the layout.  This maintains
            // compatibility with previous versions and allows addWidget(QWidget()).
            sipTransferTo(a0Wrapper, sipSelf);
        }
#line 1060 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_addWidget, doc_QLayout_addWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_addItem, "addItem(self, QLayoutItem)");

extern "C" {static PyObject *meth_QLayout_addItem(PyObject *, PyObject *);}
static PyObject *meth_QLayout_addItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QLayoutItem* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayoutItem, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLayout, sipName_addItem);
                return SIP_NULLPTR;
            }

            sipCpp->addItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_addItem, doc_QLayout_addItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_removeWidget, "removeWidget(self, QWidget)");

extern "C" {static PyObject *meth_QLayout_removeWidget(PyObject *, PyObject *);}
static PyObject *meth_QLayout_removeWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QLayout, &sipCpp, sipType_QWidget, &a0))
        {
            sipCpp->removeWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_removeWidget, doc_QLayout_removeWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_removeItem, "removeItem(self, QLayoutItem)");

extern "C" {static PyObject *meth_QLayout_removeItem(PyObject *, PyObject *);}
static PyObject *meth_QLayout_removeItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayoutItem* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayoutItem, &a0))
        {
            sipCpp->removeItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_removeItem, doc_QLayout_removeItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_expandingDirections, "expandingDirections(self) -> Qt.Orientations");

extern "C" {static PyObject *meth_QLayout_expandingDirections(PyObject *, PyObject *);}
static PyObject *meth_QLayout_expandingDirections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::Qt::Orientations*sipRes;

            sipRes = new  ::Qt::Orientations((sipSelfWasArg ? sipCpp-> ::QLayout::expandingDirections() : sipCpp->expandingDirections()));

            return sipConvertFromNewType(sipRes,sipType_Qt_Orientations,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_expandingDirections, doc_QLayout_expandingDirections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_minimumSize, "minimumSize(self) -> QSize");

extern "C" {static PyObject *meth_QLayout_minimumSize(PyObject *, PyObject *);}
static PyObject *meth_QLayout_minimumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize((sipSelfWasArg ? sipCpp-> ::QLayout::minimumSize() : sipCpp->minimumSize()));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_minimumSize, doc_QLayout_minimumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_maximumSize, "maximumSize(self) -> QSize");

extern "C" {static PyObject *meth_QLayout_maximumSize(PyObject *, PyObject *);}
static PyObject *meth_QLayout_maximumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize((sipSelfWasArg ? sipCpp-> ::QLayout::maximumSize() : sipCpp->maximumSize()));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_maximumSize, doc_QLayout_maximumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setGeometry, "setGeometry(self, QRect)");

extern "C" {static PyObject *meth_QLayout_setGeometry(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QRect* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLayout, &sipCpp, sipType_QRect, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QLayout::setGeometry(*a0) : sipCpp->setGeometry(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setGeometry, doc_QLayout_setGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_itemAt, "itemAt(self, int) -> QLayoutItem");

extern "C" {static PyObject *meth_QLayout_itemAt(PyObject *, PyObject *);}
static PyObject *meth_QLayout_itemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLayout, &sipCpp, &a0))
        {
             ::QLayoutItem*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLayout, sipName_itemAt);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->itemAt(a0);

            return sipConvertFromType(sipRes,sipType_QLayoutItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_itemAt, doc_QLayout_itemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_takeAt, "takeAt(self, int) -> QLayoutItem");

extern "C" {static PyObject *meth_QLayout_takeAt(PyObject *, PyObject *);}
static PyObject *meth_QLayout_takeAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLayout, &sipCpp, &a0))
        {
             ::QLayoutItem*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLayout, sipName_takeAt);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->takeAt(a0);

            return sipConvertFromType(sipRes,sipType_QLayoutItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_takeAt, doc_QLayout_takeAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_indexOf, "indexOf(self, QWidget) -> int\n"
"indexOf(self, QLayoutItem) -> int");

extern "C" {static PyObject *meth_QLayout_indexOf(PyObject *, PyObject *);}
static PyObject *meth_QLayout_indexOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QWidget* a0;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QLayout, &sipCpp, sipType_QWidget, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QLayout::indexOf(a0) : sipCpp->indexOf(a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    {
         ::QLayoutItem* a0;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayoutItem, &a0))
        {
            int sipRes;

            sipRes = sipCpp->indexOf(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_indexOf, doc_QLayout_indexOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_count, "count(self) -> int");

extern "C" {static PyObject *meth_QLayout_count(PyObject *, PyObject *);}
static PyObject *meth_QLayout_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QLayout, sipName_count);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->count();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_count, doc_QLayout_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QLayout_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QLayout_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QLayout::isEmpty() : sipCpp->isEmpty());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_isEmpty, doc_QLayout_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_totalHeightForWidth, "totalHeightForWidth(self, int) -> int");

extern "C" {static PyObject *meth_QLayout_totalHeightForWidth(PyObject *, PyObject *);}
static PyObject *meth_QLayout_totalHeightForWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLayout, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->totalHeightForWidth(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_totalHeightForWidth, doc_QLayout_totalHeightForWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_totalMinimumSize, "totalMinimumSize(self) -> QSize");

extern "C" {static PyObject *meth_QLayout_totalMinimumSize(PyObject *, PyObject *);}
static PyObject *meth_QLayout_totalMinimumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->totalMinimumSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_totalMinimumSize, doc_QLayout_totalMinimumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_totalMaximumSize, "totalMaximumSize(self) -> QSize");

extern "C" {static PyObject *meth_QLayout_totalMaximumSize(PyObject *, PyObject *);}
static PyObject *meth_QLayout_totalMaximumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->totalMaximumSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_totalMaximumSize, doc_QLayout_totalMaximumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_totalSizeHint, "totalSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QLayout_totalSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QLayout_totalSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->totalSizeHint());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_totalSizeHint, doc_QLayout_totalSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_layout, "layout(self) -> QLayout");

extern "C" {static PyObject *meth_QLayout_layout(PyObject *, PyObject *);}
static PyObject *meth_QLayout_layout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QLayout*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QLayout::layout() : sipCpp->layout());

            return sipConvertFromType(sipRes,sipType_QLayout,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_layout, doc_QLayout_layout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setEnabled, "setEnabled(self, bool)");

extern "C" {static PyObject *meth_QLayout_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QLayout, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setEnabled, doc_QLayout_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_QLayout_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QLayout_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_isEnabled, doc_QLayout_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_closestAcceptableSize, "closestAcceptableSize(QWidget, QSize) -> QSize");

extern "C" {static PyObject *meth_QLayout_closestAcceptableSize(PyObject *, PyObject *);}
static PyObject *meth_QLayout_closestAcceptableSize(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QSize* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J9", sipType_QWidget, &a0, sipType_QSize, &a1))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize( ::QLayout::closestAcceptableSize(a0,*a1));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_closestAcceptableSize, doc_QLayout_closestAcceptableSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_widgetEvent, "widgetEvent(self, QEvent)");

extern "C" {static PyObject *meth_QLayout_widgetEvent(PyObject *, PyObject *);}
static PyObject *meth_QLayout_widgetEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QEvent* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QLayout, &sipCpp, sipType_QEvent, &a0))
        {
            sipCpp->widgetEvent(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_widgetEvent, doc_QLayout_widgetEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_childEvent, "childEvent(self, QChildEvent)");

extern "C" {static PyObject *meth_QLayout_childEvent(PyObject *, PyObject *);}
static PyObject *meth_QLayout_childEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QChildEvent* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QLayout, &sipCpp, sipType_QChildEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QLayout::childEvent(a0) : sipCpp->childEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_childEvent, doc_QLayout_childEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_addChildLayout, "addChildLayout(self, QLayout)");

extern "C" {static PyObject *meth_QLayout_addChildLayout(PyObject *, PyObject *);}
static PyObject *meth_QLayout_addChildLayout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayout* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ:", &sipSelf, sipType_QLayout, &sipCpp, sipType_QLayout, &a0))
        {
            sipCpp->addChildLayout(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_addChildLayout, doc_QLayout_addChildLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_addChildWidget, "addChildWidget(self, QWidget)");

extern "C" {static PyObject *meth_QLayout_addChildWidget(PyObject *, PyObject *);}
static PyObject *meth_QLayout_addChildWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        PyObject *a0Wrapper;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p@J8", &sipSelf, sipType_QLayout, &sipCpp, &a0Wrapper, sipType_QWidget, &a0))
        {
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayout.sip"
        Py_BEGIN_ALLOW_THREADS
        #if defined(SIP_PROTECTED_IS_PUBLIC)
        sipCpp->addChildWidget(a0);
        #else
        sipCpp->sipProtect_addChildWidget(a0);
        #endif
        Py_END_ALLOW_THREADS
        
        // The layout's parent widget (if there is one) will now have ownership.
        QWidget *parent = sipCpp->parentWidget();
        
        if (parent)
        {
            PyObject *py_parent = sipGetPyObject(parent, sipType_QWidget);
        
            if (py_parent)
                sipTransferTo(a0Wrapper, py_parent);
        }
        else
        {
            // For now give the Python ownership to the layout.  This maintains
            // compatibility with previous versions and allows
            // addChildWidget(QWidget()).
            sipTransferTo(a0Wrapper, sipSelf);
        }
#line 1792 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_addChildWidget, doc_QLayout_addChildWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_alignmentRect, "alignmentRect(self, QRect) -> QRect");

extern "C" {static PyObject *meth_QLayout_alignmentRect(PyObject *, PyObject *);}
static PyObject *meth_QLayout_alignmentRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect* a0;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QLayout, &sipCpp, sipType_QRect, &a0))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->alignmentRect(*a0));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_alignmentRect, doc_QLayout_alignmentRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_setContentsMargins, "setContentsMargins(self, int, int, int, int)\n"
"setContentsMargins(self, QMargins)");

extern "C" {static PyObject *meth_QLayout_setContentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QLayout_setContentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QLayout, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setContentsMargins(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QMargins* a0;
         ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLayout, &sipCpp, sipType_QMargins, &a0))
        {
            sipCpp->setContentsMargins(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_setContentsMargins, doc_QLayout_setContentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_getContentsMargins, "getContentsMargins(self) -> Tuple[int, int, int, int]");

extern "C" {static PyObject *meth_QLayout_getContentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QLayout_getContentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
            sipCpp->getContentsMargins(&a0,&a1,&a2,&a3);

            return sipBuildResult(0,"(iiii)",a0,a1,a2,a3);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_getContentsMargins, doc_QLayout_getContentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_contentsRect, "contentsRect(self) -> QRect");

extern "C" {static PyObject *meth_QLayout_contentsRect(PyObject *, PyObject *);}
static PyObject *meth_QLayout_contentsRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->contentsRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_contentsRect, doc_QLayout_contentsRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_contentsMargins, "contentsMargins(self) -> QMargins");

extern "C" {static PyObject *meth_QLayout_contentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QLayout_contentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QMargins*sipRes;

            sipRes = new  ::QMargins(sipCpp->contentsMargins());

            return sipConvertFromNewType(sipRes,sipType_QMargins,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_contentsMargins, doc_QLayout_contentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_controlTypes, "controlTypes(self) -> QSizePolicy.ControlTypes");

extern "C" {static PyObject *meth_QLayout_controlTypes(PyObject *, PyObject *);}
static PyObject *meth_QLayout_controlTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QLayout *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLayout, &sipCpp))
        {
             ::QSizePolicy::ControlTypes*sipRes;

            sipRes = new  ::QSizePolicy::ControlTypes((sipSelfWasArg ? sipCpp-> ::QLayout::controlTypes() : sipCpp->controlTypes()));

            return sipConvertFromNewType(sipRes,sipType_QSizePolicy_ControlTypes,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_controlTypes, doc_QLayout_controlTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLayout_replaceWidget, "replaceWidget(self, QWidget, QWidget, options: Union[Qt.FindChildOptions, Qt.FindChildOption] = Qt.FindChildrenRecursively) -> QLayoutItem");

extern "C" {static PyObject *meth_QLayout_replaceWidget(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLayout_replaceWidget(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
         ::QWidget* a1;
         ::Qt::FindChildOptions a2def = Qt::FindChildrenRecursively;
         ::Qt::FindChildOptions* a2 = &a2def;
        int a2State = 0;
         ::QLayout *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J:|J1", &sipSelf, sipType_QLayout, &sipCpp, sipType_QWidget, &a0, sipType_QWidget, &a1, sipType_Qt_FindChildOptions, &a2, &a2State))
        {
             ::QLayoutItem*sipRes;

            sipRes = sipCpp->replaceWidget(a0,a1,*a2);
            sipReleaseType(a2,sipType_Qt_FindChildOptions,a2State);

            return sipConvertFromType(sipRes,sipType_QLayoutItem,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLayout, sipName_replaceWidget, doc_QLayout_replaceWidget);

    return SIP_NULLPTR;
}


extern "C" {static SIP_SSIZE_T slot_QLayout___len__(PyObject *);}
static SIP_SSIZE_T slot_QLayout___len__(PyObject *sipSelf)
{
     ::QLayout *sipCpp = reinterpret_cast< ::QLayout *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QLayout));

    if (!sipCpp)
        return 0;


    {
        {
            SIP_SSIZE_T sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (SIP_SSIZE_T)sipCpp->count();
#line 2043 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQLayout.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLayout(void *, const sipTypeDef *);}
static void *cast_QLayout(void *sipCppV, const sipTypeDef *targetType)
{
     ::QLayout *sipCpp = reinterpret_cast< ::QLayout *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QLayoutItem)
        return static_cast< ::QLayoutItem *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLayout(void *, int);}
static void release_QLayout(void *sipCppV, int)
{
     ::QLayout *sipCpp = reinterpret_cast< ::QLayout *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QLayout(sipSimpleWrapper *);}
static void dealloc_QLayout(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQLayout *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLayout(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QLayout(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLayout(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQLayout *sipCpp = SIP_NULLPTR;

    {
         ::QWidget* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQLayout(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQLayout();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLayout[] = {{34, 0, 0}, {193, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QLayout[] = {
    {(void *)slot_QLayout___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLayout[] = {
    {SIP_MLNAME_CAST(sipName_activate), meth_QLayout_activate, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_activate)},
    {SIP_MLNAME_CAST(sipName_addChildLayout), meth_QLayout_addChildLayout, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_addChildLayout)},
    {SIP_MLNAME_CAST(sipName_addChildWidget), meth_QLayout_addChildWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_addChildWidget)},
    {SIP_MLNAME_CAST(sipName_addItem), meth_QLayout_addItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_addItem)},
    {SIP_MLNAME_CAST(sipName_addWidget), meth_QLayout_addWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_addWidget)},
    {SIP_MLNAME_CAST(sipName_alignmentRect), meth_QLayout_alignmentRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_alignmentRect)},
    {SIP_MLNAME_CAST(sipName_childEvent), meth_QLayout_childEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_childEvent)},
    {SIP_MLNAME_CAST(sipName_closestAcceptableSize), meth_QLayout_closestAcceptableSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_closestAcceptableSize)},
    {SIP_MLNAME_CAST(sipName_contentsMargins), meth_QLayout_contentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_contentsMargins)},
    {SIP_MLNAME_CAST(sipName_contentsRect), meth_QLayout_contentsRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_contentsRect)},
    {SIP_MLNAME_CAST(sipName_controlTypes), meth_QLayout_controlTypes, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_controlTypes)},
    {SIP_MLNAME_CAST(sipName_count), meth_QLayout_count, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_count)},
    {SIP_MLNAME_CAST(sipName_expandingDirections), meth_QLayout_expandingDirections, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_expandingDirections)},
    {SIP_MLNAME_CAST(sipName_geometry), meth_QLayout_geometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_geometry)},
    {SIP_MLNAME_CAST(sipName_getContentsMargins), meth_QLayout_getContentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_getContentsMargins)},
    {SIP_MLNAME_CAST(sipName_indexOf), meth_QLayout_indexOf, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_indexOf)},
    {SIP_MLNAME_CAST(sipName_invalidate), meth_QLayout_invalidate, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_invalidate)},
    {SIP_MLNAME_CAST(sipName_isEmpty), meth_QLayout_isEmpty, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_isEmpty)},
    {SIP_MLNAME_CAST(sipName_isEnabled), meth_QLayout_isEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_isEnabled)},
    {SIP_MLNAME_CAST(sipName_itemAt), meth_QLayout_itemAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_itemAt)},
    {SIP_MLNAME_CAST(sipName_layout), meth_QLayout_layout, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_layout)},
    {SIP_MLNAME_CAST(sipName_maximumSize), meth_QLayout_maximumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_maximumSize)},
    {SIP_MLNAME_CAST(sipName_menuBar), meth_QLayout_menuBar, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_menuBar)},
    {SIP_MLNAME_CAST(sipName_minimumSize), meth_QLayout_minimumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_minimumSize)},
    {SIP_MLNAME_CAST(sipName_parentWidget), meth_QLayout_parentWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_parentWidget)},
    {SIP_MLNAME_CAST(sipName_removeItem), meth_QLayout_removeItem, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_removeItem)},
    {SIP_MLNAME_CAST(sipName_removeWidget), meth_QLayout_removeWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_removeWidget)},
    {SIP_MLNAME_CAST(sipName_replaceWidget), SIP_MLMETH_CAST(meth_QLayout_replaceWidget), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QLayout_replaceWidget)},
    {SIP_MLNAME_CAST(sipName_setAlignment), meth_QLayout_setAlignment, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setAlignment)},
    {SIP_MLNAME_CAST(sipName_setContentsMargins), meth_QLayout_setContentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setContentsMargins)},
    {SIP_MLNAME_CAST(sipName_setEnabled), meth_QLayout_setEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setEnabled)},
    {SIP_MLNAME_CAST(sipName_setGeometry), meth_QLayout_setGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setGeometry)},
    {SIP_MLNAME_CAST(sipName_setMenuBar), meth_QLayout_setMenuBar, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setMenuBar)},
    {SIP_MLNAME_CAST(sipName_setSizeConstraint), meth_QLayout_setSizeConstraint, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setSizeConstraint)},
    {SIP_MLNAME_CAST(sipName_setSpacing), meth_QLayout_setSpacing, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_setSpacing)},
    {SIP_MLNAME_CAST(sipName_sizeConstraint), meth_QLayout_sizeConstraint, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_sizeConstraint)},
    {SIP_MLNAME_CAST(sipName_spacing), meth_QLayout_spacing, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_spacing)},
    {SIP_MLNAME_CAST(sipName_takeAt), meth_QLayout_takeAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_takeAt)},
    {SIP_MLNAME_CAST(sipName_totalHeightForWidth), meth_QLayout_totalHeightForWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_totalHeightForWidth)},
    {SIP_MLNAME_CAST(sipName_totalMaximumSize), meth_QLayout_totalMaximumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_totalMaximumSize)},
    {SIP_MLNAME_CAST(sipName_totalMinimumSize), meth_QLayout_totalMinimumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_totalMinimumSize)},
    {SIP_MLNAME_CAST(sipName_totalSizeHint), meth_QLayout_totalSizeHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_totalSizeHint)},
    {SIP_MLNAME_CAST(sipName_update), meth_QLayout_update, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_update)},
    {SIP_MLNAME_CAST(sipName_widgetEvent), meth_QLayout_widgetEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QLayout_widgetEvent)}
};

static sipEnumMemberDef enummembers_QLayout[] = {
    {sipName_SetDefaultConstraint, static_cast<int>( ::QLayout::SetDefaultConstraint), 192},
    {sipName_SetFixedSize, static_cast<int>( ::QLayout::SetFixedSize), 192},
    {sipName_SetMaximumSize, static_cast<int>( ::QLayout::SetMaximumSize), 192},
    {sipName_SetMinAndMaxSize, static_cast<int>( ::QLayout::SetMinAndMaxSize), 192},
    {sipName_SetMinimumSize, static_cast<int>( ::QLayout::SetMinimumSize), 192},
    {sipName_SetNoConstraint, static_cast<int>( ::QLayout::SetNoConstraint), 192},
};

PyDoc_STRVAR(doc_QLayout, "\1QLayout(QWidget)\n"
"QLayout()");


static pyqt5ClassPluginDef plugin_QLayout = {
    & ::QLayout::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QLayout = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLayout,
        {SIP_NULLPTR},
        &plugin_QLayout
    },
    {
        sipNameNr_QLayout,
        {0, 0, 1},
        44, methods_QLayout,
        6, enummembers_QLayout,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLayout,
    -1,
    -1,
    supers_QLayout,
    slots_QLayout,
    init_type_QLayout,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QLayout,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QLayout,
    cast_QLayout,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
