/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQmlAPI_H
#define _QtQmlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QQmlAbstractUrlInterceptor__DataType 0
#define sipName_QQmlAbstractUrlInterceptor__DataType &sipStrings_QtQml[0]
#define sipNameNr_37 37
#define sipName_37 &sipStrings_QtQml[37]
#define sipNameNr_QQmlProperty__PropertyTypeCategory 72
#define sipName_QQmlProperty__PropertyTypeCategory &sipStrings_QtQml[72]
#define sipNameNr_setOutputWarningsToStandardError 107
#define sipName_setOutputWarningsToStandardError &sipStrings_QtQml[107]
#define sipNameNr_QQmlImageProviderBase__ImageType 140
#define sipName_QQmlImageProviderBase__ImageType &sipStrings_QtQml[140]
#define sipNameNr_QQmlNetworkAccessManagerFactory 173
#define sipName_QQmlNetworkAccessManagerFactory &sipStrings_QtQml[173]
#define sipNameNr_offlineStorageDatabaseFilePath 205
#define sipName_offlineStorageDatabaseFilePath &sipStrings_QtQml[205]
#define sipNameNr_setNetworkAccessManagerFactory 236
#define sipName_setNetworkAccessManagerFactory &sipStrings_QtQml[236]
#define sipNameNr_QQmlComponent__CompilationMode 267
#define sipName_QQmlComponent__CompilationMode &sipStrings_QtQml[267]
#define sipNameNr_QQmlIncubator__IncubationMode 298
#define sipName_QQmlIncubator__IncubationMode &sipStrings_QtQml[298]
#define sipNameNr_outputWarningsToStandardError 328
#define sipName_outputWarningsToStandardError &sipStrings_QtQml[328]
#define sipNameNr_ForceAsynchronousImageLoading 358
#define sipName_ForceAsynchronousImageLoading &sipStrings_QtQml[358]
#define sipNameNr_incubatingObjectCountChanged 388
#define sipName_incubatingObjectCountChanged &sipStrings_QtQml[388]
#define sipNameNr_QQmlImageProviderBase__Flags 417
#define sipName_QQmlImageProviderBase__Flags &sipStrings_QtQml[417]
#define sipNameNr_qmlAttachedPropertiesObject 446
#define sipName_qmlAttachedPropertiesObject &sipStrings_QtQml[446]
#define sipNameNr_QQmlEngine__ObjectOwnership 474
#define sipName_QQmlEngine__ObjectOwnership &sipStrings_QtQml[474]
#define sipNameNr_networkAccessManagerFactory 502
#define sipName_networkAccessManagerFactory &sipStrings_QtQml[502]
#define sipNameNr_QQmlImageProviderBase__Flag 530
#define sipName_QQmlImageProviderBase__Flag &sipStrings_QtQml[530]
#define sipNameNr_createWithInitialProperties 558
#define sipName_createWithInitialProperties &sipStrings_QtQml[558]
#define sipNameNr_qmlRegisterUncreatableType 586
#define sipName_qmlRegisterUncreatableType &sipStrings_QtQml[586]
#define sipNameNr_QQmlAbstractUrlInterceptor 613
#define sipName_QQmlAbstractUrlInterceptor &sipStrings_QtQml[613]
#define sipNameNr_GarbageCollectionExtension 640
#define sipName_GarbageCollectionExtension &sipStrings_QtQml[640]
#define sipNameNr_installTranslatorFunctions 667
#define sipName_installTranslatorFunctions &sipStrings_QtQml[667]
#define sipNameNr_694 694
#define sipName_694 &sipStrings_QtQml[694]
#define sipNameNr_QQmlEngineExtensionPlugin 720
#define sipName_QQmlEngineExtensionPlugin &sipStrings_QtQml[720]
#define sipNameNr_QQmlContext__PropertyPair 746
#define sipName_QQmlContext__PropertyPair &sipStrings_QtQml[746]
#define sipNameNr_qmlClearTypeRegistrations 772
#define sipName_qmlClearTypeRegistrations &sipStrings_QtQml[772]
#define sipNameNr_qmlRegisterSingletonType 798
#define sipName_qmlRegisterSingletonType &sipStrings_QtQml[798]
#define sipNameNr_QQmlIncubationController 823
#define sipName_QQmlIncubationController &sipStrings_QtQml[823]
#define sipNameNr_QQmlPropertyValueSource 848
#define sipName_QQmlPropertyValueSource &sipStrings_QtQml[848]
#define sipNameNr_setNotifyOnValueChanged 872
#define sipName_setNotifyOnValueChanged &sipStrings_QtQml[872]
#define sipNameNr_setIncubationController 896
#define sipName_setIncubationController &sipStrings_QtQml[896]
#define sipNameNr_QJSValue__SpecialValue 920
#define sipName_QJSValue__SpecialValue &sipStrings_QtQml[920]
#define sipNameNr_incubatingObjectCount 943
#define sipName_incubatingObjectCount &sipStrings_QtQml[943]
#define sipNameNr_QQmlIncubator__Status 965
#define sipName_QQmlIncubator__Status &sipStrings_QtQml[965]
#define sipNameNr_setOfflineStoragePath 987
#define sipName_setOfflineStoragePath &sipStrings_QtQml[987]
#define sipNameNr_QQmlImageProviderBase 1009
#define sipName_QQmlImageProviderBase &sipStrings_QtQml[1009]
#define sipNameNr_QQmlComponent__Status 1031
#define sipName_QQmlComponent__Status &sipStrings_QtQml[1031]
#define sipNameNr_QQmlApplicationEngine 1053
#define sipName_QQmlApplicationEngine &sipStrings_QtQml[1053]
#define sipNameNr_QJSEngine__Extensions 1075
#define sipName_QJSEngine__Extensions &sipStrings_QtQml[1075]
#define sipNameNr_propertyTypeCategory 1097
#define sipName_propertyTypeCategory &sipStrings_QtQml[1097]
#define sipNameNr_PropertyTypeCategory 86
#define sipName_PropertyTypeCategory &sipStrings_QtQml[86]
#define sipNameNr_AsynchronousIfNested 1118
#define sipName_AsynchronousIfNested &sipStrings_QtQml[1118]
#define sipNameNr_notifyOnValueChanged 1139
#define sipName_notifyOnValueChanged &sipStrings_QtQml[1139]
#define sipNameNr_incubationController 1160
#define sipName_incubationController &sipStrings_QtQml[1160]
#define sipNameNr_networkAccessManager 1181
#define sipName_networkAccessManager &sipStrings_QtQml[1181]
#define sipNameNr_setContextProperties 1202
#define sipName_setContextProperties &sipStrings_QtQml[1202]
#define sipNameNr_setInitialProperties 1223
#define sipName_setInitialProperties &sipStrings_QtQml[1223]
#define sipNameNr_TranslationExtension 1244
#define sipName_TranslationExtension &sipStrings_QtQml[1244]
#define sipNameNr_QJSEngine__Extension 1265
#define sipName_QJSEngine__Extension &sipStrings_QtQml[1265]
#define sipNameNr_1286 1286
#define sipName_1286 &sipStrings_QtQml[1286]
#define sipNameNr_qmlRegisterRevision 1306
#define sipName_qmlRegisterRevision &sipStrings_QtQml[1306]
#define sipNameNr_connectNotifySignal 1326
#define sipName_connectNotifySignal &sipStrings_QtQml[1326]
#define sipNameNr_QQmlExtensionPlugin 1346
#define sipName_QQmlExtensionPlugin &sipStrings_QtQml[1346]
#define sipNameNr_JavaScriptOwnership 1366
#define sipName_JavaScriptOwnership &sipStrings_QtQml[1366]
#define sipNameNr_setContextForObject 1386
#define sipName_setContextForObject &sipStrings_QtQml[1386]
#define sipNameNr_removeImageProvider 1406
#define sipName_removeImageProvider &sipStrings_QtQml[1406]
#define sipNameNr_clearComponentCache 1426
#define sipName_clearComponentCache &sipStrings_QtQml[1426]
#define sipNameNr_QJSValue__ErrorType 1446
#define sipName_QJSValue__ErrorType &sipStrings_QtQml[1446]
#define sipNameNr_attachedProperties 1466
#define sipName_attachedProperties &sipStrings_QtQml[1466]
#define sipNameNr_isUndefinedLiteral 1485
#define sipName_isUndefinedLiteral &sipStrings_QtQml[1485]
#define sipNameNr_QQmlProperty__Type 1504
#define sipName_QQmlProperty__Type &sipStrings_QtQml[1504]
#define sipNameNr_setObjectOwnership 1523
#define sipName_setObjectOwnership &sipStrings_QtQml[1523]
#define sipNameNr_offlineStoragePath 1542
#define sipName_offlineStoragePath &sipStrings_QtQml[1542]
#define sipNameNr_trimComponentCache 1561
#define sipName_trimComponentCache &sipStrings_QtQml[1561]
#define sipNameNr_setContextProperty 1580
#define sipName_setContextProperty &sipStrings_QtQml[1580]
#define sipNameNr_needsNotifySignal 1599
#define sipName_needsNotifySignal &sipStrings_QtQml[1599]
#define sipNameNr_componentComplete 1617
#define sipName_componentComplete &sipStrings_QtQml[1617]
#define sipNameNr_QQmlListReference 1635
#define sipName_QQmlListReference &sipStrings_QtQml[1635]
#define sipNameNr_setSourceLocation 1653
#define sipName_setSourceLocation &sipStrings_QtQml[1653]
#define sipNameNr_singletonInstance 1671
#define sipName_singletonInstance &sipStrings_QtQml[1671]
#define sipNameNr_setPluginPathList 1689
#define sipName_setPluginPathList &sipStrings_QtQml[1689]
#define sipNameNr_setImportPathList 1707
#define sipName_setImportPathList &sipStrings_QtQml[1707]
#define sipNameNr_PreferSynchronous 1725
#define sipName_PreferSynchronous &sipStrings_QtQml[1725]
#define sipNameNr_callAsConstructor 1743
#define sipName_callAsConstructor &sipStrings_QtQml[1743]
#define sipNameNr_uiLanguageChanged 1761
#define sipName_uiLanguageChanged &sipStrings_QtQml[1761]
#define sipNameNr_installExtensions 1779
#define sipName_installExtensions &sipStrings_QtQml[1779]
#define sipNameNr_setExtraSelectors 1797
#define sipName_setExtraSelectors &sipStrings_QtQml[1797]
#define sipNameNr_sip_simplewrapper 1815
#define sipName_sip_simplewrapper &sipStrings_QtQml[1815]
#define sipNameNr_1833 1833
#define sipName_1833 &sipStrings_QtQml[1833]
#define sipNameNr_QQmlScriptString 1850
#define sipName_QQmlScriptString &sipStrings_QtQml[1850]
#define sipNameNr_propertyTypeName 1867
#define sipName_propertyTypeName &sipStrings_QtQml[1867]
#define sipNameNr_isSignalProperty 1884
#define sipName_isSignalProperty &sipStrings_QtQml[1884]
#define sipNameNr_QQmlParserStatus 1901
#define sipName_QQmlParserStatus &sipStrings_QtQml[1901]
#define sipNameNr_QQmlFileSelector 1918
#define sipName_QQmlFileSelector &sipStrings_QtQml[1918]
#define sipNameNr_initializeEngine 1935
#define sipName_initializeEngine &sipStrings_QtQml[1935]
#define sipNameNr_valueIsUndefined 1952
#define sipName_valueIsUndefined &sipStrings_QtQml[1952]
#define sipNameNr_contextForObject 1969
#define sipName_contextForObject &sipStrings_QtQml[1969]
#define sipNameNr_addImageProvider 1986
#define sipName_addImageProvider &sipStrings_QtQml[1986]
#define sipNameNr_setContextObject 2003
#define sipName_setContextObject &sipStrings_QtQml[2003]
#define sipNameNr_QJSValueIterator 2020
#define sipName_QJSValueIterator &sipStrings_QtQml[2020]
#define sipNameNr_callWithInstance 2037
#define sipName_callWithInstance &sipStrings_QtQml[2037]
#define sipNameNr_ConsoleExtension 2054
#define sipName_ConsoleExtension &sipStrings_QtQml[2054]
#define sipNameNr_disconnectNotify 2071
#define sipName_disconnectNotify &sipStrings_QtQml[2071]
#define sipNameNr_2088 2088
#define sipName_2088 &sipStrings_QtQml[2088]
#define sipNameNr_qmlRegisterType 2104
#define sipName_qmlRegisterType &sipStrings_QtQml[2104]
#define sipNameNr_QQmlPropertyMap 2120
#define sipName_QQmlPropertyMap &sipStrings_QtQml[2120]
#define sipNameNr_InvalidCategory 2136
#define sipName_InvalidCategory &sipStrings_QtQml[2136]
#define sipNameNr_listElementType 2152
#define sipName_listElementType &sipStrings_QtQml[2152]
#define sipNameNr_forceCompletion 2168
#define sipName_forceCompletion &sipStrings_QtQml[2168]
#define sipNameNr_objectOwnership 2184
#define sipName_objectOwnership &sipStrings_QtQml[2184]
#define sipNameNr_ObjectOwnership 486
#define sipName_ObjectOwnership &sipStrings_QtQml[486]
#define sipNameNr_contextProperty 2200
#define sipName_contextProperty &sipStrings_QtQml[2200]
#define sipNameNr_progressChanged 2216
#define sipName_progressChanged &sipStrings_QtQml[2216]
#define sipNameNr_creationContext 2232
#define sipName_creationContext &sipStrings_QtQml[2232]
#define sipNameNr_CompilationMode 282
#define sipName_CompilationMode &sipStrings_QtQml[282]
#define sipNameNr_setInitialState 2248
#define sipName_setInitialState &sipStrings_QtQml[2248]
#define sipNameNr_hasNotifySignal 2264
#define sipName_hasNotifySignal &sipStrings_QtQml[2264]
#define sipNameNr_booleanLiteral 2280
#define sipName_booleanLiteral &sipStrings_QtQml[2280]
#define sipNameNr_SignalProperty 1886
#define sipName_SignalProperty &sipStrings_QtQml[1886]
#define sipNameNr_incubationMode 2295
#define sipName_incubationMode &sipStrings_QtQml[2295]
#define sipNameNr_IncubationMode 313
#define sipName_IncubationMode &sipStrings_QtQml[313]
#define sipNameNr_QQmlExpression 2310
#define sipName_QQmlExpression &sipStrings_QtQml[2310]
#define sipNameNr_setMessageType 2325
#define sipName_setMessageType &sipStrings_QtQml[2325]
#define sipNameNr_addNamedBundle 2340
#define sipName_addNamedBundle &sipStrings_QtQml[2340]
#define sipNameNr_pluginPathList 2355
#define sipName_pluginPathList &sipStrings_QtQml[2355]
#define sipNameNr_importPathList 2370
#define sipName_importPathList &sipStrings_QtQml[2370]
#define sipNameNr_completeCreate 2385
#define sipName_completeCreate &sipStrings_QtQml[2385]
#define sipNameNr_JavaScriptFile 2400
#define sipName_JavaScriptFile &sipStrings_QtQml[2400]
#define sipNameNr_ReferenceError 2415
#define sipName_ReferenceError &sipStrings_QtQml[2415]
#define sipNameNr_deleteProperty 2430
#define sipName_deleteProperty &sipStrings_QtQml[2430]
#define sipNameNr_hasOwnProperty 2445
#define sipName_hasOwnProperty &sipStrings_QtQml[2445]
#define sipNameNr_strictlyEquals 2460
#define sipName_strictlyEquals &sipStrings_QtQml[2460]
#define sipNameNr_UndefinedValue 2475
#define sipName_UndefinedValue &sipStrings_QtQml[2475]
#define sipNameNr_setInterrupted 2490
#define sipName_setInterrupted &sipStrings_QtQml[2490]
#define sipNameNr_newErrorObject 2505
#define sipName_newErrorObject &sipStrings_QtQml[2505]
#define sipNameNr_newQMetaObject 2520
#define sipName_newQMetaObject &sipStrings_QtQml[2520]
#define sipNameNr_collectGarbage 2535
#define sipName_collectGarbage &sipStrings_QtQml[2535]
#define sipNameNr_setDescription 2550
#define sipName_setDescription &sipStrings_QtQml[2550]
#define sipNameNr_numberLiteral 2565
#define sipName_numberLiteral &sipStrings_QtQml[2565]
#define sipNameNr_stringLiteral 2579
#define sipName_stringLiteral &sipStrings_QtQml[2579]
#define sipNameNr_isNullLiteral 2593
#define sipName_isNullLiteral &sipStrings_QtQml[2593]
#define sipNameNr_canRemoveLast 2607
#define sipName_canRemoveLast &sipStrings_QtQml[2607]
#define sipNameNr_isManipulable 2621
#define sipName_isManipulable &sipStrings_QtQml[2621]
#define sipNameNr_QQmlIncubator 2635
#define sipName_QQmlIncubator &sipStrings_QtQml[2635]
#define sipNameNr_registerTypes 2649
#define sipName_registerTypes &sipStrings_QtQml[2649]
#define sipNameNr_setExpression 2663
#define sipName_setExpression &sipStrings_QtQml[2663]
#define sipNameNr_imageProvider 2677
#define sipName_imageProvider &sipStrings_QtQml[2677]
#define sipNameNr_addPluginPath 2691
#define sipName_addPluginPath &sipStrings_QtQml[2691]
#define sipNameNr_addImportPath 2705
#define sipName_addImportPath &sipStrings_QtQml[2705]
#define sipNameNr_ImageResponse 2719
#define sipName_ImageResponse &sipStrings_QtQml[2719]
#define sipNameNr_nameForObject 2733
#define sipName_nameForObject &sipStrings_QtQml[2733]
#define sipNameNr_contextObject 2747
#define sipName_contextObject &sipStrings_QtQml[2747]
#define sipNameNr_parentContext 2761
#define sipName_parentContext &sipStrings_QtQml[2761]
#define sipNameNr_statusChanged 2775
#define sipName_statusChanged &sipStrings_QtQml[2775]
#define sipNameNr_QQmlComponent 2789
#define sipName_QQmlComponent &sipStrings_QtQml[2789]
#define sipNameNr_objectCreated 2803
#define sipName_objectCreated &sipStrings_QtQml[2803]
#define sipNameNr_setUiLanguage 2817
#define sipName_setUiLanguage &sipStrings_QtQml[2817]
#define sipNameNr_isInterrupted 2831
#define sipName_isInterrupted &sipStrings_QtQml[2831]
#define sipNameNr_AllExtensions 2845
#define sipName_AllExtensions &sipStrings_QtQml[2845]
#define sipNameNr_connectNotify 2074
#define sipName_connectNotify &sipStrings_QtQml[2074]
#define sipNameNr_propertyType 2859
#define sipName_propertyType &sipStrings_QtQml[2859]
#define sipNameNr_QQmlProperty 2872
#define sipName_QQmlProperty &sipStrings_QtQml[2872]
#define sipNameNr_CppOwnership 2885
#define sipName_CppOwnership &sipStrings_QtQml[2885]
#define sipNameNr_importPlugin 2898
#define sipName_importPlugin &sipStrings_QtQml[2898]
#define sipNameNr_PropertyPair 759
#define sipName_PropertyPair &sipStrings_QtQml[759]
#define sipNameNr_Asynchronous 2911
#define sipName_Asynchronous &sipStrings_QtQml[2911]
#define sipNameNr_GenericError 2924
#define sipName_GenericError &sipStrings_QtQml[2924]
#define sipNameNr_setPrototype 2937
#define sipName_setPrototype &sipStrings_QtQml[2937]
#define sipNameNr_SpecialValue 930
#define sipName_SpecialValue &sipStrings_QtQml[930]
#define sipNameNr_importModule 2950
#define sipName_importModule &sipStrings_QtQml[2950]
#define sipNameNr_globalObject 2963
#define sipName_globalObject &sipStrings_QtQml[2963]
#define sipNameNr_columnNumber 2976
#define sipName_columnNumber &sipStrings_QtQml[2976]
#define sipNameNr_valueChanged 2989
#define sipName_valueChanged &sipStrings_QtQml[2989]
#define sipNameNr_isResettable 3002
#define sipName_isResettable &sipStrings_QtQml[3002]
#define sipNameNr_isDesignable 3015
#define sipName_isDesignable &sipStrings_QtQml[3015]
#define sipNameNr_updateValue 3028
#define sipName_updateValue &sipStrings_QtQml[3028]
#define sipNameNr_incubateFor 3040
#define sipName_incubateFor &sipStrings_QtQml[3040]
#define sipNameNr_Synchronous 1731
#define sipName_Synchronous &sipStrings_QtQml[1731]
#define sipNameNr_setSelector 3052
#define sipName_setSelector &sipStrings_QtQml[3052]
#define sipNameNr_scopeObject 3064
#define sipName_scopeObject &sipStrings_QtQml[3064]
#define sipNameNr_messageType 3076
#define sipName_messageType &sipStrings_QtQml[3076]
#define sipNameNr_retranslate 3088
#define sipName_retranslate &sipStrings_QtQml[3088]
#define sipNameNr_rootContext 3100
#define sipName_rootContext &sipStrings_QtQml[3100]
#define sipNameNr_resolvedUrl 3112
#define sipName_resolvedUrl &sipStrings_QtQml[3112]
#define sipNameNr_QQmlContext 3124
#define sipName_QQmlContext &sipStrings_QtQml[3124]
#define sipNameNr_beginCreate 3136
#define sipName_beginCreate &sipStrings_QtQml[3136]
#define sipNameNr_rootObjects 3148
#define sipName_rootObjects &sipStrings_QtQml[3148]
#define sipNameNr_SyntaxError 3160
#define sipName_SyntaxError &sipStrings_QtQml[3160]
#define sipNameNr_hasProperty 3172
#define sipName_hasProperty &sipStrings_QtQml[3172]
#define sipNameNr_customEvent 3184
#define sipName_customEvent &sipStrings_QtQml[3184]
#define sipNameNr_setProperty 3196
#define sipName_setProperty &sipStrings_QtQml[3196]
#define sipNameNr_eventFilter 3208
#define sipName_eventFilter &sipStrings_QtQml[3208]
#define sipNameNr_description 3220
#define sipName_description &sipStrings_QtQml[3220]
#define sipNameNr_isUndefined 3232
#define sipName_isUndefined &sipStrings_QtQml[3232]
#define sipNameNr___getitem__ 3244
#define sipName___getitem__ &sipStrings_QtQml[3244]
#define sipNameNr_PyQt5_QtQml 3256
#define sipName_PyQt5_QtQml &sipStrings_QtQml[3256]
#define sipNameNr_isProperty 3268
#define sipName_isProperty &sipStrings_QtQml[3268]
#define sipNameNr_classBegin 3279
#define sipName_classBegin &sipStrings_QtQml[3279]
#define sipNameNr_removeLast 3290
#define sipName_removeLast &sipStrings_QtQml[3290]
#define sipNameNr_canReplace 3301
#define sipName_canReplace &sipStrings_QtQml[3301]
#define sipNameNr_sourceFile 3312
#define sipName_sourceFile &sipStrings_QtQml[3312]
#define sipNameNr_setBaseUrl 3323
#define sipName_setBaseUrl &sipStrings_QtQml[3323]
#define sipNameNr_forContext 3334
#define sipName_forContext &sipStrings_QtQml[3334]
#define sipNameNr_QQmlEngine 3345
#define sipName_QQmlEngine &sipStrings_QtQml[3345]
#define sipNameNr_QmldirFile 3356
#define sipName_QmldirFile &sipStrings_QtQml[3356]
#define sipNameNr_RangeError 3367
#define sipName_RangeError &sipStrings_QtQml[3367]
#define sipNameNr_isCallable 3378
#define sipName_isCallable &sipStrings_QtQml[3378]
#define sipNameNr_uiLanguage 3389
#define sipName_uiLanguage &sipStrings_QtQml[3389]
#define sipNameNr_throwError 3400
#define sipName_throwError &sipStrings_QtQml[3400]
#define sipNameNr_Extensions 1086
#define sipName_Extensions &sipStrings_QtQml[1086]
#define sipNameNr_newQObject 3411
#define sipName_newQObject &sipStrings_QtQml[3411]
#define sipNameNr_lineNumber 3422
#define sipName_lineNumber &sipStrings_QtQml[3422]
#define sipNameNr_clearError 3433
#define sipName_clearError &sipStrings_QtQml[3433]
#define sipNameNr_expression 3444
#define sipName_expression &sipStrings_QtQml[3444]
#define sipNameNr_childEvent 3455
#define sipName_childEvent &sipStrings_QtQml[3455]
#define sipNameNr_timerEvent 3466
#define sipName_timerEvent &sipStrings_QtQml[3466]
#define sipNameNr_toDateTime 3477
#define sipName_toDateTime &sipStrings_QtQml[3477]
#define sipNameNr_isWritable 3488
#define sipName_isWritable &sipStrings_QtQml[3488]
#define sipNameNr_isReadable 3499
#define sipName_isReadable &sipStrings_QtQml[3499]
#define sipNameNr___invert__ 3510
#define sipName___invert__ &sipStrings_QtQml[3510]
#define sipNameNr_setTarget 3521
#define sipName_setTarget &sipStrings_QtQml[3521]
#define sipNameNr_canAppend 3531
#define sipName_canAppend &sipStrings_QtQml[3531]
#define sipNameNr_setColumn 3541
#define sipName_setColumn &sipStrings_QtQml[3541]
#define sipNameNr_QQmlError 3551
#define sipName_QQmlError &sipStrings_QtQml[3551]
#define sipNameNr_imageType 3561
#define sipName_imageType &sipStrings_QtQml[3561]
#define sipNameNr_ImageType 163
#define sipName_ImageType &sipStrings_QtQml[163]
#define sipNameNr_isLoading 3571
#define sipName_isLoading &sipStrings_QtQml[3571]
#define sipNameNr_intercept 3581
#define sipName_intercept &sipStrings_QtQml[3581]
#define sipNameNr_UrlString 3591
#define sipName_UrlString &sipStrings_QtQml[3591]
#define sipNameNr_TypeError 3601
#define sipName_TypeError &sipStrings_QtQml[3601]
#define sipNameNr_EvalError 3611
#define sipName_EvalError &sipStrings_QtQml[3611]
#define sipNameNr_ErrorType 1456
#define sipName_ErrorType &sipStrings_QtQml[1456]
#define sipNameNr_prototype 3621
#define sipName_prototype &sipStrings_QtQml[3621]
#define sipNameNr_toQObject 3631
#define sipName_toQObject &sipStrings_QtQml[3631]
#define sipNameNr_isQObject 3641
#define sipName_isQObject &sipStrings_QtQml[3641]
#define sipNameNr_isVariant 3651
#define sipName_isVariant &sipStrings_QtQml[3651]
#define sipNameNr_NullValue 3661
#define sipName_NullValue &sipStrings_QtQml[3661]
#define sipNameNr_qjsEngine 3671
#define sipName_qjsEngine &sipStrings_QtQml[3671]
#define sipNameNr_errorType 3681
#define sipName_errorType &sipStrings_QtQml[3681]
#define sipNameNr_Extension 657
#define sipName_Extension &sipStrings_QtQml[657]
#define sipNameNr_newObject 3691
#define sipName_newObject &sipStrings_QtQml[3691]
#define sipNameNr_QJSEngine 3701
#define sipName_QJSEngine &sipStrings_QtQml[3701]
#define sipNameNr_qmlTypeId 3711
#define sipName_qmlTypeId &sipStrings_QtQml[3711]
#define sipNameNr_setObject 3721
#define sipName_setObject &sipStrings_QtQml[3721]
#define sipNameNr_toVariant 3731
#define sipName_toVariant &sipStrings_QtQml[3731]
#define sipNameNr___index__ 3741
#define sipName___index__ &sipStrings_QtQml[3741]
#define sipNameNr_Property 1590
#define sipName_Property &sipStrings_QtQml[1590]
#define sipNameNr_canCount 3751
#define sipName_canCount &sipStrings_QtQml[3751]
#define sipNameNr_canClear 3760
#define sipName_canClear &sipStrings_QtQml[3760]
#define sipNameNr_selector 3769
#define sipName_selector &sipStrings_QtQml[3769]
#define sipNameNr_warnings 3778
#define sipName_warnings &sipStrings_QtQml[3778]
#define sipNameNr_loadData 3787
#define sipName_loadData &sipStrings_QtQml[3787]
#define sipNameNr_DataType 28
#define sipName_DataType &sipStrings_QtQml[28]
#define sipNameNr_URIError 3796
#define sipName_URIError &sipStrings_QtQml[3796]
#define sipNameNr_toNumber 3805
#define sipName_toNumber &sipStrings_QtQml[3805]
#define sipNameNr_isRegExp 3814
#define sipName_isRegExp &sipStrings_QtQml[3814]
#define sipNameNr_isNumber 3823
#define sipName_isNumber &sipStrings_QtQml[3823]
#define sipNameNr_QJSValue 3832
#define sipName_QJSValue &sipStrings_QtQml[3832]
#define sipNameNr_newArray 3841
#define sipName_newArray &sipStrings_QtQml[3841]
#define sipNameNr_evaluate 3850
#define sipName_evaluate &sipStrings_QtQml[3850]
#define sipNameNr_hasError 3859
#define sipName_hasError &sipStrings_QtQml[3859]
#define sipNameNr_property 3868
#define sipName_property &sipStrings_QtQml[3868]
#define sipNameNr_isObject 3877
#define sipName_isObject &sipStrings_QtQml[3877]
#define sipNameNr_progress 3886
#define sipName_progress &sipStrings_QtQml[3886]
#define sipNameNr_fileName 3895
#define sipName_fileName &sipStrings_QtQml[3895]
#define sipNameNr_isString 3904
#define sipName_isString &sipStrings_QtQml[3904]
#define sipNameNr_toString 3913
#define sipName_toString &sipStrings_QtQml[3913]
#define sipNameNr_contains 3922
#define sipName_contains &sipStrings_QtQml[3922]
#define sipNameNr___hash__ 3931
#define sipName___hash__ &sipStrings_QtQml[3931]
#define sipNameNr___bool__ 3940
#define sipName___bool__ &sipStrings_QtQml[3940]
#define sipNameNr___ixor__ 3949
#define sipName___ixor__ &sipStrings_QtQml[3949]
#define sipNameNr___iand__ 3958
#define sipName___iand__ &sipStrings_QtQml[3958]
#define sipNameNr_Texture 3967
#define sipName_Texture &sipStrings_QtQml[3967]
#define sipNameNr_baseUrl 3975
#define sipName_baseUrl &sipStrings_QtQml[3975]
#define sipNameNr_loadUrl 3983
#define sipName_loadUrl &sipStrings_QtQml[3983]
#define sipNameNr_Loading 380
#define sipName_Loading &sipStrings_QtQml[380]
#define sipNameNr_QmlFile 3991
#define sipName_QmlFile &sipStrings_QtQml[3991]
#define sipNameNr_isError 3999
#define sipName_isError &sipStrings_QtQml[3999]
#define sipNameNr_isReady 4007
#define sipName_isReady &sipStrings_QtQml[4007]
#define sipNameNr_setLine 4015
#define sipName_setLine &sipStrings_QtQml[4015]
#define sipNameNr_context 4023
#define sipName_context &sipStrings_QtQml[4023]
#define sipNameNr_isArray 4031
#define sipName_isArray &sipStrings_QtQml[4031]
#define sipNameNr_hasNext 4039
#define sipName_hasNext &sipStrings_QtQml[4039]
#define sipNameNr_Invalid 4047
#define sipName_Invalid &sipStrings_QtQml[4047]
#define sipNameNr_replace 4055
#define sipName_replace &sipStrings_QtQml[4055]
#define sipNameNr_isEmpty 4063
#define sipName_isEmpty &sipStrings_QtQml[4063]
#define sipNameNr___len__ 4071
#define sipName___len__ &sipStrings_QtQml[4071]
#define sipNameNr_setData 4079
#define sipName_setData &sipStrings_QtQml[4079]
#define sipNameNr_isValid 4087
#define sipName_isValid &sipStrings_QtQml[4087]
#define sipNameNr_message 4095
#define sipName_message &sipStrings_QtQml[4095]
#define sipNameNr___xor__ 4103
#define sipName___xor__ &sipStrings_QtQml[4103]
#define sipNameNr___ior__ 4111
#define sipName___ior__ &sipStrings_QtQml[4111]
#define sipNameNr___and__ 4119
#define sipName___and__ &sipStrings_QtQml[4119]
#define sipNameNr___int__ 4127
#define sipName___int__ &sipStrings_QtQml[4127]
#define sipNameNr_Normal 4135
#define sipName_Normal &sipStrings_QtQml[4135]
#define sipNameNr_engine 4142
#define sipName_engine &sipStrings_QtQml[4142]
#define sipNameNr_equals 4149
#define sipName_equals &sipStrings_QtQml[4149]
#define sipNameNr_isDate 4156
#define sipName_isDate &sipStrings_QtQml[4156]
#define sipNameNr_errors 4163
#define sipName_errors &sipStrings_QtQml[4163]
#define sipNameNr_Pixmap 4170
#define sipName_Pixmap &sipStrings_QtQml[4170]
#define sipNameNr_setUrl 4177
#define sipName_setUrl &sipStrings_QtQml[4177]
#define sipNameNr_create 4184
#define sipName_create &sipStrings_QtQml[4184]
#define sipNameNr_Object 467
#define sipName_Object &sipStrings_QtQml[467]
#define sipNameNr_status 4191
#define sipName_status &sipStrings_QtQml[4191]
#define sipNameNr_Status 980
#define sipName_Status &sipStrings_QtQml[980]
#define sipNameNr_method 4198
#define sipName_method &sipStrings_QtQml[4198]
#define sipNameNr_toBool 4205
#define sipName_toBool &sipStrings_QtQml[4205]
#define sipNameNr_isBool 4212
#define sipName_isBool &sipStrings_QtQml[4212]
#define sipNameNr_toUInt 4219
#define sipName_toUInt &sipStrings_QtQml[4219]
#define sipNameNr_insert 4226
#define sipName_insert &sipStrings_QtQml[4226]
#define sipNameNr_append 4233
#define sipName_append &sipStrings_QtQml[4233]
#define sipNameNr_length 4240
#define sipName_length &sipStrings_QtQml[4240]
#define sipNameNr_isNull 4247
#define sipName_isNull &sipStrings_QtQml[4247]
#define sipNameNr_column 4254
#define sipName_column &sipStrings_QtQml[4254]
#define sipNameNr_object 4261
#define sipName_object &sipStrings_QtQml[4261]
#define sipNameNr_parent 4268
#define sipName_parent &sipStrings_QtQml[4268]
#define sipNameNr___ne__ 4275
#define sipName___ne__ &sipStrings_QtQml[4275]
#define sipNameNr___eq__ 4282
#define sipName___eq__ &sipStrings_QtQml[4282]
#define sipNameNr___or__ 4289
#define sipName___or__ &sipStrings_QtQml[4289]
#define sipNameNr_canAt 4296
#define sipName_canAt &sipStrings_QtQml[4296]
#define sipNameNr_Ready 4009
#define sipName_Ready &sipStrings_QtQml[4009]
#define sipNameNr_Image 4302
#define sipName_Image &sipStrings_QtQml[4302]
#define sipNameNr_scope 4308
#define sipName_scope &sipStrings_QtQml[4308]
#define sipNameNr_write 4314
#define sipName_write &sipStrings_QtQml[4314]
#define sipNameNr_error 4320
#define sipName_error &sipStrings_QtQml[4320]
#define sipNameNr_Flags 440
#define sipName_Flags &sipStrings_QtQml[440]
#define sipNameNr_reset 4326
#define sipName_reset &sipStrings_QtQml[4326]
#define sipNameNr_Error 134
#define sipName_Error &sipStrings_QtQml[134]
#define sipNameNr_toInt 4332
#define sipName_toInt &sipStrings_QtQml[4332]
#define sipNameNr_clear 4338
#define sipName_clear &sipStrings_QtQml[4338]
#define sipNameNr_count 4344
#define sipName_count &sipStrings_QtQml[4344]
#define sipNameNr_value 4350
#define sipName_value &sipStrings_QtQml[4350]
#define sipNameNr_index 4356
#define sipName_index &sipStrings_QtQml[4356]
#define sipNameNr_flags 4362
#define sipName_flags &sipStrings_QtQml[4362]
#define sipNameNr_event 4368
#define sipName_event &sipStrings_QtQml[4368]
#define sipNameNr_call 4374
#define sipName_call &sipStrings_QtQml[4374]
#define sipNameNr_args 4379
#define sipName_args &sipStrings_QtQml[4379]
#define sipNameNr_List 1702
#define sipName_List &sipStrings_QtQml[1702]
#define sipNameNr_keys 4384
#define sipName_keys &sipStrings_QtQml[4384]
#define sipNameNr_line 4389
#define sipName_line &sipStrings_QtQml[4389]
#define sipNameNr_load 4394
#define sipName_load &sipStrings_QtQml[4394]
#define sipNameNr_read 4399
#define sipName_read &sipStrings_QtQml[4399]
#define sipNameNr_quit 4404
#define sipName_quit &sipStrings_QtQml[4404]
#define sipNameNr_exit 4409
#define sipName_exit &sipStrings_QtQml[4409]
#define sipNameNr_mode 4414
#define sipName_mode &sipStrings_QtQml[4414]
#define sipNameNr_Flag 553
#define sipName_Flag &sipStrings_QtQml[553]
#define sipNameNr_next 4419
#define sipName_next &sipStrings_QtQml[4419]
#define sipNameNr_Type 32
#define sipName_Type &sipStrings_QtQml[32]
#define sipNameNr_Null 4249
#define sipName_Null &sipStrings_QtQml[4249]
#define sipNameNr_name 4424
#define sipName_name &sipStrings_QtQml[4424]
#define sipNameNr_size 4429
#define sipName_size &sipStrings_QtQml[4429]
#define sipNameNr_type 2945
#define sipName_type &sipStrings_QtQml[2945]
#define sipNameNr_get 3527
#define sipName_get &sipStrings_QtQml[3527]
#define sipNameNr_url 4434
#define sipName_url &sipStrings_QtQml[4434]
#define sipNameNr_at 4438
#define sipName_at &sipStrings_QtQml[4438]

#define sipMalloc                   sipAPI_QtQml->api_malloc
#define sipFree                     sipAPI_QtQml->api_free
#define sipBuildResult              sipAPI_QtQml->api_build_result
#define sipCallMethod               sipAPI_QtQml->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQml->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQml->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQml->api_parse_result_ex
#define sipParseResult              sipAPI_QtQml->api_parse_result
#define sipParseArgs                sipAPI_QtQml->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQml->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQml->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQml->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQml->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQml->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQml->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQml->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQml->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQml->api_add_exception
#define sipNoFunction               sipAPI_QtQml->api_no_function
#define sipNoMethod                 sipAPI_QtQml->api_no_method
#define sipAbstractMethod           sipAPI_QtQml->api_abstract_method
#define sipBadClass                 sipAPI_QtQml->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQml->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQml->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQml->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQml->api_trace
#define sipTransferBack             sipAPI_QtQml->api_transfer_back
#define sipTransferTo               sipAPI_QtQml->api_transfer_to
#define sipTransferBreak            sipAPI_QtQml->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtQml->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQml->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQml->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQml->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQml->api_get_pyobject
#define sipGetAddress               sipAPI_QtQml->api_get_address
#define sipGetMixinAddress          sipAPI_QtQml->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQml->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQml->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtQml->api_is_py_method
#define sipCallHook                 sipAPI_QtQml->api_call_hook
#define sipEndThread                sipAPI_QtQml->api_end_thread
#define sipConnectRx                sipAPI_QtQml->api_connect_rx
#define sipDisconnectRx             sipAPI_QtQml->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtQml->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQml->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQml->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQml->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtQml->api_free_sipslot
#define sipSameSlot                 sipAPI_QtQml->api_same_slot
#define sipPySlotExtend             sipAPI_QtQml->api_pyslot_extend
#define sipConvertRx                sipAPI_QtQml->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtQml->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQml->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQml->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQml->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtQml->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtQml->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQml->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQml->api_release_type
#define sipConvertFromType          sipAPI_QtQml->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQml->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQml->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQml->api_convert_from_enum
#define sipGetState                 sipAPI_QtQml->api_get_state
#define sipExportSymbol             sipAPI_QtQml->api_export_symbol
#define sipImportSymbol             sipAPI_QtQml->api_import_symbol
#define sipFindType                 sipAPI_QtQml->api_find_type
#define sipFindNamedEnum            sipAPI_QtQml->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtQml->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQml->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQml->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQml->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQml->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQml->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQml->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQml->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQml->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQml->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQml->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQml->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQml->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtQml->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtQml->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtQml->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtQml->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtQml->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtQml->api_deprecated
#define sipGetReference             sipAPI_QtQml->api_get_reference
#define sipKeepReference            sipAPI_QtQml->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQml->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQml->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQml->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQml->api_type_scope
#define sipResolveTypedef           sipAPI_QtQml->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQml->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtQml->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtQml->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtQml->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtQml->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtQml->api_init_mixin
#define sipExportModule             sipAPI_QtQml->api_export_module
#define sipInitModule               sipAPI_QtQml->api_init_module
#define sipGetInterpreter           sipAPI_QtQml->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtQml->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtQml->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQml->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQml->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQml->api_py_type_name
#define sipGetCFunction             sipAPI_QtQml->api_get_c_function
#define sipGetMethod                sipAPI_QtQml->api_get_method
#define sipFromMethod               sipAPI_QtQml->api_from_method
#define sipGetDate                  sipAPI_QtQml->api_get_date
#define sipFromDate                 sipAPI_QtQml->api_from_date
#define sipGetDateTime              sipAPI_QtQml->api_get_datetime
#define sipFromDateTime             sipAPI_QtQml->api_from_datetime
#define sipGetTime                  sipAPI_QtQml->api_get_time
#define sipFromTime                 sipAPI_QtQml->api_from_time
#define sipIsUserType               sipAPI_QtQml->api_is_user_type
#define sipGetFrame                 sipAPI_QtQml->api_get_frame
#define sipCheckPluginForType       sipAPI_QtQml->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQml->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQml->api_unicode_write
#define sipUnicodeData              sipAPI_QtQml->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQml->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQml->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQml->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQml->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQml->api_get_user_object
#define sipSetUserObject            sipAPI_QtQml->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQml->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtQml->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQml->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQml->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQml->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQml->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQml->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQml->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQml->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQml->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQml->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQml->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQml->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQml->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQml->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtQml->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtQml->api_map_int_to_class
#define sipFindClass                sipAPI_QtQml->api_find_class
#define sipFindMappedType           sipAPI_QtQml->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtQml->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQml->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQml->api_enable_gc
#define sipPrintObject              sipAPI_QtQml->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtQml->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtQml[];

#define sipType_QJSEngine sipExportedTypes_QtQml[0]
#define sipClass_QJSEngine sipExportedTypes_QtQml[0]->u.td_wrapper_type

#define sipType_QJSEngine_Extension sipExportedTypes_QtQml[1]
#define sipEnum_QJSEngine_Extension sipExportedTypes_QtQml[1]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QJSEngine;

#define sipType_QJSEngine_Extensions sipExportedTypes_QtQml[2]
#define sipClass_QJSEngine_Extensions sipExportedTypes_QtQml[2]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QJSEngine_Extensions;

#define sipType_QJSValue sipExportedTypes_QtQml[3]
#define sipClass_QJSValue sipExportedTypes_QtQml[3]->u.td_wrapper_type

#define sipType_QJSValue_ErrorType sipExportedTypes_QtQml[4]
#define sipEnum_QJSValue_ErrorType sipExportedTypes_QtQml[4]->u.td_py_type

#define sipType_QJSValue_SpecialValue sipExportedTypes_QtQml[5]
#define sipEnum_QJSValue_SpecialValue sipExportedTypes_QtQml[5]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QJSValue;

#define sipType_QJSValueIterator sipExportedTypes_QtQml[6]
#define sipClass_QJSValueIterator sipExportedTypes_QtQml[6]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QJSValueIterator;

#define sipType_QQmlAbstractUrlInterceptor sipExportedTypes_QtQml[10]
#define sipClass_QQmlAbstractUrlInterceptor sipExportedTypes_QtQml[10]->u.td_wrapper_type

#define sipType_QQmlAbstractUrlInterceptor_DataType sipExportedTypes_QtQml[11]
#define sipEnum_QQmlAbstractUrlInterceptor_DataType sipExportedTypes_QtQml[11]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlAbstractUrlInterceptor;

#define sipType_QQmlEngine sipExportedTypes_QtQml[18]
#define sipClass_QQmlEngine sipExportedTypes_QtQml[18]->u.td_wrapper_type

#define sipType_QQmlEngine_ObjectOwnership sipExportedTypes_QtQml[19]
#define sipEnum_QQmlEngine_ObjectOwnership sipExportedTypes_QtQml[19]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlEngine;

#define sipType_QQmlApplicationEngine sipExportedTypes_QtQml[12]
#define sipClass_QQmlApplicationEngine sipExportedTypes_QtQml[12]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlApplicationEngine;

#define sipType_QQmlComponent sipExportedTypes_QtQml[13]
#define sipClass_QQmlComponent sipExportedTypes_QtQml[13]->u.td_wrapper_type

#define sipType_QQmlComponent_Status sipExportedTypes_QtQml[15]
#define sipEnum_QQmlComponent_Status sipExportedTypes_QtQml[15]->u.td_py_type

#define sipType_QQmlComponent_CompilationMode sipExportedTypes_QtQml[14]
#define sipEnum_QQmlComponent_CompilationMode sipExportedTypes_QtQml[14]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlComponent;

#define sipType_QQmlContext sipExportedTypes_QtQml[16]
#define sipClass_QQmlContext sipExportedTypes_QtQml[16]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlContext;

#define sipType_QQmlContext_PropertyPair sipExportedTypes_QtQml[17]
#define sipClass_QQmlContext_PropertyPair sipExportedTypes_QtQml[17]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlContext_PropertyPair;

#define sipType_QQmlImageProviderBase sipExportedTypes_QtQml[25]
#define sipClass_QQmlImageProviderBase sipExportedTypes_QtQml[25]->u.td_wrapper_type

#define sipType_QQmlImageProviderBase_Flag sipExportedTypes_QtQml[26]
#define sipEnum_QQmlImageProviderBase_Flag sipExportedTypes_QtQml[26]->u.td_py_type

#define sipType_QQmlImageProviderBase_ImageType sipExportedTypes_QtQml[28]
#define sipEnum_QQmlImageProviderBase_ImageType sipExportedTypes_QtQml[28]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlImageProviderBase;

#define sipType_QQmlImageProviderBase_Flags sipExportedTypes_QtQml[27]
#define sipClass_QQmlImageProviderBase_Flags sipExportedTypes_QtQml[27]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlImageProviderBase_Flags;

#define sipType_QQmlError sipExportedTypes_QtQml[21]
#define sipClass_QQmlError sipExportedTypes_QtQml[21]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlError;

#define sipType_QQmlExpression sipExportedTypes_QtQml[22]
#define sipClass_QQmlExpression sipExportedTypes_QtQml[22]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlExpression;

#define sipType_QQmlExtensionPlugin sipExportedTypes_QtQml[23]
#define sipClass_QQmlExtensionPlugin sipExportedTypes_QtQml[23]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlExtensionPlugin;

#define sipType_QQmlEngineExtensionPlugin sipExportedTypes_QtQml[20]
#define sipClass_QQmlEngineExtensionPlugin sipExportedTypes_QtQml[20]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlEngineExtensionPlugin;

#define sipType_QQmlFileSelector sipExportedTypes_QtQml[24]
#define sipClass_QQmlFileSelector sipExportedTypes_QtQml[24]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlFileSelector;

#define sipType_QQmlIncubator sipExportedTypes_QtQml[30]
#define sipClass_QQmlIncubator sipExportedTypes_QtQml[30]->u.td_wrapper_type

#define sipType_QQmlIncubator_Status sipExportedTypes_QtQml[32]
#define sipEnum_QQmlIncubator_Status sipExportedTypes_QtQml[32]->u.td_py_type

#define sipType_QQmlIncubator_IncubationMode sipExportedTypes_QtQml[31]
#define sipEnum_QQmlIncubator_IncubationMode sipExportedTypes_QtQml[31]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlIncubator;

#define sipType_QQmlIncubationController sipExportedTypes_QtQml[29]
#define sipClass_QQmlIncubationController sipExportedTypes_QtQml[29]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlIncubationController;

#define sipType_QQmlListReference sipExportedTypes_QtQml[34]
#define sipClass_QQmlListReference sipExportedTypes_QtQml[34]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlListReference;

#define sipType_QQmlNetworkAccessManagerFactory sipExportedTypes_QtQml[35]
#define sipClass_QQmlNetworkAccessManagerFactory sipExportedTypes_QtQml[35]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlNetworkAccessManagerFactory;

#define sipType_QQmlParserStatus sipExportedTypes_QtQml[36]
#define sipClass_QQmlParserStatus sipExportedTypes_QtQml[36]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlParserStatus;

#define sipType_QQmlProperty sipExportedTypes_QtQml[37]
#define sipClass_QQmlProperty sipExportedTypes_QtQml[37]->u.td_wrapper_type

#define sipType_QQmlProperty_Type sipExportedTypes_QtQml[39]
#define sipEnum_QQmlProperty_Type sipExportedTypes_QtQml[39]->u.td_py_type

#define sipType_QQmlProperty_PropertyTypeCategory sipExportedTypes_QtQml[38]
#define sipEnum_QQmlProperty_PropertyTypeCategory sipExportedTypes_QtQml[38]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlProperty;

#define sipType_QQmlPropertyMap sipExportedTypes_QtQml[40]
#define sipClass_QQmlPropertyMap sipExportedTypes_QtQml[40]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlPropertyMap;

#define sipType_QQmlPropertyValueSource sipExportedTypes_QtQml[41]
#define sipClass_QQmlPropertyValueSource sipExportedTypes_QtQml[41]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlPropertyValueSource;

#define sipType_QQmlScriptString sipExportedTypes_QtQml[42]
#define sipClass_QQmlScriptString sipExportedTypes_QtQml[42]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQml_QQmlScriptString;

#define sipType_QVector_0100QQmlContext_PropertyPair sipExportedTypes_QtQml[43]

extern sipMappedTypeDef sipTypeDef_QtQml_QVector_0100QQmlContext_PropertyPair;

#define sipType_QList_0100QQmlError sipExportedTypes_QtQml[8]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QQmlError;

#define sipType_QList_0100QQmlProperty sipExportedTypes_QtQml[9]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QQmlProperty;

#define sipType_QList_0100QJSValue sipExportedTypes_QtQml[7]

extern sipMappedTypeDef sipTypeDef_QtQml_QList_0100QJSValue;

#define sipType_QQmlListProperty_0100QObject sipExportedTypes_QtQml[33]

extern sipMappedTypeDef sipTypeDef_QtQml_QQmlListProperty_0100QObject;

#define sipType_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td
#define sipEnum_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td->u.td_py_type

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQml;
extern sipExportedModuleDef sipModuleAPI_QtQml;
extern sipTypeDef *sipExportedTypes_QtQml[];

#define sipType_QObject sipImportedTypes_QtQml_QtCore[9].it_td
#define sipClass_QObject sipImportedTypes_QtQml_QtCore[9].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtQml_QtCore[0].it_td
#define sipClass_QByteArray sipImportedTypes_QtQml_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtQml_QtCore[3].it_td
#define sipClass_QEvent sipImportedTypes_QtQml_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QTimerEvent sipImportedTypes_QtQml_QtCore[12].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtQml_QtCore[12].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtQml_QtCore[1].it_td
#define sipClass_QChildEvent sipImportedTypes_QtQml_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QDateTime sipImportedTypes_QtQml_QtCore[2].it_td
#define sipClass_QDateTime sipImportedTypes_QtQml_QtCore[2].it_td->u.td_wrapper_type

#define sipType_QFileSelector sipImportedTypes_QtQml_QtCore[4].it_td
#define sipClass_QFileSelector sipImportedTypes_QtQml_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtQml_QtCore[6].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtQml_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QMetaProperty sipImportedTypes_QtQml_QtCore[8].it_td
#define sipClass_QMetaProperty sipImportedTypes_QtQml_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QMetaObject sipImportedTypes_QtQml_QtCore[7].it_td
#define sipClass_QMetaObject sipImportedTypes_QtQml_QtCore[7].it_td->u.td_wrapper_type

#define sipType_QUrl sipImportedTypes_QtQml_QtCore[13].it_td
#define sipClass_QUrl sipImportedTypes_QtQml_QtCore[13].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtQml_QtCore[14].it_td
#define sipClass_QVariant sipImportedTypes_QtQml_QtCore[14].it_td->u.td_wrapper_type

#define sipType_QList_0101QObject sipImportedTypes_QtQml_QtCore[5].it_td

#define sipType_QVariantMap sipImportedTypes_QtQml_QtCore[15].it_td

#define sipType_QStringList sipImportedTypes_QtQml_QtCore[11].it_td

#define sipType_QString sipImportedTypes_QtQml_QtCore[10].it_td

#define sipType_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td
#define sipEnum_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td->u.td_py_type
extern sipImportedTypeDef sipImportedTypes_QtQml_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQml_QtCore[];

#define sipType_QNetworkAccessManager sipImportedTypes_QtQml_QtNetwork[0].it_td
#define sipClass_QNetworkAccessManager sipImportedTypes_QtQml_QtNetwork[0].it_td->u.td_wrapper_type

#define sipType_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td
#define sipEnum_QtMsgType sipImportedTypes_QtQml_QtCore[16].it_td->u.td_py_type
extern sipImportedTypeDef sipImportedTypes_QtQml_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQml_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtQml_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQml_qt_metacast;
#line 154 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qjsengine.sip"
#include "qpyqml_api.h"
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlproperty.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt5_qtqml_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt5_qtqml_get_connection_parts_t pyqt5_qtqml_get_connection_parts;
#line 22 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qmlattachedpropertiesobject.sip"
#include <qqml.h>
#line 22 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qmlregistertype.sip"
#include <qpyqml_api.h>
#line 1197 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipAPIQtQml.h"

#endif
