/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 30 "sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGAbstractRenderer.cpp"


PyDoc_STRVAR(doc_QSGAbstractRenderer_setDeviceRect, "setDeviceRect(self, QRect)\n"
"setDeviceRect(self, QSize)");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setDeviceRect(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setDeviceRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setDeviceRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setDeviceRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setDeviceRect, doc_QSGAbstractRenderer_setDeviceRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_deviceRect, "deviceRect(self) -> QRect");

extern "C" {static PyObject *meth_QSGAbstractRenderer_deviceRect(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_deviceRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->deviceRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_deviceRect, doc_QSGAbstractRenderer_deviceRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_setViewportRect, "setViewportRect(self, QRect)\n"
"setViewportRect(self, QSize)");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setViewportRect(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setViewportRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setViewportRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setViewportRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setViewportRect, doc_QSGAbstractRenderer_setViewportRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_viewportRect, "viewportRect(self) -> QRect");

extern "C" {static PyObject *meth_QSGAbstractRenderer_viewportRect(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_viewportRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->viewportRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_viewportRect, doc_QSGAbstractRenderer_viewportRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_setProjectionMatrixToRect, "setProjectionMatrixToRect(self, QRectF)\n"
"setProjectionMatrixToRect(self, QRectF, Union[QSGAbstractRenderer.MatrixTransformFlags, QSGAbstractRenderer.MatrixTransformFlag])");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setProjectionMatrixToRect(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setProjectionMatrixToRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->setProjectionMatrixToRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRectF* a0;
         ::QSGAbstractRenderer::MatrixTransformFlags* a1;
        int a1State = 0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QRectF, &a0, sipType_QSGAbstractRenderer_MatrixTransformFlags, &a1, &a1State))
        {
            sipCpp->setProjectionMatrixToRect(*a0,*a1);
            sipReleaseType(a1,sipType_QSGAbstractRenderer_MatrixTransformFlags,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setProjectionMatrixToRect, doc_QSGAbstractRenderer_setProjectionMatrixToRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_setProjectionMatrix, "setProjectionMatrix(self, QMatrix4x4)");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setProjectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setProjectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QMatrix4x4* a0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QMatrix4x4, &a0))
        {
            sipCpp->setProjectionMatrix(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setProjectionMatrix, doc_QSGAbstractRenderer_setProjectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_projectionMatrix, "projectionMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_QSGAbstractRenderer_projectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_projectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp))
        {
             ::QMatrix4x4*sipRes;

            sipRes = new  ::QMatrix4x4(sipCpp->projectionMatrix());

            return sipConvertFromNewType(sipRes,sipType_QMatrix4x4,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_projectionMatrix, doc_QSGAbstractRenderer_projectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_setClearColor, "setClearColor(self, Union[QColor, Qt.GlobalColor])");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setClearColor(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setClearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColor* a0;
        int a0State = 0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setClearColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0),sipType_QColor,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setClearColor, doc_QSGAbstractRenderer_setClearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_clearColor, "clearColor(self) -> QColor");

extern "C" {static PyObject *meth_QSGAbstractRenderer_clearColor(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_clearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp))
        {
             ::QColor*sipRes;

            sipRes = new  ::QColor(sipCpp->clearColor());

            return sipConvertFromNewType(sipRes,sipType_QColor,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_clearColor, doc_QSGAbstractRenderer_clearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_setClearMode, "setClearMode(self, Union[QSGAbstractRenderer.ClearMode, QSGAbstractRenderer.ClearModeBit])");

extern "C" {static PyObject *meth_QSGAbstractRenderer_setClearMode(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_setClearMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGAbstractRenderer::ClearMode* a0;
        int a0State = 0;
         ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, sipType_QSGAbstractRenderer_ClearMode, &a0, &a0State))
        {
            sipCpp->setClearMode(*a0);
            sipReleaseType(a0,sipType_QSGAbstractRenderer_ClearMode,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_setClearMode, doc_QSGAbstractRenderer_setClearMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_clearMode, "clearMode(self) -> QSGAbstractRenderer.ClearMode");

extern "C" {static PyObject *meth_QSGAbstractRenderer_clearMode(PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_clearMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGAbstractRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp))
        {
             ::QSGAbstractRenderer::ClearMode*sipRes;

            sipRes = new  ::QSGAbstractRenderer::ClearMode(sipCpp->clearMode());

            return sipConvertFromNewType(sipRes,sipType_QSGAbstractRenderer_ClearMode,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_clearMode, doc_QSGAbstractRenderer_clearMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGAbstractRenderer_renderScene, "renderScene(self, fboId: int = 0)");

extern "C" {static PyObject *meth_QSGAbstractRenderer_renderScene(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSGAbstractRenderer_renderScene(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::GLuint a0 = 0;
         ::QSGAbstractRenderer *sipCpp;

        static const char *sipKwdList[] = {
            sipName_fboId,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|u", &sipSelf, sipType_QSGAbstractRenderer, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGAbstractRenderer, sipName_renderScene);
                return SIP_NULLPTR;
            }

            sipCpp->renderScene(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGAbstractRenderer, sipName_renderScene, doc_QSGAbstractRenderer_renderScene);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGAbstractRenderer(void *, const sipTypeDef *);}
static void *cast_QSGAbstractRenderer(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSGAbstractRenderer *sipCpp = reinterpret_cast< ::QSGAbstractRenderer *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGAbstractRenderer(void *, int);}
static void release_QSGAbstractRenderer(void *sipCppV, int)
{
     ::QSGAbstractRenderer *sipCpp = reinterpret_cast< ::QSGAbstractRenderer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QSGAbstractRenderer(sipSimpleWrapper *);}
static void dealloc_QSGAbstractRenderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGAbstractRenderer(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGAbstractRenderer[] = {{4, 0, 1}};


static PyMethodDef methods_QSGAbstractRenderer[] = {
    {SIP_MLNAME_CAST(sipName_clearColor), meth_QSGAbstractRenderer_clearColor, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_clearColor)},
    {SIP_MLNAME_CAST(sipName_clearMode), meth_QSGAbstractRenderer_clearMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_clearMode)},
    {SIP_MLNAME_CAST(sipName_deviceRect), meth_QSGAbstractRenderer_deviceRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_deviceRect)},
    {SIP_MLNAME_CAST(sipName_projectionMatrix), meth_QSGAbstractRenderer_projectionMatrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_projectionMatrix)},
    {SIP_MLNAME_CAST(sipName_renderScene), SIP_MLMETH_CAST(meth_QSGAbstractRenderer_renderScene), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_renderScene)},
    {SIP_MLNAME_CAST(sipName_setClearColor), meth_QSGAbstractRenderer_setClearColor, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setClearColor)},
    {SIP_MLNAME_CAST(sipName_setClearMode), meth_QSGAbstractRenderer_setClearMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setClearMode)},
    {SIP_MLNAME_CAST(sipName_setDeviceRect), meth_QSGAbstractRenderer_setDeviceRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setDeviceRect)},
    {SIP_MLNAME_CAST(sipName_setProjectionMatrix), meth_QSGAbstractRenderer_setProjectionMatrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setProjectionMatrix)},
    {SIP_MLNAME_CAST(sipName_setProjectionMatrixToRect), meth_QSGAbstractRenderer_setProjectionMatrixToRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setProjectionMatrixToRect)},
    {SIP_MLNAME_CAST(sipName_setViewportRect), meth_QSGAbstractRenderer_setViewportRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_setViewportRect)},
    {SIP_MLNAME_CAST(sipName_viewportRect), meth_QSGAbstractRenderer_viewportRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGAbstractRenderer_viewportRect)}
};

static sipEnumMemberDef enummembers_QSGAbstractRenderer[] = {
    {sipName_ClearColorBuffer, static_cast<int>( ::QSGAbstractRenderer::ClearColorBuffer), 34},
    {sipName_ClearDepthBuffer, static_cast<int>( ::QSGAbstractRenderer::ClearDepthBuffer), 34},
    {sipName_ClearStencilBuffer, static_cast<int>( ::QSGAbstractRenderer::ClearStencilBuffer), 34},
    {sipName_MatrixTransformFlipY, static_cast<int>( ::QSGAbstractRenderer::MatrixTransformFlipY), 35},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QSGAbstractRenderer[] = {
    {"sceneGraphChanged()", "\1sceneGraphChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QSGAbstractRenderer = {
    & ::QSGAbstractRenderer::staticMetaObject,
    0,
    signals_QSGAbstractRenderer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGAbstractRenderer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGAbstractRenderer,
        {SIP_NULLPTR},
        &plugin_QSGAbstractRenderer
    },
    {
        sipNameNr_QSGAbstractRenderer,
        {0, 0, 1},
        12, methods_QSGAbstractRenderer,
        4, enummembers_QSGAbstractRenderer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QSGAbstractRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGAbstractRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGAbstractRenderer,
    cast_QSGAbstractRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
