/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQuickWidgetsAPI_H
#define _QtQuickWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QQuickWidget__ResizeMode 0
#define sipName_QQuickWidget__ResizeMode &sipStrings_QtQuickWidgets[0]
#define sipNameNr_mouseDoubleClickEvent 25
#define sipName_mouseDoubleClickEvent &sipStrings_QtQuickWidgets[25]
#define sipNameNr_QQuickWidget__Status 47
#define sipName_QQuickWidget__Status &sipStrings_QtQuickWidgets[47]
#define sipNameNr_SizeRootObjectToView 68
#define sipName_SizeRootObjectToView &sipStrings_QtQuickWidgets[68]
#define sipNameNr_SizeViewToRootObject 89
#define sipName_SizeViewToRootObject &sipStrings_QtQuickWidgets[89]
#define sipNameNr_PyQt5_QtQuickWidgets 110
#define sipName_PyQt5_QtQuickWidgets &sipStrings_QtQuickWidgets[110]
#define sipNameNr_focusNextPrevChild 131
#define sipName_focusNextPrevChild &sipStrings_QtQuickWidgets[131]
#define sipNameNr_hasHeightForWidth 150
#define sipName_hasHeightForWidth &sipStrings_QtQuickWidgets[150]
#define sipNameNr_mouseReleaseEvent 168
#define sipName_mouseReleaseEvent &sipStrings_QtQuickWidgets[168]
#define sipNameNr_contextMenuEvent 186
#define sipName_contextMenuEvent &sipStrings_QtQuickWidgets[186]
#define sipNameNr_inputMethodEvent 203
#define sipName_inputMethodEvent &sipStrings_QtQuickWidgets[203]
#define sipNameNr_inputMethodQuery 220
#define sipName_inputMethodQuery &sipStrings_QtQuickWidgets[220]
#define sipNameNr_disconnectNotify 237
#define sipName_disconnectNotify &sipStrings_QtQuickWidgets[237]
#define sipNameNr_minimumSizeHint 254
#define sipName_minimumSizeHint &sipStrings_QtQuickWidgets[254]
#define sipNameNr_sceneGraphError 270
#define sipName_sceneGraphError &sipStrings_QtQuickWidgets[270]
#define sipNameNr_mousePressEvent 286
#define sipName_mousePressEvent &sipStrings_QtQuickWidgets[286]
#define sipNameNr_keyReleaseEvent 302
#define sipName_keyReleaseEvent &sipStrings_QtQuickWidgets[302]
#define sipNameNr_grabFramebuffer 318
#define sipName_grabFramebuffer &sipStrings_QtQuickWidgets[318]
#define sipNameNr_heightForWidth 334
#define sipName_heightForWidth &sipStrings_QtQuickWidgets[334]
#define sipNameNr_dragLeaveEvent 349
#define sipName_dragLeaveEvent &sipStrings_QtQuickWidgets[349]
#define sipNameNr_dragEnterEvent 364
#define sipName_dragEnterEvent &sipStrings_QtQuickWidgets[364]
#define sipNameNr_mouseMoveEvent 379
#define sipName_mouseMoveEvent &sipStrings_QtQuickWidgets[379]
#define sipNameNr_sharedPainter 394
#define sipName_sharedPainter &sipStrings_QtQuickWidgets[394]
#define sipNameNr_setClearColor 408
#define sipName_setClearColor &sipStrings_QtQuickWidgets[408]
#define sipNameNr_setResizeMode 422
#define sipName_setResizeMode &sipStrings_QtQuickWidgets[422]
#define sipNameNr_dragMoveEvent 436
#define sipName_dragMoveEvent &sipStrings_QtQuickWidgets[436]
#define sipNameNr_statusChanged 450
#define sipName_statusChanged &sipStrings_QtQuickWidgets[450]
#define sipNameNr_keyPressEvent 464
#define sipName_keyPressEvent &sipStrings_QtQuickWidgets[464]
#define sipNameNr_focusOutEvent 478
#define sipName_focusOutEvent &sipStrings_QtQuickWidgets[478]
#define sipNameNr_connectNotify 240
#define sipName_connectNotify &sipStrings_QtQuickWidgets[240]
#define sipNameNr_QQuickWidget 492
#define sipName_QQuickWidget &sipStrings_QtQuickWidgets[492]
#define sipNameNr_focusInEvent 505
#define sipName_focusInEvent &sipStrings_QtQuickWidgets[505]
#define sipNameNr_quickWindow 518
#define sipName_quickWindow &sipStrings_QtQuickWidgets[518]
#define sipNameNr_initPainter 530
#define sipName_initPainter &sipStrings_QtQuickWidgets[530]
#define sipNameNr_nativeEvent 542
#define sipName_nativeEvent &sipStrings_QtQuickWidgets[542]
#define sipNameNr_actionEvent 554
#define sipName_actionEvent &sipStrings_QtQuickWidgets[554]
#define sipNameNr_changeEvent 566
#define sipName_changeEvent &sipStrings_QtQuickWidgets[566]
#define sipNameNr_initialSize 578
#define sipName_initialSize &sipStrings_QtQuickWidgets[578]
#define sipNameNr_rootContext 590
#define sipName_rootContext &sipStrings_QtQuickWidgets[590]
#define sipNameNr_tabletEvent 602
#define sipName_tabletEvent &sipStrings_QtQuickWidgets[602]
#define sipNameNr_resizeEvent 614
#define sipName_resizeEvent &sipStrings_QtQuickWidgets[614]
#define sipNameNr_paintEngine 626
#define sipName_paintEngine &sipStrings_QtQuickWidgets[626]
#define sipNameNr_customEvent 638
#define sipName_customEvent &sipStrings_QtQuickWidgets[638]
#define sipNameNr_eventFilter 650
#define sipName_eventFilter &sipStrings_QtQuickWidgets[650]
#define sipNameNr_enterEvent 662
#define sipName_enterEvent &sipStrings_QtQuickWidgets[662]
#define sipNameNr_leaveEvent 673
#define sipName_leaveEvent &sipStrings_QtQuickWidgets[673]
#define sipNameNr_closeEvent 684
#define sipName_closeEvent &sipStrings_QtQuickWidgets[684]
#define sipNameNr_resizeMode 695
#define sipName_resizeMode &sipStrings_QtQuickWidgets[695]
#define sipNameNr_ResizeMode 14
#define sipName_ResizeMode &sipStrings_QtQuickWidgets[14]
#define sipNameNr_rootObject 706
#define sipName_rootObject &sipStrings_QtQuickWidgets[706]
#define sipNameNr_wheelEvent 717
#define sipName_wheelEvent &sipStrings_QtQuickWidgets[717]
#define sipNameNr_paintEvent 728
#define sipName_paintEvent &sipStrings_QtQuickWidgets[728]
#define sipNameNr_setVisible 739
#define sipName_setVisible &sipStrings_QtQuickWidgets[739]
#define sipNameNr_childEvent 750
#define sipName_childEvent &sipStrings_QtQuickWidgets[750]
#define sipNameNr_timerEvent 761
#define sipName_timerEvent &sipStrings_QtQuickWidgets[761]
#define sipNameNr_setSource 772
#define sipName_setSource &sipStrings_QtQuickWidgets[772]
#define sipNameNr_dropEvent 782
#define sipName_dropEvent &sipStrings_QtQuickWidgets[782]
#define sipNameNr_hideEvent 792
#define sipName_hideEvent &sipStrings_QtQuickWidgets[792]
#define sipNameNr_showEvent 802
#define sipName_showEvent &sipStrings_QtQuickWidgets[802]
#define sipNameNr_moveEvent 812
#define sipName_moveEvent &sipStrings_QtQuickWidgets[812]
#define sipNameNr_setFormat 822
#define sipName_setFormat &sipStrings_QtQuickWidgets[822]
#define sipNameNr_sizeHint 832
#define sipName_sizeHint &sipStrings_QtQuickWidgets[832]
#define sipNameNr_Loading 841
#define sipName_Loading &sipStrings_QtQuickWidgets[841]
#define sipNameNr_devType 849
#define sipName_devType &sipStrings_QtQuickWidgets[849]
#define sipNameNr_errors 857
#define sipName_errors &sipStrings_QtQuickWidgets[857]
#define sipNameNr_metric 864
#define sipName_metric &sipStrings_QtQuickWidgets[864]
#define sipNameNr_engine 871
#define sipName_engine &sipStrings_QtQuickWidgets[871]
#define sipNameNr_source 878
#define sipName_source &sipStrings_QtQuickWidgets[878]
#define sipNameNr_status 885
#define sipName_status &sipStrings_QtQuickWidgets[885]
#define sipNameNr_Status 61
#define sipName_Status &sipStrings_QtQuickWidgets[61]
#define sipNameNr_format 892
#define sipName_format &sipStrings_QtQuickWidgets[892]
#define sipNameNr_parent 899
#define sipName_parent &sipStrings_QtQuickWidgets[899]
#define sipNameNr_Ready 906
#define sipName_Ready &sipStrings_QtQuickWidgets[906]
#define sipNameNr_Error 280
#define sipName_Error &sipStrings_QtQuickWidgets[280]
#define sipNameNr_event 912
#define sipName_event &sipStrings_QtQuickWidgets[912]
#define sipNameNr_Null 918
#define sipName_Null &sipStrings_QtQuickWidgets[918]

#define sipMalloc                   sipAPI_QtQuickWidgets->api_malloc
#define sipFree                     sipAPI_QtQuickWidgets->api_free
#define sipBuildResult              sipAPI_QtQuickWidgets->api_build_result
#define sipCallMethod               sipAPI_QtQuickWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQuickWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQuickWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQuickWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtQuickWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtQuickWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQuickWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQuickWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQuickWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQuickWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQuickWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQuickWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQuickWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQuickWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQuickWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtQuickWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtQuickWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtQuickWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtQuickWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQuickWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQuickWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQuickWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQuickWidgets->api_trace
#define sipTransferBack             sipAPI_QtQuickWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtQuickWidgets->api_transfer_to
#define sipTransferBreak            sipAPI_QtQuickWidgets->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtQuickWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQuickWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQuickWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQuickWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQuickWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtQuickWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtQuickWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQuickWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQuickWidgets->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtQuickWidgets->api_is_py_method
#define sipCallHook                 sipAPI_QtQuickWidgets->api_call_hook
#define sipEndThread                sipAPI_QtQuickWidgets->api_end_thread
#define sipConnectRx                sipAPI_QtQuickWidgets->api_connect_rx
#define sipDisconnectRx             sipAPI_QtQuickWidgets->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtQuickWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQuickWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQuickWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQuickWidgets->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtQuickWidgets->api_free_sipslot
#define sipSameSlot                 sipAPI_QtQuickWidgets->api_same_slot
#define sipPySlotExtend             sipAPI_QtQuickWidgets->api_pyslot_extend
#define sipConvertRx                sipAPI_QtQuickWidgets->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtQuickWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQuickWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQuickWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQuickWidgets->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtQuickWidgets->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtQuickWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQuickWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQuickWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtQuickWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQuickWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQuickWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQuickWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtQuickWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtQuickWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtQuickWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtQuickWidgets->api_find_type
#define sipFindNamedEnum            sipAPI_QtQuickWidgets->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtQuickWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQuickWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQuickWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQuickWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQuickWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQuickWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQuickWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQuickWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQuickWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQuickWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQuickWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQuickWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQuickWidgets->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtQuickWidgets->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtQuickWidgets->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtQuickWidgets->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtQuickWidgets->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtQuickWidgets->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtQuickWidgets->api_deprecated
#define sipGetReference             sipAPI_QtQuickWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtQuickWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQuickWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQuickWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQuickWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQuickWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtQuickWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQuickWidgets->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtQuickWidgets->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtQuickWidgets->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtQuickWidgets->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtQuickWidgets->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtQuickWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtQuickWidgets->api_export_module
#define sipInitModule               sipAPI_QtQuickWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtQuickWidgets->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtQuickWidgets->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtQuickWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQuickWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQuickWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQuickWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtQuickWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtQuickWidgets->api_get_method
#define sipFromMethod               sipAPI_QtQuickWidgets->api_from_method
#define sipGetDate                  sipAPI_QtQuickWidgets->api_get_date
#define sipFromDate                 sipAPI_QtQuickWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtQuickWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtQuickWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtQuickWidgets->api_get_time
#define sipFromTime                 sipAPI_QtQuickWidgets->api_from_time
#define sipIsUserType               sipAPI_QtQuickWidgets->api_is_user_type
#define sipGetFrame                 sipAPI_QtQuickWidgets->api_get_frame
#define sipCheckPluginForType       sipAPI_QtQuickWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQuickWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQuickWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtQuickWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQuickWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQuickWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQuickWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQuickWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQuickWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtQuickWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQuickWidgets->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtQuickWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQuickWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQuickWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQuickWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQuickWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQuickWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQuickWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQuickWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQuickWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQuickWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQuickWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQuickWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQuickWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQuickWidgets->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtQuickWidgets->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtQuickWidgets->api_map_int_to_class
#define sipFindClass                sipAPI_QtQuickWidgets->api_find_class
#define sipFindMappedType           sipAPI_QtQuickWidgets->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtQuickWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQuickWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQuickWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtQuickWidgets->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtQuickWidgets->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtQuickWidgets[];

#define sipType_QQuickWidget sipExportedTypes_QtQuickWidgets[0]
#define sipClass_QQuickWidget sipExportedTypes_QtQuickWidgets[0]->u.td_wrapper_type

#define sipType_QQuickWidget_Status sipExportedTypes_QtQuickWidgets[2]
#define sipEnum_QQuickWidget_Status sipExportedTypes_QtQuickWidgets[2]->u.td_py_type

#define sipType_QQuickWidget_ResizeMode sipExportedTypes_QtQuickWidgets[1]
#define sipEnum_QQuickWidget_ResizeMode sipExportedTypes_QtQuickWidgets[1]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuickWidgets_QQuickWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQuickWidgets;
extern sipExportedModuleDef sipModuleAPI_QtQuickWidgets;
extern sipTypeDef *sipExportedTypes_QtQuickWidgets[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtQuickWidgets_QtCore[10].it_td
#define sipEnum_Qt_InputMethodQuery sipImportedTypes_QtQuickWidgets_QtCore[10].it_td->u.td_py_type

#define sipType_QObject sipImportedTypes_QtQuickWidgets_QtCore[4].it_td
#define sipClass_QObject sipImportedTypes_QtQuickWidgets_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtQuickWidgets_QtCore[0].it_td
#define sipClass_QByteArray sipImportedTypes_QtQuickWidgets_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtQuickWidgets_QtCore[2].it_td
#define sipClass_QEvent sipImportedTypes_QtQuickWidgets_QtCore[2].it_td->u.td_wrapper_type

#define sipType_QTimerEvent sipImportedTypes_QtQuickWidgets_QtCore[7].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtQuickWidgets_QtCore[7].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtQuickWidgets_QtCore[1].it_td
#define sipClass_QChildEvent sipImportedTypes_QtQuickWidgets_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtQuickWidgets_QtCore[3].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtQuickWidgets_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QSize sipImportedTypes_QtQuickWidgets_QtCore[5].it_td
#define sipClass_QSize sipImportedTypes_QtQuickWidgets_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QUrl sipImportedTypes_QtQuickWidgets_QtCore[8].it_td
#define sipClass_QUrl sipImportedTypes_QtQuickWidgets_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtQuickWidgets_QtCore[9].it_td
#define sipClass_QVariant sipImportedTypes_QtQuickWidgets_QtCore[9].it_td->u.td_wrapper_type

#define sipType_QString sipImportedTypes_QtQuickWidgets_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuickWidgets_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtQuickWidgets_QtGui[15].it_td
#define sipClass_QPaintDevice sipImportedTypes_QtQuickWidgets_QtGui[15].it_td->u.td_wrapper_type

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtQuickWidgets_QtGui[16].it_td
#define sipEnum_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtQuickWidgets_QtGui[16].it_td->u.td_py_type

#define sipType_QColor sipImportedTypes_QtQuickWidgets_QtGui[2].it_td
#define sipClass_QColor sipImportedTypes_QtQuickWidgets_QtGui[2].it_td->u.td_wrapper_type

#define sipType_QMouseEvent sipImportedTypes_QtQuickWidgets_QtGui[13].it_td
#define sipClass_QMouseEvent sipImportedTypes_QtQuickWidgets_QtGui[13].it_td->u.td_wrapper_type

#define sipType_QWheelEvent sipImportedTypes_QtQuickWidgets_QtGui[24].it_td
#define sipClass_QWheelEvent sipImportedTypes_QtQuickWidgets_QtGui[24].it_td->u.td_wrapper_type

#define sipType_QTabletEvent sipImportedTypes_QtQuickWidgets_QtGui[23].it_td
#define sipClass_QTabletEvent sipImportedTypes_QtQuickWidgets_QtGui[23].it_td->u.td_wrapper_type

#define sipType_QKeyEvent sipImportedTypes_QtQuickWidgets_QtGui[12].it_td
#define sipClass_QKeyEvent sipImportedTypes_QtQuickWidgets_QtGui[12].it_td->u.td_wrapper_type

#define sipType_QFocusEvent sipImportedTypes_QtQuickWidgets_QtGui[8].it_td
#define sipClass_QFocusEvent sipImportedTypes_QtQuickWidgets_QtGui[8].it_td->u.td_wrapper_type

#define sipType_QPaintEvent sipImportedTypes_QtQuickWidgets_QtGui[18].it_td
#define sipClass_QPaintEvent sipImportedTypes_QtQuickWidgets_QtGui[18].it_td->u.td_wrapper_type

#define sipType_QMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[14].it_td
#define sipClass_QMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[14].it_td->u.td_wrapper_type

#define sipType_QResizeEvent sipImportedTypes_QtQuickWidgets_QtGui[20].it_td
#define sipClass_QResizeEvent sipImportedTypes_QtQuickWidgets_QtGui[20].it_td->u.td_wrapper_type

#define sipType_QCloseEvent sipImportedTypes_QtQuickWidgets_QtGui[1].it_td
#define sipClass_QCloseEvent sipImportedTypes_QtQuickWidgets_QtGui[1].it_td->u.td_wrapper_type

#define sipType_QShowEvent sipImportedTypes_QtQuickWidgets_QtGui[21].it_td
#define sipClass_QShowEvent sipImportedTypes_QtQuickWidgets_QtGui[21].it_td->u.td_wrapper_type

#define sipType_QHideEvent sipImportedTypes_QtQuickWidgets_QtGui[9].it_td
#define sipClass_QHideEvent sipImportedTypes_QtQuickWidgets_QtGui[9].it_td->u.td_wrapper_type

#define sipType_QContextMenuEvent sipImportedTypes_QtQuickWidgets_QtGui[3].it_td
#define sipClass_QContextMenuEvent sipImportedTypes_QtQuickWidgets_QtGui[3].it_td->u.td_wrapper_type

#define sipType_QInputMethodEvent sipImportedTypes_QtQuickWidgets_QtGui[11].it_td
#define sipClass_QInputMethodEvent sipImportedTypes_QtQuickWidgets_QtGui[11].it_td->u.td_wrapper_type

#define sipType_QDropEvent sipImportedTypes_QtQuickWidgets_QtGui[7].it_td
#define sipClass_QDropEvent sipImportedTypes_QtQuickWidgets_QtGui[7].it_td->u.td_wrapper_type

#define sipType_QDragMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[6].it_td
#define sipClass_QDragMoveEvent sipImportedTypes_QtQuickWidgets_QtGui[6].it_td->u.td_wrapper_type

#define sipType_QDragEnterEvent sipImportedTypes_QtQuickWidgets_QtGui[4].it_td
#define sipClass_QDragEnterEvent sipImportedTypes_QtQuickWidgets_QtGui[4].it_td->u.td_wrapper_type

#define sipType_QDragLeaveEvent sipImportedTypes_QtQuickWidgets_QtGui[5].it_td
#define sipClass_QDragLeaveEvent sipImportedTypes_QtQuickWidgets_QtGui[5].it_td->u.td_wrapper_type

#define sipType_QActionEvent sipImportedTypes_QtQuickWidgets_QtGui[0].it_td
#define sipClass_QActionEvent sipImportedTypes_QtQuickWidgets_QtGui[0].it_td->u.td_wrapper_type

#define sipType_QImage sipImportedTypes_QtQuickWidgets_QtGui[10].it_td
#define sipClass_QImage sipImportedTypes_QtQuickWidgets_QtGui[10].it_td->u.td_wrapper_type

#define sipType_QPainter sipImportedTypes_QtQuickWidgets_QtGui[19].it_td
#define sipClass_QPainter sipImportedTypes_QtQuickWidgets_QtGui[19].it_td->u.td_wrapper_type

#define sipType_QPaintEngine sipImportedTypes_QtQuickWidgets_QtGui[17].it_td
#define sipClass_QPaintEngine sipImportedTypes_QtQuickWidgets_QtGui[17].it_td->u.td_wrapper_type

#define sipType_QSurfaceFormat sipImportedTypes_QtQuickWidgets_QtGui[22].it_td
#define sipClass_QSurfaceFormat sipImportedTypes_QtQuickWidgets_QtGui[22].it_td->u.td_wrapper_type
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtGui[];

#define sipType_QWidget sipImportedTypes_QtQuickWidgets_QtWidgets[0].it_td
#define sipClass_QWidget sipImportedTypes_QtQuickWidgets_QtWidgets[0].it_td->u.td_wrapper_type
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtWidgets[];

#define sipType_QQmlEngine sipImportedTypes_QtQuickWidgets_QtQml[2].it_td
#define sipClass_QQmlEngine sipImportedTypes_QtQuickWidgets_QtQml[2].it_td->u.td_wrapper_type

#define sipType_QQmlContext sipImportedTypes_QtQuickWidgets_QtQml[1].it_td
#define sipClass_QQmlContext sipImportedTypes_QtQuickWidgets_QtQml[1].it_td->u.td_wrapper_type

#define sipType_QList_0100QQmlError sipImportedTypes_QtQuickWidgets_QtQml[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtQml[];

#define sipType_QQuickItem sipImportedTypes_QtQuickWidgets_QtQuick[0].it_td
#define sipClass_QQuickItem sipImportedTypes_QtQuickWidgets_QtQuick[0].it_td->u.td_wrapper_type

#define sipType_QQuickWindow sipImportedTypes_QtQuickWidgets_QtQuick[1].it_td
#define sipClass_QQuickWindow sipImportedTypes_QtQuickWidgets_QtQuick[1].it_td->u.td_wrapper_type

#define sipType_QQuickWindow_SceneGraphError sipImportedTypes_QtQuickWidgets_QtQuick[2].it_td
#define sipEnum_QQuickWindow_SceneGraphError sipImportedTypes_QtQuickWidgets_QtQuick[2].it_td->u.td_py_type
extern sipImportedTypeDef sipImportedTypes_QtQuickWidgets_QtQuick[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQuickWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtQuickWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQuickWidgets_qt_metacast;

#endif
