/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstylehints.sip"
#include <qstylehints.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"

#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 27 "sip/QtCore/qchar.sip"
#include <qchar.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStyleHints.cpp"


PyDoc_STRVAR(doc_QStyleHints_mouseDoubleClickInterval, "mouseDoubleClickInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseDoubleClickInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseDoubleClickInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseDoubleClickInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseDoubleClickInterval, doc_QStyleHints_mouseDoubleClickInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragDistance, "startDragDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragDistance();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragDistance, doc_QStyleHints_startDragDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragTime, "startDragTime(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragTime(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragTime();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragTime, doc_QStyleHints_startDragTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_startDragVelocity, "startDragVelocity(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_startDragVelocity(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_startDragVelocity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startDragVelocity();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_startDragVelocity, doc_QStyleHints_startDragVelocity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_keyboardInputInterval, "keyboardInputInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_keyboardInputInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_keyboardInputInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->keyboardInputInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_keyboardInputInterval, doc_QStyleHints_keyboardInputInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_keyboardAutoRepeatRate, "keyboardAutoRepeatRate(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_keyboardAutoRepeatRate(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_keyboardAutoRepeatRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->keyboardAutoRepeatRate();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_keyboardAutoRepeatRate, doc_QStyleHints_keyboardAutoRepeatRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_cursorFlashTime, "cursorFlashTime(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_cursorFlashTime(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_cursorFlashTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->cursorFlashTime();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_cursorFlashTime, doc_QStyleHints_cursorFlashTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showIsFullScreen, "showIsFullScreen(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showIsFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showIsFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showIsFullScreen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showIsFullScreen, doc_QStyleHints_showIsFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_passwordMaskDelay, "passwordMaskDelay(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_passwordMaskDelay(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_passwordMaskDelay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->passwordMaskDelay();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_passwordMaskDelay, doc_QStyleHints_passwordMaskDelay);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_fontSmoothingGamma, "fontSmoothingGamma(self) -> float");

extern "C" {static PyObject *meth_QStyleHints_fontSmoothingGamma(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_fontSmoothingGamma(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->fontSmoothingGamma();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_fontSmoothingGamma, doc_QStyleHints_fontSmoothingGamma);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_useRtlExtensions, "useRtlExtensions(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_useRtlExtensions(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_useRtlExtensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useRtlExtensions();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_useRtlExtensions, doc_QStyleHints_useRtlExtensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_passwordMaskCharacter, "passwordMaskCharacter(self) -> str");

extern "C" {static PyObject *meth_QStyleHints_passwordMaskCharacter(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_passwordMaskCharacter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
             ::QChar*sipRes;

            sipRes = new  ::QChar(sipCpp->passwordMaskCharacter());

            return sipConvertFromNewType(sipRes,sipType_QChar,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_passwordMaskCharacter, doc_QStyleHints_passwordMaskCharacter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setFocusOnTouchRelease, "setFocusOnTouchRelease(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_setFocusOnTouchRelease(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setFocusOnTouchRelease(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->setFocusOnTouchRelease();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setFocusOnTouchRelease, doc_QStyleHints_setFocusOnTouchRelease);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mousePressAndHoldInterval, "mousePressAndHoldInterval(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mousePressAndHoldInterval(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mousePressAndHoldInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mousePressAndHoldInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mousePressAndHoldInterval, doc_QStyleHints_mousePressAndHoldInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_tabFocusBehavior, "tabFocusBehavior(self) -> Qt.TabFocusBehavior");

extern "C" {static PyObject *meth_QStyleHints_tabFocusBehavior(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_tabFocusBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
             ::Qt::TabFocusBehavior sipRes;

            sipRes = sipCpp->tabFocusBehavior();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_TabFocusBehavior);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_tabFocusBehavior, doc_QStyleHints_tabFocusBehavior);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_singleClickActivation, "singleClickActivation(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_singleClickActivation(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_singleClickActivation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->singleClickActivation();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_singleClickActivation, doc_QStyleHints_singleClickActivation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showIsMaximized, "showIsMaximized(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showIsMaximized(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showIsMaximized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showIsMaximized();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showIsMaximized, doc_QStyleHints_showIsMaximized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_useHoverEffects, "useHoverEffects(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_useHoverEffects(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_useHoverEffects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useHoverEffects();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_useHoverEffects, doc_QStyleHints_useHoverEffects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setUseHoverEffects, "setUseHoverEffects(self, bool)");

extern "C" {static PyObject *meth_QStyleHints_setUseHoverEffects(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setUseHoverEffects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStyleHints, &sipCpp, &a0))
        {
            sipCpp->setUseHoverEffects(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setUseHoverEffects, doc_QStyleHints_setUseHoverEffects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_wheelScrollLines, "wheelScrollLines(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_wheelScrollLines(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_wheelScrollLines(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->wheelScrollLines();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_wheelScrollLines, doc_QStyleHints_wheelScrollLines);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_showShortcutsInContextMenus, "showShortcutsInContextMenus(self) -> bool");

extern "C" {static PyObject *meth_QStyleHints_showShortcutsInContextMenus(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_showShortcutsInContextMenus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showShortcutsInContextMenus();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_showShortcutsInContextMenus, doc_QStyleHints_showShortcutsInContextMenus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mouseQuickSelectionThreshold, "mouseQuickSelectionThreshold(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseQuickSelectionThreshold(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseQuickSelectionThreshold(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseQuickSelectionThreshold();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseQuickSelectionThreshold, doc_QStyleHints_mouseQuickSelectionThreshold);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_setShowShortcutsInContextMenus, "setShowShortcutsInContextMenus(self, bool)");

extern "C" {static PyObject *meth_QStyleHints_setShowShortcutsInContextMenus(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_setShowShortcutsInContextMenus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStyleHints, &sipCpp, &a0))
        {
            sipCpp->setShowShortcutsInContextMenus(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_setShowShortcutsInContextMenus, doc_QStyleHints_setShowShortcutsInContextMenus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_mouseDoubleClickDistance, "mouseDoubleClickDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_mouseDoubleClickDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_mouseDoubleClickDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mouseDoubleClickDistance();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_mouseDoubleClickDistance, doc_QStyleHints_mouseDoubleClickDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyleHints_touchDoubleTapDistance, "touchDoubleTapDistance(self) -> int");

extern "C" {static PyObject *meth_QStyleHints_touchDoubleTapDistance(PyObject *, PyObject *);}
static PyObject *meth_QStyleHints_touchDoubleTapDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyleHints *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyleHints, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->touchDoubleTapDistance();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyleHints, sipName_touchDoubleTapDistance, doc_QStyleHints_touchDoubleTapDistance);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyleHints(void *, const sipTypeDef *);}
static void *cast_QStyleHints(void *sipCppV, const sipTypeDef *targetType)
{
     ::QStyleHints *sipCpp = reinterpret_cast< ::QStyleHints *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyleHints(void *, int);}
static void release_QStyleHints(void *sipCppV, int)
{
     ::QStyleHints *sipCpp = reinterpret_cast< ::QStyleHints *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QStyleHints(sipSimpleWrapper *);}
static void dealloc_QStyleHints(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyleHints(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyleHints[] = {{25, 0, 1}};


static PyMethodDef methods_QStyleHints[] = {
    {SIP_MLNAME_CAST(sipName_cursorFlashTime), meth_QStyleHints_cursorFlashTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_cursorFlashTime)},
    {SIP_MLNAME_CAST(sipName_fontSmoothingGamma), meth_QStyleHints_fontSmoothingGamma, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_fontSmoothingGamma)},
    {SIP_MLNAME_CAST(sipName_keyboardAutoRepeatRate), meth_QStyleHints_keyboardAutoRepeatRate, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_keyboardAutoRepeatRate)},
    {SIP_MLNAME_CAST(sipName_keyboardInputInterval), meth_QStyleHints_keyboardInputInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_keyboardInputInterval)},
    {SIP_MLNAME_CAST(sipName_mouseDoubleClickDistance), meth_QStyleHints_mouseDoubleClickDistance, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_mouseDoubleClickDistance)},
    {SIP_MLNAME_CAST(sipName_mouseDoubleClickInterval), meth_QStyleHints_mouseDoubleClickInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_mouseDoubleClickInterval)},
    {SIP_MLNAME_CAST(sipName_mousePressAndHoldInterval), meth_QStyleHints_mousePressAndHoldInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_mousePressAndHoldInterval)},
    {SIP_MLNAME_CAST(sipName_mouseQuickSelectionThreshold), meth_QStyleHints_mouseQuickSelectionThreshold, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_mouseQuickSelectionThreshold)},
    {SIP_MLNAME_CAST(sipName_passwordMaskCharacter), meth_QStyleHints_passwordMaskCharacter, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_passwordMaskCharacter)},
    {SIP_MLNAME_CAST(sipName_passwordMaskDelay), meth_QStyleHints_passwordMaskDelay, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_passwordMaskDelay)},
    {SIP_MLNAME_CAST(sipName_setFocusOnTouchRelease), meth_QStyleHints_setFocusOnTouchRelease, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_setFocusOnTouchRelease)},
    {SIP_MLNAME_CAST(sipName_setShowShortcutsInContextMenus), meth_QStyleHints_setShowShortcutsInContextMenus, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_setShowShortcutsInContextMenus)},
    {SIP_MLNAME_CAST(sipName_setUseHoverEffects), meth_QStyleHints_setUseHoverEffects, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_setUseHoverEffects)},
    {SIP_MLNAME_CAST(sipName_showIsFullScreen), meth_QStyleHints_showIsFullScreen, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_showIsFullScreen)},
    {SIP_MLNAME_CAST(sipName_showIsMaximized), meth_QStyleHints_showIsMaximized, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_showIsMaximized)},
    {SIP_MLNAME_CAST(sipName_showShortcutsInContextMenus), meth_QStyleHints_showShortcutsInContextMenus, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_showShortcutsInContextMenus)},
    {SIP_MLNAME_CAST(sipName_singleClickActivation), meth_QStyleHints_singleClickActivation, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_singleClickActivation)},
    {SIP_MLNAME_CAST(sipName_startDragDistance), meth_QStyleHints_startDragDistance, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_startDragDistance)},
    {SIP_MLNAME_CAST(sipName_startDragTime), meth_QStyleHints_startDragTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_startDragTime)},
    {SIP_MLNAME_CAST(sipName_startDragVelocity), meth_QStyleHints_startDragVelocity, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_startDragVelocity)},
    {SIP_MLNAME_CAST(sipName_tabFocusBehavior), meth_QStyleHints_tabFocusBehavior, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_tabFocusBehavior)},
    {SIP_MLNAME_CAST(sipName_touchDoubleTapDistance), meth_QStyleHints_touchDoubleTapDistance, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_touchDoubleTapDistance)},
    {SIP_MLNAME_CAST(sipName_useHoverEffects), meth_QStyleHints_useHoverEffects, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_useHoverEffects)},
    {SIP_MLNAME_CAST(sipName_useRtlExtensions), meth_QStyleHints_useRtlExtensions, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_useRtlExtensions)},
    {SIP_MLNAME_CAST(sipName_wheelScrollLines), meth_QStyleHints_wheelScrollLines, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyleHints_wheelScrollLines)}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QStyleHints[] = {
    {"showShortcutsInContextMenusChanged(bool)", "\1showShortcutsInContextMenusChanged(self, bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"mouseQuickSelectionThresholdChanged(int)", "\1mouseQuickSelectionThresholdChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"wheelScrollLinesChanged(int)", "\1wheelScrollLinesChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"useHoverEffectsChanged(bool)", "\1useHoverEffectsChanged(self, bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"tabFocusBehaviorChanged(Qt::TabFocusBehavior)", "\1tabFocusBehaviorChanged(self, Qt.TabFocusBehavior)", SIP_NULLPTR, SIP_NULLPTR},
    {"mousePressAndHoldIntervalChanged(int)", "\1mousePressAndHoldIntervalChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"startDragTimeChanged(int)", "\1startDragTimeChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"startDragDistanceChanged(int)", "\1startDragDistanceChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mouseDoubleClickIntervalChanged(int)", "\1mouseDoubleClickIntervalChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"keyboardInputIntervalChanged(int)", "\1keyboardInputIntervalChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"cursorFlashTimeChanged(int)", "\1cursorFlashTimeChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QStyleHints = {
    & ::QStyleHints::staticMetaObject,
    0,
    signals_QStyleHints,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QStyleHints = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyleHints,
        {SIP_NULLPTR},
        &plugin_QStyleHints
    },
    {
        sipNameNr_QStyleHints,
        {0, 0, 1},
        25, methods_QStyleHints,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QStyleHints,
    cast_QStyleHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
