/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtextureprovider.sip"
#include <qsgtextureprovider.h>
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 185 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 61 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 64 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 70 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 103 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 73 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 76 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitemgrabresult.sip"
#include <qquickitemgrabresult.h>
#line 79 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 82 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 85 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 570 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 88 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 619 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 91 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 592 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 94 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 608 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 97 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 238 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 100 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 726 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 103 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 253 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 106 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 205 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 109 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 384 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 112 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 509 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 115 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 363 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 118 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 121 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 124 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 127 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 442 "sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 130 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 133 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 136 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 139 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 142 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 145 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 150 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 153 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 156 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 159 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 162 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 168 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 171 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 174 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 177 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 180 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 183 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickPaintedItem.cpp"

sipQQuickPaintedItem::sipQQuickPaintedItem( ::QQuickItem*a0):  ::QQuickPaintedItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuickPaintedItem::~sipQQuickPaintedItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQuickPaintedItem::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick_qt_metaobject(sipPySelf,sipType_QQuickPaintedItem);

    return  ::QQuickPaintedItem::metaObject();
}

int sipQQuickPaintedItem::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QQuickPaintedItem::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick_qt_metacall(sipPySelf,sipType_QQuickPaintedItem,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQuickPaintedItem::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick_qt_metacast(sipPySelf, sipType_QQuickPaintedItem, _clname, &sipCpp) ? sipCpp :  ::QQuickPaintedItem::qt_metacast(_clname));
}

void sipQQuickPaintedItem::paint( ::QPainter*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,sipName_QQuickPaintedItem,sipName_paint);

    if (!sipMeth)
        return;

    extern void sipVH_QtQuick_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPainter*);

    sipVH_QtQuick_41(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtQuick_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtQuick_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtQuick_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickPaintedItem::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QQuickPaintedItem::eventFilter(a0,a1);

    extern bool sipVH_QtQuick_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtQuick_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQQuickPaintedItem::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QQuickPaintedItem::event(a0);

    extern bool sipVH_QtQuick_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtQuick_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::componentComplete()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_componentComplete);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::componentComplete();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuickPaintedItem::classBegin()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_classBegin);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::classBegin();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQQuickPaintedItem::contains(const  ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[10]),sipPySelf,SIP_NULLPTR,sipName_contains);

    if (!sipMeth)
        return  ::QQuickPaintedItem::contains(a0);

    extern bool sipVH_QtQuick_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QPointF&);

    return sipVH_QtQuick_7(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QVariant sipQQuickPaintedItem::inputMethodQuery( ::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[11]),sipPySelf,SIP_NULLPTR,sipName_inputMethodQuery);

    if (!sipMeth)
        return  ::QQuickPaintedItem::inputMethodQuery(a0);

    extern  ::QVariant sipVH_QtQuick_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::Qt::InputMethodQuery);

    return sipVH_QtQuick_8(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickPaintedItem::isTextureProvider() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[12]),sipPySelf,SIP_NULLPTR,sipName_isTextureProvider);

    if (!sipMeth)
        return  ::QQuickPaintedItem::isTextureProvider();

    extern bool sipVH_QtQuick_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_9(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSGTextureProvider* sipQQuickPaintedItem::textureProvider() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[13]),sipPySelf,SIP_NULLPTR,sipName_textureProvider);

    if (!sipMeth)
        return  ::QQuickPaintedItem::textureProvider();

    extern  ::QSGTextureProvider* sipVH_QtQuick_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_10(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuickPaintedItem::itemChange( ::QQuickItem::ItemChange a0,const  ::QQuickItem::ItemChangeData& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_itemChange);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::itemChange(a0,a1);
        return;
    }

    extern void sipVH_QtQuick_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQuickItem::ItemChange,const  ::QQuickItem::ItemChangeData&);

    sipVH_QtQuick_11(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQuickPaintedItem::keyPressEvent( ::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_keyPressEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QKeyEvent*);

    sipVH_QtQuick_12(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::keyReleaseEvent( ::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_keyReleaseEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QKeyEvent*);

    sipVH_QtQuick_12(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::inputMethodEvent( ::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[17],sipPySelf,SIP_NULLPTR,sipName_inputMethodEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QInputMethodEvent*);

    sipVH_QtQuick_13(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::focusInEvent( ::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_focusInEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QFocusEvent*);

    sipVH_QtQuick_14(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::focusOutEvent( ::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[19],sipPySelf,SIP_NULLPTR,sipName_focusOutEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QFocusEvent*);

    sipVH_QtQuick_14(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::mousePressEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_mousePressEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtQuick_15(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::mouseMoveEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[21],sipPySelf,SIP_NULLPTR,sipName_mouseMoveEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtQuick_15(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::mouseReleaseEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[22],sipPySelf,SIP_NULLPTR,sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtQuick_15(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::mouseDoubleClickEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtQuick_15(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::mouseUngrabEvent()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_mouseUngrabEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::mouseUngrabEvent();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuickPaintedItem::touchUngrabEvent()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_touchUngrabEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::touchUngrabEvent();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuickPaintedItem::wheelEvent( ::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,SIP_NULLPTR,sipName_wheelEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QWheelEvent*);

    sipVH_QtQuick_16(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::touchEvent( ::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[27],sipPySelf,SIP_NULLPTR,sipName_touchEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::touchEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTouchEvent*);

    sipVH_QtQuick_17(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::hoverEnterEvent( ::QHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[28],sipPySelf,SIP_NULLPTR,sipName_hoverEnterEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QHoverEvent*);

    sipVH_QtQuick_18(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::hoverMoveEvent( ::QHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[29],sipPySelf,SIP_NULLPTR,sipName_hoverMoveEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QHoverEvent*);

    sipVH_QtQuick_18(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::hoverLeaveEvent( ::QHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[30],sipPySelf,SIP_NULLPTR,sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QHoverEvent*);

    sipVH_QtQuick_18(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::dragEnterEvent( ::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[31],sipPySelf,SIP_NULLPTR,sipName_dragEnterEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragEnterEvent*);

    sipVH_QtQuick_19(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::dragMoveEvent( ::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[32],sipPySelf,SIP_NULLPTR,sipName_dragMoveEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragMoveEvent*);

    sipVH_QtQuick_20(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::dragLeaveEvent( ::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[33],sipPySelf,SIP_NULLPTR,sipName_dragLeaveEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragLeaveEvent*);

    sipVH_QtQuick_21(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickPaintedItem::dropEvent( ::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[34],sipPySelf,SIP_NULLPTR,sipName_dropEvent);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::dropEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDropEvent*);

    sipVH_QtQuick_22(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQuickPaintedItem::childMouseEventFilter( ::QQuickItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[35],sipPySelf,SIP_NULLPTR,sipName_childMouseEventFilter);

    if (!sipMeth)
        return  ::QQuickPaintedItem::childMouseEventFilter(a0,a1);

    extern bool sipVH_QtQuick_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQuickItem*, ::QEvent*);

    return sipVH_QtQuick_23(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQuickPaintedItem::geometryChanged(const  ::QRectF& a0,const  ::QRectF& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[36],sipPySelf,SIP_NULLPTR,sipName_geometryChanged);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::geometryChanged(a0,a1);
        return;
    }

    extern void sipVH_QtQuick_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QRectF&,const  ::QRectF&);

    sipVH_QtQuick_24(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::QSGNode* sipQQuickPaintedItem::updatePaintNode( ::QSGNode*a0, ::QQuickItem::UpdatePaintNodeData*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[37],sipPySelf,SIP_NULLPTR,sipName_updatePaintNode);

    if (!sipMeth)
        return  ::QQuickPaintedItem::updatePaintNode(a0,a1);

    extern  ::QSGNode* sipVH_QtQuick_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSGNode*, ::QQuickItem::UpdatePaintNodeData*);

    return sipVH_QtQuick_25(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQuickPaintedItem::releaseResources()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[38],sipPySelf,SIP_NULLPTR,sipName_releaseResources);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::releaseResources();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQuickPaintedItem::updatePolish()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[39],sipPySelf,SIP_NULLPTR,sipName_updatePolish);

    if (!sipMeth)
    {
         ::QQuickPaintedItem::updatePolish();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QQuickPaintedItem_update, "update(self, rect: QRect = QRect())");

extern "C" {static PyObject *meth_QQuickPaintedItem_update(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_update(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect& a0def = QRect();
        const  ::QRect* a0 = &a0def;
         ::QQuickPaintedItem *sipCpp;

        static const char *sipKwdList[] = {
            sipName_rect,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->update(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_update, doc_QQuickPaintedItem_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_opaquePainting, "opaquePainting(self) -> bool");

extern "C" {static PyObject *meth_QQuickPaintedItem_opaquePainting(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_opaquePainting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->opaquePainting();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_opaquePainting, doc_QQuickPaintedItem_opaquePainting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setOpaquePainting, "setOpaquePainting(self, bool)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setOpaquePainting(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setOpaquePainting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, &a0))
        {
            sipCpp->setOpaquePainting(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setOpaquePainting, doc_QQuickPaintedItem_setOpaquePainting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_antialiasing, "antialiasing(self) -> bool");

extern "C" {static PyObject *meth_QQuickPaintedItem_antialiasing(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_antialiasing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->antialiasing();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_antialiasing, doc_QQuickPaintedItem_antialiasing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setAntialiasing, "setAntialiasing(self, bool)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setAntialiasing(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setAntialiasing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, &a0))
        {
            sipCpp->setAntialiasing(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setAntialiasing, doc_QQuickPaintedItem_setAntialiasing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_mipmap, "mipmap(self) -> bool");

extern "C" {static PyObject *meth_QQuickPaintedItem_mipmap(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_mipmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->mipmap();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_mipmap, doc_QQuickPaintedItem_mipmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setMipmap, "setMipmap(self, bool)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setMipmap(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setMipmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, &a0))
        {
            sipCpp->setMipmap(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setMipmap, doc_QQuickPaintedItem_setMipmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_performanceHints, "performanceHints(self) -> QQuickPaintedItem.PerformanceHints");

extern "C" {static PyObject *meth_QQuickPaintedItem_performanceHints(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_performanceHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QQuickPaintedItem::PerformanceHints*sipRes;

            sipRes = new  ::QQuickPaintedItem::PerformanceHints(sipCpp->performanceHints());

            return sipConvertFromNewType(sipRes,sipType_QQuickPaintedItem_PerformanceHints,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_performanceHints, doc_QQuickPaintedItem_performanceHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setPerformanceHint, "setPerformanceHint(self, QQuickPaintedItem.PerformanceHint, enabled: bool = True)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setPerformanceHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setPerformanceHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickPaintedItem::PerformanceHint a0;
        bool a1 = 1;
         ::QQuickPaintedItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QQuickPaintedItem_PerformanceHint, &a0, &a1))
        {
            sipCpp->setPerformanceHint(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setPerformanceHint, doc_QQuickPaintedItem_setPerformanceHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setPerformanceHints, "setPerformanceHints(self, Union[QQuickPaintedItem.PerformanceHints, QQuickPaintedItem.PerformanceHint])");

extern "C" {static PyObject *meth_QQuickPaintedItem_setPerformanceHints(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setPerformanceHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickPaintedItem::PerformanceHints* a0;
        int a0State = 0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QQuickPaintedItem_PerformanceHints, &a0, &a0State))
        {
            sipCpp->setPerformanceHints(*a0);
            sipReleaseType(a0,sipType_QQuickPaintedItem_PerformanceHints,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setPerformanceHints, doc_QQuickPaintedItem_setPerformanceHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_contentsBoundingRect, "contentsBoundingRect(self) -> QRectF");

extern "C" {static PyObject *meth_QQuickPaintedItem_contentsBoundingRect(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_contentsBoundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF(sipCpp->contentsBoundingRect());

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_contentsBoundingRect, doc_QQuickPaintedItem_contentsBoundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_contentsSize, "contentsSize(self) -> QSize");

extern "C" {static PyObject *meth_QQuickPaintedItem_contentsSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_contentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->contentsSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_contentsSize, doc_QQuickPaintedItem_contentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setContentsSize, "setContentsSize(self, QSize)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setContentsSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setContentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setContentsSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setContentsSize, doc_QQuickPaintedItem_setContentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_resetContentsSize, "resetContentsSize(self)");

extern "C" {static PyObject *meth_QQuickPaintedItem_resetContentsSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_resetContentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            sipCpp->resetContentsSize();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_resetContentsSize, doc_QQuickPaintedItem_resetContentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_contentsScale, "contentsScale(self) -> float");

extern "C" {static PyObject *meth_QQuickPaintedItem_contentsScale(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_contentsScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->contentsScale();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_contentsScale, doc_QQuickPaintedItem_contentsScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setContentsScale, "setContentsScale(self, float)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setContentsScale(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setContentsScale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, &a0))
        {
            sipCpp->setContentsScale(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setContentsScale, doc_QQuickPaintedItem_setContentsScale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_fillColor, "fillColor(self) -> QColor");

extern "C" {static PyObject *meth_QQuickPaintedItem_fillColor(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_fillColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QColor*sipRes;

            sipRes = new  ::QColor(sipCpp->fillColor());

            return sipConvertFromNewType(sipRes,sipType_QColor,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_fillColor, doc_QQuickPaintedItem_fillColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setFillColor, "setFillColor(self, Union[QColor, Qt.GlobalColor])");

extern "C" {static PyObject *meth_QQuickPaintedItem_setFillColor(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setFillColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColor* a0;
        int a0State = 0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setFillColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0),sipType_QColor,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setFillColor, doc_QQuickPaintedItem_setFillColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_renderTarget, "renderTarget(self) -> QQuickPaintedItem.RenderTarget");

extern "C" {static PyObject *meth_QQuickPaintedItem_renderTarget(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_renderTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QQuickPaintedItem::RenderTarget sipRes;

            sipRes = sipCpp->renderTarget();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQuickPaintedItem_RenderTarget);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_renderTarget, doc_QQuickPaintedItem_renderTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setRenderTarget, "setRenderTarget(self, QQuickPaintedItem.RenderTarget)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setRenderTarget(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setRenderTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickPaintedItem::RenderTarget a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QQuickPaintedItem_RenderTarget, &a0))
        {
            sipCpp->setRenderTarget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setRenderTarget, doc_QQuickPaintedItem_setRenderTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_paint, "paint(self, QPainter)");

extern "C" {static PyObject *meth_QQuickPaintedItem_paint(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_paint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QPainter* a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QPainter, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQuickPaintedItem, sipName_paint);
                return SIP_NULLPTR;
            }

            sipCpp->paint(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_paint, doc_QQuickPaintedItem_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_updatePaintNode, "updatePaintNode(self, QSGNode, QQuickItem.UpdatePaintNodeData) -> QSGNode");

extern "C" {static PyObject *meth_QQuickPaintedItem_updatePaintNode(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_updatePaintNode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSGNode* a0;
         ::QQuickItem::UpdatePaintNodeData* a1;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QSGNode, &a0, sipType_QQuickItem_UpdatePaintNodeData, &a1))
        {
             ::QSGNode*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQuickPaintedItem::updatePaintNode(a0,a1) : sipCpp->updatePaintNode(a0,a1));

            return sipConvertFromType(sipRes,sipType_QSGNode,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_updatePaintNode, doc_QQuickPaintedItem_updatePaintNode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_isTextureProvider, "isTextureProvider(self) -> bool");

extern "C" {static PyObject *meth_QQuickPaintedItem_isTextureProvider(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_isTextureProvider(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQuickPaintedItem::isTextureProvider() : sipCpp->isTextureProvider());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_isTextureProvider, doc_QQuickPaintedItem_isTextureProvider);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_textureProvider, "textureProvider(self) -> QSGTextureProvider");

extern "C" {static PyObject *meth_QQuickPaintedItem_textureProvider(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_textureProvider(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QSGTextureProvider*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQuickPaintedItem::textureProvider() : sipCpp->textureProvider());

            return sipConvertFromType(sipRes,sipType_QSGTextureProvider,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_textureProvider, doc_QQuickPaintedItem_textureProvider);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_releaseResources, "releaseResources(self)");

extern "C" {static PyObject *meth_QQuickPaintedItem_releaseResources(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_releaseResources(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QQuickPaintedItem::releaseResources() : sipCpp->releaseResources());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_releaseResources, doc_QQuickPaintedItem_releaseResources);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_itemChange, "itemChange(self, QQuickItem.ItemChange, QQuickItem.ItemChangeData)");

extern "C" {static PyObject *meth_QQuickPaintedItem_itemChange(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_itemChange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQuickItem::ItemChange a0;
        const  ::QQuickItem::ItemChangeData* a1;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ9", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QQuickItem_ItemChange, &a0, sipType_QQuickItem_ItemChangeData, &a1))
        {
            (sipSelfWasArg ? sipCpp-> ::QQuickPaintedItem::itemChange(a0,*a1) : sipCpp->itemChange(a0,*a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_itemChange, doc_QQuickPaintedItem_itemChange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_textureSize, "textureSize(self) -> QSize");

extern "C" {static PyObject *meth_QQuickPaintedItem_textureSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_textureSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQuickPaintedItem, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->textureSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_textureSize, doc_QQuickPaintedItem_textureSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickPaintedItem_setTextureSize, "setTextureSize(self, QSize)");

extern "C" {static PyObject *meth_QQuickPaintedItem_setTextureSize(PyObject *, PyObject *);}
static PyObject *meth_QQuickPaintedItem_setTextureSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QQuickPaintedItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQuickPaintedItem, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setTextureSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQuickPaintedItem, sipName_setTextureSize, doc_QQuickPaintedItem_setTextureSize);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQuickPaintedItem(void *, const sipTypeDef *);}
static void *cast_QQuickPaintedItem(void *sipCppV, const sipTypeDef *targetType)
{
     ::QQuickPaintedItem *sipCpp = reinterpret_cast< ::QQuickPaintedItem *>(sipCppV);

    if (targetType == sipType_QQuickItem)
        return static_cast< ::QQuickItem *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QQmlParserStatus)
        return static_cast< ::QQmlParserStatus *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickPaintedItem(void *, int);}
static void release_QQuickPaintedItem(void *sipCppV, int)
{
     ::QQuickPaintedItem *sipCpp = reinterpret_cast< ::QQuickPaintedItem *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQuickPaintedItem(sipSimpleWrapper *);}
static void dealloc_QQuickPaintedItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuickPaintedItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickPaintedItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuickPaintedItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickPaintedItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQuickPaintedItem *sipCpp = SIP_NULLPTR;

    {
         ::QQuickItem* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QQuickItem, &a0, sipOwner))
        {
            sipCpp = new sipQQuickPaintedItem(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQuickPaintedItem[] = {{7, 255, 1}};


static PyMethodDef methods_QQuickPaintedItem[] = {
    {SIP_MLNAME_CAST(sipName_antialiasing), meth_QQuickPaintedItem_antialiasing, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_antialiasing)},
    {SIP_MLNAME_CAST(sipName_contentsBoundingRect), meth_QQuickPaintedItem_contentsBoundingRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_contentsBoundingRect)},
    {SIP_MLNAME_CAST(sipName_contentsScale), meth_QQuickPaintedItem_contentsScale, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_contentsScale)},
    {SIP_MLNAME_CAST(sipName_contentsSize), meth_QQuickPaintedItem_contentsSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_contentsSize)},
    {SIP_MLNAME_CAST(sipName_fillColor), meth_QQuickPaintedItem_fillColor, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_fillColor)},
    {SIP_MLNAME_CAST(sipName_isTextureProvider), meth_QQuickPaintedItem_isTextureProvider, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_isTextureProvider)},
    {SIP_MLNAME_CAST(sipName_itemChange), meth_QQuickPaintedItem_itemChange, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_itemChange)},
    {SIP_MLNAME_CAST(sipName_mipmap), meth_QQuickPaintedItem_mipmap, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_mipmap)},
    {SIP_MLNAME_CAST(sipName_opaquePainting), meth_QQuickPaintedItem_opaquePainting, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_opaquePainting)},
    {SIP_MLNAME_CAST(sipName_paint), meth_QQuickPaintedItem_paint, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_paint)},
    {SIP_MLNAME_CAST(sipName_performanceHints), meth_QQuickPaintedItem_performanceHints, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_performanceHints)},
    {SIP_MLNAME_CAST(sipName_releaseResources), meth_QQuickPaintedItem_releaseResources, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_releaseResources)},
    {SIP_MLNAME_CAST(sipName_renderTarget), meth_QQuickPaintedItem_renderTarget, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_renderTarget)},
    {SIP_MLNAME_CAST(sipName_resetContentsSize), meth_QQuickPaintedItem_resetContentsSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_resetContentsSize)},
    {SIP_MLNAME_CAST(sipName_setAntialiasing), meth_QQuickPaintedItem_setAntialiasing, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setAntialiasing)},
    {SIP_MLNAME_CAST(sipName_setContentsScale), meth_QQuickPaintedItem_setContentsScale, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setContentsScale)},
    {SIP_MLNAME_CAST(sipName_setContentsSize), meth_QQuickPaintedItem_setContentsSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setContentsSize)},
    {SIP_MLNAME_CAST(sipName_setFillColor), meth_QQuickPaintedItem_setFillColor, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setFillColor)},
    {SIP_MLNAME_CAST(sipName_setMipmap), meth_QQuickPaintedItem_setMipmap, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setMipmap)},
    {SIP_MLNAME_CAST(sipName_setOpaquePainting), meth_QQuickPaintedItem_setOpaquePainting, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setOpaquePainting)},
    {SIP_MLNAME_CAST(sipName_setPerformanceHint), SIP_MLMETH_CAST(meth_QQuickPaintedItem_setPerformanceHint), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setPerformanceHint)},
    {SIP_MLNAME_CAST(sipName_setPerformanceHints), meth_QQuickPaintedItem_setPerformanceHints, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setPerformanceHints)},
    {SIP_MLNAME_CAST(sipName_setRenderTarget), meth_QQuickPaintedItem_setRenderTarget, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setRenderTarget)},
    {SIP_MLNAME_CAST(sipName_setTextureSize), meth_QQuickPaintedItem_setTextureSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_setTextureSize)},
    {SIP_MLNAME_CAST(sipName_textureProvider), meth_QQuickPaintedItem_textureProvider, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_textureProvider)},
    {SIP_MLNAME_CAST(sipName_textureSize), meth_QQuickPaintedItem_textureSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_textureSize)},
    {SIP_MLNAME_CAST(sipName_update), SIP_MLMETH_CAST(meth_QQuickPaintedItem_update), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_update)},
    {SIP_MLNAME_CAST(sipName_updatePaintNode), meth_QQuickPaintedItem_updatePaintNode, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickPaintedItem_updatePaintNode)}
};

static sipEnumMemberDef enummembers_QQuickPaintedItem[] = {
    {sipName_FastFBOResizing, static_cast<int>( ::QQuickPaintedItem::FastFBOResizing), 16},
    {sipName_FramebufferObject, static_cast<int>( ::QQuickPaintedItem::FramebufferObject), 18},
    {sipName_Image, static_cast<int>( ::QQuickPaintedItem::Image), 18},
    {sipName_InvertedYFramebufferObject, static_cast<int>( ::QQuickPaintedItem::InvertedYFramebufferObject), 18},
};

PyDoc_STRVAR(doc_QQuickPaintedItem, "\1QQuickPaintedItem(parent: QQuickItem = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QQuickPaintedItem[] = {
    {"textureSizeChanged()", "\1textureSizeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"renderTargetChanged()", "\1renderTargetChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"contentsScaleChanged()", "\1contentsScaleChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"contentsSizeChanged()", "\1contentsSizeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"fillColorChanged()", "\1fillColorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QQuickPaintedItem = {
    & ::QQuickPaintedItem::staticMetaObject,
    0,
    signals_QQuickPaintedItem,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickPaintedItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickPaintedItem,
        {SIP_NULLPTR},
        &plugin_QQuickPaintedItem
    },
    {
        sipNameNr_QQuickPaintedItem,
        {0, 0, 1},
        28, methods_QQuickPaintedItem,
        4, enummembers_QQuickPaintedItem,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickPaintedItem,
    -1,
    -1,
    supers_QQuickPaintedItem,
    SIP_NULLPTR,
    init_type_QQuickPaintedItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQuickPaintedItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuickPaintedItem,
    cast_QQuickPaintedItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
