/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 263 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#include <qpair.h>
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 49 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 61 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 64 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 70 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 73 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 102 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 108 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 111 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkReply.cpp"


class sipQNetworkReply : public  ::QNetworkReply
{
public:
    sipQNetworkReply( ::QObject*);
    virtual ~sipQNetworkReply();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void ignoreSslErrorsImplementation(const QList< ::QSslError>&) SIP_OVERRIDE;
    void setSslConfigurationImplementation(const  ::QSslConfiguration&) SIP_OVERRIDE;
    void sslConfigurationImplementation( ::QSslConfiguration&) const SIP_OVERRIDE;
    void ignoreSslErrors() SIP_OVERRIDE;
    void setReadBufferSize( ::qint64) SIP_OVERRIDE;
    void abort() SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool isSequential() const SIP_OVERRIDE;
    bool open( ::QIODevice::OpenMode) SIP_OVERRIDE;
    void close() SIP_OVERRIDE;
     ::qint64 pos() const SIP_OVERRIDE;
     ::qint64 size() const SIP_OVERRIDE;
    bool seek( ::qint64) SIP_OVERRIDE;
    bool atEnd() const SIP_OVERRIDE;
    bool reset() SIP_OVERRIDE;
     ::qint64 bytesAvailable() const SIP_OVERRIDE;
     ::qint64 bytesToWrite() const SIP_OVERRIDE;
    bool canReadLine() const SIP_OVERRIDE;
    bool waitForReadyRead(int) SIP_OVERRIDE;
    bool waitForBytesWritten(int) SIP_OVERRIDE;
     ::qint64 readData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 readLineData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 writeData(const char*,PY_LONG_LONG) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNetworkReply(const sipQNetworkReply &);
    sipQNetworkReply &operator = (const sipQNetworkReply &);

    char sipPyMethods[29];
};

sipQNetworkReply::sipQNetworkReply( ::QObject*a0):  ::QNetworkReply(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNetworkReply::~sipQNetworkReply()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNetworkReply::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf,sipType_QNetworkReply);

    return  ::QNetworkReply::metaObject();
}

int sipQNetworkReply::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QNetworkReply::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf,sipType_QNetworkReply,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNetworkReply::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QNetworkReply, _clname, &sipCpp) ? sipCpp :  ::QNetworkReply::qt_metacast(_clname));
}

void sipQNetworkReply::ignoreSslErrorsImplementation(const QList< ::QSslError>& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_ignoreSslErrorsImplementation);

    if (!sipMeth)
    {
         ::QNetworkReply::ignoreSslErrorsImplementation(a0);
        return;
    }

    extern void sipVH_QtNetwork_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const QList< ::QSslError>&);

    sipVH_QtNetwork_38(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::setSslConfigurationImplementation(const  ::QSslConfiguration& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_setSslConfigurationImplementation);

    if (!sipMeth)
    {
         ::QNetworkReply::setSslConfigurationImplementation(a0);
        return;
    }

    extern void sipVH_QtNetwork_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QSslConfiguration&);

    sipVH_QtNetwork_37(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::sslConfigurationImplementation( ::QSslConfiguration& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,SIP_NULLPTR,sipName_sslConfigurationImplementation);

    if (!sipMeth)
    {
         ::QNetworkReply::sslConfigurationImplementation(a0);
        return;
    }

    extern void sipVH_QtNetwork_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSslConfiguration&);

    sipVH_QtNetwork_36(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::ignoreSslErrors()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_ignoreSslErrors);

    if (!sipMeth)
    {
         ::QNetworkReply::ignoreSslErrors();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNetworkReply::setReadBufferSize( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_setReadBufferSize);

    if (!sipMeth)
    {
         ::QNetworkReply::setReadBufferSize(a0);
        return;
    }

    extern void sipVH_QtNetwork_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    sipVH_QtNetwork_23(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::abort()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,sipName_QNetworkReply,sipName_abort);

    if (!sipMeth)
        return;

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQNetworkReply::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QNetworkReply::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QNetworkReply::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QNetworkReply::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QNetworkReply::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QNetworkReply::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNetworkReply::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QNetworkReply::eventFilter(a0,a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQNetworkReply::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QNetworkReply::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNetworkReply::isSequential() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[13]),sipPySelf,SIP_NULLPTR,sipName_isSequential);

    if (!sipMeth)
        return  ::QNetworkReply::isSequential();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNetworkReply::open( ::QIODevice::OpenMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_open);

    if (!sipMeth)
        return  ::QNetworkReply::open(a0);

    extern bool sipVH_QtNetwork_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QIODevice::OpenMode);

    return sipVH_QtNetwork_20(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkReply::close()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_close);

    if (!sipMeth)
    {
         ::QNetworkReply::close();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQNetworkReply::pos() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[16]),sipPySelf,SIP_NULLPTR,sipName_pos);

    if (!sipMeth)
        return  ::QNetworkReply::pos();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQNetworkReply::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[17]),sipPySelf,SIP_NULLPTR,sipName_size);

    if (!sipMeth)
        return  ::QNetworkReply::size();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNetworkReply::seek( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_seek);

    if (!sipMeth)
        return  ::QNetworkReply::seek(a0);

    extern bool sipVH_QtNetwork_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    return sipVH_QtNetwork_19(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNetworkReply::atEnd() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[19]),sipPySelf,SIP_NULLPTR,sipName_atEnd);

    if (!sipMeth)
        return  ::QNetworkReply::atEnd();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNetworkReply::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_reset);

    if (!sipMeth)
        return  ::QNetworkReply::reset();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQNetworkReply::bytesAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[21]),sipPySelf,SIP_NULLPTR,sipName_bytesAvailable);

    if (!sipMeth)
        return  ::QNetworkReply::bytesAvailable();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQNetworkReply::bytesToWrite() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[22]),sipPySelf,SIP_NULLPTR,sipName_bytesToWrite);

    if (!sipMeth)
        return  ::QNetworkReply::bytesToWrite();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNetworkReply::canReadLine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[23]),sipPySelf,SIP_NULLPTR,sipName_canReadLine);

    if (!sipMeth)
        return  ::QNetworkReply::canReadLine();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQNetworkReply::waitForReadyRead(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_waitForReadyRead);

    if (!sipMeth)
        return  ::QNetworkReply::waitForReadyRead(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNetworkReply::waitForBytesWritten(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_waitForBytesWritten);

    if (!sipMeth)
        return  ::QNetworkReply::waitForBytesWritten(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::qint64 sipQNetworkReply::readData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,sipName_QNetworkReply,sipName_readData);

    if (!sipMeth)
        return 0;

    extern  ::qint64 sipVH_QtNetwork_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_16(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQNetworkReply::readLineData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[27],sipPySelf,SIP_NULLPTR,sipName_readLineData);

    if (!sipMeth)
        return  ::QNetworkReply::readLineData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_15(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQNetworkReply::writeData(const char*a0,PY_LONG_LONG a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[28],sipPySelf,SIP_NULLPTR,sipName_writeData);

    if (!sipMeth)
        return  ::QNetworkReply::writeData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*,PY_LONG_LONG);

    return sipVH_QtNetwork_14(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}


PyDoc_STRVAR(doc_QNetworkReply_abort, "abort(self)");

extern "C" {static PyObject *meth_QNetworkReply_abort(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QNetworkReply, sipName_abort);
                return SIP_NULLPTR;
            }

            sipCpp->abort();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_abort, doc_QNetworkReply_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_close, "close(self)");

extern "C" {static PyObject *meth_QNetworkReply_close(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::close() : sipCpp->close());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_close, doc_QNetworkReply_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_isSequential, "isSequential(self) -> bool");

extern "C" {static PyObject *meth_QNetworkReply_isSequential(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_isSequential(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QNetworkReply::isSequential() : sipCpp->isSequential());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_isSequential, doc_QNetworkReply_isSequential);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_readBufferSize, "readBufferSize(self) -> int");

extern "C" {static PyObject *meth_QNetworkReply_readBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_readBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->readBufferSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_readBufferSize, doc_QNetworkReply_readBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setReadBufferSize, "setReadBufferSize(self, int)");

extern "C" {static PyObject *meth_QNetworkReply_setReadBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setReadBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QNetworkReply, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::setReadBufferSize(a0) : sipCpp->setReadBufferSize(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setReadBufferSize, doc_QNetworkReply_setReadBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_manager, "manager(self) -> QNetworkAccessManager");

extern "C" {static PyObject *meth_QNetworkReply_manager(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_manager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QNetworkAccessManager*sipRes;

            sipRes = sipCpp->manager();

            return sipConvertFromType(sipRes,sipType_QNetworkAccessManager,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_manager, doc_QNetworkReply_manager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_operation, "operation(self) -> QNetworkAccessManager.Operation");

extern "C" {static PyObject *meth_QNetworkReply_operation(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_operation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QNetworkAccessManager::Operation sipRes;

            sipRes = sipCpp->operation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNetworkAccessManager_Operation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_operation, doc_QNetworkReply_operation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_request, "request(self) -> QNetworkRequest");

extern "C" {static PyObject *meth_QNetworkReply_request(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_request(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QNetworkRequest*sipRes;

            sipRes = new  ::QNetworkRequest(sipCpp->request());

            return sipConvertFromNewType(sipRes,sipType_QNetworkRequest,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_request, doc_QNetworkReply_request);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_error, "error(self) -> QNetworkReply.NetworkError");

extern "C" {static PyObject *meth_QNetworkReply_error(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QNetworkReply::NetworkError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNetworkReply_NetworkError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_error, doc_QNetworkReply_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QNetworkReply_url(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_url, doc_QNetworkReply_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_header, "header(self, QNetworkRequest.KnownHeaders) -> Any");

extern "C" {static PyObject *meth_QNetworkReply_header(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_header(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkRequest::KnownHeaders a0;
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkRequest_KnownHeaders, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant(sipCpp->header(a0));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_header, doc_QNetworkReply_header);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_hasRawHeader, "hasRawHeader(self, Union[QByteArray, bytes, bytearray]) -> bool");

extern "C" {static PyObject *meth_QNetworkReply_hasRawHeader(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_hasRawHeader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasRawHeader(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_hasRawHeader, doc_QNetworkReply_hasRawHeader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_rawHeaderList, "rawHeaderList(self) -> List[QByteArray]");

extern "C" {static PyObject *meth_QNetworkReply_rawHeaderList(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_rawHeaderList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(sipCpp->rawHeaderList());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_rawHeaderList, doc_QNetworkReply_rawHeaderList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_rawHeader, "rawHeader(self, Union[QByteArray, bytes, bytearray]) -> QByteArray");

extern "C" {static PyObject *meth_QNetworkReply_rawHeader(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_rawHeader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray(sipCpp->rawHeader(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_rawHeader, doc_QNetworkReply_rawHeader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_attribute, "attribute(self, QNetworkRequest.Attribute) -> Any");

extern "C" {static PyObject *meth_QNetworkReply_attribute(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_attribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkRequest::Attribute a0;
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkRequest_Attribute, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant(sipCpp->attribute(a0));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_attribute, doc_QNetworkReply_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_sslConfiguration, "sslConfiguration(self) -> QSslConfiguration");

extern "C" {static PyObject *meth_QNetworkReply_sslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_sslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
             ::QSslConfiguration*sipRes;

            sipRes = new  ::QSslConfiguration(sipCpp->sslConfiguration());

            return sipConvertFromNewType(sipRes,sipType_QSslConfiguration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_sslConfiguration, doc_QNetworkReply_sslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setSslConfiguration, "setSslConfiguration(self, QSslConfiguration)");

extern "C" {static PyObject *meth_QNetworkReply_setSslConfiguration(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setSslConfiguration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSslConfiguration* a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            sipCpp->setSslConfiguration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setSslConfiguration, doc_QNetworkReply_setSslConfiguration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_ignoreSslErrors, "ignoreSslErrors(self)\n"
"ignoreSslErrors(self, Iterable[QSslError])");

extern "C" {static PyObject *meth_QNetworkReply_ignoreSslErrors(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_ignoreSslErrors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::ignoreSslErrors() : sipCpp->ignoreSslErrors());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const QList< ::QSslError>* a0;
        int a0State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QList_0100QSslError,&a0, &a0State))
        {
            sipCpp->ignoreSslErrors(*a0);
            sipReleaseType(const_cast<QList< ::QSslError> *>(a0),sipType_QList_0100QSslError,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_ignoreSslErrors, doc_QNetworkReply_ignoreSslErrors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_writeData, "writeData(self, bytes) -> int");

extern "C" {static PyObject *meth_QNetworkReply_writeData(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_writeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        SIP_SSIZE_T a1;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pk", &sipSelf, sipType_QNetworkReply, &sipCpp, &a0, &a1))
        {
             ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QNetworkReply::writeData(a0,(PY_LONG_LONG)a1) : sipCpp->writeData(a0,(PY_LONG_LONG)a1));
            Py_END_ALLOW_THREADS

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_writeData, doc_QNetworkReply_writeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setOperation, "setOperation(self, QNetworkAccessManager.Operation)");

extern "C" {static PyObject *meth_QNetworkReply_setOperation(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setOperation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkAccessManager::Operation a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkAccessManager_Operation, &a0))
        {
            sipCpp->setOperation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setOperation, doc_QNetworkReply_setOperation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setRequest, "setRequest(self, QNetworkRequest)");

extern "C" {static PyObject *meth_QNetworkReply_setRequest(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setRequest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkRequest* a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkRequest, &a0))
        {
            sipCpp->setRequest(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setRequest, doc_QNetworkReply_setRequest);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setError, "setError(self, QNetworkReply.NetworkError, str)");

extern "C" {static PyObject *meth_QNetworkReply_setError(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkReply::NetworkError a0;
        const  ::QString* a1;
        int a1State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkReply_NetworkError, &a0, sipType_QString,&a1, &a1State))
        {
            sipCpp->setError(a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setError, doc_QNetworkReply_setError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setUrl, "setUrl(self, QUrl)");

extern "C" {static PyObject *meth_QNetworkReply_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setUrl, doc_QNetworkReply_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setHeader, "setHeader(self, QNetworkRequest.KnownHeaders, Any)");

extern "C" {static PyObject *meth_QNetworkReply_setHeader(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setHeader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkRequest::KnownHeaders a0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkRequest_KnownHeaders, &a0, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setHeader(a0,*a1);
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setHeader, doc_QNetworkReply_setHeader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setRawHeader, "setRawHeader(self, Union[QByteArray, bytes, bytearray], Union[QByteArray, bytes, bytearray])");

extern "C" {static PyObject *meth_QNetworkReply_setRawHeader(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setRawHeader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const  ::QByteArray* a1;
        int a1State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1J1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QByteArray, &a1, &a1State))
        {
            sipCpp->setRawHeader(*a0,*a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1),sipType_QByteArray,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setRawHeader, doc_QNetworkReply_setRawHeader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setAttribute, "setAttribute(self, QNetworkRequest.Attribute, Any)");

extern "C" {static PyObject *meth_QNetworkReply_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkRequest::Attribute a0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QNetworkRequest_Attribute, &a0, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setAttribute(a0,*a1);
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setAttribute, doc_QNetworkReply_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setFinished, "setFinished(self, bool)");

extern "C" {static PyObject *meth_QNetworkReply_setFinished(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setFinished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QNetworkReply, &sipCpp, &a0))
        {
            sipCpp->setFinished(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setFinished, doc_QNetworkReply_setFinished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_isFinished, "isFinished(self) -> bool");

extern "C" {static PyObject *meth_QNetworkReply_isFinished(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_isFinished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFinished();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_isFinished, doc_QNetworkReply_isFinished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_isRunning, "isRunning(self) -> bool");

extern "C" {static PyObject *meth_QNetworkReply_isRunning(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_isRunning(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRunning();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_isRunning, doc_QNetworkReply_isRunning);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_rawHeaderPairs, "rawHeaderPairs(self) -> List[Tuple[QByteArray, QByteArray]]");

extern "C" {static PyObject *meth_QNetworkReply_rawHeaderPairs(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_rawHeaderPairs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkReply, &sipCpp))
        {
            QList<QPair<QByteArray,QByteArray> >*sipRes;

            sipRes = new QList<QPair<QByteArray,QByteArray> >(sipCpp->rawHeaderPairs());

            return sipConvertFromNewType(sipRes,sipType_QList_0600QPair_0100QByteArray_0100QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_rawHeaderPairs, doc_QNetworkReply_rawHeaderPairs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_sslConfigurationImplementation, "sslConfigurationImplementation(self, QSslConfiguration)");

extern "C" {static PyObject *meth_QNetworkReply_sslConfigurationImplementation(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_sslConfigurationImplementation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSslConfiguration* a0;
        const  ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::sslConfigurationImplementation(*a0) : sipCpp->sslConfigurationImplementation(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_sslConfigurationImplementation, doc_QNetworkReply_sslConfigurationImplementation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_setSslConfigurationImplementation, "setSslConfigurationImplementation(self, QSslConfiguration)");

extern "C" {static PyObject *meth_QNetworkReply_setSslConfigurationImplementation(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_setSslConfigurationImplementation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSslConfiguration* a0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QSslConfiguration, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::setSslConfigurationImplementation(*a0) : sipCpp->setSslConfigurationImplementation(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_setSslConfigurationImplementation, doc_QNetworkReply_setSslConfigurationImplementation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkReply_ignoreSslErrorsImplementation, "ignoreSslErrorsImplementation(self, Iterable[QSslError])");

extern "C" {static PyObject *meth_QNetworkReply_ignoreSslErrorsImplementation(PyObject *, PyObject *);}
static PyObject *meth_QNetworkReply_ignoreSslErrorsImplementation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const QList< ::QSslError>* a0;
        int a0State = 0;
         ::QNetworkReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QNetworkReply, &sipCpp, sipType_QList_0100QSslError,&a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkReply::ignoreSslErrorsImplementation(*a0) : sipCpp->ignoreSslErrorsImplementation(*a0));
            sipReleaseType(const_cast<QList< ::QSslError> *>(a0),sipType_QList_0100QSslError,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkReply, sipName_ignoreSslErrorsImplementation, doc_QNetworkReply_ignoreSslErrorsImplementation);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNetworkReply(void *, const sipTypeDef *);}
static void *cast_QNetworkReply(void *sipCppV, const sipTypeDef *targetType)
{
     ::QNetworkReply *sipCpp = reinterpret_cast< ::QNetworkReply *>(sipCppV);

    if (targetType == sipType_QIODevice)
        return static_cast< ::QIODevice *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNetworkReply(void *, int);}
static void release_QNetworkReply(void *sipCppV, int)
{
     ::QNetworkReply *sipCpp = reinterpret_cast< ::QNetworkReply *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QNetworkReply(sipSimpleWrapper *);}
static void dealloc_QNetworkReply(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNetworkReply *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNetworkReply(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNetworkReply(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNetworkReply(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNetworkReply *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQNetworkReply(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNetworkReply[] = {{8, 0, 1}};


static PyMethodDef methods_QNetworkReply[] = {
    {SIP_MLNAME_CAST(sipName_abort), meth_QNetworkReply_abort, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_abort)},
    {SIP_MLNAME_CAST(sipName_attribute), meth_QNetworkReply_attribute, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_attribute)},
    {SIP_MLNAME_CAST(sipName_close), meth_QNetworkReply_close, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_close)},
    {SIP_MLNAME_CAST(sipName_error), meth_QNetworkReply_error, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_error)},
    {SIP_MLNAME_CAST(sipName_hasRawHeader), meth_QNetworkReply_hasRawHeader, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_hasRawHeader)},
    {SIP_MLNAME_CAST(sipName_header), meth_QNetworkReply_header, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_header)},
    {SIP_MLNAME_CAST(sipName_ignoreSslErrors), meth_QNetworkReply_ignoreSslErrors, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_ignoreSslErrors)},
    {SIP_MLNAME_CAST(sipName_ignoreSslErrorsImplementation), meth_QNetworkReply_ignoreSslErrorsImplementation, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_ignoreSslErrorsImplementation)},
    {SIP_MLNAME_CAST(sipName_isFinished), meth_QNetworkReply_isFinished, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_isFinished)},
    {SIP_MLNAME_CAST(sipName_isRunning), meth_QNetworkReply_isRunning, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_isRunning)},
    {SIP_MLNAME_CAST(sipName_isSequential), meth_QNetworkReply_isSequential, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_isSequential)},
    {SIP_MLNAME_CAST(sipName_manager), meth_QNetworkReply_manager, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_manager)},
    {SIP_MLNAME_CAST(sipName_operation), meth_QNetworkReply_operation, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_operation)},
    {SIP_MLNAME_CAST(sipName_rawHeader), meth_QNetworkReply_rawHeader, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_rawHeader)},
    {SIP_MLNAME_CAST(sipName_rawHeaderList), meth_QNetworkReply_rawHeaderList, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_rawHeaderList)},
    {SIP_MLNAME_CAST(sipName_rawHeaderPairs), meth_QNetworkReply_rawHeaderPairs, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_rawHeaderPairs)},
    {SIP_MLNAME_CAST(sipName_readBufferSize), meth_QNetworkReply_readBufferSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_readBufferSize)},
    {SIP_MLNAME_CAST(sipName_request), meth_QNetworkReply_request, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_request)},
    {SIP_MLNAME_CAST(sipName_setAttribute), meth_QNetworkReply_setAttribute, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setAttribute)},
    {SIP_MLNAME_CAST(sipName_setError), meth_QNetworkReply_setError, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setError)},
    {SIP_MLNAME_CAST(sipName_setFinished), meth_QNetworkReply_setFinished, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setFinished)},
    {SIP_MLNAME_CAST(sipName_setHeader), meth_QNetworkReply_setHeader, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setHeader)},
    {SIP_MLNAME_CAST(sipName_setOperation), meth_QNetworkReply_setOperation, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setOperation)},
    {SIP_MLNAME_CAST(sipName_setRawHeader), meth_QNetworkReply_setRawHeader, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setRawHeader)},
    {SIP_MLNAME_CAST(sipName_setReadBufferSize), meth_QNetworkReply_setReadBufferSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setReadBufferSize)},
    {SIP_MLNAME_CAST(sipName_setRequest), meth_QNetworkReply_setRequest, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setRequest)},
    {SIP_MLNAME_CAST(sipName_setSslConfiguration), meth_QNetworkReply_setSslConfiguration, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setSslConfiguration)},
    {SIP_MLNAME_CAST(sipName_setSslConfigurationImplementation), meth_QNetworkReply_setSslConfigurationImplementation, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setSslConfigurationImplementation)},
    {SIP_MLNAME_CAST(sipName_setUrl), meth_QNetworkReply_setUrl, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_setUrl)},
    {SIP_MLNAME_CAST(sipName_sslConfiguration), meth_QNetworkReply_sslConfiguration, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_sslConfiguration)},
    {SIP_MLNAME_CAST(sipName_sslConfigurationImplementation), meth_QNetworkReply_sslConfigurationImplementation, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_sslConfigurationImplementation)},
    {SIP_MLNAME_CAST(sipName_url), meth_QNetworkReply_url, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_url)},
    {SIP_MLNAME_CAST(sipName_writeData), meth_QNetworkReply_writeData, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkReply_writeData)}
};

static sipEnumMemberDef enummembers_QNetworkReply[] = {
    {sipName_AuthenticationRequiredError, static_cast<int>( ::QNetworkReply::AuthenticationRequiredError), 90},
    {sipName_BackgroundRequestNotAllowedError, static_cast<int>( ::QNetworkReply::BackgroundRequestNotAllowedError), 90},
    {sipName_ConnectionRefusedError, static_cast<int>( ::QNetworkReply::ConnectionRefusedError), 90},
    {sipName_ContentAccessDenied, static_cast<int>( ::QNetworkReply::ContentAccessDenied), 90},
    {sipName_ContentConflictError, static_cast<int>( ::QNetworkReply::ContentConflictError), 90},
    {sipName_ContentGoneError, static_cast<int>( ::QNetworkReply::ContentGoneError), 90},
    {sipName_ContentNotFoundError, static_cast<int>( ::QNetworkReply::ContentNotFoundError), 90},
    {sipName_ContentOperationNotPermittedError, static_cast<int>( ::QNetworkReply::ContentOperationNotPermittedError), 90},
    {sipName_ContentReSendError, static_cast<int>( ::QNetworkReply::ContentReSendError), 90},
    {sipName_HostNotFoundError, static_cast<int>( ::QNetworkReply::HostNotFoundError), 90},
    {sipName_InsecureRedirectError, static_cast<int>( ::QNetworkReply::InsecureRedirectError), 90},
    {sipName_InternalServerError, static_cast<int>( ::QNetworkReply::InternalServerError), 90},
    {sipName_NetworkSessionFailedError, static_cast<int>( ::QNetworkReply::NetworkSessionFailedError), 90},
    {sipName_NoError, static_cast<int>( ::QNetworkReply::NoError), 90},
    {sipName_OperationCanceledError, static_cast<int>( ::QNetworkReply::OperationCanceledError), 90},
    {sipName_OperationNotImplementedError, static_cast<int>( ::QNetworkReply::OperationNotImplementedError), 90},
    {sipName_ProtocolFailure, static_cast<int>( ::QNetworkReply::ProtocolFailure), 90},
    {sipName_ProtocolInvalidOperationError, static_cast<int>( ::QNetworkReply::ProtocolInvalidOperationError), 90},
    {sipName_ProtocolUnknownError, static_cast<int>( ::QNetworkReply::ProtocolUnknownError), 90},
    {sipName_ProxyAuthenticationRequiredError, static_cast<int>( ::QNetworkReply::ProxyAuthenticationRequiredError), 90},
    {sipName_ProxyConnectionClosedError, static_cast<int>( ::QNetworkReply::ProxyConnectionClosedError), 90},
    {sipName_ProxyConnectionRefusedError, static_cast<int>( ::QNetworkReply::ProxyConnectionRefusedError), 90},
    {sipName_ProxyNotFoundError, static_cast<int>( ::QNetworkReply::ProxyNotFoundError), 90},
    {sipName_ProxyTimeoutError, static_cast<int>( ::QNetworkReply::ProxyTimeoutError), 90},
    {sipName_RemoteHostClosedError, static_cast<int>( ::QNetworkReply::RemoteHostClosedError), 90},
    {sipName_ServiceUnavailableError, static_cast<int>( ::QNetworkReply::ServiceUnavailableError), 90},
    {sipName_SslHandshakeFailedError, static_cast<int>( ::QNetworkReply::SslHandshakeFailedError), 90},
    {sipName_TemporaryNetworkFailureError, static_cast<int>( ::QNetworkReply::TemporaryNetworkFailureError), 90},
    {sipName_TimeoutError, static_cast<int>( ::QNetworkReply::TimeoutError), 90},
    {sipName_TooManyRedirectsError, static_cast<int>( ::QNetworkReply::TooManyRedirectsError), 90},
    {sipName_UnknownContentError, static_cast<int>( ::QNetworkReply::UnknownContentError), 90},
    {sipName_UnknownNetworkError, static_cast<int>( ::QNetworkReply::UnknownNetworkError), 90},
    {sipName_UnknownProxyError, static_cast<int>( ::QNetworkReply::UnknownProxyError), 90},
    {sipName_UnknownServerError, static_cast<int>( ::QNetworkReply::UnknownServerError), 90},
};

PyDoc_STRVAR(doc_QNetworkReply, "\1QNetworkReply(parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QNetworkReply[] = {
    {"redirectAllowed()", "\1redirectAllowed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"redirected(QUrl)", "\1redirected(self, QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"preSharedKeyAuthenticationRequired(QSslPreSharedKeyAuthenticator*)", "\1preSharedKeyAuthenticationRequired(self, QSslPreSharedKeyAuthenticator)", SIP_NULLPTR, SIP_NULLPTR},
    {"downloadProgress(qint64,qint64)", "\1downloadProgress(self, int, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"uploadProgress(qint64,qint64)", "\1uploadProgress(self, int, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sslErrors(QList<QSslError>)", "\1sslErrors(self, Iterable[QSslError])", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QNetworkReply::NetworkError)", "\1errorOccurred(self, QNetworkReply.NetworkError)", SIP_NULLPTR, SIP_NULLPTR},
    {"encrypted()", "\1encrypted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged()", "\1metaDataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QNetworkReply::NetworkError)", "\1error(self, QNetworkReply.NetworkError)", &methods_QNetworkReply[3], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QNetworkReply = {
    & ::QNetworkReply::staticMetaObject,
    0,
    signals_QNetworkReply,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QNetworkReply = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNetworkReply,
        {SIP_NULLPTR},
        &plugin_QNetworkReply
    },
    {
        sipNameNr_QNetworkReply,
        {0, 0, 1},
        33, methods_QNetworkReply,
        34, enummembers_QNetworkReply,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNetworkReply,
    -1,
    -1,
    supers_QNetworkReply,
    SIP_NULLPTR,
    init_type_QNetworkReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QNetworkReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNetworkReply,
    cast_QNetworkReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
