/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRendererInterface.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRendererInterface.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRendererInterface.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRendererInterface.cpp"


PyDoc_STRVAR(doc_QSGRendererInterface_graphicsApi, "graphicsApi(self) -> QSGRendererInterface.GraphicsApi");

extern "C" {static PyObject *meth_QSGRendererInterface_graphicsApi(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_graphicsApi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRendererInterface, &sipCpp))
        {
             ::QSGRendererInterface::GraphicsApi sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGRendererInterface, sipName_graphicsApi);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->graphicsApi();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGRendererInterface_GraphicsApi);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_graphicsApi, doc_QSGRendererInterface_graphicsApi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRendererInterface_getResource, "getResource(self, QQuickWindow, QSGRendererInterface.Resource) -> sip.voidptr\n"
"getResource(self, QQuickWindow, str) -> sip.voidptr");

extern "C" {static PyObject *meth_QSGRendererInterface_getResource(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_getResource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQuickWindow* a0;
         ::QSGRendererInterface::Resource a1;
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8E", &sipSelf, sipType_QSGRendererInterface, &sipCpp, sipType_QQuickWindow, &a0, sipType_QSGRendererInterface_Resource, &a1))
        {
            void*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGRendererInterface::getResource(a0,a1) : sipCpp->getResource(a0,a1));

            return sipConvertFromVoidPtr(sipRes);
        }
    }

    {
         ::QQuickWindow* a0;
        const char* a1;
        PyObject *a1Keep;
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8AA", &sipSelf, sipType_QSGRendererInterface, &sipCpp, sipType_QQuickWindow, &a0, &a1Keep, &a1))
        {
            void*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGRendererInterface::getResource(a0,a1) : sipCpp->getResource(a0,a1));
            Py_DECREF(a1Keep);

            return sipConvertFromVoidPtr(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_getResource, doc_QSGRendererInterface_getResource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRendererInterface_shaderType, "shaderType(self) -> QSGRendererInterface.ShaderType");

extern "C" {static PyObject *meth_QSGRendererInterface_shaderType(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_shaderType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRendererInterface, &sipCpp))
        {
             ::QSGRendererInterface::ShaderType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGRendererInterface, sipName_shaderType);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->shaderType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGRendererInterface_ShaderType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_shaderType, doc_QSGRendererInterface_shaderType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRendererInterface_shaderCompilationType, "shaderCompilationType(self) -> QSGRendererInterface.ShaderCompilationTypes");

extern "C" {static PyObject *meth_QSGRendererInterface_shaderCompilationType(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_shaderCompilationType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRendererInterface, &sipCpp))
        {
             ::QSGRendererInterface::ShaderCompilationTypes*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGRendererInterface, sipName_shaderCompilationType);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QSGRendererInterface::ShaderCompilationTypes(sipCpp->shaderCompilationType());

            return sipConvertFromNewType(sipRes,sipType_QSGRendererInterface_ShaderCompilationTypes,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_shaderCompilationType, doc_QSGRendererInterface_shaderCompilationType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRendererInterface_shaderSourceType, "shaderSourceType(self) -> QSGRendererInterface.ShaderSourceTypes");

extern "C" {static PyObject *meth_QSGRendererInterface_shaderSourceType(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_shaderSourceType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGRendererInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRendererInterface, &sipCpp))
        {
             ::QSGRendererInterface::ShaderSourceTypes*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGRendererInterface, sipName_shaderSourceType);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QSGRendererInterface::ShaderSourceTypes(sipCpp->shaderSourceType());

            return sipConvertFromNewType(sipRes,sipType_QSGRendererInterface_ShaderSourceTypes,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_shaderSourceType, doc_QSGRendererInterface_shaderSourceType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRendererInterface_isApiRhiBased, "isApiRhiBased(QSGRendererInterface.GraphicsApi) -> bool");

extern "C" {static PyObject *meth_QSGRendererInterface_isApiRhiBased(PyObject *, PyObject *);}
static PyObject *meth_QSGRendererInterface_isApiRhiBased(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGRendererInterface::GraphicsApi a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QSGRendererInterface_GraphicsApi, &a0))
        {
            bool sipRes;

            sipRes =  ::QSGRendererInterface::isApiRhiBased(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRendererInterface, sipName_isApiRhiBased, doc_QSGRendererInterface_isApiRhiBased);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGRendererInterface(void *, int);}
static void release_QSGRendererInterface(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSGRendererInterface *>(sipCppV);
}


extern "C" {static void dealloc_QSGRendererInterface(sipSimpleWrapper *);}
static void dealloc_QSGRendererInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGRendererInterface(sipGetAddress(sipSelf), 0);
    }
}


static PyMethodDef methods_QSGRendererInterface[] = {
    {SIP_MLNAME_CAST(sipName_getResource), meth_QSGRendererInterface_getResource, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_getResource)},
    {SIP_MLNAME_CAST(sipName_graphicsApi), meth_QSGRendererInterface_graphicsApi, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_graphicsApi)},
    {SIP_MLNAME_CAST(sipName_isApiRhiBased), meth_QSGRendererInterface_isApiRhiBased, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_isApiRhiBased)},
    {SIP_MLNAME_CAST(sipName_shaderCompilationType), meth_QSGRendererInterface_shaderCompilationType, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_shaderCompilationType)},
    {SIP_MLNAME_CAST(sipName_shaderSourceType), meth_QSGRendererInterface_shaderSourceType, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_shaderSourceType)},
    {SIP_MLNAME_CAST(sipName_shaderType), meth_QSGRendererInterface_shaderType, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRendererInterface_shaderType)}
};

static sipEnumMemberDef enummembers_QSGRendererInterface[] = {
    {sipName_CommandEncoderResource, static_cast<int>( ::QSGRendererInterface::CommandEncoderResource), 92},
    {sipName_CommandListResource, static_cast<int>( ::QSGRendererInterface::CommandListResource), 92},
    {sipName_CommandQueueResource, static_cast<int>( ::QSGRendererInterface::CommandQueueResource), 92},
    {sipName_DeviceContextResource, static_cast<int>( ::QSGRendererInterface::DeviceContextResource), 92},
    {sipName_DeviceResource, static_cast<int>( ::QSGRendererInterface::DeviceResource), 92},
    {sipName_Direct3D11Rhi, static_cast<int>( ::QSGRendererInterface::Direct3D11Rhi), 91},
    {sipName_Direct3D12, static_cast<int>( ::QSGRendererInterface::Direct3D12), 91},
    {sipName_GLSL, static_cast<int>( ::QSGRendererInterface::GLSL), 97},
    {sipName_HLSL, static_cast<int>( ::QSGRendererInterface::HLSL), 97},
    {sipName_MetalRhi, static_cast<int>( ::QSGRendererInterface::MetalRhi), 91},
    {sipName_NullRhi, static_cast<int>( ::QSGRendererInterface::NullRhi), 91},
    {sipName_OfflineCompilation, static_cast<int>( ::QSGRendererInterface::OfflineCompilation), 93},
    {sipName_OpenGL, static_cast<int>( ::QSGRendererInterface::OpenGL), 91},
    {sipName_OpenGLContextResource, static_cast<int>( ::QSGRendererInterface::OpenGLContextResource), 92},
    {sipName_OpenGLRhi, static_cast<int>( ::QSGRendererInterface::OpenGLRhi), 91},
    {sipName_OpenVG, static_cast<int>( ::QSGRendererInterface::OpenVG), 91},
    {sipName_PainterResource, static_cast<int>( ::QSGRendererInterface::PainterResource), 92},
    {sipName_PhysicalDeviceResource, static_cast<int>( ::QSGRendererInterface::PhysicalDeviceResource), 92},
    {sipName_RenderPassResource, static_cast<int>( ::QSGRendererInterface::RenderPassResource), 92},
    {sipName_RhiResource, static_cast<int>( ::QSGRendererInterface::RhiResource), 92},
    {sipName_RhiShader, static_cast<int>( ::QSGRendererInterface::RhiShader), 97},
    {sipName_RuntimeCompilation, static_cast<int>( ::QSGRendererInterface::RuntimeCompilation), 93},
    {sipName_ShaderByteCode, static_cast<int>( ::QSGRendererInterface::ShaderByteCode), 95},
    {sipName_ShaderSourceFile, static_cast<int>( ::QSGRendererInterface::ShaderSourceFile), 95},
    {sipName_ShaderSourceString, static_cast<int>( ::QSGRendererInterface::ShaderSourceString), 95},
    {sipName_Software, static_cast<int>( ::QSGRendererInterface::Software), 91},
    {sipName_Unknown, static_cast<int>( ::QSGRendererInterface::Unknown), 91},
    {sipName_UnknownShadingLanguage, static_cast<int>( ::QSGRendererInterface::UnknownShadingLanguage), 97},
    {sipName_VulkanInstanceResource, static_cast<int>( ::QSGRendererInterface::VulkanInstanceResource), 92},
    {sipName_VulkanRhi, static_cast<int>( ::QSGRendererInterface::VulkanRhi), 91},
};


static pyqt5ClassPluginDef plugin_QSGRendererInterface = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGRendererInterface = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGRendererInterface,
        {SIP_NULLPTR},
        &plugin_QSGRendererInterface
    },
    {
        sipNameNr_QSGRendererInterface,
        {0, 0, 1},
        6, methods_QSGRendererInterface,
        30, enummembers_QSGRendererInterface,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGRendererInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGRendererInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
