/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 31 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShaderRenderState.cpp"

#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShaderRenderState.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShaderRenderState.cpp"
#line 30 "sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShaderRenderState.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShaderRenderState.cpp"


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_dirtyStates, "dirtyStates(self) -> QSGMaterialShader.RenderState.DirtyStates");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_dirtyStates(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_dirtyStates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QSGMaterialRhiShader::RenderState::DirtyStates*sipRes;

            sipRes = new  ::QSGMaterialRhiShader::RenderState::DirtyStates(sipCpp->dirtyStates());

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialShader_RenderState_DirtyStates,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_dirtyStates, doc_QSGMaterialRhiShader_RenderState_dirtyStates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_isMatrixDirty, "isMatrixDirty(self) -> bool");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_isMatrixDirty(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_isMatrixDirty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMatrixDirty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_isMatrixDirty, doc_QSGMaterialRhiShader_RenderState_isMatrixDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_isOpacityDirty, "isOpacityDirty(self) -> bool");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_isOpacityDirty(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_isOpacityDirty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isOpacityDirty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_isOpacityDirty, doc_QSGMaterialRhiShader_RenderState_isOpacityDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_opacity, "opacity(self) -> float");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_opacity(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_opacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->opacity();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_opacity, doc_QSGMaterialRhiShader_RenderState_opacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_combinedMatrix, "combinedMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_combinedMatrix(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_combinedMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QMatrix4x4*sipRes;

            sipRes = new  ::QMatrix4x4(sipCpp->combinedMatrix());

            return sipConvertFromNewType(sipRes,sipType_QMatrix4x4,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_combinedMatrix, doc_QSGMaterialRhiShader_RenderState_combinedMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_modelViewMatrix, "modelViewMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_modelViewMatrix(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_modelViewMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QMatrix4x4*sipRes;

            sipRes = new  ::QMatrix4x4(sipCpp->modelViewMatrix());

            return sipConvertFromNewType(sipRes,sipType_QMatrix4x4,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_modelViewMatrix, doc_QSGMaterialRhiShader_RenderState_modelViewMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_projectionMatrix, "projectionMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_projectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_projectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QMatrix4x4*sipRes;

            sipRes = new  ::QMatrix4x4(sipCpp->projectionMatrix());

            return sipConvertFromNewType(sipRes,sipType_QMatrix4x4,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_projectionMatrix, doc_QSGMaterialRhiShader_RenderState_projectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_viewportRect, "viewportRect(self) -> QRect");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_viewportRect(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_viewportRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->viewportRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_viewportRect, doc_QSGMaterialRhiShader_RenderState_viewportRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_deviceRect, "deviceRect(self) -> QRect");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_deviceRect(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_deviceRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->deviceRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_deviceRect, doc_QSGMaterialRhiShader_RenderState_deviceRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_determinant, "determinant(self) -> float");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_determinant(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_determinant(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->determinant();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_determinant, doc_QSGMaterialRhiShader_RenderState_determinant);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_devicePixelRatio, "devicePixelRatio(self) -> float");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_devicePixelRatio(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_devicePixelRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->devicePixelRatio();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_devicePixelRatio, doc_QSGMaterialRhiShader_RenderState_devicePixelRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState_uniformData, "uniformData(self) -> QByteArray");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_RenderState_uniformData(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_RenderState_uniformData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterialRhiShader::RenderState *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader_RenderState, &sipCpp))
        {
             ::QByteArray*sipRes;

            sipRes = sipCpp->uniformData();

            return sipConvertFromType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RenderState, sipName_uniformData, doc_QSGMaterialRhiShader_RenderState_uniformData);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGMaterialRhiShader_RenderState(void *, int);}
static void release_QSGMaterialRhiShader_RenderState(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSGMaterialRhiShader::RenderState *>(sipCppV);
}


extern "C" {static void *array_QSGMaterialRhiShader_RenderState(Py_ssize_t);}
static void *array_QSGMaterialRhiShader_RenderState(Py_ssize_t sipNrElem)
{
    return new  ::QSGMaterialRhiShader::RenderState[sipNrElem];
}


extern "C" {static void assign_QSGMaterialRhiShader_RenderState(void *, SIP_SSIZE_T, void *);}
static void assign_QSGMaterialRhiShader_RenderState(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QSGMaterialRhiShader::RenderState *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QSGMaterialRhiShader::RenderState *>(sipSrc);
}


extern "C" {static void *copy_QSGMaterialRhiShader_RenderState(const void *, SIP_SSIZE_T);}
static void *copy_QSGMaterialRhiShader_RenderState(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QSGMaterialRhiShader::RenderState(reinterpret_cast<const  ::QSGMaterialRhiShader::RenderState *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QSGMaterialRhiShader_RenderState(sipSimpleWrapper *);}
static void dealloc_QSGMaterialRhiShader_RenderState(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGMaterialRhiShader_RenderState(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QSGMaterialRhiShader_RenderState(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGMaterialRhiShader_RenderState(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QSGMaterialRhiShader::RenderState *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QSGMaterialRhiShader::RenderState();

            return sipCpp;
        }
    }

    {
        const  ::QSGMaterialRhiShader::RenderState* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSGMaterialRhiShader_RenderState, &a0))
        {
            sipCpp = new  ::QSGMaterialRhiShader::RenderState(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QSGMaterialRhiShader_RenderState[] = {
    {SIP_MLNAME_CAST(sipName_combinedMatrix), meth_QSGMaterialRhiShader_RenderState_combinedMatrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_combinedMatrix)},
    {SIP_MLNAME_CAST(sipName_determinant), meth_QSGMaterialRhiShader_RenderState_determinant, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_determinant)},
    {SIP_MLNAME_CAST(sipName_devicePixelRatio), meth_QSGMaterialRhiShader_RenderState_devicePixelRatio, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_devicePixelRatio)},
    {SIP_MLNAME_CAST(sipName_deviceRect), meth_QSGMaterialRhiShader_RenderState_deviceRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_deviceRect)},
    {SIP_MLNAME_CAST(sipName_dirtyStates), meth_QSGMaterialRhiShader_RenderState_dirtyStates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_dirtyStates)},
    {SIP_MLNAME_CAST(sipName_isMatrixDirty), meth_QSGMaterialRhiShader_RenderState_isMatrixDirty, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_isMatrixDirty)},
    {SIP_MLNAME_CAST(sipName_isOpacityDirty), meth_QSGMaterialRhiShader_RenderState_isOpacityDirty, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_isOpacityDirty)},
    {SIP_MLNAME_CAST(sipName_modelViewMatrix), meth_QSGMaterialRhiShader_RenderState_modelViewMatrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_modelViewMatrix)},
    {SIP_MLNAME_CAST(sipName_opacity), meth_QSGMaterialRhiShader_RenderState_opacity, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_opacity)},
    {SIP_MLNAME_CAST(sipName_projectionMatrix), meth_QSGMaterialRhiShader_RenderState_projectionMatrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_projectionMatrix)},
    {SIP_MLNAME_CAST(sipName_uniformData), meth_QSGMaterialRhiShader_RenderState_uniformData, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_uniformData)},
    {SIP_MLNAME_CAST(sipName_viewportRect), meth_QSGMaterialRhiShader_RenderState_viewportRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_RenderState_viewportRect)}
};

PyDoc_STRVAR(doc_QSGMaterialRhiShader_RenderState, "\1QSGMaterialRhiShader.RenderState()\n"
"QSGMaterialRhiShader.RenderState(QSGMaterialRhiShader.RenderState)");


static pyqt5ClassPluginDef plugin_QSGMaterialRhiShader_RenderState = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_RenderState = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGMaterialRhiShader__RenderState,
        {SIP_NULLPTR},
        &plugin_QSGMaterialRhiShader_RenderState
    },
    {
        sipNameNr_RenderState,
        {61, 255, 0},
        12, methods_QSGMaterialRhiShader_RenderState,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGMaterialRhiShader_RenderState,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QSGMaterialRhiShader_RenderState,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGMaterialRhiShader_RenderState,
    assign_QSGMaterialRhiShader_RenderState,
    array_QSGMaterialRhiShader_RenderState,
    copy_QSGMaterialRhiShader_RenderState,
    release_QSGMaterialRhiShader_RenderState,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
