/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtXmlAPI_H
#define _QtXmlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QDomImplementation__InvalidDataPolicy 0
#define sipName_QDomImplementation__InvalidDataPolicy &sipStrings_QtXml[0]
#define sipNameNr_createProcessingInstruction 38
#define sipName_createProcessingInstruction &sipStrings_QtXml[38]
#define sipNameNr_QDomProcessingInstruction 66
#define sipName_QDomProcessingInstruction &sipStrings_QtXml[66]
#define sipNameNr_ProcessingInstructionNode 92
#define sipName_ProcessingInstructionNode &sipStrings_QtXml[92]
#define sipNameNr_QDomNode__EncodingPolicy 118
#define sipName_QDomNode__EncodingPolicy &sipStrings_QtXml[118]
#define sipNameNr_toProcessingInstruction 143
#define sipName_toProcessingInstruction &sipStrings_QtXml[143]
#define sipNameNr_isProcessingInstruction 167
#define sipName_isProcessingInstruction &sipStrings_QtXml[167]
#define sipNameNr_createDocumentFragment 191
#define sipName_createDocumentFragment &sipStrings_QtXml[191]
#define sipNameNr_previousSiblingElement 214
#define sipName_previousSiblingElement &sipStrings_QtXml[214]
#define sipNameNr_EncodingFromTextStream 237
#define sipName_EncodingFromTextStream &sipStrings_QtXml[237]
#define sipNameNr_processingInstruction 260
#define sipName_processingInstruction &sipStrings_QtXml[260]
#define sipNameNr_createEntityReference 282
#define sipName_createEntityReference &sipStrings_QtXml[282]
#define sipNameNr_QXmlNamespaceSupport 304
#define sipName_QXmlNamespaceSupport &sipStrings_QtXml[304]
#define sipNameNr_QDomDocumentFragment 325
#define sipName_QDomDocumentFragment &sipStrings_QtXml[325]
#define sipNameNr_EncodingFromDocument 346
#define sipName_EncodingFromDocument &sipStrings_QtXml[346]
#define sipNameNr_DocumentFragmentNode 367
#define sipName_DocumentFragmentNode &sipStrings_QtXml[367]
#define sipNameNr_setInvalidDataPolicy 388
#define sipName_setInvalidDataPolicy &sipStrings_QtXml[388]
#define sipNameNr_ignorableWhitespace 409
#define sipName_ignorableWhitespace &sipStrings_QtXml[409]
#define sipNameNr_QDomEntityReference 429
#define sipName_QDomEntityReference &sipStrings_QtXml[429]
#define sipNameNr_removeAttributeNode 449
#define sipName_removeAttributeNode &sipStrings_QtXml[449]
#define sipNameNr_elementsByTagNameNS 469
#define sipName_elementsByTagNameNS &sipStrings_QtXml[469]
#define sipNameNr_EntityReferenceNode 489
#define sipName_EntityReferenceNode &sipStrings_QtXml[489]
#define sipNameNr_QXmlDefaultHandler 509
#define sipName_QXmlDefaultHandler &sipStrings_QtXml[509]
#define sipNameNr_externalEntityDecl 528
#define sipName_externalEntityDecl &sipStrings_QtXml[528]
#define sipNameNr_internalEntityDecl 547
#define sipName_internalEntityDecl &sipStrings_QtXml[547]
#define sipNameNr_QXmlLexicalHandler 566
#define sipName_QXmlLexicalHandler &sipStrings_QtXml[566]
#define sipNameNr_QXmlEntityResolver 585
#define sipName_QXmlEntityResolver &sipStrings_QtXml[585]
#define sipNameNr_unparsedEntityDecl 604
#define sipName_unparsedEntityDecl &sipStrings_QtXml[604]
#define sipNameNr_startPrefixMapping 623
#define sipName_startPrefixMapping &sipStrings_QtXml[623]
#define sipNameNr_setDocumentLocator 642
#define sipName_setDocumentLocator &sipStrings_QtXml[642]
#define sipNameNr_QXmlContentHandler 661
#define sipName_QXmlContentHandler &sipStrings_QtXml[661]
#define sipNameNr_QXmlParseException 680
#define sipName_QXmlParseException &sipStrings_QtXml[680]
#define sipNameNr_setAttributeNodeNS 699
#define sipName_setAttributeNodeNS &sipStrings_QtXml[699]
#define sipNameNr_createCDATASection 718
#define sipName_createCDATASection &sipStrings_QtXml[718]
#define sipNameNr_nextSiblingElement 737
#define sipName_nextSiblingElement &sipStrings_QtXml[737]
#define sipNameNr_toDocumentFragment 756
#define sipName_toDocumentFragment &sipStrings_QtXml[756]
#define sipNameNr_isDocumentFragment 775
#define sipName_isDocumentFragment &sipStrings_QtXml[775]
#define sipNameNr_QDomNode__NodeType 794
#define sipName_QDomNode__NodeType &sipStrings_QtXml[794]
#define sipNameNr_AcceptInvalidChars 813
#define sipName_AcceptInvalidChars &sipStrings_QtXml[813]
#define sipNameNr_createDocumentType 832
#define sipName_createDocumentType &sipStrings_QtXml[832]
#define sipNameNr_QDomImplementation 851
#define sipName_QDomImplementation &sipStrings_QtXml[851]
#define sipNameNr_setLexicalHandler 870
#define sipName_setLexicalHandler &sipStrings_QtXml[870]
#define sipNameNr_setContentHandler 888
#define sipName_setContentHandler &sipStrings_QtXml[888]
#define sipNameNr_removeAttributeNS 906
#define sipName_removeAttributeNS &sipStrings_QtXml[906]
#define sipNameNr_QDomCharacterData 924
#define sipName_QDomCharacterData &sipStrings_QtXml[924]
#define sipNameNr_removeNamedItemNS 942
#define sipName_removeNamedItemNS &sipStrings_QtXml[942]
#define sipNameNr_createAttributeNS 960
#define sipName_createAttributeNS &sipStrings_QtXml[960]
#define sipNameNr_elementsByTagName 978
#define sipName_elementsByTagName &sipStrings_QtXml[978]
#define sipNameNr_firstChildElement 996
#define sipName_firstChildElement &sipStrings_QtXml[996]
#define sipNameNr_toEntityReference 1014
#define sipName_toEntityReference &sipStrings_QtXml[1014]
#define sipNameNr_CharacterDataNode 1032
#define sipName_CharacterDataNode &sipStrings_QtXml[1032]
#define sipNameNr_invalidDataPolicy 1050
#define sipName_invalidDataPolicy &sipStrings_QtXml[1050]
#define sipNameNr_InvalidDataPolicy 20
#define sipName_InvalidDataPolicy &sipStrings_QtXml[20]
#define sipNameNr_setEntityResolver 1068
#define sipName_setEntityResolver &sipStrings_QtXml[1068]
#define sipNameNr_isEntityReference 1086
#define sipName_isEntityReference &sipStrings_QtXml[1086]
#define sipNameNr_sip_simplewrapper 1104
#define sipName_sip_simplewrapper &sipStrings_QtXml[1104]
#define sipNameNr_QXmlErrorHandler 1122
#define sipName_QXmlErrorHandler &sipStrings_QtXml[1122]
#define sipNameNr_endPrefixMapping 1139
#define sipName_endPrefixMapping &sipStrings_QtXml[1139]
#define sipNameNr_QXmlSimpleReader 1156
#define sipName_QXmlSimpleReader &sipStrings_QtXml[1156]
#define sipNameNr_QDomCDATASection 1173
#define sipName_QDomCDATASection &sipStrings_QtXml[1173]
#define sipNameNr_setAttributeNode 1190
#define sipName_setAttributeNode &sipStrings_QtXml[1190]
#define sipNameNr_QDomNamedNodeMap 1207
#define sipName_QDomNamedNodeMap &sipStrings_QtXml[1207]
#define sipNameNr_QDomDocumentType 1224
#define sipName_QDomDocumentType &sipStrings_QtXml[1224]
#define sipNameNr_lastChildElement 1241
#define sipName_lastChildElement &sipStrings_QtXml[1241]
#define sipNameNr_DocumentTypeNode 1258
#define sipName_DocumentTypeNode &sipStrings_QtXml[1258]
#define sipNameNr_CDATASectionNode 1275
#define sipName_CDATASectionNode &sipStrings_QtXml[1275]
#define sipNameNr_DropInvalidChars 1292
#define sipName_DropInvalidChars &sipStrings_QtXml[1292]
#define sipNameNr_QXmlDeclHandler 1309
#define sipName_QXmlDeclHandler &sipStrings_QtXml[1309]
#define sipNameNr_setErrorHandler 1325
#define sipName_setErrorHandler &sipStrings_QtXml[1325]
#define sipNameNr_QXmlInputSource 1341
#define sipName_QXmlInputSource &sipStrings_QtXml[1341]
#define sipNameNr_attributeNodeNS 1357
#define sipName_attributeNodeNS &sipStrings_QtXml[1357]
#define sipNameNr_removeAttribute 1373
#define sipName_removeAttribute &sipStrings_QtXml[1373]
#define sipNameNr_removeNamedItem 1389
#define sipName_removeNamedItem &sipStrings_QtXml[1389]
#define sipNameNr_documentElement 1405
#define sipName_documentElement &sipStrings_QtXml[1405]
#define sipNameNr_createElementNS 1421
#define sipName_createElementNS &sipStrings_QtXml[1421]
#define sipNameNr_createAttribute 1437
#define sipName_createAttribute &sipStrings_QtXml[1437]
#define sipNameNr_toCharacterData 1453
#define sipName_toCharacterData &sipStrings_QtXml[1453]
#define sipNameNr_isCharacterData 1469
#define sipName_isCharacterData &sipStrings_QtXml[1469]
#define sipNameNr_previousSibling 1485
#define sipName_previousSibling &sipStrings_QtXml[1485]
#define sipNameNr_QXmlDTDHandler 1501
#define sipName_QXmlDTDHandler &sipStrings_QtXml[1501]
#define sipNameNr_setDeclHandler 1516
#define sipName_setDeclHandler &sipStrings_QtXml[1516]
#define sipNameNr_lexicalHandler 1531
#define sipName_lexicalHandler &sipStrings_QtXml[1531]
#define sipNameNr_contentHandler 1546
#define sipName_contentHandler &sipStrings_QtXml[1546]
#define sipNameNr_QXmlAttributes 1561
#define sipName_QXmlAttributes &sipStrings_QtXml[1561]
#define sipNameNr_hasAttributeNS 1576
#define sipName_hasAttributeNS &sipStrings_QtXml[1576]
#define sipNameNr_setAttributeNS 1591
#define sipName_setAttributeNS &sipStrings_QtXml[1591]
#define sipNameNr_setNamedItemNS 1606
#define sipName_setNamedItemNS &sipStrings_QtXml[1606]
#define sipNameNr_implementation 1621
#define sipName_implementation &sipStrings_QtXml[1621]
#define sipNameNr_createTextNode 1636
#define sipName_createTextNode &sipStrings_QtXml[1636]
#define sipNameNr_internalSubset 1651
#define sipName_internalSubset &sipStrings_QtXml[1651]
#define sipNameNr_toDocumentType 1666
#define sipName_toDocumentType &sipStrings_QtXml[1666]
#define sipNameNr_toCDATASection 1681
#define sipName_toCDATASection &sipStrings_QtXml[1681]
#define sipNameNr_isDocumentType 1696
#define sipName_isDocumentType &sipStrings_QtXml[1696]
#define sipNameNr_isCDATASection 1711
#define sipName_isCDATASection &sipStrings_QtXml[1711]
#define sipNameNr_EncodingPolicy 128
#define sipName_EncodingPolicy &sipStrings_QtXml[128]
#define sipNameNr_ReturnNullNode 1726
#define sipName_ReturnNullNode &sipStrings_QtXml[1726]
#define sipNameNr_createDocument 1741
#define sipName_createDocument &sipStrings_QtXml[1741]
#define sipNameNr_entityResolver 1756
#define sipName_entityResolver &sipStrings_QtXml[1756]
#define sipNameNr_attributeDecl 1771
#define sipName_attributeDecl &sipStrings_QtXml[1771]
#define sipNameNr_resolveEntity 1785
#define sipName_resolveEntity &sipStrings_QtXml[1785]
#define sipNameNr_skippedEntity 1799
#define sipName_skippedEntity &sipStrings_QtXml[1799]
#define sipNameNr_startDocument 1813
#define sipName_startDocument &sipStrings_QtXml[1813]
#define sipNameNr_parseContinue 1827
#define sipName_parseContinue &sipStrings_QtXml[1827]
#define sipNameNr_setDTDHandler 1841
#define sipName_setDTDHandler &sipStrings_QtXml[1841]
#define sipNameNr_EndOfDocument 1855
#define sipName_EndOfDocument &sipStrings_QtXml[1855]
#define sipNameNr_attributeNode 1869
#define sipName_attributeNode &sipStrings_QtXml[1869]
#define sipNameNr_substringData 1883
#define sipName_substringData &sipStrings_QtXml[1883]
#define sipNameNr_createComment 1897
#define sipName_createComment &sipStrings_QtXml[1897]
#define sipNameNr_createElement 1911
#define sipName_createElement &sipStrings_QtXml[1911]
#define sipNameNr_hasAttributes 1925
#define sipName_hasAttributes &sipStrings_QtXml[1925]
#define sipNameNr_ownerDocument 1939
#define sipName_ownerDocument &sipStrings_QtXml[1939]
#define sipNameNr_hasChildNodes 1953
#define sipName_hasChildNodes &sipStrings_QtXml[1953]
#define sipNameNr_AttributeNode 455
#define sipName_AttributeNode &sipStrings_QtXml[455]
#define sipNameNr_notationDecl 1967
#define sipName_notationDecl &sipStrings_QtXml[1967]
#define sipNameNr_startElement 1980
#define sipName_startElement &sipStrings_QtXml[1980]
#define sipNameNr_errorHandler 1993
#define sipName_errorHandler &sipStrings_QtXml[1993]
#define sipNameNr_QDomNotation 2006
#define sipName_QDomNotation &sipStrings_QtXml[2006]
#define sipNameNr_ownerElement 2019
#define sipName_ownerElement &sipStrings_QtXml[2019]
#define sipNameNr_setNamedItem 2032
#define sipName_setNamedItem &sipStrings_QtXml[2032]
#define sipNameNr_QDomDocument 2045
#define sipName_QDomDocument &sipStrings_QtXml[2045]
#define sipNameNr_QDomNodeList 2058
#define sipName_QDomNodeList &sipStrings_QtXml[2058]
#define sipNameNr_setNodeValue 2071
#define sipName_setNodeValue &sipStrings_QtXml[2071]
#define sipNameNr_namespaceURI 2084
#define sipName_namespaceURI &sipStrings_QtXml[2084]
#define sipNameNr_replaceChild 2097
#define sipName_replaceChild &sipStrings_QtXml[2097]
#define sipNameNr_insertBefore 2110
#define sipName_insertBefore &sipStrings_QtXml[2110]
#define sipNameNr_NotationNode 2123
#define sipName_NotationNode &sipStrings_QtXml[2123]
#define sipNameNr_DocumentNode 2136
#define sipName_DocumentNode &sipStrings_QtXml[2136]
#define sipNameNr_columnNumber 2149
#define sipName_columnNumber &sipStrings_QtXml[2149]
#define sipNameNr_notationName 2162
#define sipName_notationName &sipStrings_QtXml[2162]
#define sipNameNr_hasAttribute 2175
#define sipName_hasAttribute &sipStrings_QtXml[2175]
#define sipNameNr_setAttribute 2188
#define sipName_setAttribute &sipStrings_QtXml[2188]
#define sipNameNr_defaultValue 2201
#define sipName_defaultValue &sipStrings_QtXml[2201]
#define sipNameNr_startEntity 2214
#define sipName_startEntity &sipStrings_QtXml[2214]
#define sipNameNr_endDocument 2226
#define sipName_endDocument &sipStrings_QtXml[2226]
#define sipNameNr_QXmlLocator 2238
#define sipName_QXmlLocator &sipStrings_QtXml[2238]
#define sipNameNr_declHandler 2250
#define sipName_declHandler &sipStrings_QtXml[2250]
#define sipNameNr_hasProperty 2262
#define sipName_hasProperty &sipStrings_QtXml[2262]
#define sipNameNr_pushContext 2274
#define sipName_pushContext &sipStrings_QtXml[2274]
#define sipNameNr_processName 2286
#define sipName_processName &sipStrings_QtXml[2286]
#define sipNameNr_QDomComment 2298
#define sipName_QDomComment &sipStrings_QtXml[2298]
#define sipNameNr_attributeNS 2310
#define sipName_attributeNS &sipStrings_QtXml[2310]
#define sipNameNr_QDomElement 2322
#define sipName_QDomElement &sipStrings_QtXml[2322]
#define sipNameNr_replaceData 2334
#define sipName_replaceData &sipStrings_QtXml[2334]
#define sipNameNr_namedItemNS 2346
#define sipName_namedItemNS &sipStrings_QtXml[2346]
#define sipNameNr_errorColumn 2358
#define sipName_errorColumn &sipStrings_QtXml[2358]
#define sipNameNr_elementById 2370
#define sipName_elementById &sipStrings_QtXml[2370]
#define sipNameNr_nextSibling 2382
#define sipName_nextSibling &sipStrings_QtXml[2382]
#define sipNameNr_isSupported 2394
#define sipName_isSupported &sipStrings_QtXml[2394]
#define sipNameNr_appendChild 2406
#define sipName_appendChild &sipStrings_QtXml[2406]
#define sipNameNr_removeChild 2418
#define sipName_removeChild &sipStrings_QtXml[2418]
#define sipNameNr_insertAfter 2430
#define sipName_insertAfter &sipStrings_QtXml[2430]
#define sipNameNr_CommentNode 2442
#define sipName_CommentNode &sipStrings_QtXml[2442]
#define sipNameNr_ElementNode 2454
#define sipName_ElementNode &sipStrings_QtXml[2454]
#define sipNameNr_toByteArray 2466
#define sipName_toByteArray &sipStrings_QtXml[2466]
#define sipNameNr_setProperty 2478
#define sipName_setProperty &sipStrings_QtXml[2478]
#define sipNameNr_errorString 2490
#define sipName_errorString &sipStrings_QtXml[2490]
#define sipNameNr_fromRawData 2502
#define sipName_fromRawData &sipStrings_QtXml[2502]
#define sipNameNr_PyQt5_QtXml 2514
#define sipName_PyQt5_QtXml &sipStrings_QtXml[2514]
#define sipNameNr_startCDATA 2526
#define sipName_startCDATA &sipStrings_QtXml[2526]
#define sipNameNr_fatalError 2537
#define sipName_fatalError &sipStrings_QtXml[2537]
#define sipNameNr_characters 2548
#define sipName_characters &sipStrings_QtXml[2548]
#define sipNameNr_endElement 2559
#define sipName_endElement &sipStrings_QtXml[2559]
#define sipNameNr_DTDHandler 1505
#define sipName_DTDHandler &sipStrings_QtXml[1505]
#define sipNameNr_setFeature 2570
#define sipName_setFeature &sipStrings_QtXml[2570]
#define sipNameNr_QXmlReader 2581
#define sipName_QXmlReader &sipStrings_QtXml[2581]
#define sipNameNr_popContext 2592
#define sipName_popContext &sipStrings_QtXml[2592]
#define sipNameNr_QDomEntity 2603
#define sipName_QDomEntity &sipStrings_QtXml[2603]
#define sipNameNr_setTagName 2614
#define sipName_setTagName &sipStrings_QtXml[2614]
#define sipNameNr_deleteData 2625
#define sipName_deleteData &sipStrings_QtXml[2625]
#define sipNameNr_insertData 2636
#define sipName_insertData &sipStrings_QtXml[2636]
#define sipNameNr_appendData 2647
#define sipName_appendData &sipStrings_QtXml[2647]
#define sipNameNr_setContent 2658
#define sipName_setContent &sipStrings_QtXml[2658]
#define sipNameNr_importNode 2669
#define sipName_importNode &sipStrings_QtXml[2669]
#define sipNameNr_toNotation 2680
#define sipName_toNotation &sipStrings_QtXml[2680]
#define sipNameNr_toDocument 2691
#define sipName_toDocument &sipStrings_QtXml[2691]
#define sipNameNr_isNotation 2702
#define sipName_isNotation &sipStrings_QtXml[2702]
#define sipNameNr_isDocument 2713
#define sipName_isDocument &sipStrings_QtXml[2713]
#define sipNameNr_firstChild 2724
#define sipName_firstChild &sipStrings_QtXml[2724]
#define sipNameNr_childNodes 2735
#define sipName_childNodes &sipStrings_QtXml[2735]
#define sipNameNr_parentNode 2746
#define sipName_parentNode &sipStrings_QtXml[2746]
#define sipNameNr_EntityNode 2757
#define sipName_EntityNode &sipStrings_QtXml[2757]
#define sipNameNr_hasFeature 2768
#define sipName_hasFeature &sipStrings_QtXml[2768]
#define sipNameNr_attributes 2779
#define sipName_attributes &sipStrings_QtXml[2779]
#define sipNameNr_lineNumber 2790
#define sipName_lineNumber &sipStrings_QtXml[2790]
#define sipNameNr___lshift__ 2801
#define sipName___lshift__ &sipStrings_QtXml[2801]
#define sipNameNr_endEntity 2812
#define sipName_endEntity &sipStrings_QtXml[2812]
#define sipNameNr_beginning 2822
#define sipName_beginning &sipStrings_QtXml[2822]
#define sipNameNr_EndOfData 2832
#define sipName_EndOfData &sipStrings_QtXml[2832]
#define sipNameNr_fetchData 2842
#define sipName_fetchData &sipStrings_QtXml[2842]
#define sipNameNr_splitName 2852
#define sipName_splitName &sipStrings_QtXml[2852]
#define sipNameNr_splitText 2862
#define sipName_splitText &sipStrings_QtXml[2862]
#define sipNameNr_specified 2872
#define sipName_specified &sipStrings_QtXml[2872]
#define sipNameNr_errorLine 2882
#define sipName_errorLine &sipStrings_QtXml[2882]
#define sipNameNr_notations 2892
#define sipName_notations &sipStrings_QtXml[2892]
#define sipNameNr_toComment 2902
#define sipName_toComment &sipStrings_QtXml[2902]
#define sipNameNr_toElement 2912
#define sipName_toElement &sipStrings_QtXml[2912]
#define sipNameNr_namedItem 2922
#define sipName_namedItem &sipStrings_QtXml[2922]
#define sipNameNr_isElement 2932
#define sipName_isElement &sipStrings_QtXml[2932]
#define sipNameNr_setPrefix 2942
#define sipName_setPrefix &sipStrings_QtXml[2942]
#define sipNameNr_nodeValue 2952
#define sipName_nodeValue &sipStrings_QtXml[2952]
#define sipNameNr_localName 2962
#define sipName_localName &sipStrings_QtXml[2962]
#define sipNameNr_lastChild 2972
#define sipName_lastChild &sipStrings_QtXml[2972]
#define sipNameNr_normalize 2982
#define sipName_normalize &sipStrings_QtXml[2982]
#define sipNameNr_cloneNode 2992
#define sipName_cloneNode &sipStrings_QtXml[2992]
#define sipNameNr_isComment 3002
#define sipName_isComment &sipStrings_QtXml[3002]
#define sipNameNr_attribute 3012
#define sipName_attribute &sipStrings_QtXml[3012]
#define sipNameNr_endCDATA 3022
#define sipName_endCDATA &sipStrings_QtXml[3022]
#define sipNameNr_startDTD 3031
#define sipName_startDTD &sipStrings_QtXml[3031]
#define sipNameNr_prefixes 3040
#define sipName_prefixes &sipStrings_QtXml[3040]
#define sipNameNr_QDomText 3049
#define sipName_QDomText &sipStrings_QtXml[3049]
#define sipNameNr_QDomAttr 3058
#define sipName_QDomAttr &sipStrings_QtXml[3058]
#define sipNameNr_errorMsg 3067
#define sipName_errorMsg &sipStrings_QtXml[3067]
#define sipNameNr_entities 3076
#define sipName_entities &sipStrings_QtXml[3076]
#define sipNameNr_toEntity 3085
#define sipName_toEntity &sipStrings_QtXml[3085]
#define sipNameNr_isEntity 3094
#define sipName_isEntity &sipStrings_QtXml[3094]
#define sipNameNr_nodeType 3103
#define sipName_nodeType &sipStrings_QtXml[3103]
#define sipNameNr_nodeName 3112
#define sipName_nodeName &sipStrings_QtXml[3112]
#define sipNameNr_BaseNode 3121
#define sipName_BaseNode &sipStrings_QtXml[3121]
#define sipNameNr_TextNode 1642
#define sipName_TextNode &sipStrings_QtXml[1642]
#define sipNameNr_NodeType 804
#define sipName_NodeType &sipStrings_QtXml[804]
#define sipNameNr_QDomNode 3130
#define sipName_QDomNode &sipStrings_QtXml[3130]
#define sipNameNr_publicId 3139
#define sipName_publicId &sipStrings_QtXml[3139]
#define sipNameNr_systemId 3148
#define sipName_systemId &sipStrings_QtXml[3148]
#define sipNameNr_setValue 3157
#define sipName_setValue &sipStrings_QtXml[3157]
#define sipNameNr_property 3166
#define sipName_property &sipStrings_QtXml[3166]
#define sipNameNr_toString 3175
#define sipName_toString &sipStrings_QtXml[3175]
#define sipNameNr_contains 3184
#define sipName_contains &sipStrings_QtXml[3184]
#define sipNameNr_tagName 3193
#define sipName_tagName &sipStrings_QtXml[3193]
#define sipNameNr_doctype 3201
#define sipName_doctype &sipStrings_QtXml[3201]
#define sipNameNr_feature 3209
#define sipName_feature &sipStrings_QtXml[3209]
#define sipNameNr_comment 3217
#define sipName_comment &sipStrings_QtXml[3217]
#define sipNameNr_warning 3225
#define sipName_warning &sipStrings_QtXml[3225]
#define sipNameNr_isEmpty 3233
#define sipName_isEmpty &sipStrings_QtXml[3233]
#define sipNameNr___len__ 3241
#define sipName___len__ &sipStrings_QtXml[3241]
#define sipNameNr_setData 3249
#define sipName_setData &sipStrings_QtXml[3249]
#define sipNameNr_message 3257
#define sipName_message &sipStrings_QtXml[3257]
#define sipNameNr_endDTD 3265
#define sipName_endDTD &sipStrings_QtXml[3265]
#define sipNameNr_indent 3272
#define sipName_indent &sipStrings_QtXml[3272]
#define sipNameNr_taName 3279
#define sipName_taName &sipStrings_QtXml[3279]
#define sipNameNr_toText 3286
#define sipName_toText &sipStrings_QtXml[3286]
#define sipNameNr_toAttr 3293
#define sipName_toAttr &sipStrings_QtXml[3293]
#define sipNameNr_isText 3300
#define sipName_isText &sipStrings_QtXml[3300]
#define sipNameNr_isAttr 3307
#define sipName_isAttr &sipStrings_QtXml[3307]
#define sipNameNr_prefix 3314
#define sipName_prefix &sipStrings_QtXml[3314]
#define sipNameNr_append 3321
#define sipName_append &sipStrings_QtXml[3321]
#define sipNameNr_length 3328
#define sipName_length &sipStrings_QtXml[3328]
#define sipNameNr_isNull 3335
#define sipName_isNull &sipStrings_QtXml[3335]
#define sipNameNr_target 3342
#define sipName_target &sipStrings_QtXml[3342]
#define sipNameNr_column 3349
#define sipName_column &sipStrings_QtXml[3349]
#define sipNameNr___ne__ 3356
#define sipName___ne__ &sipStrings_QtXml[3356]
#define sipNameNr___eq__ 3363
#define sipName___eq__ &sipStrings_QtXml[3363]
#define sipNameNr_qName 3370
#define sipName_qName &sipStrings_QtXml[3370]
#define sipNameNr_error 3376
#define sipName_error &sipStrings_QtXml[3376]
#define sipNameNr_parse 3382
#define sipName_parse &sipStrings_QtXml[3382]
#define sipNameNr_reset 3388
#define sipName_reset &sipStrings_QtXml[3388]
#define sipNameNr_clear 3394
#define sipName_clear &sipStrings_QtXml[3394]
#define sipNameNr_count 3400
#define sipName_count &sipStrings_QtXml[3400]
#define sipNameNr_value 3406
#define sipName_value &sipStrings_QtXml[3406]
#define sipNameNr_index 3412
#define sipName_index &sipStrings_QtXml[3412]
#define sipNameNr_item 3418
#define sipName_item &sipStrings_QtXml[3418]
#define sipNameNr_deep 3423
#define sipName_deep &sipStrings_QtXml[3423]
#define sipNameNr_save 3428
#define sipName_save &sipStrings_QtXml[3428]
#define sipNameNr_text 2281
#define sipName_text &sipStrings_QtXml[2281]
#define sipNameNr_line 3433
#define sipName_line &sipStrings_QtXml[3433]
#define sipNameNr_next 3438
#define sipName_next &sipStrings_QtXml[3438]
#define sipNameNr_name 3443
#define sipName_name &sipStrings_QtXml[3443]
#define sipNameNr_size 3448
#define sipName_size &sipStrings_QtXml[3448]
#define sipNameNr_type 3204
#define sipName_type &sipStrings_QtXml[3204]
#define sipNameNr_swap 3453
#define sipName_swap &sipStrings_QtXml[3453]
#define sipNameNr_data 3458
#define sipName_data &sipStrings_QtXml[3458]
#define sipNameNr_uri 3463
#define sipName_uri &sipStrings_QtXml[3463]
#define sipNameNr_ok 3467
#define sipName_ok &sipStrings_QtXml[3467]
#define sipNameNr_at 3470
#define sipName_at &sipStrings_QtXml[3470]

#define sipMalloc                   sipAPI_QtXml->api_malloc
#define sipFree                     sipAPI_QtXml->api_free
#define sipBuildResult              sipAPI_QtXml->api_build_result
#define sipCallMethod               sipAPI_QtXml->api_call_method
#define sipCallProcedureMethod      sipAPI_QtXml->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtXml->api_call_error_handler
#define sipParseResultEx            sipAPI_QtXml->api_parse_result_ex
#define sipParseResult              sipAPI_QtXml->api_parse_result
#define sipParseArgs                sipAPI_QtXml->api_parse_args
#define sipParseKwdArgs             sipAPI_QtXml->api_parse_kwd_args
#define sipParsePair                sipAPI_QtXml->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtXml->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtXml->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtXml->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtXml->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtXml->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtXml->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtXml->api_add_exception
#define sipNoFunction               sipAPI_QtXml->api_no_function
#define sipNoMethod                 sipAPI_QtXml->api_no_method
#define sipAbstractMethod           sipAPI_QtXml->api_abstract_method
#define sipBadClass                 sipAPI_QtXml->api_bad_class
#define sipBadCatcherResult         sipAPI_QtXml->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtXml->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtXml->api_bad_operator_arg
#define sipTrace                    sipAPI_QtXml->api_trace
#define sipTransferBack             sipAPI_QtXml->api_transfer_back
#define sipTransferTo               sipAPI_QtXml->api_transfer_to
#define sipTransferBreak            sipAPI_QtXml->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtXml->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtXml->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtXml->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtXml->api_voidptr_type
#define sipGetPyObject              sipAPI_QtXml->api_get_pyobject
#define sipGetAddress               sipAPI_QtXml->api_get_address
#define sipGetMixinAddress          sipAPI_QtXml->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtXml->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtXml->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtXml->api_is_py_method
#define sipCallHook                 sipAPI_QtXml->api_call_hook
#define sipEndThread                sipAPI_QtXml->api_end_thread
#define sipConnectRx                sipAPI_QtXml->api_connect_rx
#define sipDisconnectRx             sipAPI_QtXml->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtXml->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtXml->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtXml->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtXml->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtXml->api_free_sipslot
#define sipSameSlot                 sipAPI_QtXml->api_same_slot
#define sipPySlotExtend             sipAPI_QtXml->api_pyslot_extend
#define sipConvertRx                sipAPI_QtXml->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtXml->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtXml->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtXml->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtXml->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtXml->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtXml->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtXml->api_convert_to_bool
#define sipReleaseType              sipAPI_QtXml->api_release_type
#define sipConvertFromType          sipAPI_QtXml->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtXml->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtXml->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtXml->api_convert_from_enum
#define sipGetState                 sipAPI_QtXml->api_get_state
#define sipExportSymbol             sipAPI_QtXml->api_export_symbol
#define sipImportSymbol             sipAPI_QtXml->api_import_symbol
#define sipFindType                 sipAPI_QtXml->api_find_type
#define sipFindNamedEnum            sipAPI_QtXml->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtXml->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtXml->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtXml->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtXml->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtXml->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtXml->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtXml->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtXml->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtXml->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtXml->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtXml->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtXml->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtXml->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtXml->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtXml->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtXml->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtXml->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtXml->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtXml->api_deprecated
#define sipGetReference             sipAPI_QtXml->api_get_reference
#define sipKeepReference            sipAPI_QtXml->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtXml->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtXml->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtXml->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtXml->api_type_scope
#define sipResolveTypedef           sipAPI_QtXml->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtXml->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtXml->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtXml->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtXml->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtXml->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtXml->api_init_mixin
#define sipExportModule             sipAPI_QtXml->api_export_module
#define sipInitModule               sipAPI_QtXml->api_init_module
#define sipGetInterpreter           sipAPI_QtXml->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtXml->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtXml->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtXml->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtXml->api_py_type_dict
#define sipPyTypeName               sipAPI_QtXml->api_py_type_name
#define sipGetCFunction             sipAPI_QtXml->api_get_c_function
#define sipGetMethod                sipAPI_QtXml->api_get_method
#define sipFromMethod               sipAPI_QtXml->api_from_method
#define sipGetDate                  sipAPI_QtXml->api_get_date
#define sipFromDate                 sipAPI_QtXml->api_from_date
#define sipGetDateTime              sipAPI_QtXml->api_get_datetime
#define sipFromDateTime             sipAPI_QtXml->api_from_datetime
#define sipGetTime                  sipAPI_QtXml->api_get_time
#define sipFromTime                 sipAPI_QtXml->api_from_time
#define sipIsUserType               sipAPI_QtXml->api_is_user_type
#define sipGetFrame                 sipAPI_QtXml->api_get_frame
#define sipCheckPluginForType       sipAPI_QtXml->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtXml->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtXml->api_unicode_write
#define sipUnicodeData              sipAPI_QtXml->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtXml->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtXml->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtXml->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtXml->api_is_derived_class
#define sipGetUserObject            sipAPI_QtXml->api_get_user_object
#define sipSetUserObject            sipAPI_QtXml->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtXml->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtXml->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtXml->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtXml->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtXml->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtXml->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtXml->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtXml->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtXml->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtXml->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtXml->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtXml->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtXml->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtXml->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtXml->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtXml->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtXml->api_map_int_to_class
#define sipFindClass                sipAPI_QtXml->api_find_class
#define sipFindMappedType           sipAPI_QtXml->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtXml->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtXml->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtXml->api_enable_gc
#define sipPrintObject              sipAPI_QtXml->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtXml->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtXml[];

#define sipType_QDomImplementation sipExportedTypes_QtXml[10]
#define sipClass_QDomImplementation sipExportedTypes_QtXml[10]->u.td_wrapper_type

#define sipType_QDomImplementation_InvalidDataPolicy sipExportedTypes_QtXml[11]
#define sipEnum_QDomImplementation_InvalidDataPolicy sipExportedTypes_QtXml[11]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomImplementation;

#define sipType_QDomNode sipExportedTypes_QtXml[13]
#define sipClass_QDomNode sipExportedTypes_QtXml[13]->u.td_wrapper_type

#define sipType_QDomNode_EncodingPolicy sipExportedTypes_QtXml[14]
#define sipEnum_QDomNode_EncodingPolicy sipExportedTypes_QtXml[14]->u.td_py_type

#define sipType_QDomNode_NodeType sipExportedTypes_QtXml[15]
#define sipEnum_QDomNode_NodeType sipExportedTypes_QtXml[15]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomNode;

#define sipType_QDomNodeList sipExportedTypes_QtXml[16]
#define sipClass_QDomNodeList sipExportedTypes_QtXml[16]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomNodeList;

#define sipType_QDomDocumentType sipExportedTypes_QtXml[6]
#define sipClass_QDomDocumentType sipExportedTypes_QtXml[6]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocumentType;

#define sipType_QDomDocument sipExportedTypes_QtXml[4]
#define sipClass_QDomDocument sipExportedTypes_QtXml[4]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocument;

#define sipType_QDomNamedNodeMap sipExportedTypes_QtXml[12]
#define sipClass_QDomNamedNodeMap sipExportedTypes_QtXml[12]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomNamedNodeMap;

#define sipType_QDomDocumentFragment sipExportedTypes_QtXml[5]
#define sipClass_QDomDocumentFragment sipExportedTypes_QtXml[5]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomDocumentFragment;

#define sipType_QDomCharacterData sipExportedTypes_QtXml[2]
#define sipClass_QDomCharacterData sipExportedTypes_QtXml[2]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomCharacterData;

#define sipType_QDomAttr sipExportedTypes_QtXml[0]
#define sipClass_QDomAttr sipExportedTypes_QtXml[0]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomAttr;

#define sipType_QDomElement sipExportedTypes_QtXml[7]
#define sipClass_QDomElement sipExportedTypes_QtXml[7]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomElement;

#define sipType_QDomText sipExportedTypes_QtXml[19]
#define sipClass_QDomText sipExportedTypes_QtXml[19]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomText;

#define sipType_QDomComment sipExportedTypes_QtXml[3]
#define sipClass_QDomComment sipExportedTypes_QtXml[3]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomComment;

#define sipType_QDomCDATASection sipExportedTypes_QtXml[1]
#define sipClass_QDomCDATASection sipExportedTypes_QtXml[1]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomCDATASection;

#define sipType_QDomNotation sipExportedTypes_QtXml[17]
#define sipClass_QDomNotation sipExportedTypes_QtXml[17]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomNotation;

#define sipType_QDomEntity sipExportedTypes_QtXml[8]
#define sipClass_QDomEntity sipExportedTypes_QtXml[8]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomEntity;

#define sipType_QDomEntityReference sipExportedTypes_QtXml[9]
#define sipClass_QDomEntityReference sipExportedTypes_QtXml[9]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomEntityReference;

#define sipType_QDomProcessingInstruction sipExportedTypes_QtXml[18]
#define sipClass_QDomProcessingInstruction sipExportedTypes_QtXml[18]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QDomProcessingInstruction;

#define sipType_QXmlNamespaceSupport sipExportedTypes_QtXml[30]
#define sipClass_QXmlNamespaceSupport sipExportedTypes_QtXml[30]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlNamespaceSupport;

#define sipType_QXmlAttributes sipExportedTypes_QtXml[20]
#define sipClass_QXmlAttributes sipExportedTypes_QtXml[20]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlAttributes;

#define sipType_QXmlInputSource sipExportedTypes_QtXml[27]
#define sipClass_QXmlInputSource sipExportedTypes_QtXml[27]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlInputSource;

#define sipType_QXmlParseException sipExportedTypes_QtXml[31]
#define sipClass_QXmlParseException sipExportedTypes_QtXml[31]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlParseException;

#define sipType_QXmlReader sipExportedTypes_QtXml[32]
#define sipClass_QXmlReader sipExportedTypes_QtXml[32]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlReader;

#define sipType_QXmlSimpleReader sipExportedTypes_QtXml[33]
#define sipClass_QXmlSimpleReader sipExportedTypes_QtXml[33]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlSimpleReader;

#define sipType_QXmlLocator sipExportedTypes_QtXml[29]
#define sipClass_QXmlLocator sipExportedTypes_QtXml[29]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlLocator;

#define sipType_QXmlContentHandler sipExportedTypes_QtXml[21]
#define sipClass_QXmlContentHandler sipExportedTypes_QtXml[21]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlContentHandler;

#define sipType_QXmlErrorHandler sipExportedTypes_QtXml[26]
#define sipClass_QXmlErrorHandler sipExportedTypes_QtXml[26]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlErrorHandler;

#define sipType_QXmlDTDHandler sipExportedTypes_QtXml[22]
#define sipClass_QXmlDTDHandler sipExportedTypes_QtXml[22]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlDTDHandler;

#define sipType_QXmlEntityResolver sipExportedTypes_QtXml[25]
#define sipClass_QXmlEntityResolver sipExportedTypes_QtXml[25]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlEntityResolver;

#define sipType_QXmlLexicalHandler sipExportedTypes_QtXml[28]
#define sipClass_QXmlLexicalHandler sipExportedTypes_QtXml[28]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlLexicalHandler;

#define sipType_QXmlDeclHandler sipExportedTypes_QtXml[23]
#define sipClass_QXmlDeclHandler sipExportedTypes_QtXml[23]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlDeclHandler;

#define sipType_QXmlDefaultHandler sipExportedTypes_QtXml[24]
#define sipClass_QXmlDefaultHandler sipExportedTypes_QtXml[24]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtXml_QXmlDefaultHandler;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtXml;
extern sipExportedModuleDef sipModuleAPI_QtXml;
extern sipTypeDef *sipExportedTypes_QtXml[];

#define sipType_QIODevice sipImportedTypes_QtXml_QtCore[2].it_td
#define sipClass_QIODevice sipImportedTypes_QtXml_QtCore[2].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtXml_QtCore[0].it_td
#define sipClass_QByteArray sipImportedTypes_QtXml_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QTextStream sipImportedTypes_QtXml_QtCore[5].it_td
#define sipClass_QTextStream sipImportedTypes_QtXml_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QXmlStreamReader sipImportedTypes_QtXml_QtCore[6].it_td
#define sipClass_QXmlStreamReader sipImportedTypes_QtXml_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QStringList sipImportedTypes_QtXml_QtCore[4].it_td

#define sipType_QString sipImportedTypes_QtXml_QtCore[3].it_td

#define sipType_QChar sipImportedTypes_QtXml_QtCore[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtXml_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtXml_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtXml_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtXml_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtXml_qt_metacast;

#endif
