/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlincubator.sip"
#include <qqmlincubator.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubator.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubator.cpp"
#line 24 "sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubator.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubator.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlerror.sip"
#include <qqmlerror.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubator.cpp"


class sipQQmlIncubator : public  ::QQmlIncubator
{
public:
    sipQQmlIncubator( ::QQmlIncubator::IncubationMode);
    virtual ~sipQQmlIncubator();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setInitialState( ::QObject*) SIP_OVERRIDE;
    void statusChanged( ::QQmlIncubator::Status) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlIncubator(const sipQQmlIncubator &);
    sipQQmlIncubator &operator = (const sipQQmlIncubator &);

    char sipPyMethods[2];
};

sipQQmlIncubator::sipQQmlIncubator( ::QQmlIncubator::IncubationMode a0):  ::QQmlIncubator(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlIncubator::~sipQQmlIncubator()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQQmlIncubator::setInitialState( ::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_setInitialState);

    if (!sipMeth)
    {
         ::QQmlIncubator::setInitialState(a0);
        return;
    }

    extern void sipVH_QtQml_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*);

    sipVH_QtQml_14(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlIncubator::statusChanged( ::QQmlIncubator::Status a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_statusChanged);

    if (!sipMeth)
    {
         ::QQmlIncubator::statusChanged(a0);
        return;
    }

    extern void sipVH_QtQml_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQmlIncubator::Status);

    sipVH_QtQml_13(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlIncubator_clear, "clear(self)");

extern "C" {static PyObject *meth_QQmlIncubator_clear(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_clear, doc_QQmlIncubator_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_forceCompletion, "forceCompletion(self)");

extern "C" {static PyObject *meth_QQmlIncubator_forceCompletion(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_forceCompletion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            sipCpp->forceCompletion();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_forceCompletion, doc_QQmlIncubator_forceCompletion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QQmlIncubator_isNull(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_isNull, doc_QQmlIncubator_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_isReady, "isReady(self) -> bool");

extern "C" {static PyObject *meth_QQmlIncubator_isReady(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_isReady(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReady();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_isReady, doc_QQmlIncubator_isReady);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_isError, "isError(self) -> bool");

extern "C" {static PyObject *meth_QQmlIncubator_isError(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_isError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_isError, doc_QQmlIncubator_isError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_isLoading, "isLoading(self) -> bool");

extern "C" {static PyObject *meth_QQmlIncubator_isLoading(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_isLoading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLoading();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_isLoading, doc_QQmlIncubator_isLoading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_errors, "errors(self) -> List[QQmlError]");

extern "C" {static PyObject *meth_QQmlIncubator_errors(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_errors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
            QList< ::QQmlError>*sipRes;

            sipRes = new QList< ::QQmlError>(sipCpp->errors());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QQmlError,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_errors, doc_QQmlIncubator_errors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_incubationMode, "incubationMode(self) -> QQmlIncubator.IncubationMode");

extern "C" {static PyObject *meth_QQmlIncubator_incubationMode(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_incubationMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
             ::QQmlIncubator::IncubationMode sipRes;

            sipRes = sipCpp->incubationMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQmlIncubator_IncubationMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_incubationMode, doc_QQmlIncubator_incubationMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_status, "status(self) -> QQmlIncubator.Status");

extern "C" {static PyObject *meth_QQmlIncubator_status(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
             ::QQmlIncubator::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQmlIncubator_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_status, doc_QQmlIncubator_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_object, "object(self) -> QObject");

extern "C" {static PyObject *meth_QQmlIncubator_object(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_object(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubator, &sipCpp))
        {
             ::QObject*sipRes;

            sipRes = sipCpp->object();

            return sipConvertFromNewType(sipRes,sipType_QObject,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_object, doc_QQmlIncubator_object);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_setInitialProperties, "setInitialProperties(self, Dict[str, Any])");

extern "C" {static PyObject *meth_QQmlIncubator_setInitialProperties(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_setInitialProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVariantMap* a0;
        int a0State = 0;
         ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlIncubator, &sipCpp, sipType_QVariantMap,&a0, &a0State))
        {
            sipCpp->setInitialProperties(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0),sipType_QVariantMap,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_setInitialProperties, doc_QQmlIncubator_setInitialProperties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_statusChanged, "statusChanged(self, QQmlIncubator.Status)");

extern "C" {static PyObject *meth_QQmlIncubator_statusChanged(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_statusChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQmlIncubator::Status a0;
         ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QQmlIncubator, &sipCpp, sipType_QQmlIncubator_Status, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QQmlIncubator::statusChanged(a0) : sipCpp->statusChanged(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_statusChanged, doc_QQmlIncubator_statusChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubator_setInitialState, "setInitialState(self, QObject)");

extern "C" {static PyObject *meth_QQmlIncubator_setInitialState(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubator_setInitialState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QObject* a0;
         ::QQmlIncubator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QQmlIncubator, &sipCpp, sipType_QObject, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QQmlIncubator::setInitialState(a0) : sipCpp->setInitialState(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubator, sipName_setInitialState, doc_QQmlIncubator_setInitialState);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlIncubator(void *, int);}
static void release_QQmlIncubator(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQQmlIncubator *>(sipCppV);
    else
        delete reinterpret_cast< ::QQmlIncubator *>(sipCppV);
}


extern "C" {static void *array_QQmlIncubator(Py_ssize_t);}
static void *array_QQmlIncubator(Py_ssize_t sipNrElem)
{
    return new  ::QQmlIncubator[sipNrElem];
}


extern "C" {static void dealloc_QQmlIncubator(sipSimpleWrapper *);}
static void dealloc_QQmlIncubator(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlIncubator *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlIncubator(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlIncubator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlIncubator(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQmlIncubator *sipCpp = SIP_NULLPTR;

    {
         ::QQmlIncubator::IncubationMode a0 = QQmlIncubator::Asynchronous;

        static const char *sipKwdList[] = {
            sipName_mode,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|E", sipType_QQmlIncubator_IncubationMode, &a0))
        {
            sipCpp = new sipQQmlIncubator(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQmlIncubator[] = {
    {SIP_MLNAME_CAST(sipName_clear), meth_QQmlIncubator_clear, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_clear)},
    {SIP_MLNAME_CAST(sipName_errors), meth_QQmlIncubator_errors, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_errors)},
    {SIP_MLNAME_CAST(sipName_forceCompletion), meth_QQmlIncubator_forceCompletion, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_forceCompletion)},
    {SIP_MLNAME_CAST(sipName_incubationMode), meth_QQmlIncubator_incubationMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_incubationMode)},
    {SIP_MLNAME_CAST(sipName_isError), meth_QQmlIncubator_isError, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_isError)},
    {SIP_MLNAME_CAST(sipName_isLoading), meth_QQmlIncubator_isLoading, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_isLoading)},
    {SIP_MLNAME_CAST(sipName_isNull), meth_QQmlIncubator_isNull, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_isNull)},
    {SIP_MLNAME_CAST(sipName_isReady), meth_QQmlIncubator_isReady, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_isReady)},
    {SIP_MLNAME_CAST(sipName_object), meth_QQmlIncubator_object, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_object)},
    {SIP_MLNAME_CAST(sipName_setInitialProperties), meth_QQmlIncubator_setInitialProperties, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_setInitialProperties)},
    {SIP_MLNAME_CAST(sipName_setInitialState), meth_QQmlIncubator_setInitialState, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_setInitialState)},
    {SIP_MLNAME_CAST(sipName_status), meth_QQmlIncubator_status, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_status)},
    {SIP_MLNAME_CAST(sipName_statusChanged), meth_QQmlIncubator_statusChanged, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubator_statusChanged)}
};

static sipEnumMemberDef enummembers_QQmlIncubator[] = {
    {sipName_Asynchronous, static_cast<int>( ::QQmlIncubator::Asynchronous), 31},
    {sipName_AsynchronousIfNested, static_cast<int>( ::QQmlIncubator::AsynchronousIfNested), 31},
    {sipName_Error, static_cast<int>( ::QQmlIncubator::Error), 32},
    {sipName_Loading, static_cast<int>( ::QQmlIncubator::Loading), 32},
    {sipName_Null, static_cast<int>( ::QQmlIncubator::Null), 32},
    {sipName_Ready, static_cast<int>( ::QQmlIncubator::Ready), 32},
    {sipName_Synchronous, static_cast<int>( ::QQmlIncubator::Synchronous), 31},
};

PyDoc_STRVAR(doc_QQmlIncubator, "\1QQmlIncubator(mode: QQmlIncubator.IncubationMode = QQmlIncubator.Asynchronous)");


static pyqt5ClassPluginDef plugin_QQmlIncubator = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlIncubator = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlIncubator,
        {SIP_NULLPTR},
        &plugin_QQmlIncubator
    },
    {
        sipNameNr_QQmlIncubator,
        {0, 0, 1},
        13, methods_QQmlIncubator,
        7, enummembers_QQmlIncubator,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlIncubator,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQmlIncubator,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlIncubator,
    SIP_NULLPTR,
    array_QQmlIncubator,
    SIP_NULLPTR,
    release_QQmlIncubator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
