/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlabstracturlinterceptor.sip"
#include <qqmlabstracturlinterceptor.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlAbstractUrlInterceptor.cpp"

#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlAbstractUrlInterceptor.cpp"


class sipQQmlAbstractUrlInterceptor : public  ::QQmlAbstractUrlInterceptor
{
public:
    sipQQmlAbstractUrlInterceptor();
    sipQQmlAbstractUrlInterceptor(const  ::QQmlAbstractUrlInterceptor&);
    virtual ~sipQQmlAbstractUrlInterceptor();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
     ::QUrl intercept(const  ::QUrl&, ::QQmlAbstractUrlInterceptor::DataType) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlAbstractUrlInterceptor(const sipQQmlAbstractUrlInterceptor &);
    sipQQmlAbstractUrlInterceptor &operator = (const sipQQmlAbstractUrlInterceptor &);

    char sipPyMethods[1];
};

sipQQmlAbstractUrlInterceptor::sipQQmlAbstractUrlInterceptor():  ::QQmlAbstractUrlInterceptor(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlAbstractUrlInterceptor::sipQQmlAbstractUrlInterceptor(const  ::QQmlAbstractUrlInterceptor& a0):  ::QQmlAbstractUrlInterceptor(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlAbstractUrlInterceptor::~sipQQmlAbstractUrlInterceptor()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

 ::QUrl sipQQmlAbstractUrlInterceptor::intercept(const  ::QUrl& a0, ::QQmlAbstractUrlInterceptor::DataType a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,sipName_QQmlAbstractUrlInterceptor,sipName_intercept);

    if (!sipMeth)
        return  ::QUrl();

    extern  ::QUrl sipVH_QtQml_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QUrl&, ::QQmlAbstractUrlInterceptor::DataType);

    return sipVH_QtQml_6(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}


PyDoc_STRVAR(doc_QQmlAbstractUrlInterceptor_intercept, "intercept(self, QUrl, QQmlAbstractUrlInterceptor.DataType) -> QUrl");

extern "C" {static PyObject *meth_QQmlAbstractUrlInterceptor_intercept(PyObject *, PyObject *);}
static PyObject *meth_QQmlAbstractUrlInterceptor_intercept(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QUrl* a0;
         ::QQmlAbstractUrlInterceptor::DataType a1;
         ::QQmlAbstractUrlInterceptor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9E", &sipSelf, sipType_QQmlAbstractUrlInterceptor, &sipCpp, sipType_QUrl, &a0, sipType_QQmlAbstractUrlInterceptor_DataType, &a1))
        {
             ::QUrl*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlAbstractUrlInterceptor, sipName_intercept);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QUrl(sipCpp->intercept(*a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlAbstractUrlInterceptor, sipName_intercept, doc_QQmlAbstractUrlInterceptor_intercept);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlAbstractUrlInterceptor(void *, int);}
static void release_QQmlAbstractUrlInterceptor(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQQmlAbstractUrlInterceptor *>(sipCppV);
    else
        delete reinterpret_cast< ::QQmlAbstractUrlInterceptor *>(sipCppV);
}


extern "C" {static void dealloc_QQmlAbstractUrlInterceptor(sipSimpleWrapper *);}
static void dealloc_QQmlAbstractUrlInterceptor(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlAbstractUrlInterceptor *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlAbstractUrlInterceptor(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlAbstractUrlInterceptor(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlAbstractUrlInterceptor(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQmlAbstractUrlInterceptor *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQmlAbstractUrlInterceptor();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QQmlAbstractUrlInterceptor* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQmlAbstractUrlInterceptor, &a0))
        {
            sipCpp = new sipQQmlAbstractUrlInterceptor(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQmlAbstractUrlInterceptor[] = {
    {SIP_MLNAME_CAST(sipName_intercept), meth_QQmlAbstractUrlInterceptor_intercept, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlAbstractUrlInterceptor_intercept)}
};

static sipEnumMemberDef enummembers_QQmlAbstractUrlInterceptor[] = {
    {sipName_JavaScriptFile, static_cast<int>( ::QQmlAbstractUrlInterceptor::JavaScriptFile), 11},
    {sipName_QmlFile, static_cast<int>( ::QQmlAbstractUrlInterceptor::QmlFile), 11},
    {sipName_QmldirFile, static_cast<int>( ::QQmlAbstractUrlInterceptor::QmldirFile), 11},
    {sipName_UrlString, static_cast<int>( ::QQmlAbstractUrlInterceptor::UrlString), 11},
};

PyDoc_STRVAR(doc_QQmlAbstractUrlInterceptor, "\1QQmlAbstractUrlInterceptor()\n"
"QQmlAbstractUrlInterceptor(QQmlAbstractUrlInterceptor)");


static pyqt5ClassPluginDef plugin_QQmlAbstractUrlInterceptor = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlAbstractUrlInterceptor = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlAbstractUrlInterceptor,
        {SIP_NULLPTR},
        &plugin_QQmlAbstractUrlInterceptor
    },
    {
        sipNameNr_QQmlAbstractUrlInterceptor,
        {0, 0, 1},
        1, methods_QQmlAbstractUrlInterceptor,
        4, enummembers_QQmlAbstractUrlInterceptor,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlAbstractUrlInterceptor,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQmlAbstractUrlInterceptor,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlAbstractUrlInterceptor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlAbstractUrlInterceptor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
