/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 31 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickItemItemChangeData.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickItemItemChangeData.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickItemItemChangeData.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QQuickItem_ItemChangeData(void *, int);}
static void release_QQuickItem_ItemChangeData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipCppV);
}


extern "C" {static void assign_QQuickItem_ItemChangeData(void *, SIP_SSIZE_T, void *);}
static void assign_QQuickItem_ItemChangeData(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSrc);
}


extern "C" {static void *copy_QQuickItem_ItemChangeData(const void *, SIP_SSIZE_T);}
static void *copy_QQuickItem_ItemChangeData(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QQuickItem::ItemChangeData(reinterpret_cast<const  ::QQuickItem::ItemChangeData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuickItem_ItemChangeData(sipSimpleWrapper *);}
static void dealloc_QQuickItem_ItemChangeData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickItem_ItemChangeData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuickItem_ItemChangeData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickItem_ItemChangeData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QQuickItem::ItemChangeData *sipCpp = SIP_NULLPTR;

    {
         ::QQuickItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QQuickItem, &a0))
        {
            sipCpp = new  ::QQuickItem::ItemChangeData(a0);

            return sipCpp;
        }
    }

    {
         ::QQuickWindow* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QQuickWindow, &a0))
        {
            sipCpp = new  ::QQuickItem::ItemChangeData(a0);

            return sipCpp;
        }
    }

    {
         ::qreal a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Xd", &a0))
        {
            sipCpp = new  ::QQuickItem::ItemChangeData(a0);

            return sipCpp;
        }
    }

    {
        bool a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Xb", &a0))
        {
            sipCpp = new  ::QQuickItem::ItemChangeData(a0);

            return sipCpp;
        }
    }

    {
        const  ::QQuickItem::ItemChangeData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuickItem_ItemChangeData, &a0))
        {
            sipCpp = new  ::QQuickItem::ItemChangeData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QQuickItem_ItemChangeData_boolValue(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuickItem_ItemChangeData_boolValue(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = sipCpp->boolValue;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QQuickItem_ItemChangeData_boolValue(void *, PyObject *, PyObject *);}
static int varset_QQuickItem_ItemChangeData_boolValue(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->boolValue = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QQuickItem_ItemChangeData_item(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuickItem_ItemChangeData_item(void *sipSelf, PyObject *, PyObject *)
{
     ::QQuickItem*sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = sipCpp->item;

    return sipConvertFromType(sipVal, sipType_QQuickItem, SIP_NULLPTR);
}


extern "C" {static int varset_QQuickItem_ItemChangeData_item(void *, PyObject *, PyObject *);}
static int varset_QQuickItem_ItemChangeData_item(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QQuickItem*sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QQuickItem *>(sipForceConvertToType(sipPy, sipType_QQuickItem, SIP_NULLPTR, 0, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->item = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuickItem_ItemChangeData_realValue(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuickItem_ItemChangeData_realValue(void *sipSelf, PyObject *, PyObject *)
{
     ::qreal sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = sipCpp->realValue;

    return PyFloat_FromDouble(sipVal);
}


extern "C" {static int varset_QQuickItem_ItemChangeData_realValue(void *, PyObject *, PyObject *);}
static int varset_QQuickItem_ItemChangeData_realValue(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::qreal sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = PyFloat_AsDouble(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->realValue = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QQuickItem_ItemChangeData_window(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuickItem_ItemChangeData_window(void *sipSelf, PyObject *, PyObject *)
{
     ::QQuickWindow*sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    sipVal = sipCpp->window;

    return sipConvertFromType(sipVal, sipType_QQuickWindow, SIP_NULLPTR);
}


extern "C" {static int varset_QQuickItem_ItemChangeData_window(void *, PyObject *, PyObject *);}
static int varset_QQuickItem_ItemChangeData_window(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QQuickWindow*sipVal;
     ::QQuickItem::ItemChangeData *sipCpp = reinterpret_cast< ::QQuickItem::ItemChangeData *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QQuickWindow *>(sipForceConvertToType(sipPy, sipType_QQuickWindow, SIP_NULLPTR, 0, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->window = sipVal;

    return 0;
}

sipVariableDef variables_QQuickItem_ItemChangeData[] = {
    {InstanceVariable, sipName_boolValue, (PyMethodDef *)varget_QQuickItem_ItemChangeData_boolValue, (PyMethodDef *)varset_QQuickItem_ItemChangeData_boolValue, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_item, (PyMethodDef *)varget_QQuickItem_ItemChangeData_item, (PyMethodDef *)varset_QQuickItem_ItemChangeData_item, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_realValue, (PyMethodDef *)varget_QQuickItem_ItemChangeData_realValue, (PyMethodDef *)varset_QQuickItem_ItemChangeData_realValue, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_window, (PyMethodDef *)varget_QQuickItem_ItemChangeData_window, (PyMethodDef *)varset_QQuickItem_ItemChangeData_window, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QQuickItem_ItemChangeData, "\1QQuickItem.ItemChangeData(QQuickItem)\n"
"QQuickItem.ItemChangeData(QQuickWindow)\n"
"QQuickItem.ItemChangeData(float)\n"
"QQuickItem.ItemChangeData(bool)\n"
"QQuickItem.ItemChangeData(QQuickItem.ItemChangeData)");


static pyqt5ClassPluginDef plugin_QQuickItem_ItemChangeData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_ItemChangeData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickItem__ItemChangeData,
        {SIP_NULLPTR},
        &plugin_QQuickItem_ItemChangeData
    },
    {
        sipNameNr_ItemChangeData,
        {7, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        4, variables_QQuickItem_ItemChangeData,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickItem_ItemChangeData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuickItem_ItemChangeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQuickItem_ItemChangeData,
    assign_QQuickItem_ItemChangeData,
    SIP_NULLPTR,
    copy_QQuickItem_ItemChangeData,
    release_QQuickItem_ItemChangeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
