/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 294 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 27 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 283 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 262 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 243 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 224 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQXmlStreamReader.cpp"


PyDoc_STRVAR(doc_QXmlStreamReader_setDevice, "setDevice(self, QIODevice)");

extern "C" {static PyObject *meth_QXmlStreamReader_setDevice(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_setDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QIODevice* a0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_setDevice, doc_QXmlStreamReader_setDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_device, "device(self) -> QIODevice");

extern "C" {static PyObject *meth_QXmlStreamReader_device(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_device(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QIODevice*sipRes;

            sipRes = sipCpp->device();

            return sipConvertFromType(sipRes,sipType_QIODevice,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_device, doc_QXmlStreamReader_device);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_addData, "addData(self, Union[QByteArray, bytes, bytearray])\n"
"addData(self, str)");

extern "C" {static PyObject *meth_QXmlStreamReader_addData(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_addData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->addData(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->addData(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_addData, doc_QXmlStreamReader_addData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_clear, "clear(self)");

extern "C" {static PyObject *meth_QXmlStreamReader_clear(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_clear, doc_QXmlStreamReader_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_atEnd, "atEnd(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_atEnd(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_atEnd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->atEnd();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_atEnd, doc_QXmlStreamReader_atEnd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_readNext, "readNext(self) -> QXmlStreamReader.TokenType");

extern "C" {static PyObject *meth_QXmlStreamReader_readNext(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_readNext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamReader::TokenType sipRes;

            sipRes = sipCpp->readNext();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlStreamReader_TokenType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_readNext, doc_QXmlStreamReader_readNext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_tokenType, "tokenType(self) -> QXmlStreamReader.TokenType");

extern "C" {static PyObject *meth_QXmlStreamReader_tokenType(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_tokenType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamReader::TokenType sipRes;

            sipRes = sipCpp->tokenType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlStreamReader_TokenType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_tokenType, doc_QXmlStreamReader_tokenType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_tokenString, "tokenString(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_tokenString(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_tokenString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->tokenString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_tokenString, doc_QXmlStreamReader_tokenString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_setNamespaceProcessing, "setNamespaceProcessing(self, bool)");

extern "C" {static PyObject *meth_QXmlStreamReader_setNamespaceProcessing(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_setNamespaceProcessing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QXmlStreamReader, &sipCpp, &a0))
        {
            sipCpp->setNamespaceProcessing(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_setNamespaceProcessing, doc_QXmlStreamReader_setNamespaceProcessing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_namespaceProcessing, "namespaceProcessing(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_namespaceProcessing(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_namespaceProcessing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->namespaceProcessing();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_namespaceProcessing, doc_QXmlStreamReader_namespaceProcessing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isStartDocument, "isStartDocument(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isStartDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isStartDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isStartDocument();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isStartDocument, doc_QXmlStreamReader_isStartDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isEndDocument, "isEndDocument(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isEndDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isEndDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEndDocument();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isEndDocument, doc_QXmlStreamReader_isEndDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isStartElement, "isStartElement(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isStartElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isStartElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isStartElement();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isStartElement, doc_QXmlStreamReader_isStartElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isEndElement, "isEndElement(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isEndElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isEndElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEndElement();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isEndElement, doc_QXmlStreamReader_isEndElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isCharacters, "isCharacters(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isCharacters(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isCharacters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCharacters();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isCharacters, doc_QXmlStreamReader_isCharacters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isWhitespace, "isWhitespace(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isWhitespace(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isWhitespace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isWhitespace();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isWhitespace, doc_QXmlStreamReader_isWhitespace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isCDATA, "isCDATA(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isCDATA(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isCDATA(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCDATA();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isCDATA, doc_QXmlStreamReader_isCDATA);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isComment, "isComment(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isComment(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isComment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isComment();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isComment, doc_QXmlStreamReader_isComment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isDTD, "isDTD(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isDTD(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isDTD(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDTD();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isDTD, doc_QXmlStreamReader_isDTD);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isEntityReference, "isEntityReference(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isEntityReference(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isEntityReference(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEntityReference();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isEntityReference, doc_QXmlStreamReader_isEntityReference);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isProcessingInstruction, "isProcessingInstruction(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isProcessingInstruction(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isProcessingInstruction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isProcessingInstruction();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isProcessingInstruction, doc_QXmlStreamReader_isProcessingInstruction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_isStandaloneDocument, "isStandaloneDocument(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_isStandaloneDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_isStandaloneDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isStandaloneDocument();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_isStandaloneDocument, doc_QXmlStreamReader_isStandaloneDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_documentVersion, "documentVersion(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_documentVersion(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_documentVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->documentVersion());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_documentVersion, doc_QXmlStreamReader_documentVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_documentEncoding, "documentEncoding(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_documentEncoding(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_documentEncoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->documentEncoding());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_documentEncoding, doc_QXmlStreamReader_documentEncoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_lineNumber, "lineNumber(self) -> int");

extern "C" {static PyObject *meth_QXmlStreamReader_lineNumber(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_lineNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->lineNumber();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_lineNumber, doc_QXmlStreamReader_lineNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_columnNumber, "columnNumber(self) -> int");

extern "C" {static PyObject *meth_QXmlStreamReader_columnNumber(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_columnNumber(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->columnNumber();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_columnNumber, doc_QXmlStreamReader_columnNumber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_characterOffset, "characterOffset(self) -> int");

extern "C" {static PyObject *meth_QXmlStreamReader_characterOffset(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_characterOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->characterOffset();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_characterOffset, doc_QXmlStreamReader_characterOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_attributes, "attributes(self) -> QXmlStreamAttributes");

extern "C" {static PyObject *meth_QXmlStreamReader_attributes(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_attributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamAttributes*sipRes;

            sipRes = new  ::QXmlStreamAttributes(sipCpp->attributes());

            return sipConvertFromNewType(sipRes,sipType_QXmlStreamAttributes,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_attributes, doc_QXmlStreamReader_attributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_readElementText, "readElementText(self, behaviour: QXmlStreamReader.ReadElementTextBehaviour = QXmlStreamReader.ErrorOnUnexpectedElement) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_readElementText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_readElementText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamReader::ReadElementTextBehaviour a0 = QXmlStreamReader::ErrorOnUnexpectedElement;
         ::QXmlStreamReader *sipCpp;

        static const char *sipKwdList[] = {
            sipName_behaviour,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QXmlStreamReader_ReadElementTextBehaviour, &a0))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readElementText(a0));

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_readElementText, doc_QXmlStreamReader_readElementText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_name, "name(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_name(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->name());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_name, doc_QXmlStreamReader_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_namespaceUri, "namespaceUri(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_namespaceUri(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_namespaceUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->namespaceUri());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_namespaceUri, doc_QXmlStreamReader_namespaceUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_qualifiedName, "qualifiedName(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_qualifiedName(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_qualifiedName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->qualifiedName());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_qualifiedName, doc_QXmlStreamReader_qualifiedName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_prefix, "prefix(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_prefix(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_prefix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->prefix());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_prefix, doc_QXmlStreamReader_prefix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_processingInstructionTarget, "processingInstructionTarget(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_processingInstructionTarget(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_processingInstructionTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->processingInstructionTarget());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_processingInstructionTarget, doc_QXmlStreamReader_processingInstructionTarget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_processingInstructionData, "processingInstructionData(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_processingInstructionData(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_processingInstructionData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->processingInstructionData());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_processingInstructionData, doc_QXmlStreamReader_processingInstructionData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_text, "text(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_text(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->text());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_text, doc_QXmlStreamReader_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_namespaceDeclarations, "namespaceDeclarations(self) -> List[QXmlStreamNamespaceDeclaration]");

extern "C" {static PyObject *meth_QXmlStreamReader_namespaceDeclarations(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_namespaceDeclarations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamNamespaceDeclarations*sipRes;

            sipRes = new  ::QXmlStreamNamespaceDeclarations(sipCpp->namespaceDeclarations());

            return sipConvertFromNewType(sipRes,sipType_QVector_0100QXmlStreamNamespaceDeclaration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_namespaceDeclarations, doc_QXmlStreamReader_namespaceDeclarations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_addExtraNamespaceDeclaration, "addExtraNamespaceDeclaration(self, QXmlStreamNamespaceDeclaration)");

extern "C" {static PyObject *meth_QXmlStreamReader_addExtraNamespaceDeclaration(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_addExtraNamespaceDeclaration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamNamespaceDeclaration* a0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QXmlStreamNamespaceDeclaration, &a0))
        {
            sipCpp->addExtraNamespaceDeclaration(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_addExtraNamespaceDeclaration, doc_QXmlStreamReader_addExtraNamespaceDeclaration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_addExtraNamespaceDeclarations, "addExtraNamespaceDeclarations(self, Iterable[QXmlStreamNamespaceDeclaration])");

extern "C" {static PyObject *meth_QXmlStreamReader_addExtraNamespaceDeclarations(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_addExtraNamespaceDeclarations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamNamespaceDeclarations* a0;
        int a0State = 0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QVector_0100QXmlStreamNamespaceDeclaration,&a0, &a0State))
        {
            sipCpp->addExtraNamespaceDeclarations(*a0);
            sipReleaseType(const_cast< ::QXmlStreamNamespaceDeclarations *>(a0),sipType_QVector_0100QXmlStreamNamespaceDeclaration,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_addExtraNamespaceDeclarations, doc_QXmlStreamReader_addExtraNamespaceDeclarations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_notationDeclarations, "notationDeclarations(self) -> List[QXmlStreamNotationDeclaration]");

extern "C" {static PyObject *meth_QXmlStreamReader_notationDeclarations(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_notationDeclarations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamNotationDeclarations*sipRes;

            sipRes = new  ::QXmlStreamNotationDeclarations(sipCpp->notationDeclarations());

            return sipConvertFromNewType(sipRes,sipType_QVector_0100QXmlStreamNotationDeclaration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_notationDeclarations, doc_QXmlStreamReader_notationDeclarations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_entityDeclarations, "entityDeclarations(self) -> List[QXmlStreamEntityDeclaration]");

extern "C" {static PyObject *meth_QXmlStreamReader_entityDeclarations(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_entityDeclarations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamEntityDeclarations*sipRes;

            sipRes = new  ::QXmlStreamEntityDeclarations(sipCpp->entityDeclarations());

            return sipConvertFromNewType(sipRes,sipType_QVector_0100QXmlStreamEntityDeclaration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_entityDeclarations, doc_QXmlStreamReader_entityDeclarations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_dtdName, "dtdName(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_dtdName(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_dtdName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->dtdName());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_dtdName, doc_QXmlStreamReader_dtdName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_dtdPublicId, "dtdPublicId(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_dtdPublicId(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_dtdPublicId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->dtdPublicId());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_dtdPublicId, doc_QXmlStreamReader_dtdPublicId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_dtdSystemId, "dtdSystemId(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_dtdSystemId(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_dtdSystemId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QStringRef*sipRes;

            sipRes = new  ::QStringRef(sipCpp->dtdSystemId());

            return sipConvertFromNewType(sipRes,sipType_QStringRef,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_dtdSystemId, doc_QXmlStreamReader_dtdSystemId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_raiseError, "raiseError(self, message: str = '')");

extern "C" {static PyObject *meth_QXmlStreamReader_raiseError(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_raiseError(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString& a0def = QString();
        const  ::QString* a0 = &a0def;
        int a0State = 0;
         ::QXmlStreamReader *sipCpp;

        static const char *sipKwdList[] = {
            sipName_message,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QXmlStreamReader, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->raiseError(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_raiseError, doc_QXmlStreamReader_raiseError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamReader_errorString(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_errorString, doc_QXmlStreamReader_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_error, "error(self) -> QXmlStreamReader.Error");

extern "C" {static PyObject *meth_QXmlStreamReader_error(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamReader::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlStreamReader_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_error, doc_QXmlStreamReader_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_hasError, "hasError(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_hasError(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_hasError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_hasError, doc_QXmlStreamReader_hasError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_setEntityResolver, "setEntityResolver(self, QXmlStreamEntityResolver)");

extern "C" {static PyObject *meth_QXmlStreamReader_setEntityResolver(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_setEntityResolver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamEntityResolver* a0;
        PyObject *a0Keep;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QXmlStreamReader, &sipCpp, &a0Keep, sipType_QXmlStreamEntityResolver, &a0))
        {
            sipCpp->setEntityResolver(a0);

            sipKeepReference(sipSelf, -12, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_setEntityResolver, doc_QXmlStreamReader_setEntityResolver);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_entityResolver, "entityResolver(self) -> QXmlStreamEntityResolver");

extern "C" {static PyObject *meth_QXmlStreamReader_entityResolver(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_entityResolver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
             ::QXmlStreamEntityResolver*sipRes;

            sipRes = sipCpp->entityResolver();

            return sipConvertFromType(sipRes,sipType_QXmlStreamEntityResolver,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_entityResolver, doc_QXmlStreamReader_entityResolver);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_readNextStartElement, "readNextStartElement(self) -> bool");

extern "C" {static PyObject *meth_QXmlStreamReader_readNextStartElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_readNextStartElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->readNextStartElement();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_readNextStartElement, doc_QXmlStreamReader_readNextStartElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_skipCurrentElement, "skipCurrentElement(self)");

extern "C" {static PyObject *meth_QXmlStreamReader_skipCurrentElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_skipCurrentElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            sipCpp->skipCurrentElement();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_skipCurrentElement, doc_QXmlStreamReader_skipCurrentElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_entityExpansionLimit, "entityExpansionLimit(self) -> int");

extern "C" {static PyObject *meth_QXmlStreamReader_entityExpansionLimit(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_entityExpansionLimit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamReader, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->entityExpansionLimit();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_entityExpansionLimit, doc_QXmlStreamReader_entityExpansionLimit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamReader_setEntityExpansionLimit, "setEntityExpansionLimit(self, int)");

extern "C" {static PyObject *meth_QXmlStreamReader_setEntityExpansionLimit(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamReader_setEntityExpansionLimit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QXmlStreamReader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QXmlStreamReader, &sipCpp, &a0))
        {
            sipCpp->setEntityExpansionLimit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamReader, sipName_setEntityExpansionLimit, doc_QXmlStreamReader_setEntityExpansionLimit);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlStreamReader(void *, int);}
static void release_QXmlStreamReader(void *sipCppV, int)
{
    delete reinterpret_cast< ::QXmlStreamReader *>(sipCppV);
}


extern "C" {static void *array_QXmlStreamReader(Py_ssize_t);}
static void *array_QXmlStreamReader(Py_ssize_t sipNrElem)
{
    return new  ::QXmlStreamReader[sipNrElem];
}


extern "C" {static void dealloc_QXmlStreamReader(sipSimpleWrapper *);}
static void dealloc_QXmlStreamReader(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlStreamReader(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlStreamReader(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlStreamReader(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QXmlStreamReader *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QXmlStreamReader();

            return sipCpp;
        }
    }

    {
         ::QIODevice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QIODevice, &a0))
        {
            sipCpp = new  ::QXmlStreamReader(a0);

            return sipCpp;
        }
    }

    {
        const  ::QByteArray* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QByteArray, &a0, &a0State))
        {
            sipCpp = new  ::QXmlStreamReader(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString,&a0, &a0State))
        {
            sipCpp = new  ::QXmlStreamReader(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QXmlStreamReader[] = {
    {SIP_MLNAME_CAST(sipName_addData), meth_QXmlStreamReader_addData, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_addData)},
    {SIP_MLNAME_CAST(sipName_addExtraNamespaceDeclaration), meth_QXmlStreamReader_addExtraNamespaceDeclaration, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_addExtraNamespaceDeclaration)},
    {SIP_MLNAME_CAST(sipName_addExtraNamespaceDeclarations), meth_QXmlStreamReader_addExtraNamespaceDeclarations, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_addExtraNamespaceDeclarations)},
    {SIP_MLNAME_CAST(sipName_atEnd), meth_QXmlStreamReader_atEnd, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_atEnd)},
    {SIP_MLNAME_CAST(sipName_attributes), meth_QXmlStreamReader_attributes, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_attributes)},
    {SIP_MLNAME_CAST(sipName_characterOffset), meth_QXmlStreamReader_characterOffset, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_characterOffset)},
    {SIP_MLNAME_CAST(sipName_clear), meth_QXmlStreamReader_clear, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_clear)},
    {SIP_MLNAME_CAST(sipName_columnNumber), meth_QXmlStreamReader_columnNumber, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_columnNumber)},
    {SIP_MLNAME_CAST(sipName_device), meth_QXmlStreamReader_device, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_device)},
    {SIP_MLNAME_CAST(sipName_documentEncoding), meth_QXmlStreamReader_documentEncoding, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_documentEncoding)},
    {SIP_MLNAME_CAST(sipName_documentVersion), meth_QXmlStreamReader_documentVersion, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_documentVersion)},
    {SIP_MLNAME_CAST(sipName_dtdName), meth_QXmlStreamReader_dtdName, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_dtdName)},
    {SIP_MLNAME_CAST(sipName_dtdPublicId), meth_QXmlStreamReader_dtdPublicId, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_dtdPublicId)},
    {SIP_MLNAME_CAST(sipName_dtdSystemId), meth_QXmlStreamReader_dtdSystemId, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_dtdSystemId)},
    {SIP_MLNAME_CAST(sipName_entityDeclarations), meth_QXmlStreamReader_entityDeclarations, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_entityDeclarations)},
    {SIP_MLNAME_CAST(sipName_entityExpansionLimit), meth_QXmlStreamReader_entityExpansionLimit, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_entityExpansionLimit)},
    {SIP_MLNAME_CAST(sipName_entityResolver), meth_QXmlStreamReader_entityResolver, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_entityResolver)},
    {SIP_MLNAME_CAST(sipName_error), meth_QXmlStreamReader_error, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_error)},
    {SIP_MLNAME_CAST(sipName_errorString), meth_QXmlStreamReader_errorString, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_errorString)},
    {SIP_MLNAME_CAST(sipName_hasError), meth_QXmlStreamReader_hasError, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_hasError)},
    {SIP_MLNAME_CAST(sipName_isCDATA), meth_QXmlStreamReader_isCDATA, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isCDATA)},
    {SIP_MLNAME_CAST(sipName_isCharacters), meth_QXmlStreamReader_isCharacters, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isCharacters)},
    {SIP_MLNAME_CAST(sipName_isComment), meth_QXmlStreamReader_isComment, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isComment)},
    {SIP_MLNAME_CAST(sipName_isDTD), meth_QXmlStreamReader_isDTD, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isDTD)},
    {SIP_MLNAME_CAST(sipName_isEndDocument), meth_QXmlStreamReader_isEndDocument, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isEndDocument)},
    {SIP_MLNAME_CAST(sipName_isEndElement), meth_QXmlStreamReader_isEndElement, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isEndElement)},
    {SIP_MLNAME_CAST(sipName_isEntityReference), meth_QXmlStreamReader_isEntityReference, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isEntityReference)},
    {SIP_MLNAME_CAST(sipName_isProcessingInstruction), meth_QXmlStreamReader_isProcessingInstruction, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isProcessingInstruction)},
    {SIP_MLNAME_CAST(sipName_isStandaloneDocument), meth_QXmlStreamReader_isStandaloneDocument, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isStandaloneDocument)},
    {SIP_MLNAME_CAST(sipName_isStartDocument), meth_QXmlStreamReader_isStartDocument, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isStartDocument)},
    {SIP_MLNAME_CAST(sipName_isStartElement), meth_QXmlStreamReader_isStartElement, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isStartElement)},
    {SIP_MLNAME_CAST(sipName_isWhitespace), meth_QXmlStreamReader_isWhitespace, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_isWhitespace)},
    {SIP_MLNAME_CAST(sipName_lineNumber), meth_QXmlStreamReader_lineNumber, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_lineNumber)},
    {SIP_MLNAME_CAST(sipName_name), meth_QXmlStreamReader_name, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_name)},
    {SIP_MLNAME_CAST(sipName_namespaceDeclarations), meth_QXmlStreamReader_namespaceDeclarations, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_namespaceDeclarations)},
    {SIP_MLNAME_CAST(sipName_namespaceProcessing), meth_QXmlStreamReader_namespaceProcessing, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_namespaceProcessing)},
    {SIP_MLNAME_CAST(sipName_namespaceUri), meth_QXmlStreamReader_namespaceUri, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_namespaceUri)},
    {SIP_MLNAME_CAST(sipName_notationDeclarations), meth_QXmlStreamReader_notationDeclarations, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_notationDeclarations)},
    {SIP_MLNAME_CAST(sipName_prefix), meth_QXmlStreamReader_prefix, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_prefix)},
    {SIP_MLNAME_CAST(sipName_processingInstructionData), meth_QXmlStreamReader_processingInstructionData, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_processingInstructionData)},
    {SIP_MLNAME_CAST(sipName_processingInstructionTarget), meth_QXmlStreamReader_processingInstructionTarget, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_processingInstructionTarget)},
    {SIP_MLNAME_CAST(sipName_qualifiedName), meth_QXmlStreamReader_qualifiedName, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_qualifiedName)},
    {SIP_MLNAME_CAST(sipName_raiseError), SIP_MLMETH_CAST(meth_QXmlStreamReader_raiseError), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QXmlStreamReader_raiseError)},
    {SIP_MLNAME_CAST(sipName_readElementText), SIP_MLMETH_CAST(meth_QXmlStreamReader_readElementText), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QXmlStreamReader_readElementText)},
    {SIP_MLNAME_CAST(sipName_readNext), meth_QXmlStreamReader_readNext, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_readNext)},
    {SIP_MLNAME_CAST(sipName_readNextStartElement), meth_QXmlStreamReader_readNextStartElement, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_readNextStartElement)},
    {SIP_MLNAME_CAST(sipName_setDevice), meth_QXmlStreamReader_setDevice, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_setDevice)},
    {SIP_MLNAME_CAST(sipName_setEntityExpansionLimit), meth_QXmlStreamReader_setEntityExpansionLimit, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_setEntityExpansionLimit)},
    {SIP_MLNAME_CAST(sipName_setEntityResolver), meth_QXmlStreamReader_setEntityResolver, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_setEntityResolver)},
    {SIP_MLNAME_CAST(sipName_setNamespaceProcessing), meth_QXmlStreamReader_setNamespaceProcessing, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_setNamespaceProcessing)},
    {SIP_MLNAME_CAST(sipName_skipCurrentElement), meth_QXmlStreamReader_skipCurrentElement, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_skipCurrentElement)},
    {SIP_MLNAME_CAST(sipName_text), meth_QXmlStreamReader_text, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_text)},
    {SIP_MLNAME_CAST(sipName_tokenString), meth_QXmlStreamReader_tokenString, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_tokenString)},
    {SIP_MLNAME_CAST(sipName_tokenType), meth_QXmlStreamReader_tokenType, METH_VARARGS, SIP_MLDOC_CAST(doc_QXmlStreamReader_tokenType)}
};

static sipEnumMemberDef enummembers_QXmlStreamReader[] = {
    {sipName_Characters, static_cast<int>( ::QXmlStreamReader::Characters), 348},
    {sipName_Comment, static_cast<int>( ::QXmlStreamReader::Comment), 348},
    {sipName_CustomError, static_cast<int>( ::QXmlStreamReader::CustomError), 346},
    {sipName_DTD, static_cast<int>( ::QXmlStreamReader::DTD), 348},
    {sipName_EndDocument, static_cast<int>( ::QXmlStreamReader::EndDocument), 348},
    {sipName_EndElement, static_cast<int>( ::QXmlStreamReader::EndElement), 348},
    {sipName_EntityReference, static_cast<int>( ::QXmlStreamReader::EntityReference), 348},
    {sipName_ErrorOnUnexpectedElement, static_cast<int>( ::QXmlStreamReader::ErrorOnUnexpectedElement), 347},
    {sipName_IncludeChildElements, static_cast<int>( ::QXmlStreamReader::IncludeChildElements), 347},
    {sipName_Invalid, static_cast<int>( ::QXmlStreamReader::Invalid), 348},
    {sipName_NoError, static_cast<int>( ::QXmlStreamReader::NoError), 346},
    {sipName_NoToken, static_cast<int>( ::QXmlStreamReader::NoToken), 348},
    {sipName_NotWellFormedError, static_cast<int>( ::QXmlStreamReader::NotWellFormedError), 346},
    {sipName_PrematureEndOfDocumentError, static_cast<int>( ::QXmlStreamReader::PrematureEndOfDocumentError), 346},
    {sipName_ProcessingInstruction, static_cast<int>( ::QXmlStreamReader::ProcessingInstruction), 348},
    {sipName_SkipChildElements, static_cast<int>( ::QXmlStreamReader::SkipChildElements), 347},
    {sipName_StartDocument, static_cast<int>( ::QXmlStreamReader::StartDocument), 348},
    {sipName_StartElement, static_cast<int>( ::QXmlStreamReader::StartElement), 348},
    {sipName_UnexpectedElementError, static_cast<int>( ::QXmlStreamReader::UnexpectedElementError), 346},
};

PyDoc_STRVAR(doc_QXmlStreamReader, "\1QXmlStreamReader()\n"
"QXmlStreamReader(QIODevice)\n"
"QXmlStreamReader(Union[QByteArray, bytes, bytearray])\n"
"QXmlStreamReader(str)");


static pyqt5ClassPluginDef plugin_QXmlStreamReader = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QXmlStreamReader = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlStreamReader,
        {SIP_NULLPTR},
        &plugin_QXmlStreamReader
    },
    {
        sipNameNr_QXmlStreamReader,
        {0, 0, 1},
        54, methods_QXmlStreamReader,
        19, enummembers_QXmlStreamReader,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlStreamReader,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QXmlStreamReader,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QXmlStreamReader,
    SIP_NULLPTR,
    array_QXmlStreamReader,
    SIP_NULLPTR,
    release_QXmlStreamReader,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
