/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qocspresponse.sip"
#include <qocspresponse.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQOcspResponse.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcertificate.sip"
#include <qsslcertificate.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQOcspResponse.cpp"


PyDoc_STRVAR(doc_QOcspResponse_certificateStatus, "certificateStatus(self) -> QOcspCertificateStatus");

extern "C" {static PyObject *meth_QOcspResponse_certificateStatus(PyObject *, PyObject *);}
static PyObject *meth_QOcspResponse_certificateStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOcspResponse, &sipCpp))
        {
             ::QOcspCertificateStatus sipRes;

            sipRes = sipCpp->certificateStatus();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOcspCertificateStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOcspResponse, sipName_certificateStatus, doc_QOcspResponse_certificateStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOcspResponse_revocationReason, "revocationReason(self) -> QOcspRevocationReason");

extern "C" {static PyObject *meth_QOcspResponse_revocationReason(PyObject *, PyObject *);}
static PyObject *meth_QOcspResponse_revocationReason(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOcspResponse, &sipCpp))
        {
             ::QOcspRevocationReason sipRes;

            sipRes = sipCpp->revocationReason();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOcspRevocationReason);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOcspResponse, sipName_revocationReason, doc_QOcspResponse_revocationReason);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOcspResponse_responder, "responder(self) -> QSslCertificate");

extern "C" {static PyObject *meth_QOcspResponse_responder(PyObject *, PyObject *);}
static PyObject *meth_QOcspResponse_responder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOcspResponse, &sipCpp))
        {
             ::QSslCertificate*sipRes;

            sipRes = new  ::QSslCertificate(sipCpp->responder());

            return sipConvertFromNewType(sipRes,sipType_QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOcspResponse, sipName_responder, doc_QOcspResponse_responder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOcspResponse_subject, "subject(self) -> QSslCertificate");

extern "C" {static PyObject *meth_QOcspResponse_subject(PyObject *, PyObject *);}
static PyObject *meth_QOcspResponse_subject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOcspResponse, &sipCpp))
        {
             ::QSslCertificate*sipRes;

            sipRes = new  ::QSslCertificate(sipCpp->subject());

            return sipConvertFromNewType(sipRes,sipType_QSslCertificate,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOcspResponse, sipName_subject, doc_QOcspResponse_subject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOcspResponse_swap, "swap(self, QOcspResponse)");

extern "C" {static PyObject *meth_QOcspResponse_swap(PyObject *, PyObject *);}
static PyObject *meth_QOcspResponse_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOcspResponse* a0;
         ::QOcspResponse *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QOcspResponse, &sipCpp, sipType_QOcspResponse, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOcspResponse, sipName_swap, doc_QOcspResponse_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QOcspResponse___eq__(PyObject *,PyObject *);}
static PyObject *slot_QOcspResponse___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QOcspResponse *sipCpp = reinterpret_cast< ::QOcspResponse *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QOcspResponse));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOcspResponse, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, eq_slot, sipType_QOcspResponse, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QOcspResponse___ne__(PyObject *,PyObject *);}
static PyObject *slot_QOcspResponse___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QOcspResponse *sipCpp = reinterpret_cast< ::QOcspResponse *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QOcspResponse));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOcspResponse* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QOcspResponse, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, ne_slot, sipType_QOcspResponse, sipSelf, sipArg);
}


extern "C" {static long slot_QOcspResponse___hash__(PyObject *);}
static long slot_QOcspResponse___hash__(PyObject *sipSelf)
{
     ::QOcspResponse *sipCpp = reinterpret_cast< ::QOcspResponse *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QOcspResponse));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qocspresponse.sip"
        sipRes = qHash(*sipCpp);
#line 250 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQOcspResponse.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOcspResponse(void *, int);}
static void release_QOcspResponse(void *sipCppV, int)
{
    delete reinterpret_cast< ::QOcspResponse *>(sipCppV);
}


extern "C" {static void *array_QOcspResponse(Py_ssize_t);}
static void *array_QOcspResponse(Py_ssize_t sipNrElem)
{
    return new  ::QOcspResponse[sipNrElem];
}


extern "C" {static void assign_QOcspResponse(void *, SIP_SSIZE_T, void *);}
static void assign_QOcspResponse(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QOcspResponse *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QOcspResponse *>(sipSrc);
}


extern "C" {static void *copy_QOcspResponse(const void *, SIP_SSIZE_T);}
static void *copy_QOcspResponse(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QOcspResponse(reinterpret_cast<const  ::QOcspResponse *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QOcspResponse(sipSimpleWrapper *);}
static void dealloc_QOcspResponse(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOcspResponse(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QOcspResponse(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOcspResponse(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QOcspResponse *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QOcspResponse();

            return sipCpp;
        }
    }

    {
        const  ::QOcspResponse* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QOcspResponse, &a0))
        {
            sipCpp = new  ::QOcspResponse(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QOcspResponse[] = {
    {(void *)slot_QOcspResponse___eq__, eq_slot},
    {(void *)slot_QOcspResponse___ne__, ne_slot},
    {(void *)slot_QOcspResponse___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QOcspResponse[] = {
    {SIP_MLNAME_CAST(sipName_certificateStatus), meth_QOcspResponse_certificateStatus, METH_VARARGS, SIP_MLDOC_CAST(doc_QOcspResponse_certificateStatus)},
    {SIP_MLNAME_CAST(sipName_responder), meth_QOcspResponse_responder, METH_VARARGS, SIP_MLDOC_CAST(doc_QOcspResponse_responder)},
    {SIP_MLNAME_CAST(sipName_revocationReason), meth_QOcspResponse_revocationReason, METH_VARARGS, SIP_MLDOC_CAST(doc_QOcspResponse_revocationReason)},
    {SIP_MLNAME_CAST(sipName_subject), meth_QOcspResponse_subject, METH_VARARGS, SIP_MLDOC_CAST(doc_QOcspResponse_subject)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QOcspResponse_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QOcspResponse_swap)}
};

PyDoc_STRVAR(doc_QOcspResponse, "\1QOcspResponse()\n"
"QOcspResponse(QOcspResponse)");


static pyqt5ClassPluginDef plugin_QOcspResponse = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QOcspResponse = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOcspResponse,
        {SIP_NULLPTR},
        &plugin_QOcspResponse
    },
    {
        sipNameNr_QOcspResponse,
        {0, 0, 1},
        5, methods_QOcspResponse,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOcspResponse,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QOcspResponse,
    init_type_QOcspResponse,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QOcspResponse,
    assign_QOcspResponse,
    array_QOcspResponse,
    copy_QOcspResponse,
    release_QOcspResponse,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
