/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlImageProviderBase.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlImageProviderBase.cpp"


PyDoc_STRVAR(doc_QQmlImageProviderBase_imageType, "imageType(self) -> QQmlImageProviderBase.ImageType");

extern "C" {static PyObject *meth_QQmlImageProviderBase_imageType(PyObject *, PyObject *);}
static PyObject *meth_QQmlImageProviderBase_imageType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QQmlImageProviderBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlImageProviderBase, &sipCpp))
        {
             ::QQmlImageProviderBase::ImageType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlImageProviderBase, sipName_imageType);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->imageType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQmlImageProviderBase_ImageType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlImageProviderBase, sipName_imageType, doc_QQmlImageProviderBase_imageType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlImageProviderBase_flags, "flags(self) -> QQmlImageProviderBase.Flags");

extern "C" {static PyObject *meth_QQmlImageProviderBase_flags(PyObject *, PyObject *);}
static PyObject *meth_QQmlImageProviderBase_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QQmlImageProviderBase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlImageProviderBase, &sipCpp))
        {
             ::QQmlImageProviderBase::Flags*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlImageProviderBase, sipName_flags);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QQmlImageProviderBase::Flags(sipCpp->flags());

            return sipConvertFromNewType(sipRes,sipType_QQmlImageProviderBase_Flags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlImageProviderBase, sipName_flags, doc_QQmlImageProviderBase_flags);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlImageProviderBase(void *, int);}
static void release_QQmlImageProviderBase(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQmlImageProviderBase *>(sipCppV);
}


extern "C" {static void dealloc_QQmlImageProviderBase(sipSimpleWrapper *);}
static void dealloc_QQmlImageProviderBase(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlImageProviderBase(sipGetAddress(sipSelf), 0);
    }
}


static PyMethodDef methods_QQmlImageProviderBase[] = {
    {SIP_MLNAME_CAST(sipName_flags), meth_QQmlImageProviderBase_flags, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlImageProviderBase_flags)},
    {SIP_MLNAME_CAST(sipName_imageType), meth_QQmlImageProviderBase_imageType, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlImageProviderBase_imageType)}
};

static sipEnumMemberDef enummembers_QQmlImageProviderBase[] = {
    {sipName_ForceAsynchronousImageLoading, static_cast<int>( ::QQmlImageProviderBase::ForceAsynchronousImageLoading), 26},
    {sipName_Image, static_cast<int>( ::QQmlImageProviderBase::Image), 28},
    {sipName_ImageResponse, static_cast<int>( ::QQmlImageProviderBase::ImageResponse), 28},
    {sipName_Pixmap, static_cast<int>( ::QQmlImageProviderBase::Pixmap), 28},
    {sipName_Texture, static_cast<int>( ::QQmlImageProviderBase::Texture), 28},
};


static pyqt5ClassPluginDef plugin_QQmlImageProviderBase = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlImageProviderBase = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlImageProviderBase,
        {SIP_NULLPTR},
        &plugin_QQmlImageProviderBase
    },
    {
        sipNameNr_QQmlImageProviderBase,
        {0, 0, 1},
        2, methods_QQmlImageProviderBase,
        5, enummembers_QQmlImageProviderBase,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlImageProviderBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlImageProviderBase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
