/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qtablewidget.sip"
#include <qtablewidget.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"

#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtGui/qfont.sip"
#include <qfont.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qtablewidget.sip"
#include <qtablewidget.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQTableWidgetItem.cpp"


class sipQTableWidgetItem : public  ::QTableWidgetItem
{
public:
    sipQTableWidgetItem(int);
    sipQTableWidgetItem(const  ::QString&,int);
    sipQTableWidgetItem(const  ::QIcon&,const  ::QString&,int);
    sipQTableWidgetItem(const  ::QTableWidgetItem&);
    virtual ~sipQTableWidgetItem();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void write( ::QDataStream&) const SIP_OVERRIDE;
    void read( ::QDataStream&) SIP_OVERRIDE;
    bool operator<(const  ::QTableWidgetItem&) const SIP_OVERRIDE;
    void setData(int,const  ::QVariant&) SIP_OVERRIDE;
     ::QVariant data(int) const SIP_OVERRIDE;
     ::QTableWidgetItem* clone() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTableWidgetItem(const sipQTableWidgetItem &);
    sipQTableWidgetItem &operator = (const sipQTableWidgetItem &);

    char sipPyMethods[6];
};

sipQTableWidgetItem::sipQTableWidgetItem(int a0):  ::QTableWidgetItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTableWidgetItem::sipQTableWidgetItem(const  ::QString& a0,int a1):  ::QTableWidgetItem(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTableWidgetItem::sipQTableWidgetItem(const  ::QIcon& a0,const  ::QString& a1,int a2):  ::QTableWidgetItem(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTableWidgetItem::sipQTableWidgetItem(const  ::QTableWidgetItem& a0):  ::QTableWidgetItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTableWidgetItem::~sipQTableWidgetItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQTableWidgetItem::write( ::QDataStream& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,SIP_NULLPTR,sipName_write);

    if (!sipMeth)
    {
         ::QTableWidgetItem::write(a0);
        return;
    }

    extern void sipVH_QtWidgets_179(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDataStream&);

    sipVH_QtWidgets_179(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTableWidgetItem::read( ::QDataStream& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_read);

    if (!sipMeth)
    {
         ::QTableWidgetItem::read(a0);
        return;
    }

    extern void sipVH_QtWidgets_179(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDataStream&);

    sipVH_QtWidgets_179(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTableWidgetItem::operator<(const  ::QTableWidgetItem& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,SIP_NULLPTR,sipName___lt__);

    if (!sipMeth)
        return  ::QTableWidgetItem::operator<(a0);

    extern bool sipVH_QtWidgets_204(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QTableWidgetItem&);

    return sipVH_QtWidgets_204(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTableWidgetItem::setData(int a0,const  ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_setData);

    if (!sipMeth)
    {
         ::QTableWidgetItem::setData(a0,a1);
        return;
    }

    extern void sipVH_QtWidgets_177(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,const  ::QVariant&);

    sipVH_QtWidgets_177(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::QVariant sipQTableWidgetItem::data(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,SIP_NULLPTR,sipName_data);

    if (!sipMeth)
        return  ::QTableWidgetItem::data(a0);

    extern  ::QVariant sipVH_QtWidgets_176(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_176(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QTableWidgetItem* sipQTableWidgetItem::clone() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,SIP_NULLPTR,sipName_clone);

    if (!sipMeth)
        return  ::QTableWidgetItem::clone();

    extern  ::QTableWidgetItem* sipVH_QtWidgets_203(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_203(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QTableWidgetItem_clone, "clone(self) -> QTableWidgetItem");

extern "C" {static PyObject *meth_QTableWidgetItem_clone(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QTableWidgetItem*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QTableWidgetItem::clone() : sipCpp->clone());

            return sipConvertFromNewType(sipRes,sipType_QTableWidgetItem,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_clone, doc_QTableWidgetItem_clone);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_tableWidget, "tableWidget(self) -> QTableWidget");

extern "C" {static PyObject *meth_QTableWidgetItem_tableWidget(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_tableWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QTableWidget*sipRes;

            sipRes = sipCpp->tableWidget();

            return sipConvertFromType(sipRes,sipType_QTableWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_tableWidget, doc_QTableWidgetItem_tableWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_flags, "flags(self) -> Qt.ItemFlags");

extern "C" {static PyObject *meth_QTableWidgetItem_flags(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::Qt::ItemFlags*sipRes;

            sipRes = new  ::Qt::ItemFlags(sipCpp->flags());

            return sipConvertFromNewType(sipRes,sipType_Qt_ItemFlags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_flags, doc_QTableWidgetItem_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_text, "text(self) -> str");

extern "C" {static PyObject *meth_QTableWidgetItem_text(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_text, doc_QTableWidgetItem_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QTableWidgetItem_icon(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QIcon*sipRes;

            sipRes = new  ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_icon, doc_QTableWidgetItem_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_statusTip, "statusTip(self) -> str");

extern "C" {static PyObject *meth_QTableWidgetItem_statusTip(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_statusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->statusTip());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_statusTip, doc_QTableWidgetItem_statusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_toolTip, "toolTip(self) -> str");

extern "C" {static PyObject *meth_QTableWidgetItem_toolTip(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_toolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toolTip());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_toolTip, doc_QTableWidgetItem_toolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_whatsThis, "whatsThis(self) -> str");

extern "C" {static PyObject *meth_QTableWidgetItem_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_whatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->whatsThis());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_whatsThis, doc_QTableWidgetItem_whatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QTableWidgetItem_font(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QFont*sipRes;

            sipRes = new  ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes,sipType_QFont,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_font, doc_QTableWidgetItem_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_textAlignment, "textAlignment(self) -> int");

extern "C" {static PyObject *meth_QTableWidgetItem_textAlignment(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_textAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->textAlignment();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_textAlignment, doc_QTableWidgetItem_textAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setTextAlignment, "setTextAlignment(self, int)");

extern "C" {static PyObject *meth_QTableWidgetItem_setTextAlignment(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setTextAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTableWidgetItem, &sipCpp, &a0))
        {
            sipCpp->setTextAlignment(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setTextAlignment, doc_QTableWidgetItem_setTextAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_checkState, "checkState(self) -> Qt.CheckState");

extern "C" {static PyObject *meth_QTableWidgetItem_checkState(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_checkState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::Qt::CheckState sipRes;

            sipRes = sipCpp->checkState();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_CheckState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_checkState, doc_QTableWidgetItem_checkState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setCheckState, "setCheckState(self, Qt.CheckState)");

extern "C" {static PyObject *meth_QTableWidgetItem_setCheckState(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setCheckState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::CheckState a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_Qt_CheckState, &a0))
        {
            sipCpp->setCheckState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setCheckState, doc_QTableWidgetItem_setCheckState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_data, "data(self, int) -> Any");

extern "C" {static PyObject *meth_QTableWidgetItem_data(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTableWidgetItem, &sipCpp, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QTableWidgetItem::data(a0) : sipCpp->data(a0)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_data, doc_QTableWidgetItem_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setData, "setData(self, int, Any)");

extern "C" {static PyObject *meth_QTableWidgetItem_setData(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, &a0, sipType_QVariant, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp-> ::QTableWidgetItem::setData(a0,*a1) : sipCpp->setData(a0,*a1));
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setData, doc_QTableWidgetItem_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_read, "read(self, QDataStream)");

extern "C" {static PyObject *meth_QTableWidgetItem_read(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_read(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDataStream* a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QDataStream, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QTableWidgetItem::read(*a0) : sipCpp->read(*a0));
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_read, doc_QTableWidgetItem_read);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_write, "write(self, QDataStream)");

extern "C" {static PyObject *meth_QTableWidgetItem_write(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_write(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDataStream* a0;
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QDataStream, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QTableWidgetItem::write(*a0) : sipCpp->write(*a0));
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_write, doc_QTableWidgetItem_write);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_type, "type(self) -> int");

extern "C" {static PyObject *meth_QTableWidgetItem_type(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->type();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_type, doc_QTableWidgetItem_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setFlags, "setFlags(self, Union[Qt.ItemFlags, Qt.ItemFlag])");

extern "C" {static PyObject *meth_QTableWidgetItem_setFlags(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::ItemFlags* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_Qt_ItemFlags, &a0, &a0State))
        {
            sipCpp->setFlags(*a0);
            sipReleaseType(a0,sipType_Qt_ItemFlags,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setFlags, doc_QTableWidgetItem_setFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setText, "setText(self, str)");

extern "C" {static PyObject *meth_QTableWidgetItem_setText(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setText, doc_QTableWidgetItem_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setIcon, "setIcon(self, QIcon)");

extern "C" {static PyObject *meth_QTableWidgetItem_setIcon(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon* a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->setIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setIcon, doc_QTableWidgetItem_setIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setStatusTip, "setStatusTip(self, str)");

extern "C" {static PyObject *meth_QTableWidgetItem_setStatusTip(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setStatusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setStatusTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setStatusTip, doc_QTableWidgetItem_setStatusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setToolTip, "setToolTip(self, str)");

extern "C" {static PyObject *meth_QTableWidgetItem_setToolTip(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setToolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setToolTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setToolTip, doc_QTableWidgetItem_setToolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setWhatsThis, "setWhatsThis(self, str)");

extern "C" {static PyObject *meth_QTableWidgetItem_setWhatsThis(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setWhatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWhatsThis(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setWhatsThis, doc_QTableWidgetItem_setWhatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setFont, "setFont(self, QFont)");

extern "C" {static PyObject *meth_QTableWidgetItem_setFont(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QFont* a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setFont, doc_QTableWidgetItem_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QTableWidgetItem_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->sizeHint());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_sizeHint, doc_QTableWidgetItem_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setSizeHint, "setSizeHint(self, QSize)");

extern "C" {static PyObject *meth_QTableWidgetItem_setSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSizeHint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setSizeHint, doc_QTableWidgetItem_setSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_background, "background(self) -> QBrush");

extern "C" {static PyObject *meth_QTableWidgetItem_background(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_background(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->background());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_background, doc_QTableWidgetItem_background);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setBackground, "setBackground(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTableWidgetItem_setBackground(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setBackground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBackground(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setBackground, doc_QTableWidgetItem_setBackground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_foreground, "foreground(self) -> QBrush");

extern "C" {static PyObject *meth_QTableWidgetItem_foreground(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_foreground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->foreground());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_foreground, doc_QTableWidgetItem_foreground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setForeground, "setForeground(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTableWidgetItem_setForeground(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setForeground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTableWidgetItem, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setForeground(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setForeground, doc_QTableWidgetItem_setForeground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_row, "row(self) -> int");

extern "C" {static PyObject *meth_QTableWidgetItem_row(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_row(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->row();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_row, doc_QTableWidgetItem_row);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_column, "column(self) -> int");

extern "C" {static PyObject *meth_QTableWidgetItem_column(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_column(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->column();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_column, doc_QTableWidgetItem_column);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_setSelected, "setSelected(self, bool)");

extern "C" {static PyObject *meth_QTableWidgetItem_setSelected(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_setSelected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QTableWidgetItem, &sipCpp, &a0))
        {
            sipCpp->setSelected(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_setSelected, doc_QTableWidgetItem_setSelected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTableWidgetItem_isSelected, "isSelected(self) -> bool");

extern "C" {static PyObject *meth_QTableWidgetItem_isSelected(PyObject *, PyObject *);}
static PyObject *meth_QTableWidgetItem_isSelected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTableWidgetItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSelected();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTableWidgetItem, sipName_isSelected, doc_QTableWidgetItem_isSelected);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QTableWidgetItem___ge__(PyObject *,PyObject *);}
static PyObject *slot_QTableWidgetItem___ge__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QTableWidgetItem *sipCpp = reinterpret_cast< ::QTableWidgetItem *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QTableWidgetItem));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QTableWidgetItem, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp-> ::QTableWidgetItem::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, ge_slot, sipType_QTableWidgetItem, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QTableWidgetItem___lt__(PyObject *,PyObject *);}
static PyObject *slot_QTableWidgetItem___lt__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QTableWidgetItem *sipCpp = reinterpret_cast< ::QTableWidgetItem *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QTableWidgetItem));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTableWidgetItem* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QTableWidgetItem, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QTableWidgetItem::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, lt_slot, sipType_QTableWidgetItem, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QTableWidgetItem(void *, int);}
static void release_QTableWidgetItem(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQTableWidgetItem *>(sipCppV);
    else
        delete reinterpret_cast< ::QTableWidgetItem *>(sipCppV);
}


extern "C" {static void dealloc_QTableWidgetItem(sipSimpleWrapper *);}
static void dealloc_QTableWidgetItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTableWidgetItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTableWidgetItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTableWidgetItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTableWidgetItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQTableWidgetItem *sipCpp = SIP_NULLPTR;

    {
        int a0 = QTableWidgetItem::ItemType::Type;

        static const char *sipKwdList[] = {
            sipName_type,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|i", &a0))
        {
            sipCpp = new sipQTableWidgetItem(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
        int a1 = QTableWidgetItem::ItemType::Type;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_type,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|i", sipType_QString,&a0, &a0State, &a1))
        {
            sipCpp = new sipQTableWidgetItem(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QIcon* a0;
        const  ::QString* a1;
        int a1State = 0;
        int a2 = QTableWidgetItem::ItemType::Type;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_type,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9J1|i", sipType_QIcon, &a0, sipType_QString,&a1, &a1State, &a2))
        {
            sipCpp = new sipQTableWidgetItem(*a0,*a1,a2);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QTableWidgetItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QTableWidgetItem, &a0))
        {
            sipCpp = new sipQTableWidgetItem(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QTableWidgetItem[] = {
    {(void *)slot_QTableWidgetItem___ge__, ge_slot},
    {(void *)slot_QTableWidgetItem___lt__, lt_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QTableWidgetItem[] = {
    {SIP_MLNAME_CAST(sipName_background), meth_QTableWidgetItem_background, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_background)},
    {SIP_MLNAME_CAST(sipName_checkState), meth_QTableWidgetItem_checkState, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_checkState)},
    {SIP_MLNAME_CAST(sipName_clone), meth_QTableWidgetItem_clone, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_clone)},
    {SIP_MLNAME_CAST(sipName_column), meth_QTableWidgetItem_column, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_column)},
    {SIP_MLNAME_CAST(sipName_data), meth_QTableWidgetItem_data, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_data)},
    {SIP_MLNAME_CAST(sipName_flags), meth_QTableWidgetItem_flags, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_flags)},
    {SIP_MLNAME_CAST(sipName_font), meth_QTableWidgetItem_font, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_font)},
    {SIP_MLNAME_CAST(sipName_foreground), meth_QTableWidgetItem_foreground, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_foreground)},
    {SIP_MLNAME_CAST(sipName_icon), meth_QTableWidgetItem_icon, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_icon)},
    {SIP_MLNAME_CAST(sipName_isSelected), meth_QTableWidgetItem_isSelected, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_isSelected)},
    {SIP_MLNAME_CAST(sipName_read), meth_QTableWidgetItem_read, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_read)},
    {SIP_MLNAME_CAST(sipName_row), meth_QTableWidgetItem_row, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_row)},
    {SIP_MLNAME_CAST(sipName_setBackground), meth_QTableWidgetItem_setBackground, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setBackground)},
    {SIP_MLNAME_CAST(sipName_setCheckState), meth_QTableWidgetItem_setCheckState, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setCheckState)},
    {SIP_MLNAME_CAST(sipName_setData), meth_QTableWidgetItem_setData, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setData)},
    {SIP_MLNAME_CAST(sipName_setFlags), meth_QTableWidgetItem_setFlags, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setFlags)},
    {SIP_MLNAME_CAST(sipName_setFont), meth_QTableWidgetItem_setFont, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setFont)},
    {SIP_MLNAME_CAST(sipName_setForeground), meth_QTableWidgetItem_setForeground, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setForeground)},
    {SIP_MLNAME_CAST(sipName_setIcon), meth_QTableWidgetItem_setIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setIcon)},
    {SIP_MLNAME_CAST(sipName_setSelected), meth_QTableWidgetItem_setSelected, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setSelected)},
    {SIP_MLNAME_CAST(sipName_setSizeHint), meth_QTableWidgetItem_setSizeHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setSizeHint)},
    {SIP_MLNAME_CAST(sipName_setStatusTip), meth_QTableWidgetItem_setStatusTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setStatusTip)},
    {SIP_MLNAME_CAST(sipName_setText), meth_QTableWidgetItem_setText, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setText)},
    {SIP_MLNAME_CAST(sipName_setTextAlignment), meth_QTableWidgetItem_setTextAlignment, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setTextAlignment)},
    {SIP_MLNAME_CAST(sipName_setToolTip), meth_QTableWidgetItem_setToolTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setToolTip)},
    {SIP_MLNAME_CAST(sipName_setWhatsThis), meth_QTableWidgetItem_setWhatsThis, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_setWhatsThis)},
    {SIP_MLNAME_CAST(sipName_sizeHint), meth_QTableWidgetItem_sizeHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_sizeHint)},
    {SIP_MLNAME_CAST(sipName_statusTip), meth_QTableWidgetItem_statusTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_statusTip)},
    {SIP_MLNAME_CAST(sipName_tableWidget), meth_QTableWidgetItem_tableWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_tableWidget)},
    {SIP_MLNAME_CAST(sipName_text), meth_QTableWidgetItem_text, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_text)},
    {SIP_MLNAME_CAST(sipName_textAlignment), meth_QTableWidgetItem_textAlignment, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_textAlignment)},
    {SIP_MLNAME_CAST(sipName_toolTip), meth_QTableWidgetItem_toolTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_toolTip)},
    {SIP_MLNAME_CAST(sipName_type), meth_QTableWidgetItem_type, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_type)},
    {SIP_MLNAME_CAST(sipName_whatsThis), meth_QTableWidgetItem_whatsThis, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_whatsThis)},
    {SIP_MLNAME_CAST(sipName_write), meth_QTableWidgetItem_write, METH_VARARGS, SIP_MLDOC_CAST(doc_QTableWidgetItem_write)}
};

static sipEnumMemberDef enummembers_QTableWidgetItem[] = {
    {sipName_Type, static_cast<int>( ::QTableWidgetItem::Type), 433},
    {sipName_UserType, static_cast<int>( ::QTableWidgetItem::UserType), 433},
};

PyDoc_STRVAR(doc_QTableWidgetItem, "\1QTableWidgetItem(type: int = QTableWidgetItem.ItemType.Type)\n"
"QTableWidgetItem(str, type: int = QTableWidgetItem.ItemType.Type)\n"
"QTableWidgetItem(QIcon, str, type: int = QTableWidgetItem.ItemType.Type)\n"
"QTableWidgetItem(QTableWidgetItem)");


static pyqt5ClassPluginDef plugin_QTableWidgetItem = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTableWidgetItem,
        {SIP_NULLPTR},
        &plugin_QTableWidgetItem
    },
    {
        sipNameNr_QTableWidgetItem,
        {0, 0, 1},
        35, methods_QTableWidgetItem,
        2, enummembers_QTableWidgetItem,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTableWidgetItem,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QTableWidgetItem,
    init_type_QTableWidgetItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QTableWidgetItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QTableWidgetItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
