/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"


extern "C" {static long slot_QGraphicsBlurEffect_BlurHints___hash__(PyObject *);}
static long slot_QGraphicsBlurEffect_BlurHints___hash__(PyObject *sipSelf)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGraphicsBlurEffect::BlurHints::Int();
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QGraphicsBlurEffect_BlurHints___bool__(PyObject *);}
static int slot_QGraphicsBlurEffect_BlurHints___bool__(PyObject *sipSelf)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsBlurEffect::BlurHints::Int() != 0);
#line 76 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___ne__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsBlurEffect::BlurHints::Int() != a0->operator QGraphicsBlurEffect::BlurHints::Int());
#line 106 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"
            sipReleaseType(const_cast< ::QGraphicsBlurEffect::BlurHints *>(a0),sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, ne_slot, sipType_QGraphicsBlurEffect_BlurHints, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___eq__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsBlurEffect::BlurHints::Int() == a0->operator QGraphicsBlurEffect::BlurHints::Int());
#line 142 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"
            sipReleaseType(const_cast< ::QGraphicsBlurEffect::BlurHints *>(a0),sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, eq_slot, sipType_QGraphicsBlurEffect_BlurHints, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___ixor__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___ixor__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsBlurEffect_BlurHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "sip/QtCore/qglobal.sip"
        *sipCpp = QGraphicsBlurEffect::BlurHints(*sipCpp ^ a0);
#line 181 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___xor__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___xor__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State, &a1))
        {
             ::QGraphicsBlurEffect::BlurHints*sipRes;

            sipRes = new  ::QGraphicsBlurEffect::BlurHints((*a0 ^ a1));
            sipReleaseType(a0,sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return sipConvertFromNewType(sipRes,sipType_QGraphicsBlurEffect_BlurHints,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___ior__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___ior__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsBlurEffect_BlurHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "sip/QtCore/qglobal.sip"
        *sipCpp = QGraphicsBlurEffect::BlurHints(*sipCpp | a0);
#line 253 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___or__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State, &a1))
        {
             ::QGraphicsBlurEffect::BlurHints*sipRes;

            sipRes = new  ::QGraphicsBlurEffect::BlurHints((*a0 | a1));
            sipReleaseType(a0,sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return sipConvertFromNewType(sipRes,sipType_QGraphicsBlurEffect_BlurHints,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___iand__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___iand__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsBlurEffect_BlurHints)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp-> ::QGraphicsBlurEffect::BlurHints::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___and__(PyObject *,PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___and__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State, &a1))
        {
             ::QGraphicsBlurEffect::BlurHints*sipRes;

            sipRes = new  ::QGraphicsBlurEffect::BlurHints((*a0 & a1));
            sipReleaseType(a0,sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return sipConvertFromNewType(sipRes,sipType_QGraphicsBlurEffect_BlurHints,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___invert__(PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___invert__(PyObject *sipSelf)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
             ::QGraphicsBlurEffect::BlurHints*sipRes;

            sipRes = new  ::QGraphicsBlurEffect::BlurHints(~(*sipCpp));

            return sipConvertFromNewType(sipRes,sipType_QGraphicsBlurEffect_BlurHints,SIP_NULLPTR);
        }
    }

    return 0;
}


#if PY_VERSION_HEX >= 0x02050000
extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___index__(PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___index__(PyObject *sipSelf)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGraphicsBlurEffect::BlurHints::Int();
#line 411 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"

            return SIPLong_FromLong(sipRes);
        }
    }

    return 0;
}
#endif


extern "C" {static PyObject *slot_QGraphicsBlurEffect_BlurHints___int__(PyObject *);}
static PyObject *slot_QGraphicsBlurEffect_BlurHints___int__(PyObject *sipSelf)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGraphicsBlurEffect_BlurHints));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = *sipCpp;

            return SIPLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsBlurEffect_BlurHints(void *, int);}
static void release_QGraphicsBlurEffect_BlurHints(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipCppV);
}


extern "C" {static void *array_QGraphicsBlurEffect_BlurHints(Py_ssize_t);}
static void *array_QGraphicsBlurEffect_BlurHints(Py_ssize_t sipNrElem)
{
    return new  ::QGraphicsBlurEffect::BlurHints[sipNrElem];
}


extern "C" {static void assign_QGraphicsBlurEffect_BlurHints(void *, SIP_SSIZE_T, void *);}
static void assign_QGraphicsBlurEffect_BlurHints(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGraphicsBlurEffect::BlurHints *>(sipSrc);
}


extern "C" {static void *copy_QGraphicsBlurEffect_BlurHints(const void *, SIP_SSIZE_T);}
static void *copy_QGraphicsBlurEffect_BlurHints(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QGraphicsBlurEffect::BlurHints(reinterpret_cast<const  ::QGraphicsBlurEffect::BlurHints *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGraphicsBlurEffect_BlurHints(sipSimpleWrapper *);}
static void dealloc_QGraphicsBlurEffect_BlurHints(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsBlurEffect_BlurHints(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGraphicsBlurEffect_BlurHints(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsBlurEffect_BlurHints(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QGraphicsBlurEffect::BlurHints *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QGraphicsBlurEffect::BlurHints();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new  ::QGraphicsBlurEffect::BlurHints(a0);

            return sipCpp;
        }
    }

    {
        const  ::QGraphicsBlurEffect::BlurHints* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QGraphicsBlurEffect_BlurHints, &a0, &a0State))
        {
            sipCpp = new  ::QGraphicsBlurEffect::BlurHints(*a0);
            sipReleaseType(const_cast< ::QGraphicsBlurEffect::BlurHints *>(a0),sipType_QGraphicsBlurEffect_BlurHints,a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QGraphicsBlurEffect_BlurHints(PyObject *, void **, int *, PyObject *);}
static int convertTo_QGraphicsBlurEffect_BlurHints(PyObject *sipPy,void **sipCppPtrV,int *sipIsErr,PyObject *sipTransferObj)
{
     ::QGraphicsBlurEffect::BlurHints **sipCppPtr = reinterpret_cast< ::QGraphicsBlurEffect::BlurHints **>(sipCppPtrV);

#line 127 "sip/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QGraphicsBlurEffect::BlurHints is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGraphicsBlurEffect_BlurHint)) ||
            sipCanConvertToType(sipPy, sipType_QGraphicsBlurEffect_BlurHints, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGraphicsBlurEffect_BlurHint)))
{
    *sipCppPtr = new QGraphicsBlurEffect::BlurHints(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QGraphicsBlurEffect::BlurHints *>(sipConvertToType(sipPy, sipType_QGraphicsBlurEffect_BlurHints, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 548 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQGraphicsBlurEffectBlurHints.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGraphicsBlurEffect_BlurHints[] = {
    {(void *)slot_QGraphicsBlurEffect_BlurHints___hash__, hash_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___bool__, bool_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___ne__, ne_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___eq__, eq_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___ixor__, ixor_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___xor__, xor_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___ior__, ior_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___or__, or_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___iand__, iand_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___and__, and_slot},
    {(void *)slot_QGraphicsBlurEffect_BlurHints___invert__, invert_slot},
#if PY_VERSION_HEX >= 0x02050000
    {(void *)slot_QGraphicsBlurEffect_BlurHints___index__, index_slot},
#endif
    {(void *)slot_QGraphicsBlurEffect_BlurHints___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QGraphicsBlurEffect_BlurHints, "\1QGraphicsBlurEffect.BlurHints()\n"
"QGraphicsBlurEffect.BlurHints(Union[QGraphicsBlurEffect.BlurHints, QGraphicsBlurEffect.BlurHint])\n"
"QGraphicsBlurEffect.BlurHints(QGraphicsBlurEffect.BlurHints)");


static pyqt5ClassPluginDef plugin_QGraphicsBlurEffect_BlurHints = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect_BlurHints = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsBlurEffect__BlurHints,
        {SIP_NULLPTR},
        &plugin_QGraphicsBlurEffect_BlurHints
    },
    {
        sipNameNr_BlurHints,
        {115, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsBlurEffect_BlurHints,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGraphicsBlurEffect_BlurHints,
    init_type_QGraphicsBlurEffect_BlurHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QGraphicsBlurEffect_BlurHints,
    assign_QGraphicsBlurEffect_BlurHints,
    array_QGraphicsBlurEffect_BlurHints,
    copy_QGraphicsBlurEffect_BlurHints,
    release_QGraphicsBlurEffect_BlurHints,
    SIP_NULLPTR,
    convertTo_QGraphicsBlurEffect_BlurHints,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
