/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhttp2configuration.sip"
#include <qhttp2configuration.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQHttp2Configuration.cpp"



PyDoc_STRVAR(doc_QHttp2Configuration_setServerPushEnabled, "setServerPushEnabled(self, bool)");

extern "C" {static PyObject *meth_QHttp2Configuration_setServerPushEnabled(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_setServerPushEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHttp2Configuration, &sipCpp, &a0))
        {
            sipCpp->setServerPushEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_setServerPushEnabled, doc_QHttp2Configuration_setServerPushEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_serverPushEnabled, "serverPushEnabled(self) -> bool");

extern "C" {static PyObject *meth_QHttp2Configuration_serverPushEnabled(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_serverPushEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp2Configuration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->serverPushEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_serverPushEnabled, doc_QHttp2Configuration_serverPushEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_setHuffmanCompressionEnabled, "setHuffmanCompressionEnabled(self, bool)");

extern "C" {static PyObject *meth_QHttp2Configuration_setHuffmanCompressionEnabled(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_setHuffmanCompressionEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHttp2Configuration, &sipCpp, &a0))
        {
            sipCpp->setHuffmanCompressionEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_setHuffmanCompressionEnabled, doc_QHttp2Configuration_setHuffmanCompressionEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_huffmanCompressionEnabled, "huffmanCompressionEnabled(self) -> bool");

extern "C" {static PyObject *meth_QHttp2Configuration_huffmanCompressionEnabled(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_huffmanCompressionEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp2Configuration, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->huffmanCompressionEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_huffmanCompressionEnabled, doc_QHttp2Configuration_huffmanCompressionEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_setSessionReceiveWindowSize, "setSessionReceiveWindowSize(self, int) -> bool");

extern "C" {static PyObject *meth_QHttp2Configuration_setSessionReceiveWindowSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_setSessionReceiveWindowSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        uint a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QHttp2Configuration, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setSessionReceiveWindowSize(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_setSessionReceiveWindowSize, doc_QHttp2Configuration_setSessionReceiveWindowSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_sessionReceiveWindowSize, "sessionReceiveWindowSize(self) -> int");

extern "C" {static PyObject *meth_QHttp2Configuration_sessionReceiveWindowSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_sessionReceiveWindowSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp2Configuration, &sipCpp))
        {
            uint sipRes;

            sipRes = sipCpp->sessionReceiveWindowSize();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_sessionReceiveWindowSize, doc_QHttp2Configuration_sessionReceiveWindowSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_setStreamReceiveWindowSize, "setStreamReceiveWindowSize(self, int) -> bool");

extern "C" {static PyObject *meth_QHttp2Configuration_setStreamReceiveWindowSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_setStreamReceiveWindowSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        uint a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QHttp2Configuration, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setStreamReceiveWindowSize(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_setStreamReceiveWindowSize, doc_QHttp2Configuration_setStreamReceiveWindowSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_streamReceiveWindowSize, "streamReceiveWindowSize(self) -> int");

extern "C" {static PyObject *meth_QHttp2Configuration_streamReceiveWindowSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_streamReceiveWindowSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp2Configuration, &sipCpp))
        {
            uint sipRes;

            sipRes = sipCpp->streamReceiveWindowSize();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_streamReceiveWindowSize, doc_QHttp2Configuration_streamReceiveWindowSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_setMaxFrameSize, "setMaxFrameSize(self, int) -> bool");

extern "C" {static PyObject *meth_QHttp2Configuration_setMaxFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_setMaxFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        uint a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QHttp2Configuration, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setMaxFrameSize(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_setMaxFrameSize, doc_QHttp2Configuration_setMaxFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_maxFrameSize, "maxFrameSize(self) -> int");

extern "C" {static PyObject *meth_QHttp2Configuration_maxFrameSize(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_maxFrameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHttp2Configuration, &sipCpp))
        {
            uint sipRes;

            sipRes = sipCpp->maxFrameSize();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_maxFrameSize, doc_QHttp2Configuration_maxFrameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHttp2Configuration_swap, "swap(self, QHttp2Configuration)");

extern "C" {static PyObject *meth_QHttp2Configuration_swap(PyObject *, PyObject *);}
static PyObject *meth_QHttp2Configuration_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QHttp2Configuration* a0;
         ::QHttp2Configuration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHttp2Configuration, &sipCpp, sipType_QHttp2Configuration, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHttp2Configuration, sipName_swap, doc_QHttp2Configuration_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QHttp2Configuration___eq__(PyObject *,PyObject *);}
static PyObject *slot_QHttp2Configuration___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QHttp2Configuration *sipCpp = reinterpret_cast< ::QHttp2Configuration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QHttp2Configuration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHttp2Configuration, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, eq_slot, sipType_QHttp2Configuration, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QHttp2Configuration___ne__(PyObject *,PyObject *);}
static PyObject *slot_QHttp2Configuration___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QHttp2Configuration *sipCpp = reinterpret_cast< ::QHttp2Configuration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QHttp2Configuration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHttp2Configuration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHttp2Configuration, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtNetwork, ne_slot, sipType_QHttp2Configuration, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QHttp2Configuration(void *, int);}
static void release_QHttp2Configuration(void *sipCppV, int)
{
    delete reinterpret_cast< ::QHttp2Configuration *>(sipCppV);
}


extern "C" {static void *array_QHttp2Configuration(Py_ssize_t);}
static void *array_QHttp2Configuration(Py_ssize_t sipNrElem)
{
    return new  ::QHttp2Configuration[sipNrElem];
}


extern "C" {static void assign_QHttp2Configuration(void *, SIP_SSIZE_T, void *);}
static void assign_QHttp2Configuration(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QHttp2Configuration *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QHttp2Configuration *>(sipSrc);
}


extern "C" {static void *copy_QHttp2Configuration(const void *, SIP_SSIZE_T);}
static void *copy_QHttp2Configuration(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QHttp2Configuration(reinterpret_cast<const  ::QHttp2Configuration *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QHttp2Configuration(sipSimpleWrapper *);}
static void dealloc_QHttp2Configuration(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHttp2Configuration(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QHttp2Configuration(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHttp2Configuration(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QHttp2Configuration *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QHttp2Configuration();

            return sipCpp;
        }
    }

    {
        const  ::QHttp2Configuration* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QHttp2Configuration, &a0))
        {
            sipCpp = new  ::QHttp2Configuration(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QHttp2Configuration[] = {
    {(void *)slot_QHttp2Configuration___eq__, eq_slot},
    {(void *)slot_QHttp2Configuration___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QHttp2Configuration[] = {
    {SIP_MLNAME_CAST(sipName_huffmanCompressionEnabled), meth_QHttp2Configuration_huffmanCompressionEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_huffmanCompressionEnabled)},
    {SIP_MLNAME_CAST(sipName_maxFrameSize), meth_QHttp2Configuration_maxFrameSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_maxFrameSize)},
    {SIP_MLNAME_CAST(sipName_serverPushEnabled), meth_QHttp2Configuration_serverPushEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_serverPushEnabled)},
    {SIP_MLNAME_CAST(sipName_sessionReceiveWindowSize), meth_QHttp2Configuration_sessionReceiveWindowSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_sessionReceiveWindowSize)},
    {SIP_MLNAME_CAST(sipName_setHuffmanCompressionEnabled), meth_QHttp2Configuration_setHuffmanCompressionEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_setHuffmanCompressionEnabled)},
    {SIP_MLNAME_CAST(sipName_setMaxFrameSize), meth_QHttp2Configuration_setMaxFrameSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_setMaxFrameSize)},
    {SIP_MLNAME_CAST(sipName_setServerPushEnabled), meth_QHttp2Configuration_setServerPushEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_setServerPushEnabled)},
    {SIP_MLNAME_CAST(sipName_setSessionReceiveWindowSize), meth_QHttp2Configuration_setSessionReceiveWindowSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_setSessionReceiveWindowSize)},
    {SIP_MLNAME_CAST(sipName_setStreamReceiveWindowSize), meth_QHttp2Configuration_setStreamReceiveWindowSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_setStreamReceiveWindowSize)},
    {SIP_MLNAME_CAST(sipName_streamReceiveWindowSize), meth_QHttp2Configuration_streamReceiveWindowSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_streamReceiveWindowSize)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QHttp2Configuration_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QHttp2Configuration_swap)}
};

PyDoc_STRVAR(doc_QHttp2Configuration, "\1QHttp2Configuration()\n"
"QHttp2Configuration(QHttp2Configuration)");


static pyqt5ClassPluginDef plugin_QHttp2Configuration = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QHttp2Configuration = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHttp2Configuration,
        {SIP_NULLPTR},
        &plugin_QHttp2Configuration
    },
    {
        sipNameNr_QHttp2Configuration,
        {0, 0, 1},
        11, methods_QHttp2Configuration,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHttp2Configuration,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QHttp2Configuration,
    init_type_QHttp2Configuration,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QHttp2Configuration,
    assign_QHttp2Configuration,
    array_QHttp2Configuration,
    copy_QHttp2Configuration,
    release_QHttp2Configuration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
