/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlerror.sip"
#include <qqmlerror.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlError.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlError.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlError.cpp"
#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlError.cpp"


PyDoc_STRVAR(doc_QQmlError_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QQmlError_isValid(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_isValid, doc_QQmlError_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QQmlError_url(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_url, doc_QQmlError_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setUrl, "setUrl(self, QUrl)");

extern "C" {static PyObject *meth_QQmlError_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQmlError, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setUrl, doc_QQmlError_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_description, "description(self) -> str");

extern "C" {static PyObject *meth_QQmlError_description(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_description(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->description());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_description, doc_QQmlError_description);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setDescription, "setDescription(self, str)");

extern "C" {static PyObject *meth_QQmlError_setDescription(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlError, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setDescription(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setDescription, doc_QQmlError_setDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_line, "line(self) -> int");

extern "C" {static PyObject *meth_QQmlError_line(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_line(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->line();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_line, doc_QQmlError_line);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setLine, "setLine(self, int)");

extern "C" {static PyObject *meth_QQmlError_setLine(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQmlError, &sipCpp, &a0))
        {
            sipCpp->setLine(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setLine, doc_QQmlError_setLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_column, "column(self) -> int");

extern "C" {static PyObject *meth_QQmlError_column(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_column(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->column();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_column, doc_QQmlError_column);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setColumn, "setColumn(self, int)");

extern "C" {static PyObject *meth_QQmlError_setColumn(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQmlError, &sipCpp, &a0))
        {
            sipCpp->setColumn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setColumn, doc_QQmlError_setColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QQmlError_toString(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_toString, doc_QQmlError_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_object, "object(self) -> QObject");

extern "C" {static PyObject *meth_QQmlError_object(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_object(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
             ::QObject*sipRes;

            sipRes = sipCpp->object();

            return sipConvertFromType(sipRes,sipType_QObject,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_object, doc_QQmlError_object);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setObject, "setObject(self, QObject)");

extern "C" {static PyObject *meth_QQmlError_setObject(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QObject* a0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQmlError, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setObject(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setObject, doc_QQmlError_setObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_messageType, "messageType(self) -> QtMsgType");

extern "C" {static PyObject *meth_QQmlError_messageType(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_messageType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlError, &sipCpp))
        {
             ::QtMsgType sipRes;

            sipRes = sipCpp->messageType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtMsgType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_messageType, doc_QQmlError_messageType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlError_setMessageType, "setMessageType(self, QtMsgType)");

extern "C" {static PyObject *meth_QQmlError_setMessageType(PyObject *, PyObject *);}
static PyObject *meth_QQmlError_setMessageType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QtMsgType a0;
         ::QQmlError *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QQmlError, &sipCpp, sipType_QtMsgType, &a0))
        {
            sipCpp->setMessageType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlError, sipName_setMessageType, doc_QQmlError_setMessageType);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlError(void *, int);}
static void release_QQmlError(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQmlError *>(sipCppV);
}


extern "C" {static void *array_QQmlError(Py_ssize_t);}
static void *array_QQmlError(Py_ssize_t sipNrElem)
{
    return new  ::QQmlError[sipNrElem];
}


extern "C" {static void assign_QQmlError(void *, SIP_SSIZE_T, void *);}
static void assign_QQmlError(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQmlError *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQmlError *>(sipSrc);
}


extern "C" {static void *copy_QQmlError(const void *, SIP_SSIZE_T);}
static void *copy_QQmlError(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QQmlError(reinterpret_cast<const  ::QQmlError *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQmlError(sipSimpleWrapper *);}
static void dealloc_QQmlError(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlError(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQmlError(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlError(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QQmlError *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QQmlError();

            return sipCpp;
        }
    }

    {
        const  ::QQmlError* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQmlError, &a0))
        {
            sipCpp = new  ::QQmlError(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQmlError[] = {
    {SIP_MLNAME_CAST(sipName_column), meth_QQmlError_column, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_column)},
    {SIP_MLNAME_CAST(sipName_description), meth_QQmlError_description, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_description)},
    {SIP_MLNAME_CAST(sipName_isValid), meth_QQmlError_isValid, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_isValid)},
    {SIP_MLNAME_CAST(sipName_line), meth_QQmlError_line, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_line)},
    {SIP_MLNAME_CAST(sipName_messageType), meth_QQmlError_messageType, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_messageType)},
    {SIP_MLNAME_CAST(sipName_object), meth_QQmlError_object, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_object)},
    {SIP_MLNAME_CAST(sipName_setColumn), meth_QQmlError_setColumn, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setColumn)},
    {SIP_MLNAME_CAST(sipName_setDescription), meth_QQmlError_setDescription, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setDescription)},
    {SIP_MLNAME_CAST(sipName_setLine), meth_QQmlError_setLine, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setLine)},
    {SIP_MLNAME_CAST(sipName_setMessageType), meth_QQmlError_setMessageType, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setMessageType)},
    {SIP_MLNAME_CAST(sipName_setObject), meth_QQmlError_setObject, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setObject)},
    {SIP_MLNAME_CAST(sipName_setUrl), meth_QQmlError_setUrl, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_setUrl)},
    {SIP_MLNAME_CAST(sipName_toString), meth_QQmlError_toString, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_toString)},
    {SIP_MLNAME_CAST(sipName_url), meth_QQmlError_url, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlError_url)}
};

PyDoc_STRVAR(doc_QQmlError, "\1QQmlError()\n"
"QQmlError(QQmlError)");


static pyqt5ClassPluginDef plugin_QQmlError = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlError = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlError,
        {SIP_NULLPTR},
        &plugin_QQmlError
    },
    {
        sipNameNr_QQmlError,
        {0, 0, 1},
        14, methods_QQmlError,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlError,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQmlError,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlError,
    assign_QQmlError,
    array_QQmlError,
    copy_QQmlError,
    release_QQmlError,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
