/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"

#line 299 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 30 "sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGRenderNode.cpp"


class sipQSGRenderNode : public  ::QSGRenderNode
{
public:
    sipQSGRenderNode();
    virtual ~sipQSGRenderNode();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
     ::QRectF rect() const SIP_OVERRIDE;
     ::QSGRenderNode::RenderingFlags flags() const SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void render(const  ::QSGRenderNode::RenderState*) SIP_OVERRIDE;
     ::QSGRenderNode::StateFlags changedStates() const SIP_OVERRIDE;
    bool isSubtreeBlocked() const SIP_OVERRIDE;
    void preprocess() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSGRenderNode(const sipQSGRenderNode &);
    sipQSGRenderNode &operator = (const sipQSGRenderNode &);

    char sipPyMethods[7];
};

sipQSGRenderNode::sipQSGRenderNode():  ::QSGRenderNode(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSGRenderNode::~sipQSGRenderNode()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

 ::QRectF sipQSGRenderNode::rect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,SIP_NULLPTR,sipName_rect);

    if (!sipMeth)
        return  ::QSGRenderNode::rect();

    extern  ::QRectF sipVH_QtQuick_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_57(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSGRenderNode::RenderingFlags sipQSGRenderNode::flags() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,SIP_NULLPTR,sipName_flags);

    if (!sipMeth)
        return  ::QSGRenderNode::flags();

    extern  ::QSGRenderNode::RenderingFlags sipVH_QtQuick_81(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_81(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGRenderNode::releaseResources()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_releaseResources);

    if (!sipMeth)
    {
         ::QSGRenderNode::releaseResources();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGRenderNode::render(const  ::QSGRenderNode::RenderState*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,sipName_QSGRenderNode,sipName_render);

    if (!sipMeth)
        return;

    extern void sipVH_QtQuick_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QSGRenderNode::RenderState*);

    sipVH_QtQuick_80(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QSGRenderNode::StateFlags sipQSGRenderNode::changedStates() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,SIP_NULLPTR,sipName_changedStates);

    if (!sipMeth)
        return  ::QSGRenderNode::changedStates();

    extern  ::QSGRenderNode::StateFlags sipVH_QtQuick_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_79(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSGRenderNode::isSubtreeBlocked() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,SIP_NULLPTR,sipName_isSubtreeBlocked);

    if (!sipMeth)
        return  ::QSGRenderNode::isSubtreeBlocked();

    extern bool sipVH_QtQuick_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_9(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGRenderNode::preprocess()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_preprocess);

    if (!sipMeth)
    {
         ::QSGRenderNode::preprocess();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QSGRenderNode_changedStates, "changedStates(self) -> QSGRenderNode.StateFlags");

extern "C" {static PyObject *meth_QSGRenderNode_changedStates(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_changedStates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
             ::QSGRenderNode::StateFlags*sipRes;

            sipRes = new  ::QSGRenderNode::StateFlags((sipSelfWasArg ? sipCpp-> ::QSGRenderNode::changedStates() : sipCpp->changedStates()));

            return sipConvertFromNewType(sipRes,sipType_QSGRenderNode_StateFlags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_changedStates, doc_QSGRenderNode_changedStates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_render, "render(self, QSGRenderNode.RenderState)");

extern "C" {static PyObject *meth_QSGRenderNode_render(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_render(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGRenderNode::RenderState* a0;
         ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSGRenderNode, &sipCpp, sipType_QSGRenderNode_RenderState, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGRenderNode, sipName_render);
                return SIP_NULLPTR;
            }

            sipCpp->render(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_render, doc_QSGRenderNode_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_releaseResources, "releaseResources(self)");

extern "C" {static PyObject *meth_QSGRenderNode_releaseResources(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_releaseResources(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QSGRenderNode::releaseResources() : sipCpp->releaseResources());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_releaseResources, doc_QSGRenderNode_releaseResources);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_flags, "flags(self) -> QSGRenderNode.RenderingFlags");

extern "C" {static PyObject *meth_QSGRenderNode_flags(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
             ::QSGRenderNode::RenderingFlags*sipRes;

            sipRes = new  ::QSGRenderNode::RenderingFlags((sipSelfWasArg ? sipCpp-> ::QSGRenderNode::flags() : sipCpp->flags()));

            return sipConvertFromNewType(sipRes,sipType_QSGRenderNode_RenderingFlags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_flags, doc_QSGRenderNode_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_rect, "rect(self) -> QRectF");

extern "C" {static PyObject *meth_QSGRenderNode_rect(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_rect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF((sipSelfWasArg ? sipCpp-> ::QSGRenderNode::rect() : sipCpp->rect()));

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_rect, doc_QSGRenderNode_rect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_matrix, "matrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_QSGRenderNode_matrix(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_matrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
            const  ::QMatrix4x4*sipRes;

            sipRes = sipCpp->matrix();

            return sipConvertFromType(const_cast< ::QMatrix4x4 *>(sipRes),sipType_QMatrix4x4,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_matrix, doc_QSGRenderNode_matrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_clipList, "clipList(self) -> QSGClipNode");

extern "C" {static PyObject *meth_QSGRenderNode_clipList(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_clipList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
            const  ::QSGClipNode*sipRes;

            sipRes = sipCpp->clipList();

            return sipConvertFromType(const_cast< ::QSGClipNode *>(sipRes),sipType_QSGClipNode,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_clipList, doc_QSGRenderNode_clipList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGRenderNode_inheritedOpacity, "inheritedOpacity(self) -> float");

extern "C" {static PyObject *meth_QSGRenderNode_inheritedOpacity(PyObject *, PyObject *);}
static PyObject *meth_QSGRenderNode_inheritedOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGRenderNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGRenderNode, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->inheritedOpacity();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGRenderNode, sipName_inheritedOpacity, doc_QSGRenderNode_inheritedOpacity);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGRenderNode(void *, const sipTypeDef *);}
static void *cast_QSGRenderNode(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSGRenderNode *sipCpp = reinterpret_cast< ::QSGRenderNode *>(sipCppV);

    if (targetType == sipType_QSGNode)
        return static_cast< ::QSGNode *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGRenderNode(void *, int);}
static void release_QSGRenderNode(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQSGRenderNode *>(sipCppV);
    else
        delete reinterpret_cast< ::QSGRenderNode *>(sipCppV);
}


extern "C" {static void dealloc_QSGRenderNode(sipSimpleWrapper *);}
static void dealloc_QSGRenderNode(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSGRenderNode *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGRenderNode(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSGRenderNode(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGRenderNode(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSGRenderNode *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSGRenderNode();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGRenderNode[] = {{75, 255, 1}};


static PyMethodDef methods_QSGRenderNode[] = {
    {SIP_MLNAME_CAST(sipName_changedStates), meth_QSGRenderNode_changedStates, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_changedStates)},
    {SIP_MLNAME_CAST(sipName_clipList), meth_QSGRenderNode_clipList, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_clipList)},
    {SIP_MLNAME_CAST(sipName_flags), meth_QSGRenderNode_flags, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_flags)},
    {SIP_MLNAME_CAST(sipName_inheritedOpacity), meth_QSGRenderNode_inheritedOpacity, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_inheritedOpacity)},
    {SIP_MLNAME_CAST(sipName_matrix), meth_QSGRenderNode_matrix, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_matrix)},
    {SIP_MLNAME_CAST(sipName_rect), meth_QSGRenderNode_rect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_rect)},
    {SIP_MLNAME_CAST(sipName_releaseResources), meth_QSGRenderNode_releaseResources, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_releaseResources)},
    {SIP_MLNAME_CAST(sipName_render), meth_QSGRenderNode_render, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGRenderNode_render)}
};

static sipEnumMemberDef enummembers_QSGRenderNode[] = {
    {sipName_BlendState, static_cast<int>( ::QSGRenderNode::BlendState), 88},
    {sipName_BoundedRectRendering, static_cast<int>( ::QSGRenderNode::BoundedRectRendering), 86},
    {sipName_ColorState, static_cast<int>( ::QSGRenderNode::ColorState), 88},
    {sipName_CullState, static_cast<int>( ::QSGRenderNode::CullState), 88},
    {sipName_DepthAwareRendering, static_cast<int>( ::QSGRenderNode::DepthAwareRendering), 86},
    {sipName_DepthState, static_cast<int>( ::QSGRenderNode::DepthState), 88},
    {sipName_OpaqueRendering, static_cast<int>( ::QSGRenderNode::OpaqueRendering), 86},
    {sipName_RenderTargetState, static_cast<int>( ::QSGRenderNode::RenderTargetState), 88},
    {sipName_ScissorState, static_cast<int>( ::QSGRenderNode::ScissorState), 88},
    {sipName_StencilState, static_cast<int>( ::QSGRenderNode::StencilState), 88},
    {sipName_ViewportState, static_cast<int>( ::QSGRenderNode::ViewportState), 88},
};

PyDoc_STRVAR(doc_QSGRenderNode, "\1QSGRenderNode()");


static pyqt5ClassPluginDef plugin_QSGRenderNode = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGRenderNode,
        {SIP_NULLPTR},
        &plugin_QSGRenderNode
    },
    {
        sipNameNr_QSGRenderNode,
        {0, 0, 1},
        8, methods_QSGRenderNode,
        11, enummembers_QSGRenderNode,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGRenderNode,
    -1,
    -1,
    supers_QSGRenderNode,
    SIP_NULLPTR,
    init_type_QSGRenderNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGRenderNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGRenderNode,
    cast_QSGRenderNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
