/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQSsl.cpp"


static sipEnumMemberDef enummembers_QSsl[] = {
    {sipName_AnyProtocol, static_cast<int>( ::QSsl::AnyProtocol), 116},
    {sipName_Der, static_cast<int>( ::QSsl::Der), 111},
    {sipName_Dh, static_cast<int>( ::QSsl::Dh), 112},
    {sipName_DnsEntry, static_cast<int>( ::QSsl::DnsEntry), 110},
    {sipName_Dsa, static_cast<int>( ::QSsl::Dsa), 112},
    {sipName_DtlsV1_0, static_cast<int>( ::QSsl::DtlsV1_0), 116},
    {sipName_DtlsV1_0OrLater, static_cast<int>( ::QSsl::DtlsV1_0OrLater), 116},
    {sipName_DtlsV1_2, static_cast<int>( ::QSsl::DtlsV1_2), 116},
    {sipName_DtlsV1_2OrLater, static_cast<int>( ::QSsl::DtlsV1_2OrLater), 116},
    {sipName_Ec, static_cast<int>( ::QSsl::Ec), 112},
    {sipName_EmailEntry, static_cast<int>( ::QSsl::EmailEntry), 110},
    {sipName_IpAddressEntry, static_cast<int>( ::QSsl::IpAddressEntry), 110},
    {sipName_Opaque, static_cast<int>( ::QSsl::Opaque), 112},
    {sipName_Pem, static_cast<int>( ::QSsl::Pem), 111},
    {sipName_PrivateKey, static_cast<int>( ::QSsl::PrivateKey), 113},
    {sipName_PublicKey, static_cast<int>( ::QSsl::PublicKey), 113},
    {sipName_Rsa, static_cast<int>( ::QSsl::Rsa), 112},
    {sipName_SecureProtocols, static_cast<int>( ::QSsl::SecureProtocols), 116},
    {sipName_SslOptionDisableCompression, static_cast<int>( ::QSsl::SslOptionDisableCompression), 114},
    {sipName_SslOptionDisableEmptyFragments, static_cast<int>( ::QSsl::SslOptionDisableEmptyFragments), 114},
    {sipName_SslOptionDisableLegacyRenegotiation, static_cast<int>( ::QSsl::SslOptionDisableLegacyRenegotiation), 114},
    {sipName_SslOptionDisableServerCipherPreference, static_cast<int>( ::QSsl::SslOptionDisableServerCipherPreference), 114},
    {sipName_SslOptionDisableServerNameIndication, static_cast<int>( ::QSsl::SslOptionDisableServerNameIndication), 114},
    {sipName_SslOptionDisableSessionPersistence, static_cast<int>( ::QSsl::SslOptionDisableSessionPersistence), 114},
    {sipName_SslOptionDisableSessionSharing, static_cast<int>( ::QSsl::SslOptionDisableSessionSharing), 114},
    {sipName_SslOptionDisableSessionTickets, static_cast<int>( ::QSsl::SslOptionDisableSessionTickets), 114},
    {sipName_SslV2, static_cast<int>( ::QSsl::SslV2), 116},
    {sipName_SslV3, static_cast<int>( ::QSsl::SslV3), 116},
    {sipName_TlsV1SslV3, static_cast<int>( ::QSsl::TlsV1SslV3), 116},
    {sipName_TlsV1_0, static_cast<int>( ::QSsl::TlsV1_0), 116},
    {sipName_TlsV1_0OrLater, static_cast<int>( ::QSsl::TlsV1_0OrLater), 116},
    {sipName_TlsV1_1, static_cast<int>( ::QSsl::TlsV1_1), 116},
    {sipName_TlsV1_1OrLater, static_cast<int>( ::QSsl::TlsV1_1OrLater), 116},
    {sipName_TlsV1_2, static_cast<int>( ::QSsl::TlsV1_2), 116},
    {sipName_TlsV1_2OrLater, static_cast<int>( ::QSsl::TlsV1_2OrLater), 116},
    {sipName_TlsV1_3, static_cast<int>( ::QSsl::TlsV1_3), 116},
    {sipName_TlsV1_3OrLater, static_cast<int>( ::QSsl::TlsV1_3OrLater), 116},
    {sipName_UnknownProtocol, static_cast<int>( ::QSsl::UnknownProtocol), 116},
};


static pyqt5ClassPluginDef plugin_QSsl = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QSsl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QSsl,
        {SIP_NULLPTR},
        &plugin_QSsl
    },
    {
        sipNameNr_QSsl,
        {0, 0, 1},
        0, SIP_NULLPTR,
        38, enummembers_QSsl,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
