/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstatictext.sip"
#include <qstatictext.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"

#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"
#line 103 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQStaticText.cpp"


PyDoc_STRVAR(doc_QStaticText_setText, "setText(self, str)");

extern "C" {static PyObject *meth_QStaticText_setText(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStaticText, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_setText, doc_QStaticText_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_text, "text(self) -> str");

extern "C" {static PyObject *meth_QStaticText_text(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_text, doc_QStaticText_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_setTextFormat, "setTextFormat(self, Qt.TextFormat)");

extern "C" {static PyObject *meth_QStaticText_setTextFormat(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_setTextFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::TextFormat a0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QStaticText, &sipCpp, sipType_Qt_TextFormat, &a0))
        {
            sipCpp->setTextFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_setTextFormat, doc_QStaticText_setTextFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_textFormat, "textFormat(self) -> Qt.TextFormat");

extern "C" {static PyObject *meth_QStaticText_textFormat(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_textFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::Qt::TextFormat sipRes;

            sipRes = sipCpp->textFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_TextFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_textFormat, doc_QStaticText_textFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_setTextWidth, "setTextWidth(self, float)");

extern "C" {static PyObject *meth_QStaticText_setTextWidth(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_setTextWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QStaticText, &sipCpp, &a0))
        {
            sipCpp->setTextWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_setTextWidth, doc_QStaticText_setTextWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_textWidth, "textWidth(self) -> float");

extern "C" {static PyObject *meth_QStaticText_textWidth(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_textWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->textWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_textWidth, doc_QStaticText_textWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_setTextOption, "setTextOption(self, QTextOption)");

extern "C" {static PyObject *meth_QStaticText_setTextOption(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_setTextOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextOption* a0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStaticText, &sipCpp, sipType_QTextOption, &a0))
        {
            sipCpp->setTextOption(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_setTextOption, doc_QStaticText_setTextOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_textOption, "textOption(self) -> QTextOption");

extern "C" {static PyObject *meth_QStaticText_textOption(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_textOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::QTextOption*sipRes;

            sipRes = new  ::QTextOption(sipCpp->textOption());

            return sipConvertFromNewType(sipRes,sipType_QTextOption,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_textOption, doc_QStaticText_textOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_size, "size(self) -> QSizeF");

extern "C" {static PyObject *meth_QStaticText_size(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::QSizeF*sipRes;

            sipRes = new  ::QSizeF(sipCpp->size());

            return sipConvertFromNewType(sipRes,sipType_QSizeF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_size, doc_QStaticText_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_prepare, "prepare(self, matrix: QTransform = QTransform(), font: QFont = QFont())");

extern "C" {static PyObject *meth_QStaticText_prepare(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStaticText_prepare(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTransform& a0def = QTransform();
        const  ::QTransform* a0 = &a0def;
        const  ::QFont& a1def = QFont();
        const  ::QFont* a1 = &a1def;
         ::QStaticText *sipCpp;

        static const char *sipKwdList[] = {
            sipName_matrix,
            sipName_font,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9J9", &sipSelf, sipType_QStaticText, &sipCpp, sipType_QTransform, &a0, sipType_QFont, &a1))
        {
            sipCpp->prepare(*a0,*a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_prepare, doc_QStaticText_prepare);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_setPerformanceHint, "setPerformanceHint(self, QStaticText.PerformanceHint)");

extern "C" {static PyObject *meth_QStaticText_setPerformanceHint(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_setPerformanceHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QStaticText::PerformanceHint a0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QStaticText, &sipCpp, sipType_QStaticText_PerformanceHint, &a0))
        {
            sipCpp->setPerformanceHint(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_setPerformanceHint, doc_QStaticText_setPerformanceHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_performanceHint, "performanceHint(self) -> QStaticText.PerformanceHint");

extern "C" {static PyObject *meth_QStaticText_performanceHint(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_performanceHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStaticText, &sipCpp))
        {
             ::QStaticText::PerformanceHint sipRes;

            sipRes = sipCpp->performanceHint();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QStaticText_PerformanceHint);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_performanceHint, doc_QStaticText_performanceHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStaticText_swap, "swap(self, QStaticText)");

extern "C" {static PyObject *meth_QStaticText_swap(PyObject *, PyObject *);}
static PyObject *meth_QStaticText_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QStaticText* a0;
         ::QStaticText *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStaticText, &sipCpp, sipType_QStaticText, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStaticText, sipName_swap, doc_QStaticText_swap);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QStaticText___ne__(PyObject *,PyObject *);}
static PyObject *slot_QStaticText___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QStaticText *sipCpp = reinterpret_cast< ::QStaticText *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QStaticText));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QStaticText, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QStaticText::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QStaticText, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QStaticText___eq__(PyObject *,PyObject *);}
static PyObject *slot_QStaticText___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QStaticText *sipCpp = reinterpret_cast< ::QStaticText *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QStaticText));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStaticText* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QStaticText, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QStaticText::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QStaticText, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QStaticText(void *, int);}
static void release_QStaticText(void *sipCppV, int)
{
    delete reinterpret_cast< ::QStaticText *>(sipCppV);
}


extern "C" {static void *array_QStaticText(Py_ssize_t);}
static void *array_QStaticText(Py_ssize_t sipNrElem)
{
    return new  ::QStaticText[sipNrElem];
}


extern "C" {static void assign_QStaticText(void *, SIP_SSIZE_T, void *);}
static void assign_QStaticText(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QStaticText *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QStaticText *>(sipSrc);
}


extern "C" {static void *copy_QStaticText(const void *, SIP_SSIZE_T);}
static void *copy_QStaticText(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QStaticText(reinterpret_cast<const  ::QStaticText *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QStaticText(sipSimpleWrapper *);}
static void dealloc_QStaticText(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStaticText(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QStaticText(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStaticText(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QStaticText *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QStaticText();

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString,&a0, &a0State))
        {
            sipCpp = new  ::QStaticText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipCpp;
        }
    }

    {
        const  ::QStaticText* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QStaticText, &a0))
        {
            sipCpp = new  ::QStaticText(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QStaticText[] = {
    {(void *)slot_QStaticText___ne__, ne_slot},
    {(void *)slot_QStaticText___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QStaticText[] = {
    {SIP_MLNAME_CAST(sipName_performanceHint), meth_QStaticText_performanceHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_performanceHint)},
    {SIP_MLNAME_CAST(sipName_prepare), SIP_MLMETH_CAST(meth_QStaticText_prepare), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStaticText_prepare)},
    {SIP_MLNAME_CAST(sipName_setPerformanceHint), meth_QStaticText_setPerformanceHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_setPerformanceHint)},
    {SIP_MLNAME_CAST(sipName_setText), meth_QStaticText_setText, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_setText)},
    {SIP_MLNAME_CAST(sipName_setTextFormat), meth_QStaticText_setTextFormat, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_setTextFormat)},
    {SIP_MLNAME_CAST(sipName_setTextOption), meth_QStaticText_setTextOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_setTextOption)},
    {SIP_MLNAME_CAST(sipName_setTextWidth), meth_QStaticText_setTextWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_setTextWidth)},
    {SIP_MLNAME_CAST(sipName_size), meth_QStaticText_size, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_size)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QStaticText_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_swap)},
    {SIP_MLNAME_CAST(sipName_text), meth_QStaticText_text, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_text)},
    {SIP_MLNAME_CAST(sipName_textFormat), meth_QStaticText_textFormat, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_textFormat)},
    {SIP_MLNAME_CAST(sipName_textOption), meth_QStaticText_textOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_textOption)},
    {SIP_MLNAME_CAST(sipName_textWidth), meth_QStaticText_textWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QStaticText_textWidth)}
};

static sipEnumMemberDef enummembers_QStaticText[] = {
    {sipName_AggressiveCaching, static_cast<int>( ::QStaticText::AggressiveCaching), 270},
    {sipName_ModerateCaching, static_cast<int>( ::QStaticText::ModerateCaching), 270},
};

PyDoc_STRVAR(doc_QStaticText, "\1QStaticText()\n"
"QStaticText(str)\n"
"QStaticText(QStaticText)");


static pyqt5ClassPluginDef plugin_QStaticText = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QStaticText = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStaticText,
        {SIP_NULLPTR},
        &plugin_QStaticText
    },
    {
        sipNameNr_QStaticText,
        {0, 0, 1},
        13, methods_QStaticText,
        2, enummembers_QStaticText,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStaticText,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QStaticText,
    init_type_QStaticText,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QStaticText,
    assign_QStaticText,
    array_QStaticText,
    copy_QStaticText,
    release_QStaticText,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
