/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 123 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQGradient.cpp"

#line 253 "sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#include <qpair.h>
#line 34 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQGradient.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 37 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQGradient.cpp"


PyDoc_STRVAR(doc_QGradient_type, "type(self) -> QGradient.Type");

extern "C" {static PyObject *meth_QGradient_type(PyObject *, PyObject *);}
static PyObject *meth_QGradient_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGradient, &sipCpp))
        {
             ::QGradient::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGradient_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_type, doc_QGradient_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_spread, "spread(self) -> QGradient.Spread");

extern "C" {static PyObject *meth_QGradient_spread(PyObject *, PyObject *);}
static PyObject *meth_QGradient_spread(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGradient, &sipCpp))
        {
             ::QGradient::Spread sipRes;

            sipRes = sipCpp->spread();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGradient_Spread);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_spread, doc_QGradient_spread);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_setColorAt, "setColorAt(self, float, Union[QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QGradient_setColorAt(PyObject *, PyObject *);}
static PyObject *meth_QGradient_setColorAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
        const  ::QColor* a1;
        int a1State = 0;
         ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BdJ1", &sipSelf, sipType_QGradient, &sipCpp, &a0, sipType_QColor, &a1, &a1State))
        {
            sipCpp->setColorAt(a0,*a1);
            sipReleaseType(const_cast< ::QColor *>(a1),sipType_QColor,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_setColorAt, doc_QGradient_setColorAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_setStops, "setStops(self, Iterable[Tuple[float, Union[QColor, Qt.GlobalColor, QGradient]]])");

extern "C" {static PyObject *meth_QGradient_setStops(PyObject *, PyObject *);}
static PyObject *meth_QGradient_setStops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradientStops* a0;
        int a0State = 0;
         ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGradient, &sipCpp, sipType_QVector_0600QPair_2400_0100QColor,&a0, &a0State))
        {
            sipCpp->setStops(*a0);
            sipReleaseType(const_cast< ::QGradientStops *>(a0),sipType_QVector_0600QPair_2400_0100QColor,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_setStops, doc_QGradient_setStops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_stops, "stops(self) -> List[Tuple[float, QColor]]");

extern "C" {static PyObject *meth_QGradient_stops(PyObject *, PyObject *);}
static PyObject *meth_QGradient_stops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGradient, &sipCpp))
        {
             ::QGradientStops*sipRes;

            sipRes = new  ::QGradientStops(sipCpp->stops());

            return sipConvertFromNewType(sipRes,sipType_QVector_0600QPair_2400_0100QColor,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_stops, doc_QGradient_stops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_setSpread, "setSpread(self, QGradient.Spread)");

extern "C" {static PyObject *meth_QGradient_setSpread(PyObject *, PyObject *);}
static PyObject *meth_QGradient_setSpread(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGradient::Spread a0;
         ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGradient, &sipCpp, sipType_QGradient_Spread, &a0))
        {
            sipCpp->setSpread(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_setSpread, doc_QGradient_setSpread);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_coordinateMode, "coordinateMode(self) -> QGradient.CoordinateMode");

extern "C" {static PyObject *meth_QGradient_coordinateMode(PyObject *, PyObject *);}
static PyObject *meth_QGradient_coordinateMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGradient, &sipCpp))
        {
             ::QGradient::CoordinateMode sipRes;

            sipRes = sipCpp->coordinateMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGradient_CoordinateMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_coordinateMode, doc_QGradient_coordinateMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGradient_setCoordinateMode, "setCoordinateMode(self, QGradient.CoordinateMode)");

extern "C" {static PyObject *meth_QGradient_setCoordinateMode(PyObject *, PyObject *);}
static PyObject *meth_QGradient_setCoordinateMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGradient::CoordinateMode a0;
         ::QGradient *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGradient, &sipCpp, sipType_QGradient_CoordinateMode, &a0))
        {
            sipCpp->setCoordinateMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGradient, sipName_setCoordinateMode, doc_QGradient_setCoordinateMode);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGradient___ne__(PyObject *,PyObject *);}
static PyObject *slot_QGradient___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QGradient *sipCpp = reinterpret_cast< ::QGradient *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGradient));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGradient, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QGradient::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QGradient, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGradient___eq__(PyObject *,PyObject *);}
static PyObject *slot_QGradient___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QGradient *sipCpp = reinterpret_cast< ::QGradient *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QGradient));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QGradient* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGradient, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QGradient::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QGradient, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QGradient(void *, int);}
static void release_QGradient(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGradient *>(sipCppV);
}


extern "C" {static void *array_QGradient(Py_ssize_t);}
static void *array_QGradient(Py_ssize_t sipNrElem)
{
    return new  ::QGradient[sipNrElem];
}


extern "C" {static void assign_QGradient(void *, SIP_SSIZE_T, void *);}
static void assign_QGradient(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGradient *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGradient *>(sipSrc);
}


extern "C" {static void *copy_QGradient(const void *, SIP_SSIZE_T);}
static void *copy_QGradient(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QGradient(reinterpret_cast<const  ::QGradient *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGradient(sipSimpleWrapper *);}
static void dealloc_QGradient(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGradient(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGradient(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGradient(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QGradient *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QGradient();

            return sipCpp;
        }
    }

    {
         ::QGradient::Preset a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "E", sipType_QGradient_Preset, &a0))
        {
            sipCpp = new  ::QGradient(a0);

            return sipCpp;
        }
    }

    {
        const  ::QGradient* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGradient, &a0))
        {
            sipCpp = new  ::QGradient(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGradient[] = {
    {(void *)slot_QGradient___ne__, ne_slot},
    {(void *)slot_QGradient___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGradient[] = {
    {SIP_MLNAME_CAST(sipName_coordinateMode), meth_QGradient_coordinateMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_coordinateMode)},
    {SIP_MLNAME_CAST(sipName_setColorAt), meth_QGradient_setColorAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_setColorAt)},
    {SIP_MLNAME_CAST(sipName_setCoordinateMode), meth_QGradient_setCoordinateMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_setCoordinateMode)},
    {SIP_MLNAME_CAST(sipName_setSpread), meth_QGradient_setSpread, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_setSpread)},
    {SIP_MLNAME_CAST(sipName_setStops), meth_QGradient_setStops, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_setStops)},
    {SIP_MLNAME_CAST(sipName_spread), meth_QGradient_spread, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_spread)},
    {SIP_MLNAME_CAST(sipName_stops), meth_QGradient_stops, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_stops)},
    {SIP_MLNAME_CAST(sipName_type), meth_QGradient_type, METH_VARARGS, SIP_MLDOC_CAST(doc_QGradient_type)}
};

static sipEnumMemberDef enummembers_QGradient[] = {
    {sipName_AboveTheSky, static_cast<int>( ::QGradient::AboveTheSky), 58},
    {sipName_AfricanField, static_cast<int>( ::QGradient::AfricanField), 58},
    {sipName_AlchemistLab, static_cast<int>( ::QGradient::AlchemistLab), 58},
    {sipName_AmourAmour, static_cast<int>( ::QGradient::AmourAmour), 58},
    {sipName_AmyCrisp, static_cast<int>( ::QGradient::AmyCrisp), 58},
    {sipName_AngelCare, static_cast<int>( ::QGradient::AngelCare), 58},
    {sipName_AquaGuidance, static_cast<int>( ::QGradient::AquaGuidance), 58},
    {sipName_AquaSplash, static_cast<int>( ::QGradient::AquaSplash), 58},
    {sipName_AwesomePine, static_cast<int>( ::QGradient::AwesomePine), 58},
    {sipName_BigMango, static_cast<int>( ::QGradient::BigMango), 58},
    {sipName_BlackSea, static_cast<int>( ::QGradient::BlackSea), 58},
    {sipName_Blessing, static_cast<int>( ::QGradient::Blessing), 58},
    {sipName_BurningSpring, static_cast<int>( ::QGradient::BurningSpring), 58},
    {sipName_CheerfulCaramel, static_cast<int>( ::QGradient::CheerfulCaramel), 58},
    {sipName_ChildCare, static_cast<int>( ::QGradient::ChildCare), 58},
    {sipName_CleanMirror, static_cast<int>( ::QGradient::CleanMirror), 58},
    {sipName_CloudyApple, static_cast<int>( ::QGradient::CloudyApple), 58},
    {sipName_CloudyKnoxville, static_cast<int>( ::QGradient::CloudyKnoxville), 58},
    {sipName_CochitiLake, static_cast<int>( ::QGradient::CochitiLake), 58},
    {sipName_ColdEvening, static_cast<int>( ::QGradient::ColdEvening), 58},
    {sipName_ColorfulPeach, static_cast<int>( ::QGradient::ColorfulPeach), 58},
    {sipName_ConfidentCloud, static_cast<int>( ::QGradient::ConfidentCloud), 58},
    {sipName_ConicalGradient, static_cast<int>( ::QGradient::ConicalGradient), 60},
    {sipName_CrystalRiver, static_cast<int>( ::QGradient::CrystalRiver), 58},
    {sipName_Crystalline, static_cast<int>( ::QGradient::Crystalline), 58},
    {sipName_DeepBlue, static_cast<int>( ::QGradient::DeepBlue), 58},
    {sipName_DeepRelief, static_cast<int>( ::QGradient::DeepRelief), 58},
    {sipName_DenseWater, static_cast<int>( ::QGradient::DenseWater), 58},
    {sipName_DesertHump, static_cast<int>( ::QGradient::DesertHump), 58},
    {sipName_DirtyBeauty, static_cast<int>( ::QGradient::DirtyBeauty), 58},
    {sipName_DustyGrass, static_cast<int>( ::QGradient::DustyGrass), 58},
    {sipName_EternalConstance, static_cast<int>( ::QGradient::EternalConstance), 58},
    {sipName_EverlastingSky, static_cast<int>( ::QGradient::EverlastingSky), 58},
    {sipName_FabledSunset, static_cast<int>( ::QGradient::FabledSunset), 58},
    {sipName_FarawayRiver, static_cast<int>( ::QGradient::FarawayRiver), 58},
    {sipName_FebruaryInk, static_cast<int>( ::QGradient::FebruaryInk), 58},
    {sipName_FlyHigh, static_cast<int>( ::QGradient::FlyHigh), 58},
    {sipName_FlyingLemon, static_cast<int>( ::QGradient::FlyingLemon), 58},
    {sipName_ForestInei, static_cast<int>( ::QGradient::ForestInei), 58},
    {sipName_FreshMilk, static_cast<int>( ::QGradient::FreshMilk), 58},
    {sipName_FreshOasis, static_cast<int>( ::QGradient::FreshOasis), 58},
    {sipName_FrozenBerry, static_cast<int>( ::QGradient::FrozenBerry), 58},
    {sipName_FrozenDreams, static_cast<int>( ::QGradient::FrozenDreams), 58},
    {sipName_FrozenHeat, static_cast<int>( ::QGradient::FrozenHeat), 58},
    {sipName_FruitBlend, static_cast<int>( ::QGradient::FruitBlend), 58},
    {sipName_GagarinView, static_cast<int>( ::QGradient::GagarinView), 58},
    {sipName_GentleCare, static_cast<int>( ::QGradient::GentleCare), 58},
    {sipName_GlassWater, static_cast<int>( ::QGradient::GlassWater), 58},
    {sipName_GrassShampoo, static_cast<int>( ::QGradient::GrassShampoo), 58},
    {sipName_GreatWhale, static_cast<int>( ::QGradient::GreatWhale), 58},
    {sipName_GrownEarly, static_cast<int>( ::QGradient::GrownEarly), 58},
    {sipName_HappyAcid, static_cast<int>( ::QGradient::HappyAcid), 58},
    {sipName_HappyFisher, static_cast<int>( ::QGradient::HappyFisher), 58},
    {sipName_HappyMemories, static_cast<int>( ::QGradient::HappyMemories), 58},
    {sipName_HappyUnicorn, static_cast<int>( ::QGradient::HappyUnicorn), 58},
    {sipName_HealthyWater, static_cast<int>( ::QGradient::HealthyWater), 58},
    {sipName_HeavenPeach, static_cast<int>( ::QGradient::HeavenPeach), 58},
    {sipName_HeavyRain, static_cast<int>( ::QGradient::HeavyRain), 58},
    {sipName_HiddenJaguar, static_cast<int>( ::QGradient::HiddenJaguar), 58},
    {sipName_HighFlight, static_cast<int>( ::QGradient::HighFlight), 58},
    {sipName_ItmeoBranding, static_cast<int>( ::QGradient::ItmeoBranding), 58},
    {sipName_JapanBlush, static_cast<int>( ::QGradient::JapanBlush), 58},
    {sipName_JuicyCake, static_cast<int>( ::QGradient::JuicyCake), 58},
    {sipName_JuicyPeach, static_cast<int>( ::QGradient::JuicyPeach), 58},
    {sipName_JungleDay, static_cast<int>( ::QGradient::JungleDay), 58},
    {sipName_KindSteel, static_cast<int>( ::QGradient::KindSteel), 58},
    {sipName_LadogaBottom, static_cast<int>( ::QGradient::LadogaBottom), 58},
    {sipName_LadyLips, static_cast<int>( ::QGradient::LadyLips), 58},
    {sipName_LandingAircraft, static_cast<int>( ::QGradient::LandingAircraft), 58},
    {sipName_LeCocktail, static_cast<int>( ::QGradient::LeCocktail), 58},
    {sipName_LemonGate, static_cast<int>( ::QGradient::LemonGate), 58},
    {sipName_LightBlue, static_cast<int>( ::QGradient::LightBlue), 58},
    {sipName_LilyMeadow, static_cast<int>( ::QGradient::LilyMeadow), 58},
    {sipName_LinearGradient, static_cast<int>( ::QGradient::LinearGradient), 60},
    {sipName_LogicalMode, static_cast<int>( ::QGradient::LogicalMode), 57},
    {sipName_LoveKiss, static_cast<int>( ::QGradient::LoveKiss), 58},
    {sipName_MagicLake, static_cast<int>( ::QGradient::MagicLake), 58},
    {sipName_MagicRay, static_cast<int>( ::QGradient::MagicRay), 58},
    {sipName_MalibuBeach, static_cast<int>( ::QGradient::MalibuBeach), 58},
    {sipName_MarbleWall, static_cast<int>( ::QGradient::MarbleWall), 58},
    {sipName_MarsParty, static_cast<int>( ::QGradient::MarsParty), 58},
    {sipName_MeanFruit, static_cast<int>( ::QGradient::MeanFruit), 58},
    {sipName_MidnightBloom, static_cast<int>( ::QGradient::MidnightBloom), 58},
    {sipName_MillenniumPine, static_cast<int>( ::QGradient::MillenniumPine), 58},
    {sipName_MindCrawl, static_cast<int>( ::QGradient::MindCrawl), 58},
    {sipName_MixedHopes, static_cast<int>( ::QGradient::MixedHopes), 58},
    {sipName_MoleHall, static_cast<int>( ::QGradient::MoleHall), 58},
    {sipName_MorningSalad, static_cast<int>( ::QGradient::MorningSalad), 58},
    {sipName_MorpheusDen, static_cast<int>( ::QGradient::MorpheusDen), 58},
    {sipName_MountainRock, static_cast<int>( ::QGradient::MountainRock), 58},
    {sipName_NearMoon, static_cast<int>( ::QGradient::NearMoon), 58},
    {sipName_Nega, static_cast<int>( ::QGradient::Nega), 58},
    {sipName_NewLife, static_cast<int>( ::QGradient::NewLife), 58},
    {sipName_NewRetrowave, static_cast<int>( ::QGradient::NewRetrowave), 58},
    {sipName_NewYork, static_cast<int>( ::QGradient::NewYork), 58},
    {sipName_NightCall, static_cast<int>( ::QGradient::NightCall), 58},
    {sipName_NightFade, static_cast<int>( ::QGradient::NightFade), 58},
    {sipName_NightParty, static_cast<int>( ::QGradient::NightParty), 58},
    {sipName_NightSky, static_cast<int>( ::QGradient::NightSky), 58},
    {sipName_NoGradient, static_cast<int>( ::QGradient::NoGradient), 60},
    {sipName_NorseBeauty, static_cast<int>( ::QGradient::NorseBeauty), 58},
    {sipName_NorthMiracle, static_cast<int>( ::QGradient::NorthMiracle), 58},
    {sipName_NumPresets, static_cast<int>( ::QGradient::NumPresets), 58},
    {sipName_ObjectBoundingMode, static_cast<int>( ::QGradient::ObjectBoundingMode), 57},
    {sipName_ObjectMode, static_cast<int>( ::QGradient::ObjectMode), 57},
    {sipName_OctoberSilence, static_cast<int>( ::QGradient::OctoberSilence), 58},
    {sipName_OldHat, static_cast<int>( ::QGradient::OldHat), 58},
    {sipName_OrangeJuice, static_cast<int>( ::QGradient::OrangeJuice), 58},
    {sipName_OverSun, static_cast<int>( ::QGradient::OverSun), 58},
    {sipName_PadSpread, static_cast<int>( ::QGradient::PadSpread), 59},
    {sipName_PaloAlto, static_cast<int>( ::QGradient::PaloAlto), 58},
    {sipName_PartyBliss, static_cast<int>( ::QGradient::PartyBliss), 58},
    {sipName_PassionateBed, static_cast<int>( ::QGradient::PassionateBed), 58},
    {sipName_PerfectBlue, static_cast<int>( ::QGradient::PerfectBlue), 58},
    {sipName_PerfectWhite, static_cast<int>( ::QGradient::PerfectWhite), 58},
    {sipName_PhoenixStart, static_cast<int>( ::QGradient::PhoenixStart), 58},
    {sipName_PlumBath, static_cast<int>( ::QGradient::PlumBath), 58},
    {sipName_PlumPlate, static_cast<int>( ::QGradient::PlumPlate), 58},
    {sipName_PoliteRumors, static_cast<int>( ::QGradient::PoliteRumors), 58},
    {sipName_PremiumDark, static_cast<int>( ::QGradient::PremiumDark), 58},
    {sipName_PremiumWhite, static_cast<int>( ::QGradient::PremiumWhite), 58},
    {sipName_PurpleDivision, static_cast<int>( ::QGradient::PurpleDivision), 58},
    {sipName_RadialGradient, static_cast<int>( ::QGradient::RadialGradient), 60},
    {sipName_RainyAshville, static_cast<int>( ::QGradient::RainyAshville), 58},
    {sipName_RareWind, static_cast<int>( ::QGradient::RareWind), 58},
    {sipName_RedSalvation, static_cast<int>( ::QGradient::RedSalvation), 58},
    {sipName_ReflectSpread, static_cast<int>( ::QGradient::ReflectSpread), 59},
    {sipName_RepeatSpread, static_cast<int>( ::QGradient::RepeatSpread), 59},
    {sipName_RichMetal, static_cast<int>( ::QGradient::RichMetal), 58},
    {sipName_RipeMalinka, static_cast<int>( ::QGradient::RipeMalinka), 58},
    {sipName_RiskyConcrete, static_cast<int>( ::QGradient::RiskyConcrete), 58},
    {sipName_RiverCity, static_cast<int>( ::QGradient::RiverCity), 58},
    {sipName_RoyalGarden, static_cast<int>( ::QGradient::RoyalGarden), 58},
    {sipName_SaintPetersburg, static_cast<int>( ::QGradient::SaintPetersburg), 58},
    {sipName_SaltMountain, static_cast<int>( ::QGradient::SaltMountain), 58},
    {sipName_SandStrike, static_cast<int>( ::QGradient::SandStrike), 58},
    {sipName_SeaLord, static_cast<int>( ::QGradient::SeaLord), 58},
    {sipName_SeaStrike, static_cast<int>( ::QGradient::SeaStrike), 58},
    {sipName_Seashore, static_cast<int>( ::QGradient::Seashore), 58},
    {sipName_ShadyWater, static_cast<int>( ::QGradient::ShadyWater), 58},
    {sipName_SharpBlues, static_cast<int>( ::QGradient::SharpBlues), 58},
    {sipName_SharpeyeEagle, static_cast<int>( ::QGradient::SharpeyeEagle), 58},
    {sipName_ShyRainbow, static_cast<int>( ::QGradient::ShyRainbow), 58},
    {sipName_SkyGlider, static_cast<int>( ::QGradient::SkyGlider), 58},
    {sipName_SleeplessNight, static_cast<int>( ::QGradient::SleeplessNight), 58},
    {sipName_SmartIndigo, static_cast<int>( ::QGradient::SmartIndigo), 58},
    {sipName_SmilingRain, static_cast<int>( ::QGradient::SmilingRain), 58},
    {sipName_SnowAgain, static_cast<int>( ::QGradient::SnowAgain), 58},
    {sipName_SoftCherish, static_cast<int>( ::QGradient::SoftCherish), 58},
    {sipName_SoftGrass, static_cast<int>( ::QGradient::SoftGrass), 58},
    {sipName_SoftLipstick, static_cast<int>( ::QGradient::SoftLipstick), 58},
    {sipName_SolidStone, static_cast<int>( ::QGradient::SolidStone), 58},
    {sipName_SpaceShift, static_cast<int>( ::QGradient::SpaceShift), 58},
    {sipName_SpikyNaga, static_cast<int>( ::QGradient::SpikyNaga), 58},
    {sipName_SpringWarmth, static_cast<int>( ::QGradient::SpringWarmth), 58},
    {sipName_StarWine, static_cast<int>( ::QGradient::StarWine), 58},
    {sipName_StretchToDeviceMode, static_cast<int>( ::QGradient::StretchToDeviceMode), 57},
    {sipName_StrictNovember, static_cast<int>( ::QGradient::StrictNovember), 58},
    {sipName_StrongBliss, static_cast<int>( ::QGradient::StrongBliss), 58},
    {sipName_StrongStick, static_cast<int>( ::QGradient::StrongStick), 58},
    {sipName_SugarLollipop, static_cast<int>( ::QGradient::SugarLollipop), 58},
    {sipName_SummerGames, static_cast<int>( ::QGradient::SummerGames), 58},
    {sipName_SunVeggie, static_cast<int>( ::QGradient::SunVeggie), 58},
    {sipName_SunnyMorning, static_cast<int>( ::QGradient::SunnyMorning), 58},
    {sipName_SupremeSky, static_cast<int>( ::QGradient::SupremeSky), 58},
    {sipName_SweetDessert, static_cast<int>( ::QGradient::SweetDessert), 58},
    {sipName_SweetPeriod, static_cast<int>( ::QGradient::SweetPeriod), 58},
    {sipName_TeenNotebook, static_cast<int>( ::QGradient::TeenNotebook), 58},
    {sipName_TeenParty, static_cast<int>( ::QGradient::TeenParty), 58},
    {sipName_TemptingAzure, static_cast<int>( ::QGradient::TemptingAzure), 58},
    {sipName_TrueSunset, static_cast<int>( ::QGradient::TrueSunset), 58},
    {sipName_ViciousStance, static_cast<int>( ::QGradient::ViciousStance), 58},
    {sipName_WarmFlame, static_cast<int>( ::QGradient::WarmFlame), 58},
    {sipName_WideMatrix, static_cast<int>( ::QGradient::WideMatrix), 58},
    {sipName_WildApple, static_cast<int>( ::QGradient::WildApple), 58},
    {sipName_WinterNeva, static_cast<int>( ::QGradient::WinterNeva), 58},
    {sipName_WitchDance, static_cast<int>( ::QGradient::WitchDance), 58},
    {sipName_YoungGrass, static_cast<int>( ::QGradient::YoungGrass), 58},
    {sipName_YoungPassion, static_cast<int>( ::QGradient::YoungPassion), 58},
    {sipName_ZeusMiracle, static_cast<int>( ::QGradient::ZeusMiracle), 58},
};

PyDoc_STRVAR(doc_QGradient, "\1QGradient()\n"
"QGradient(QGradient.Preset)\n"
"QGradient(QGradient)");


static pyqt5ClassPluginDef plugin_QGradient = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QGradient = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGradient,
        {SIP_NULLPTR},
        &plugin_QGradient
    },
    {
        sipNameNr_QGradient,
        {0, 0, 1},
        8, methods_QGradient,
        180, enummembers_QGradient,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGradient,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGradient,
    init_type_QGradient,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QGradient,
    assign_QGradient,
    array_QGradient,
    copy_QGradient,
    release_QGradient,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
