/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qjsvalueiterator.sip"
#include <qjsvalueiterator.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQJSValueIterator.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qjsvalue.sip"
#include <qjsvalue.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQJSValueIterator.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQJSValueIterator.cpp"


PyDoc_STRVAR(doc_QJSValueIterator_hasNext, "hasNext(self) -> bool");

extern "C" {static PyObject *meth_QJSValueIterator_hasNext(PyObject *, PyObject *);}
static PyObject *meth_QJSValueIterator_hasNext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QJSValueIterator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSValueIterator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasNext();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSValueIterator, sipName_hasNext, doc_QJSValueIterator_hasNext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSValueIterator_next, "next(self) -> bool");

extern "C" {static PyObject *meth_QJSValueIterator_next(PyObject *, PyObject *);}
static PyObject *meth_QJSValueIterator_next(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QJSValueIterator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSValueIterator, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->next();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSValueIterator, sipName_next, doc_QJSValueIterator_next);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSValueIterator_name, "name(self) -> str");

extern "C" {static PyObject *meth_QJSValueIterator_name(PyObject *, PyObject *);}
static PyObject *meth_QJSValueIterator_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QJSValueIterator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSValueIterator, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSValueIterator, sipName_name, doc_QJSValueIterator_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QJSValueIterator_value, "value(self) -> QJSValue");

extern "C" {static PyObject *meth_QJSValueIterator_value(PyObject *, PyObject *);}
static PyObject *meth_QJSValueIterator_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QJSValueIterator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QJSValueIterator, &sipCpp))
        {
             ::QJSValue*sipRes;

            sipRes = new  ::QJSValue(sipCpp->value());

            return sipConvertFromNewType(sipRes,sipType_QJSValue,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QJSValueIterator, sipName_value, doc_QJSValueIterator_value);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QJSValueIterator(void *, int);}
static void release_QJSValueIterator(void *sipCppV, int)
{
    delete reinterpret_cast< ::QJSValueIterator *>(sipCppV);
}


extern "C" {static void dealloc_QJSValueIterator(sipSimpleWrapper *);}
static void dealloc_QJSValueIterator(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QJSValueIterator(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QJSValueIterator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QJSValueIterator(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QJSValueIterator *sipCpp = SIP_NULLPTR;

    {
        const  ::QJSValue* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QJSValue, &a0, &a0State))
        {
            sipCpp = new  ::QJSValueIterator(*a0);
            sipReleaseType(const_cast< ::QJSValue *>(a0),sipType_QJSValue,a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QJSValueIterator[] = {
    {SIP_MLNAME_CAST(sipName_hasNext), meth_QJSValueIterator_hasNext, METH_VARARGS, SIP_MLDOC_CAST(doc_QJSValueIterator_hasNext)},
    {SIP_MLNAME_CAST(sipName_name), meth_QJSValueIterator_name, METH_VARARGS, SIP_MLDOC_CAST(doc_QJSValueIterator_name)},
    {SIP_MLNAME_CAST(sipName_next), meth_QJSValueIterator_next, METH_VARARGS, SIP_MLDOC_CAST(doc_QJSValueIterator_next)},
    {SIP_MLNAME_CAST(sipName_value), meth_QJSValueIterator_value, METH_VARARGS, SIP_MLDOC_CAST(doc_QJSValueIterator_value)}
};

PyDoc_STRVAR(doc_QJSValueIterator, "\1QJSValueIterator(Union[QJSValue, QJSValue.SpecialValue, bool, int, float, str])");


static pyqt5ClassPluginDef plugin_QJSValueIterator = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QJSValueIterator = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QJSValueIterator,
        {SIP_NULLPTR},
        &plugin_QJSValueIterator
    },
    {
        sipNameNr_QJSValueIterator,
        {0, 0, 1},
        4, methods_QJSValueIterator,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QJSValueIterator,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QJSValueIterator,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QJSValueIterator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QJSValueIterator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
