/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"


PyDoc_STRVAR(doc_QIcon_pixmap, "pixmap(self, QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, int, int, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, int, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap\n"
"pixmap(self, QWindow, QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QPixmap");

extern "C" {static PyObject *meth_QIcon_pixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_pixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QIcon::Mode a1 = QIcon::Normal;
         ::QIcon::State a2 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QSize, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
             ::QPixmap*sipRes;

            sipRes = new  ::QPixmap(sipCpp->pixmap(*a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;
         ::QIcon::Mode a2 = QIcon::Normal;
         ::QIcon::State a3 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|EE", &sipSelf, sipType_QIcon, &sipCpp, &a0, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
             ::QPixmap*sipRes;

            sipRes = new  ::QPixmap(sipCpp->pixmap(a0,a1,a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    {
        int a0;
         ::QIcon::Mode a1 = QIcon::Normal;
         ::QIcon::State a2 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|EE", &sipSelf, sipType_QIcon, &sipCpp, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
             ::QPixmap*sipRes;

            sipRes = new  ::QPixmap(sipCpp->pixmap(a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    {
         ::QWindow* a0;
        const  ::QSize* a1;
         ::QIcon::Mode a2 = QIcon::Normal;
         ::QIcon::State a3 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QWindow, &a0, sipType_QSize, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
             ::QPixmap*sipRes;

            sipRes = new  ::QPixmap(sipCpp->pixmap(a0,*a1,a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_pixmap, doc_QIcon_pixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_actualSize, "actualSize(self, QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QSize\n"
"actualSize(self, QWindow, QSize, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> QSize");

extern "C" {static PyObject *meth_QIcon_actualSize(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_actualSize(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QIcon::Mode a1 = QIcon::Normal;
         ::QIcon::State a2 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QSize, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->actualSize(*a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    {
         ::QWindow* a0;
        const  ::QSize* a1;
         ::QIcon::Mode a2 = QIcon::Normal;
         ::QIcon::State a3 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QWindow, &a0, sipType_QSize, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->actualSize(a0,*a1,a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_actualSize, doc_QIcon_actualSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_availableSizes, "availableSizes(self, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off) -> List[QSize]");

extern "C" {static PyObject *meth_QIcon_availableSizes(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_availableSizes(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QIcon::Mode a0 = QIcon::Normal;
         ::QIcon::State a1 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QIcon_Mode, &a0, sipType_QIcon_State, &a1))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->availableSizes(a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QList_0100QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_availableSizes, doc_QIcon_availableSizes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_paint, "paint(self, QPainter, QRect, alignment: Union[Qt.Alignment, Qt.AlignmentFlag] = Qt.AlignCenter, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)\n"
"paint(self, QPainter, int, int, int, int, alignment: Union[Qt.Alignment, Qt.AlignmentFlag] = Qt.AlignCenter, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainter* a0;
        const  ::QRect* a1;
         ::Qt::Alignment a2def = Qt::AlignCenter;
         ::Qt::Alignment* a2 = &a2def;
        int a2State = 0;
         ::QIcon::Mode a3 = QIcon::Normal;
         ::QIcon::State a4 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_alignment,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J9|J1EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, sipType_Qt_Alignment, &a2, &a2State, sipType_QIcon_Mode, &a3, sipType_QIcon_State, &a4))
        {
            sipCpp->paint(a0,*a1,*a2,a3,a4);
            sipReleaseType(a2,sipType_Qt_Alignment,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QPainter* a0;
        int a1;
        int a2;
        int a3;
        int a4;
         ::Qt::Alignment a5def = Qt::AlignCenter;
         ::Qt::Alignment* a5 = &a5def;
        int a5State = 0;
         ::QIcon::Mode a6 = QIcon::Normal;
         ::QIcon::State a7 = QIcon::Off;
        const  ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_alignment,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8iiii|J1EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPainter, &a0, &a1, &a2, &a3, &a4, sipType_Qt_Alignment, &a5, &a5State, sipType_QIcon_Mode, &a6, sipType_QIcon_State, &a7))
        {
            sipCpp->paint(a0,a1,a2,a3,a4,*a5,a6,a7);
            sipReleaseType(a5,sipType_Qt_Alignment,a5State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_paint, doc_QIcon_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isNull(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isNull, doc_QIcon_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isDetached, "isDetached(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isDetached(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isDetached(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDetached();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isDetached, doc_QIcon_isDetached);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_addPixmap, "addPixmap(self, QPixmap, mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_addPixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_addPixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPixmap* a0;
         ::QIcon::Mode a1 = QIcon::Normal;
         ::QIcon::State a2 = QIcon::Off;
         ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QPixmap, &a0, sipType_QIcon_Mode, &a1, sipType_QIcon_State, &a2))
        {
            sipCpp->addPixmap(*a0,a1,a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_addPixmap, doc_QIcon_addPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_addFile, "addFile(self, str, size: QSize = QSize(), mode: QIcon.Mode = QIcon.Normal, state: QIcon.State = QIcon.Off)");

extern "C" {static PyObject *meth_QIcon_addFile(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QIcon_addFile(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QSize& a1def = QSize();
        const  ::QSize* a1 = &a1def;
         ::QIcon::Mode a2 = QIcon::Normal;
         ::QIcon::State a3 = QIcon::Off;
         ::QIcon *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_size,
            sipName_mode,
            sipName_state,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9EE", &sipSelf, sipType_QIcon, &sipCpp, sipType_QString,&a0, &a0State, sipType_QSize, &a1, sipType_QIcon_Mode, &a2, sipType_QIcon_State, &a3))
        {
            sipCpp->addFile(*a0,*a1,a2,a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_addFile, doc_QIcon_addFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_cacheKey, "cacheKey(self) -> int");

extern "C" {static PyObject *meth_QIcon_cacheKey(PyObject *, PyObject *);}
static PyObject *meth_QIcon_cacheKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->cacheKey();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_cacheKey, doc_QIcon_cacheKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fromTheme, "fromTheme(str) -> QIcon\n"
"fromTheme(str, QIcon) -> QIcon");

extern "C" {static PyObject *meth_QIcon_fromTheme(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fromTheme(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QIcon*sipRes;

            sipRes = new  ::QIcon( ::QIcon::fromTheme(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QIcon* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1J9", sipType_QString,&a0, &a0State, sipType_QIcon, &a1))
        {
             ::QIcon*sipRes;

            sipRes = new  ::QIcon( ::QIcon::fromTheme(*a0,*a1));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fromTheme, doc_QIcon_fromTheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_hasThemeIcon, "hasThemeIcon(str) -> bool");

extern "C" {static PyObject *meth_QIcon_hasThemeIcon(PyObject *, PyObject *);}
static PyObject *meth_QIcon_hasThemeIcon(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::QIcon::hasThemeIcon(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_hasThemeIcon, doc_QIcon_hasThemeIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_themeSearchPaths, "themeSearchPaths() -> List[str]");

extern "C" {static PyObject *meth_QIcon_themeSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_themeSearchPaths(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList( ::QIcon::themeSearchPaths());

            return sipConvertFromNewType(sipRes,sipType_QStringList,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_themeSearchPaths, doc_QIcon_themeSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setThemeSearchPaths, "setThemeSearchPaths(Iterable[str])");

extern "C" {static PyObject *meth_QIcon_setThemeSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setThemeSearchPaths(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QStringList,&a0, &a0State))
        {
             ::QIcon::setThemeSearchPaths(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setThemeSearchPaths, doc_QIcon_setThemeSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_themeName, "themeName() -> str");

extern "C" {static PyObject *meth_QIcon_themeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_themeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QIcon::themeName());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_themeName, doc_QIcon_themeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setThemeName, "setThemeName(str)");

extern "C" {static PyObject *meth_QIcon_setThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setThemeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QIcon::setThemeName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setThemeName, doc_QIcon_setThemeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_name, "name(self) -> str");

extern "C" {static PyObject *meth_QIcon_name(PyObject *, PyObject *);}
static PyObject *meth_QIcon_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_name, doc_QIcon_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_swap, "swap(self, QIcon)");

extern "C" {static PyObject *meth_QIcon_swap(PyObject *, PyObject *);}
static PyObject *meth_QIcon_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QIcon* a0;
         ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QIcon, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_swap, doc_QIcon_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setIsMask, "setIsMask(self, bool)");

extern "C" {static PyObject *meth_QIcon_setIsMask(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setIsMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QIcon, &sipCpp, &a0))
        {
            sipCpp->setIsMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setIsMask, doc_QIcon_setIsMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_isMask, "isMask(self) -> bool");

extern "C" {static PyObject *meth_QIcon_isMask(PyObject *, PyObject *);}
static PyObject *meth_QIcon_isMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMask();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_isMask, doc_QIcon_isMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fallbackSearchPaths, "fallbackSearchPaths() -> List[str]");

extern "C" {static PyObject *meth_QIcon_fallbackSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fallbackSearchPaths(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList( ::QIcon::fallbackSearchPaths());

            return sipConvertFromNewType(sipRes,sipType_QStringList,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fallbackSearchPaths, doc_QIcon_fallbackSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setFallbackSearchPaths, "setFallbackSearchPaths(Iterable[str])");

extern "C" {static PyObject *meth_QIcon_setFallbackSearchPaths(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setFallbackSearchPaths(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QStringList,&a0, &a0State))
        {
             ::QIcon::setFallbackSearchPaths(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setFallbackSearchPaths, doc_QIcon_setFallbackSearchPaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_fallbackThemeName, "fallbackThemeName() -> str");

extern "C" {static PyObject *meth_QIcon_fallbackThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_fallbackThemeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QIcon::fallbackThemeName());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_fallbackThemeName, doc_QIcon_fallbackThemeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QIcon_setFallbackThemeName, "setFallbackThemeName(str)");

extern "C" {static PyObject *meth_QIcon_setFallbackThemeName(PyObject *, PyObject *);}
static PyObject *meth_QIcon_setFallbackThemeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QIcon::setFallbackThemeName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QIcon, sipName_setFallbackThemeName, doc_QIcon_setFallbackThemeName);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QIcon(void *, int);}
static void release_QIcon(void *sipCppV, int)
{
    delete reinterpret_cast< ::QIcon *>(sipCppV);
}


extern "C" {static void *array_QIcon(Py_ssize_t);}
static void *array_QIcon(Py_ssize_t sipNrElem)
{
    return new  ::QIcon[sipNrElem];
}


extern "C" {static void assign_QIcon(void *, SIP_SSIZE_T, void *);}
static void assign_QIcon(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QIcon *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QIcon *>(sipSrc);
}


extern "C" {static void *copy_QIcon(const void *, SIP_SSIZE_T);}
static void *copy_QIcon(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QIcon(reinterpret_cast<const  ::QIcon *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QIcon(sipSimpleWrapper *);}
static void dealloc_QIcon(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QIcon(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QIcon(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QIcon(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QIcon *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QIcon();

            return sipCpp;
        }
    }

    {
        const  ::QPixmap* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPixmap, &a0))
        {
            sipCpp = new  ::QIcon(*a0);

            return sipCpp;
        }
    }

    {
        const  ::QIcon* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QIcon, &a0))
        {
            sipCpp = new  ::QIcon(*a0);

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString,&a0, &a0State))
        {
            sipCpp = new  ::QIcon(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipCpp;
        }
    }

    {
         ::QIconEngine* a0;
        PyObject *a0Wrapper;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "@J8", &a0Wrapper, sipType_QIconEngine, &a0))
        {
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qicon.sip"
        sipCpp = new QIcon(a0);
        
        // The QIconEngine is implicitly shared by copies of the QIcon and is destroyed
        // by C++ when the last copy is destroyed.  Therefore we need to transfer
        // ownership but not to associate it with this QIcon.  The Python object will
        // get tidied up when the virtual dtor gets called.
        sipTransferTo(a0Wrapper, Py_None);
#line 1006 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"

            return sipCpp;
        }
    }

    {
        const  ::QVariant* a0;
        PyObject *a0Wrapper;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "@J1", &a0Wrapper, sipType_QVariant, &a0, &a0State))
        {
            sipErrorState sipError = sipErrorNone;

#line 61 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qicon.sip"
        if (a0->canConvert<QIcon>())
            sipCpp = new QIcon(a0->value<QIcon>());
        else
            sipError = sipBadCallableArg(0, a0Wrapper);
#line 1026 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQIcon.cpp"
            sipReleaseType(const_cast< ::QVariant *>(a0),sipType_QVariant,a0State);

            if (sipError == sipErrorNone)
                return sipCpp;

            if (sipUnused)
            {
                Py_XDECREF(*sipUnused);
            }

            sipAddException(sipError, sipParseErr);

            if (sipError == sipErrorFail)
                return SIP_NULLPTR;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QIcon[] = {
    {SIP_MLNAME_CAST(sipName_actualSize), SIP_MLMETH_CAST(meth_QIcon_actualSize), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_actualSize)},
    {SIP_MLNAME_CAST(sipName_addFile), SIP_MLMETH_CAST(meth_QIcon_addFile), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_addFile)},
    {SIP_MLNAME_CAST(sipName_addPixmap), SIP_MLMETH_CAST(meth_QIcon_addPixmap), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_addPixmap)},
    {SIP_MLNAME_CAST(sipName_availableSizes), SIP_MLMETH_CAST(meth_QIcon_availableSizes), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_availableSizes)},
    {SIP_MLNAME_CAST(sipName_cacheKey), meth_QIcon_cacheKey, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_cacheKey)},
    {SIP_MLNAME_CAST(sipName_fallbackSearchPaths), meth_QIcon_fallbackSearchPaths, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_fallbackSearchPaths)},
    {SIP_MLNAME_CAST(sipName_fallbackThemeName), meth_QIcon_fallbackThemeName, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_fallbackThemeName)},
    {SIP_MLNAME_CAST(sipName_fromTheme), meth_QIcon_fromTheme, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_fromTheme)},
    {SIP_MLNAME_CAST(sipName_hasThemeIcon), meth_QIcon_hasThemeIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_hasThemeIcon)},
    {SIP_MLNAME_CAST(sipName_isDetached), meth_QIcon_isDetached, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_isDetached)},
    {SIP_MLNAME_CAST(sipName_isMask), meth_QIcon_isMask, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_isMask)},
    {SIP_MLNAME_CAST(sipName_isNull), meth_QIcon_isNull, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_isNull)},
    {SIP_MLNAME_CAST(sipName_name), meth_QIcon_name, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_name)},
    {SIP_MLNAME_CAST(sipName_paint), SIP_MLMETH_CAST(meth_QIcon_paint), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_paint)},
    {SIP_MLNAME_CAST(sipName_pixmap), SIP_MLMETH_CAST(meth_QIcon_pixmap), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QIcon_pixmap)},
    {SIP_MLNAME_CAST(sipName_setFallbackSearchPaths), meth_QIcon_setFallbackSearchPaths, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_setFallbackSearchPaths)},
    {SIP_MLNAME_CAST(sipName_setFallbackThemeName), meth_QIcon_setFallbackThemeName, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_setFallbackThemeName)},
    {SIP_MLNAME_CAST(sipName_setIsMask), meth_QIcon_setIsMask, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_setIsMask)},
    {SIP_MLNAME_CAST(sipName_setThemeName), meth_QIcon_setThemeName, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_setThemeName)},
    {SIP_MLNAME_CAST(sipName_setThemeSearchPaths), meth_QIcon_setThemeSearchPaths, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_setThemeSearchPaths)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QIcon_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_swap)},
    {SIP_MLNAME_CAST(sipName_themeName), meth_QIcon_themeName, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_themeName)},
    {SIP_MLNAME_CAST(sipName_themeSearchPaths), meth_QIcon_themeSearchPaths, METH_VARARGS, SIP_MLDOC_CAST(doc_QIcon_themeSearchPaths)}
};

static sipEnumMemberDef enummembers_QIcon[] = {
    {sipName_Active, static_cast<int>( ::QIcon::Active), 66},
    {sipName_Disabled, static_cast<int>( ::QIcon::Disabled), 66},
    {sipName_Normal, static_cast<int>( ::QIcon::Normal), 66},
    {sipName_Off, static_cast<int>( ::QIcon::Off), 67},
    {sipName_On, static_cast<int>( ::QIcon::On), 67},
    {sipName_Selected, static_cast<int>( ::QIcon::Selected), 66},
};

PyDoc_STRVAR(doc_QIcon, "\1QIcon()\n"
"QIcon(QPixmap)\n"
"QIcon(QIcon)\n"
"QIcon(str)\n"
"QIcon(QIconEngine)\n"
"QIcon(Any)");


static pyqt5ClassPluginDef plugin_QIcon = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QIcon = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QIcon,
        {SIP_NULLPTR},
        &plugin_QIcon
    },
    {
        sipNameNr_QIcon,
        {0, 0, 1},
        23, methods_QIcon,
        6, enummembers_QIcon,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QIcon,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QIcon,
    assign_QIcon,
    array_QIcon,
    copy_QIcon,
    release_QIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
