/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 27 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpygui_qvector.sip"
#include <qvector.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQOpenGLDebugLogger.cpp"


class sipQOpenGLDebugLogger : public  ::QOpenGLDebugLogger
{
public:
    sipQOpenGLDebugLogger( ::QObject*);
    virtual ~sipQOpenGLDebugLogger();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLDebugLogger(const sipQOpenGLDebugLogger &);
    sipQOpenGLDebugLogger &operator = (const sipQOpenGLDebugLogger &);

    char sipPyMethods[7];
};

sipQOpenGLDebugLogger::sipQOpenGLDebugLogger( ::QObject*a0):  ::QOpenGLDebugLogger(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLDebugLogger::~sipQOpenGLDebugLogger()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQOpenGLDebugLogger::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf,sipType_QOpenGLDebugLogger);

    return  ::QOpenGLDebugLogger::metaObject();
}

int sipQOpenGLDebugLogger::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QOpenGLDebugLogger::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf,sipType_QOpenGLDebugLogger,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQOpenGLDebugLogger::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QOpenGLDebugLogger, _clname, &sipCpp) ? sipCpp :  ::QOpenGLDebugLogger::qt_metacast(_clname));
}

bool sipQOpenGLDebugLogger::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QOpenGLDebugLogger::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQOpenGLDebugLogger::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QOpenGLDebugLogger::eventFilter(a0,a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOpenGLDebugLogger::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QOpenGLDebugLogger::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLDebugLogger::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QOpenGLDebugLogger::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLDebugLogger::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QOpenGLDebugLogger::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLDebugLogger::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QOpenGLDebugLogger::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLDebugLogger::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QOpenGLDebugLogger::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_initialize, "initialize(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_initialize(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_initialize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->initialize();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_initialize, doc_QOpenGLDebugLogger_initialize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_isLogging, "isLogging(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_isLogging(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_isLogging(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLogging();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_isLogging, doc_QOpenGLDebugLogger_isLogging);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_loggingMode, "loggingMode(self) -> QOpenGLDebugLogger.LoggingMode");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_loggingMode(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_loggingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
             ::QOpenGLDebugLogger::LoggingMode sipRes;

            sipRes = sipCpp->loggingMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QOpenGLDebugLogger_LoggingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_loggingMode, doc_QOpenGLDebugLogger_loggingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_maximumMessageLength, "maximumMessageLength(self) -> int");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_maximumMessageLength(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_maximumMessageLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->maximumMessageLength();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_maximumMessageLength, doc_QOpenGLDebugLogger_maximumMessageLength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_pushGroup, "pushGroup(self, str, id: int = 0, source: QOpenGLDebugMessage.Source = QOpenGLDebugMessage.ApplicationSource)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_pushGroup(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_pushGroup(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::GLuint a1 = 0;
         ::QOpenGLDebugMessage::Source a2 = QOpenGLDebugMessage::ApplicationSource;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_id,
            sipName_source,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|uE", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QString,&a0, &a0State, &a1, sipType_QOpenGLDebugMessage_Source, &a2))
        {
            sipCpp->pushGroup(*a0,a1,a2);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_pushGroup, doc_QOpenGLDebugLogger_pushGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_popGroup, "popGroup(self)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_popGroup(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_popGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
            sipCpp->popGroup();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_popGroup, doc_QOpenGLDebugLogger_popGroup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_enableMessages, "enableMessages(self, sources: Union[QOpenGLDebugMessage.Sources, QOpenGLDebugMessage.Source] = QOpenGLDebugMessage.AnySource, types: Union[QOpenGLDebugMessage.Types, QOpenGLDebugMessage.Type] = QOpenGLDebugMessage.AnyType, severities: Union[QOpenGLDebugMessage.Severities, QOpenGLDebugMessage.Severity] = QOpenGLDebugMessage.Severity.AnySeverity)\n"
"enableMessages(self, Iterable[int], sources: Union[QOpenGLDebugMessage.Sources, QOpenGLDebugMessage.Source] = QOpenGLDebugMessage.AnySource, types: Union[QOpenGLDebugMessage.Types, QOpenGLDebugMessage.Type] = QOpenGLDebugMessage.AnyType)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_enableMessages(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_enableMessages(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugMessage::Sources a0def = QOpenGLDebugMessage::AnySource;
         ::QOpenGLDebugMessage::Sources* a0 = &a0def;
        int a0State = 0;
         ::QOpenGLDebugMessage::Types a1def = QOpenGLDebugMessage::AnyType;
         ::QOpenGLDebugMessage::Types* a1 = &a1def;
        int a1State = 0;
         ::QOpenGLDebugMessage::Severities a2def = QOpenGLDebugMessage::Severity::AnySeverity;
         ::QOpenGLDebugMessage::Severities* a2 = &a2def;
        int a2State = 0;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            sipName_sources,
            sipName_types,
            sipName_severities,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1J1J1", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QOpenGLDebugMessage_Sources, &a0, &a0State, sipType_QOpenGLDebugMessage_Types, &a1, &a1State, sipType_QOpenGLDebugMessage_Severities, &a2, &a2State))
        {
            sipCpp->enableMessages(*a0,*a1,*a2);
            sipReleaseType(a0,sipType_QOpenGLDebugMessage_Sources,a0State);
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Types,a1State);
            sipReleaseType(a2,sipType_QOpenGLDebugMessage_Severities,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QVector<uint>* a0;
        int a0State = 0;
         ::QOpenGLDebugMessage::Sources a1def = QOpenGLDebugMessage::AnySource;
         ::QOpenGLDebugMessage::Sources* a1 = &a1def;
        int a1State = 0;
         ::QOpenGLDebugMessage::Types a2def = QOpenGLDebugMessage::AnyType;
         ::QOpenGLDebugMessage::Types* a2 = &a2def;
        int a2State = 0;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_sources,
            sipName_types,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J1", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QVector_1900,&a0, &a0State, sipType_QOpenGLDebugMessage_Sources, &a1, &a1State, sipType_QOpenGLDebugMessage_Types, &a2, &a2State))
        {
            sipCpp->enableMessages(*a0,*a1,*a2);
            sipReleaseType(const_cast< ::QVector<uint> *>(a0),sipType_QVector_1900,a0State);
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Sources,a1State);
            sipReleaseType(a2,sipType_QOpenGLDebugMessage_Types,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_enableMessages, doc_QOpenGLDebugLogger_enableMessages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_disableMessages, "disableMessages(self, sources: Union[QOpenGLDebugMessage.Sources, QOpenGLDebugMessage.Source] = QOpenGLDebugMessage.AnySource, types: Union[QOpenGLDebugMessage.Types, QOpenGLDebugMessage.Type] = QOpenGLDebugMessage.AnyType, severities: Union[QOpenGLDebugMessage.Severities, QOpenGLDebugMessage.Severity] = QOpenGLDebugMessage.Severity.AnySeverity)\n"
"disableMessages(self, Iterable[int], sources: Union[QOpenGLDebugMessage.Sources, QOpenGLDebugMessage.Source] = QOpenGLDebugMessage.AnySource, types: Union[QOpenGLDebugMessage.Types, QOpenGLDebugMessage.Type] = QOpenGLDebugMessage.AnyType)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_disableMessages(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_disableMessages(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugMessage::Sources a0def = QOpenGLDebugMessage::AnySource;
         ::QOpenGLDebugMessage::Sources* a0 = &a0def;
        int a0State = 0;
         ::QOpenGLDebugMessage::Types a1def = QOpenGLDebugMessage::AnyType;
         ::QOpenGLDebugMessage::Types* a1 = &a1def;
        int a1State = 0;
         ::QOpenGLDebugMessage::Severities a2def = QOpenGLDebugMessage::Severity::AnySeverity;
         ::QOpenGLDebugMessage::Severities* a2 = &a2def;
        int a2State = 0;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            sipName_sources,
            sipName_types,
            sipName_severities,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1J1J1", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QOpenGLDebugMessage_Sources, &a0, &a0State, sipType_QOpenGLDebugMessage_Types, &a1, &a1State, sipType_QOpenGLDebugMessage_Severities, &a2, &a2State))
        {
            sipCpp->disableMessages(*a0,*a1,*a2);
            sipReleaseType(a0,sipType_QOpenGLDebugMessage_Sources,a0State);
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Types,a1State);
            sipReleaseType(a2,sipType_QOpenGLDebugMessage_Severities,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QVector<uint>* a0;
        int a0State = 0;
         ::QOpenGLDebugMessage::Sources a1def = QOpenGLDebugMessage::AnySource;
         ::QOpenGLDebugMessage::Sources* a1 = &a1def;
        int a1State = 0;
         ::QOpenGLDebugMessage::Types a2def = QOpenGLDebugMessage::AnyType;
         ::QOpenGLDebugMessage::Types* a2 = &a2def;
        int a2State = 0;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_sources,
            sipName_types,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J1", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QVector_1900,&a0, &a0State, sipType_QOpenGLDebugMessage_Sources, &a1, &a1State, sipType_QOpenGLDebugMessage_Types, &a2, &a2State))
        {
            sipCpp->disableMessages(*a0,*a1,*a2);
            sipReleaseType(const_cast< ::QVector<uint> *>(a0),sipType_QVector_1900,a0State);
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Sources,a1State);
            sipReleaseType(a2,sipType_QOpenGLDebugMessage_Types,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_disableMessages, doc_QOpenGLDebugLogger_disableMessages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_loggedMessages, "loggedMessages(self) -> List[QOpenGLDebugMessage]");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_loggedMessages(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_loggedMessages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
            QList< ::QOpenGLDebugMessage>*sipRes;

            sipRes = new QList< ::QOpenGLDebugMessage>(sipCpp->loggedMessages());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QOpenGLDebugMessage,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_loggedMessages, doc_QOpenGLDebugLogger_loggedMessages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_logMessage, "logMessage(self, QOpenGLDebugMessage)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_logMessage(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_logMessage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QOpenGLDebugMessage* a0;
         ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QOpenGLDebugMessage, &a0))
        {
            sipCpp->logMessage(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_logMessage, doc_QOpenGLDebugLogger_logMessage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_startLogging, "startLogging(self, loggingMode: QOpenGLDebugLogger.LoggingMode = QOpenGLDebugLogger.AsynchronousLogging)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_startLogging(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_startLogging(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugLogger::LoggingMode a0 = QOpenGLDebugLogger::AsynchronousLogging;
         ::QOpenGLDebugLogger *sipCpp;

        static const char *sipKwdList[] = {
            sipName_loggingMode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp, sipType_QOpenGLDebugLogger_LoggingMode, &a0))
        {
            sipCpp->startLogging(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_startLogging, doc_QOpenGLDebugLogger_startLogging);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLDebugLogger_stopLogging, "stopLogging(self)");

extern "C" {static PyObject *meth_QOpenGLDebugLogger_stopLogging(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLDebugLogger_stopLogging(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugLogger *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLDebugLogger, &sipCpp))
        {
            sipCpp->stopLogging();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLDebugLogger, sipName_stopLogging, doc_QOpenGLDebugLogger_stopLogging);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLDebugLogger(void *, const sipTypeDef *);}
static void *cast_QOpenGLDebugLogger(void *sipCppV, const sipTypeDef *targetType)
{
     ::QOpenGLDebugLogger *sipCpp = reinterpret_cast< ::QOpenGLDebugLogger *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLDebugLogger(void *, int);}
static void release_QOpenGLDebugLogger(void *sipCppV, int)
{
     ::QOpenGLDebugLogger *sipCpp = reinterpret_cast< ::QOpenGLDebugLogger *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QOpenGLDebugLogger(Py_ssize_t);}
static void *array_QOpenGLDebugLogger(Py_ssize_t sipNrElem)
{
    return new  ::QOpenGLDebugLogger[sipNrElem];
}


extern "C" {static void dealloc_QOpenGLDebugLogger(sipSimpleWrapper *);}
static void dealloc_QOpenGLDebugLogger(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLDebugLogger *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLDebugLogger(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLDebugLogger(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLDebugLogger(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQOpenGLDebugLogger *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQOpenGLDebugLogger(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLDebugLogger[] = {{25, 0, 1}};


static PyMethodDef methods_QOpenGLDebugLogger[] = {
    {SIP_MLNAME_CAST(sipName_disableMessages), SIP_MLMETH_CAST(meth_QOpenGLDebugLogger_disableMessages), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_disableMessages)},
    {SIP_MLNAME_CAST(sipName_enableMessages), SIP_MLMETH_CAST(meth_QOpenGLDebugLogger_enableMessages), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_enableMessages)},
    {SIP_MLNAME_CAST(sipName_initialize), meth_QOpenGLDebugLogger_initialize, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_initialize)},
    {SIP_MLNAME_CAST(sipName_isLogging), meth_QOpenGLDebugLogger_isLogging, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_isLogging)},
    {SIP_MLNAME_CAST(sipName_logMessage), meth_QOpenGLDebugLogger_logMessage, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_logMessage)},
    {SIP_MLNAME_CAST(sipName_loggedMessages), meth_QOpenGLDebugLogger_loggedMessages, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_loggedMessages)},
    {SIP_MLNAME_CAST(sipName_loggingMode), meth_QOpenGLDebugLogger_loggingMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_loggingMode)},
    {SIP_MLNAME_CAST(sipName_maximumMessageLength), meth_QOpenGLDebugLogger_maximumMessageLength, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_maximumMessageLength)},
    {SIP_MLNAME_CAST(sipName_popGroup), meth_QOpenGLDebugLogger_popGroup, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_popGroup)},
    {SIP_MLNAME_CAST(sipName_pushGroup), SIP_MLMETH_CAST(meth_QOpenGLDebugLogger_pushGroup), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_pushGroup)},
    {SIP_MLNAME_CAST(sipName_startLogging), SIP_MLMETH_CAST(meth_QOpenGLDebugLogger_startLogging), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_startLogging)},
    {SIP_MLNAME_CAST(sipName_stopLogging), meth_QOpenGLDebugLogger_stopLogging, METH_VARARGS, SIP_MLDOC_CAST(doc_QOpenGLDebugLogger_stopLogging)}
};

static sipEnumMemberDef enummembers_QOpenGLDebugLogger[] = {
    {sipName_AsynchronousLogging, static_cast<int>( ::QOpenGLDebugLogger::AsynchronousLogging), 142},
    {sipName_SynchronousLogging, static_cast<int>( ::QOpenGLDebugLogger::SynchronousLogging), 142},
};

PyDoc_STRVAR(doc_QOpenGLDebugLogger, "\1QOpenGLDebugLogger(parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QOpenGLDebugLogger[] = {
    {"messageLogged(QOpenGLDebugMessage)", "\1messageLogged(self, QOpenGLDebugMessage)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QOpenGLDebugLogger = {
    & ::QOpenGLDebugLogger::staticMetaObject,
    0,
    signals_QOpenGLDebugLogger,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugLogger = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLDebugLogger,
        {SIP_NULLPTR},
        &plugin_QOpenGLDebugLogger
    },
    {
        sipNameNr_QOpenGLDebugLogger,
        {0, 0, 1},
        12, methods_QOpenGLDebugLogger,
        2, enummembers_QOpenGLDebugLogger,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLDebugLogger,
    -1,
    -1,
    supers_QOpenGLDebugLogger,
    SIP_NULLPTR,
    init_type_QOpenGLDebugLogger,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QOpenGLDebugLogger,
    SIP_NULLPTR,
    array_QOpenGLDebugLogger,
    SIP_NULLPTR,
    release_QOpenGLDebugLogger,
    cast_QOpenGLDebugLogger,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
