/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 94 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQDnsLookup.cpp"


class sipQDnsLookup : public  ::QDnsLookup
{
public:
    sipQDnsLookup( ::QObject*);
    sipQDnsLookup( ::QDnsLookup::Type,const  ::QString&, ::QObject*);
    sipQDnsLookup( ::QDnsLookup::Type,const  ::QString&,const  ::QHostAddress&, ::QObject*);
    virtual ~sipQDnsLookup();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDnsLookup(const sipQDnsLookup &);
    sipQDnsLookup &operator = (const sipQDnsLookup &);

    char sipPyMethods[7];
};

sipQDnsLookup::sipQDnsLookup( ::QObject*a0):  ::QDnsLookup(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDnsLookup::sipQDnsLookup( ::QDnsLookup::Type a0,const  ::QString& a1, ::QObject*a2):  ::QDnsLookup(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDnsLookup::sipQDnsLookup( ::QDnsLookup::Type a0,const  ::QString& a1,const  ::QHostAddress& a2, ::QObject*a3):  ::QDnsLookup(a0,a1,a2,a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDnsLookup::~sipQDnsLookup()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQDnsLookup::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf,sipType_QDnsLookup);

    return  ::QDnsLookup::metaObject();
}

int sipQDnsLookup::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QDnsLookup::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf,sipType_QDnsLookup,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQDnsLookup::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QDnsLookup, _clname, &sipCpp) ? sipCpp :  ::QDnsLookup::qt_metacast(_clname));
}

bool sipQDnsLookup::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QDnsLookup::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDnsLookup::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QDnsLookup::eventFilter(a0,a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQDnsLookup::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QDnsLookup::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDnsLookup::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QDnsLookup::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDnsLookup::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QDnsLookup::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDnsLookup::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QDnsLookup::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQDnsLookup::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QDnsLookup::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QDnsLookup_error, "error(self) -> QDnsLookup.Error");

extern "C" {static PyObject *meth_QDnsLookup_error(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
             ::QDnsLookup::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDnsLookup_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_error, doc_QDnsLookup_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QDnsLookup_errorString(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_errorString, doc_QDnsLookup_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_isFinished, "isFinished(self) -> bool");

extern "C" {static PyObject *meth_QDnsLookup_isFinished(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_isFinished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFinished();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_isFinished, doc_QDnsLookup_isFinished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDnsLookup_name(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_name, doc_QDnsLookup_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_setName, "setName(self, str)");

extern "C" {static PyObject *meth_QDnsLookup_setName(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDnsLookup, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_setName, doc_QDnsLookup_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_type, "type(self) -> QDnsLookup.Type");

extern "C" {static PyObject *meth_QDnsLookup_type(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
             ::QDnsLookup::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDnsLookup_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_type, doc_QDnsLookup_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_setType, "setType(self, QDnsLookup.Type)");

extern "C" {static PyObject *meth_QDnsLookup_setType(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_setType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDnsLookup::Type a0;
         ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QDnsLookup, &sipCpp, sipType_QDnsLookup_Type, &a0))
        {
            sipCpp->setType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_setType, doc_QDnsLookup_setType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_canonicalNameRecords, "canonicalNameRecords(self) -> List[QDnsDomainNameRecord]");

extern "C" {static PyObject *meth_QDnsLookup_canonicalNameRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_canonicalNameRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsDomainNameRecord>*sipRes;

            sipRes = new QList< ::QDnsDomainNameRecord>(sipCpp->canonicalNameRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsDomainNameRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_canonicalNameRecords, doc_QDnsLookup_canonicalNameRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_hostAddressRecords, "hostAddressRecords(self) -> List[QDnsHostAddressRecord]");

extern "C" {static PyObject *meth_QDnsLookup_hostAddressRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_hostAddressRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsHostAddressRecord>*sipRes;

            sipRes = new QList< ::QDnsHostAddressRecord>(sipCpp->hostAddressRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsHostAddressRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_hostAddressRecords, doc_QDnsLookup_hostAddressRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_mailExchangeRecords, "mailExchangeRecords(self) -> List[QDnsMailExchangeRecord]");

extern "C" {static PyObject *meth_QDnsLookup_mailExchangeRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_mailExchangeRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsMailExchangeRecord>*sipRes;

            sipRes = new QList< ::QDnsMailExchangeRecord>(sipCpp->mailExchangeRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsMailExchangeRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_mailExchangeRecords, doc_QDnsLookup_mailExchangeRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_nameServerRecords, "nameServerRecords(self) -> List[QDnsDomainNameRecord]");

extern "C" {static PyObject *meth_QDnsLookup_nameServerRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_nameServerRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsDomainNameRecord>*sipRes;

            sipRes = new QList< ::QDnsDomainNameRecord>(sipCpp->nameServerRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsDomainNameRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_nameServerRecords, doc_QDnsLookup_nameServerRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_pointerRecords, "pointerRecords(self) -> List[QDnsDomainNameRecord]");

extern "C" {static PyObject *meth_QDnsLookup_pointerRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_pointerRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsDomainNameRecord>*sipRes;

            sipRes = new QList< ::QDnsDomainNameRecord>(sipCpp->pointerRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsDomainNameRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_pointerRecords, doc_QDnsLookup_pointerRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_serviceRecords, "serviceRecords(self) -> List[QDnsServiceRecord]");

extern "C" {static PyObject *meth_QDnsLookup_serviceRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_serviceRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsServiceRecord>*sipRes;

            sipRes = new QList< ::QDnsServiceRecord>(sipCpp->serviceRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsServiceRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_serviceRecords, doc_QDnsLookup_serviceRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_textRecords, "textRecords(self) -> List[QDnsTextRecord]");

extern "C" {static PyObject *meth_QDnsLookup_textRecords(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_textRecords(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            QList< ::QDnsTextRecord>*sipRes;

            sipRes = new QList< ::QDnsTextRecord>(sipCpp->textRecords());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QDnsTextRecord,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_textRecords, doc_QDnsLookup_textRecords);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_abort, "abort(self)");

extern "C" {static PyObject *meth_QDnsLookup_abort(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->abort();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_abort, doc_QDnsLookup_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_lookup, "lookup(self)");

extern "C" {static PyObject *meth_QDnsLookup_lookup(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_lookup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->lookup();
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_lookup, doc_QDnsLookup_lookup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_nameserver, "nameserver(self) -> QHostAddress");

extern "C" {static PyObject *meth_QDnsLookup_nameserver(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_nameserver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsLookup, &sipCpp))
        {
             ::QHostAddress*sipRes;

            sipRes = new  ::QHostAddress(sipCpp->nameserver());

            return sipConvertFromNewType(sipRes,sipType_QHostAddress,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_nameserver, doc_QDnsLookup_nameserver);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsLookup_setNameserver, "setNameserver(self, Union[QHostAddress, QHostAddress.SpecialAddress])");

extern "C" {static PyObject *meth_QDnsLookup_setNameserver(PyObject *, PyObject *);}
static PyObject *meth_QDnsLookup_setNameserver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;
         ::QDnsLookup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDnsLookup, &sipCpp, sipType_QHostAddress, &a0, &a0State))
        {
            sipCpp->setNameserver(*a0);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsLookup, sipName_setNameserver, doc_QDnsLookup_setNameserver);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDnsLookup(void *, const sipTypeDef *);}
static void *cast_QDnsLookup(void *sipCppV, const sipTypeDef *targetType)
{
     ::QDnsLookup *sipCpp = reinterpret_cast< ::QDnsLookup *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDnsLookup(void *, int);}
static void release_QDnsLookup(void *sipCppV, int)
{
     ::QDnsLookup *sipCpp = reinterpret_cast< ::QDnsLookup *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QDnsLookup(Py_ssize_t);}
static void *array_QDnsLookup(Py_ssize_t sipNrElem)
{
    return new  ::QDnsLookup[sipNrElem];
}


extern "C" {static void dealloc_QDnsLookup(sipSimpleWrapper *);}
static void dealloc_QDnsLookup(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDnsLookup *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDnsLookup(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDnsLookup(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDnsLookup(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQDnsLookup *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQDnsLookup(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QDnsLookup::Type a0;
        const  ::QString* a1;
        int a1State = 0;
         ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "EJ1|JH", sipType_QDnsLookup_Type, &a0, sipType_QString,&a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQDnsLookup(a0,*a1,a2);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QDnsLookup::Type a0;
        const  ::QString* a1;
        int a1State = 0;
        const  ::QHostAddress* a2;
        int a2State = 0;
         ::QObject* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "EJ1J1|JH", sipType_QDnsLookup_Type, &a0, sipType_QString,&a1, &a1State, sipType_QHostAddress, &a2, &a2State, sipType_QObject, &a3, sipOwner))
        {
            sipCpp = new sipQDnsLookup(a0,*a1,*a2,a3);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);
            sipReleaseType(const_cast< ::QHostAddress *>(a2),sipType_QHostAddress,a2State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDnsLookup[] = {{12, 0, 1}};


static PyMethodDef methods_QDnsLookup[] = {
    {SIP_MLNAME_CAST(sipName_abort), meth_QDnsLookup_abort, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_abort)},
    {SIP_MLNAME_CAST(sipName_canonicalNameRecords), meth_QDnsLookup_canonicalNameRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_canonicalNameRecords)},
    {SIP_MLNAME_CAST(sipName_error), meth_QDnsLookup_error, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_error)},
    {SIP_MLNAME_CAST(sipName_errorString), meth_QDnsLookup_errorString, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_errorString)},
    {SIP_MLNAME_CAST(sipName_hostAddressRecords), meth_QDnsLookup_hostAddressRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_hostAddressRecords)},
    {SIP_MLNAME_CAST(sipName_isFinished), meth_QDnsLookup_isFinished, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_isFinished)},
    {SIP_MLNAME_CAST(sipName_lookup), meth_QDnsLookup_lookup, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_lookup)},
    {SIP_MLNAME_CAST(sipName_mailExchangeRecords), meth_QDnsLookup_mailExchangeRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_mailExchangeRecords)},
    {SIP_MLNAME_CAST(sipName_name), meth_QDnsLookup_name, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_name)},
    {SIP_MLNAME_CAST(sipName_nameServerRecords), meth_QDnsLookup_nameServerRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_nameServerRecords)},
    {SIP_MLNAME_CAST(sipName_nameserver), meth_QDnsLookup_nameserver, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_nameserver)},
    {SIP_MLNAME_CAST(sipName_pointerRecords), meth_QDnsLookup_pointerRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_pointerRecords)},
    {SIP_MLNAME_CAST(sipName_serviceRecords), meth_QDnsLookup_serviceRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_serviceRecords)},
    {SIP_MLNAME_CAST(sipName_setName), meth_QDnsLookup_setName, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_setName)},
    {SIP_MLNAME_CAST(sipName_setNameserver), meth_QDnsLookup_setNameserver, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_setNameserver)},
    {SIP_MLNAME_CAST(sipName_setType), meth_QDnsLookup_setType, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_setType)},
    {SIP_MLNAME_CAST(sipName_textRecords), meth_QDnsLookup_textRecords, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_textRecords)},
    {SIP_MLNAME_CAST(sipName_type), meth_QDnsLookup_type, METH_VARARGS, SIP_MLDOC_CAST(doc_QDnsLookup_type)}
};

static sipEnumMemberDef enummembers_QDnsLookup[] = {
    {sipName_A, static_cast<int>( ::QDnsLookup::A), 16},
    {sipName_AAAA, static_cast<int>( ::QDnsLookup::AAAA), 16},
    {sipName_ANY, static_cast<int>( ::QDnsLookup::ANY), 16},
    {sipName_CNAME, static_cast<int>( ::QDnsLookup::CNAME), 16},
    {sipName_InvalidReplyError, static_cast<int>( ::QDnsLookup::InvalidReplyError), 15},
    {sipName_InvalidRequestError, static_cast<int>( ::QDnsLookup::InvalidRequestError), 15},
    {sipName_MX, static_cast<int>( ::QDnsLookup::MX), 16},
    {sipName_NS, static_cast<int>( ::QDnsLookup::NS), 16},
    {sipName_NoError, static_cast<int>( ::QDnsLookup::NoError), 15},
    {sipName_NotFoundError, static_cast<int>( ::QDnsLookup::NotFoundError), 15},
    {sipName_OperationCancelledError, static_cast<int>( ::QDnsLookup::OperationCancelledError), 15},
    {sipName_PTR, static_cast<int>( ::QDnsLookup::PTR), 16},
    {sipName_ResolverError, static_cast<int>( ::QDnsLookup::ResolverError), 15},
    {sipName_SRV, static_cast<int>( ::QDnsLookup::SRV), 16},
    {sipName_ServerFailureError, static_cast<int>( ::QDnsLookup::ServerFailureError), 15},
    {sipName_ServerRefusedError, static_cast<int>( ::QDnsLookup::ServerRefusedError), 15},
    {sipName_TXT, static_cast<int>( ::QDnsLookup::TXT), 16},
};

PyDoc_STRVAR(doc_QDnsLookup, "\1QDnsLookup(parent: QObject = None)\n"
"QDnsLookup(QDnsLookup.Type, str, parent: QObject = None)\n"
"QDnsLookup(QDnsLookup.Type, str, Union[QHostAddress, QHostAddress.SpecialAddress], parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QDnsLookup[] = {
    {"nameserverChanged(QHostAddress)", "\1nameserverChanged(self, Union[QHostAddress, QHostAddress.SpecialAddress])", SIP_NULLPTR, SIP_NULLPTR},
    {"typeChanged(Type)|(QDnsLookup::Type)", "\1typeChanged(self, QDnsLookup.Type)", SIP_NULLPTR, SIP_NULLPTR},
    {"nameChanged(QString)", "\1nameChanged(self, str)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QDnsLookup = {
    & ::QDnsLookup::staticMetaObject,
    0,
    signals_QDnsLookup,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QDnsLookup = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDnsLookup,
        {SIP_NULLPTR},
        &plugin_QDnsLookup
    },
    {
        sipNameNr_QDnsLookup,
        {0, 0, 1},
        18, methods_QDnsLookup,
        17, enummembers_QDnsLookup,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDnsLookup,
    -1,
    -1,
    supers_QDnsLookup,
    SIP_NULLPTR,
    init_type_QDnsLookup,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QDnsLookup,
    SIP_NULLPTR,
    array_QDnsLookup,
    SIP_NULLPTR,
    release_QDnsLookup,
    cast_QDnsLookup,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
