/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 43 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 49 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 28 "sip/QtGui/qopenglshaderprogram.sip"
#include <qopenglshaderprogram.h>
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 73 "sip/QtGui/qopenglshaderprogram.sip"
#include <qopenglshaderprogram.h>
#line 61 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGMaterialRhiShader.cpp"


class sipQSGMaterialRhiShader : public  ::QSGMaterialRhiShader
{
public:
    sipQSGMaterialRhiShader();
    virtual ~sipQSGMaterialRhiShader();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool updateGraphicsPipelineState( ::QSGMaterialRhiShader::RenderState&, ::QSGMaterialRhiShader::GraphicsPipelineState*, ::QSGMaterial*, ::QSGMaterial*) SIP_OVERRIDE;
    void updateSampledImage( ::QSGMaterialRhiShader::RenderState&,int, ::QSGTexture**, ::QSGMaterial*, ::QSGMaterial*) SIP_OVERRIDE;
    bool updateUniformData( ::QSGMaterialRhiShader::RenderState&, ::QSGMaterial*, ::QSGMaterial*) SIP_OVERRIDE;
    void activate() SIP_OVERRIDE;
    void deactivate() SIP_OVERRIDE;
    void updateState(const  ::QSGMaterialShader::RenderState&, ::QSGMaterial*, ::QSGMaterial*) SIP_OVERRIDE;
    const char* const* attributeNames() const SIP_OVERRIDE;
    void compile() SIP_OVERRIDE;
    void initialize() SIP_OVERRIDE;
    const char* vertexShader() const SIP_OVERRIDE;
    const char* fragmentShader() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSGMaterialRhiShader(const sipQSGMaterialRhiShader &);
    sipQSGMaterialRhiShader &operator = (const sipQSGMaterialRhiShader &);

    char sipPyMethods[11];
};

sipQSGMaterialRhiShader::sipQSGMaterialRhiShader():  ::QSGMaterialRhiShader(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSGMaterialRhiShader::~sipQSGMaterialRhiShader()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQSGMaterialRhiShader::updateGraphicsPipelineState( ::QSGMaterialRhiShader::RenderState& a0, ::QSGMaterialRhiShader::GraphicsPipelineState*a1, ::QSGMaterial*a2, ::QSGMaterial*a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_updateGraphicsPipelineState);

    if (!sipMeth)
        return  ::QSGMaterialRhiShader::updateGraphicsPipelineState(a0,a1,a2,a3);

    extern bool sipVH_QtQuick_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSGMaterialRhiShader::RenderState&, ::QSGMaterialRhiShader::GraphicsPipelineState*, ::QSGMaterial*, ::QSGMaterial*);

    return sipVH_QtQuick_70(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQSGMaterialRhiShader::updateSampledImage( ::QSGMaterialRhiShader::RenderState& a0,int a1, ::QSGTexture**a2, ::QSGMaterial*a3, ::QSGMaterial*a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_updateSampledImage);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::updateSampledImage(a0,a1,a2,a3,a4);
        return;
    }

    extern void sipVH_QtQuick_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSGMaterialRhiShader::RenderState&,int, ::QSGTexture**, ::QSGMaterial*, ::QSGMaterial*);

    sipVH_QtQuick_69(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQSGMaterialRhiShader::updateUniformData( ::QSGMaterialRhiShader::RenderState& a0, ::QSGMaterial*a1, ::QSGMaterial*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_updateUniformData);

    if (!sipMeth)
        return  ::QSGMaterialRhiShader::updateUniformData(a0,a1,a2);

    extern bool sipVH_QtQuick_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSGMaterialRhiShader::RenderState&, ::QSGMaterial*, ::QSGMaterial*);

    return sipVH_QtQuick_68(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQSGMaterialRhiShader::activate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_activate);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::activate();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGMaterialRhiShader::deactivate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_deactivate);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::deactivate();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGMaterialRhiShader::updateState(const  ::QSGMaterialShader::RenderState& a0, ::QSGMaterial*a1, ::QSGMaterial*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_updateState);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::updateState(a0,a1,a2);
        return;
    }

    extern void sipVH_QtQuick_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QSGMaterialShader::RenderState&, ::QSGMaterial*, ::QSGMaterial*);

    sipVH_QtQuick_65(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

const char* const* sipQSGMaterialRhiShader::attributeNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[6]),sipPySelf,sipName_QSGMaterialRhiShader,sipName_attributeNames);

    if (!sipMeth)
        return 0;

    extern const char* const* sipVH_QtQuick_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtQuick_66(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, -3);
}

void sipQSGMaterialRhiShader::compile()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_compile);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::compile();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSGMaterialRhiShader::initialize()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_initialize);

    if (!sipMeth)
    {
         ::QSGMaterialRhiShader::initialize();
        return;
    }

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

const char* sipQSGMaterialRhiShader::vertexShader() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[9]),sipPySelf,SIP_NULLPTR,sipName_vertexShader);

    if (!sipMeth)
        return  ::QSGMaterialRhiShader::vertexShader();

    extern const char* sipVH_QtQuick_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtQuick_67(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, -4);
}

const char* sipQSGMaterialRhiShader::fragmentShader() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[10]),sipPySelf,SIP_NULLPTR,sipName_fragmentShader);

    if (!sipMeth)
        return  ::QSGMaterialRhiShader::fragmentShader();

    extern const char* sipVH_QtQuick_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtQuick_67(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, -5);
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_updateUniformData, "updateUniformData(self, QSGMaterialRhiShader.RenderState, QSGMaterial, QSGMaterial) -> bool");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_updateUniformData(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_updateUniformData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSGMaterialRhiShader::RenderState* a0;
         ::QSGMaterial* a1;
         ::QSGMaterial* a2;
         ::QSGMaterialRhiShader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8J8", &sipSelf, sipType_QSGMaterialRhiShader, &sipCpp, sipType_QSGMaterialRhiShader_RenderState, &a0, sipType_QSGMaterial, &a1, sipType_QSGMaterial, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGMaterialRhiShader::updateUniformData(*a0,a1,a2) : sipCpp->updateUniformData(*a0,a1,a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGMaterialRhiShader, sipName_updateUniformData, doc_QSGMaterialRhiShader_updateUniformData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_updateSampledImage, "updateSampledImage(self, QSGMaterialRhiShader.RenderState, int, QSGMaterial, QSGMaterial) -> QSGTexture");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_updateSampledImage(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_updateSampledImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSGMaterialRhiShader::RenderState* a0;
        int a1;
         ::QSGTexture* a2;
         ::QSGMaterial* a3;
         ::QSGMaterial* a4;
         ::QSGMaterialRhiShader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iJ8J8", &sipSelf, sipType_QSGMaterialRhiShader, &sipCpp, sipType_QSGMaterialRhiShader_RenderState, &a0, &a1, sipType_QSGMaterial, &a3, sipType_QSGMaterial, &a4))
        {
            (sipSelfWasArg ? sipCpp-> ::QSGMaterialRhiShader::updateSampledImage(*a0,a1,&a2,a3,a4) : sipCpp->updateSampledImage(*a0,a1,&a2,a3,a4));

            return sipConvertFromType(a2,sipType_QSGTexture,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGMaterialRhiShader, sipName_updateSampledImage, doc_QSGMaterialRhiShader_updateSampledImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_updateGraphicsPipelineState, "updateGraphicsPipelineState(self, QSGMaterialRhiShader.RenderState, QSGMaterialRhiShader.GraphicsPipelineState, QSGMaterial, QSGMaterial) -> bool");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_updateGraphicsPipelineState(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_updateGraphicsPipelineState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QSGMaterialRhiShader::RenderState* a0;
         ::QSGMaterialRhiShader::GraphicsPipelineState* a1;
         ::QSGMaterial* a2;
         ::QSGMaterial* a3;
         ::QSGMaterialRhiShader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8J8J8", &sipSelf, sipType_QSGMaterialRhiShader, &sipCpp, sipType_QSGMaterialRhiShader_RenderState, &a0, sipType_QSGMaterialRhiShader_GraphicsPipelineState, &a1, sipType_QSGMaterial, &a2, sipType_QSGMaterial, &a3))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGMaterialRhiShader::updateGraphicsPipelineState(*a0,a1,a2,a3) : sipCpp->updateGraphicsPipelineState(*a0,a1,a2,a3));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGMaterialRhiShader, sipName_updateGraphicsPipelineState, doc_QSGMaterialRhiShader_updateGraphicsPipelineState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_flags, "flags(self) -> QSGMaterialRhiShader.Flags");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_flags(PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGMaterialRhiShader *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGMaterialRhiShader, &sipCpp))
        {
             ::QSGMaterialRhiShader::Flags*sipRes;

            sipRes = new  ::QSGMaterialRhiShader::Flags(sipCpp->flags());

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialRhiShader_Flags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGMaterialRhiShader, sipName_flags, doc_QSGMaterialRhiShader_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGMaterialRhiShader_setFlag, "setFlag(self, Union[QSGMaterialRhiShader.Flags, QSGMaterialRhiShader.Flag], on: bool = True)");

extern "C" {static PyObject *meth_QSGMaterialRhiShader_setFlag(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSGMaterialRhiShader_setFlag(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterialRhiShader::Flags* a0;
        int a0State = 0;
        bool a1 = 1;
         ::QSGMaterialRhiShader *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_on,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|b", &sipSelf, sipType_QSGMaterialRhiShader, &sipCpp, sipType_QSGMaterialRhiShader_Flags, &a0, &a0State, &a1))
        {
            sipCpp->setFlag(*a0,a1);
            sipReleaseType(a0,sipType_QSGMaterialRhiShader_Flags,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGMaterialRhiShader, sipName_setFlag, doc_QSGMaterialRhiShader_setFlag);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGMaterialRhiShader(void *, const sipTypeDef *);}
static void *cast_QSGMaterialRhiShader(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSGMaterialRhiShader *sipCpp = reinterpret_cast< ::QSGMaterialRhiShader *>(sipCppV);

    if (targetType == sipType_QSGMaterialShader)
        return static_cast< ::QSGMaterialShader *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGMaterialRhiShader(void *, int);}
static void release_QSGMaterialRhiShader(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQSGMaterialRhiShader *>(sipCppV);
    else
        delete reinterpret_cast< ::QSGMaterialRhiShader *>(sipCppV);
}


extern "C" {static void dealloc_QSGMaterialRhiShader(sipSimpleWrapper *);}
static void dealloc_QSGMaterialRhiShader(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSGMaterialRhiShader *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGMaterialRhiShader(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSGMaterialRhiShader(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGMaterialRhiShader(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSGMaterialRhiShader *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSGMaterialRhiShader();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGMaterialRhiShader[] = {{70, 255, 1}};


static PyMethodDef methods_QSGMaterialRhiShader[] = {
    {SIP_MLNAME_CAST(sipName_flags), meth_QSGMaterialRhiShader_flags, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_flags)},
    {SIP_MLNAME_CAST(sipName_setFlag), SIP_MLMETH_CAST(meth_QSGMaterialRhiShader_setFlag), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_setFlag)},
    {SIP_MLNAME_CAST(sipName_updateGraphicsPipelineState), meth_QSGMaterialRhiShader_updateGraphicsPipelineState, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_updateGraphicsPipelineState)},
    {SIP_MLNAME_CAST(sipName_updateSampledImage), meth_QSGMaterialRhiShader_updateSampledImage, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_updateSampledImage)},
    {SIP_MLNAME_CAST(sipName_updateUniformData), meth_QSGMaterialRhiShader_updateUniformData, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGMaterialRhiShader_updateUniformData)}
};

static sipEnumMemberDef enummembers_QSGMaterialRhiShader[] = {
    {sipName_UpdatesGraphicsPipelineState, static_cast<int>( ::QSGMaterialRhiShader::UpdatesGraphicsPipelineState), 62},
};

PyDoc_STRVAR(doc_QSGMaterialRhiShader, "\1QSGMaterialRhiShader()");


static pyqt5ClassPluginDef plugin_QSGMaterialRhiShader = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGMaterialRhiShader,
        {SIP_NULLPTR},
        &plugin_QSGMaterialRhiShader
    },
    {
        sipNameNr_QSGMaterialRhiShader,
        {0, 0, 1},
        5, methods_QSGMaterialRhiShader,
        1, enummembers_QSGMaterialRhiShader,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGMaterialRhiShader,
    -1,
    -1,
    supers_QSGMaterialRhiShader,
    SIP_NULLPTR,
    init_type_QSGMaterialRhiShader,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGMaterialRhiShader,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGMaterialRhiShader,
    cast_QSGMaterialRhiShader,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
