/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQEvent.cpp"



class sipQEvent : public  ::QEvent
{
public:
    sipQEvent( ::QEvent::Type);
    sipQEvent(const  ::QEvent&);
    ~sipQEvent();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQEvent(const sipQEvent &);
    sipQEvent &operator = (const sipQEvent &);
};

sipQEvent::sipQEvent( ::QEvent::Type a0):  ::QEvent(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQEvent::sipQEvent(const  ::QEvent& a0):  ::QEvent(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQEvent::~sipQEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QEvent_type, "type(self) -> QEvent.Type");

extern "C" {static PyObject *meth_QEvent_type(PyObject *, PyObject *);}
static PyObject *meth_QEvent_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
             ::QEvent::Type sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QEvent_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_type, doc_QEvent_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_spontaneous, "spontaneous(self) -> bool");

extern "C" {static PyObject *meth_QEvent_spontaneous(PyObject *, PyObject *);}
static PyObject *meth_QEvent_spontaneous(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->spontaneous();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_spontaneous, doc_QEvent_spontaneous);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_setAccepted, "setAccepted(self, bool)");

extern "C" {static PyObject *meth_QEvent_setAccepted(PyObject *, PyObject *);}
static PyObject *meth_QEvent_setAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QEvent, &sipCpp, &a0))
        {
            sipCpp->setAccepted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_setAccepted, doc_QEvent_setAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_isAccepted, "isAccepted(self) -> bool");

extern "C" {static PyObject *meth_QEvent_isAccepted(PyObject *, PyObject *);}
static PyObject *meth_QEvent_isAccepted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAccepted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_isAccepted, doc_QEvent_isAccepted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_accept, "accept(self)");

extern "C" {static PyObject *meth_QEvent_accept(PyObject *, PyObject *);}
static PyObject *meth_QEvent_accept(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            sipCpp->accept();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_accept, doc_QEvent_accept);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_ignore, "ignore(self)");

extern "C" {static PyObject *meth_QEvent_ignore(PyObject *, PyObject *);}
static PyObject *meth_QEvent_ignore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QEvent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QEvent, &sipCpp))
        {
            sipCpp->ignore();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_ignore, doc_QEvent_ignore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QEvent_registerEventType, "registerEventType(hint: int = -1) -> int");

extern "C" {static PyObject *meth_QEvent_registerEventType(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QEvent_registerEventType(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_hint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|i", &a0))
        {
            int sipRes;

            sipRes =  ::QEvent::registerEventType(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QEvent, sipName_registerEventType, doc_QEvent_registerEventType);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QEvent(void *, int);}
static void release_QEvent(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQEvent *>(sipCppV);
    else
        delete reinterpret_cast< ::QEvent *>(sipCppV);
}


extern "C" {static void assign_QEvent(void *, SIP_SSIZE_T, void *);}
static void assign_QEvent(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QEvent *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QEvent *>(sipSrc);
}


extern "C" {static void *copy_QEvent(const void *, SIP_SSIZE_T);}
static void *copy_QEvent(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QEvent(reinterpret_cast<const  ::QEvent *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QEvent(sipSimpleWrapper *);}
static void dealloc_QEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQEvent *sipCpp = SIP_NULLPTR;

    {
         ::QEvent::Type a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "E", sipType_QEvent_Type, &a0))
        {
            sipCpp = new sipQEvent(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QEvent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QEvent, &a0))
        {
            sipCpp = new sipQEvent(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QEvent[] = {
    {SIP_MLNAME_CAST(sipName_accept), meth_QEvent_accept, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_accept)},
    {SIP_MLNAME_CAST(sipName_ignore), meth_QEvent_ignore, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_ignore)},
    {SIP_MLNAME_CAST(sipName_isAccepted), meth_QEvent_isAccepted, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_isAccepted)},
    {SIP_MLNAME_CAST(sipName_registerEventType), SIP_MLMETH_CAST(meth_QEvent_registerEventType), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QEvent_registerEventType)},
    {SIP_MLNAME_CAST(sipName_setAccepted), meth_QEvent_setAccepted, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_setAccepted)},
    {SIP_MLNAME_CAST(sipName_spontaneous), meth_QEvent_spontaneous, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_spontaneous)},
    {SIP_MLNAME_CAST(sipName_type), meth_QEvent_type, METH_VARARGS, SIP_MLDOC_CAST(doc_QEvent_type)}
};

static sipEnumMemberDef enummembers_QEvent[] = {
    {sipName_ActionAdded, static_cast<int>( ::QEvent::ActionAdded), 77},
    {sipName_ActionChanged, static_cast<int>( ::QEvent::ActionChanged), 77},
    {sipName_ActionRemoved, static_cast<int>( ::QEvent::ActionRemoved), 77},
    {sipName_ActivationChange, static_cast<int>( ::QEvent::ActivationChange), 77},
    {sipName_ApplicationActivate, static_cast<int>( ::QEvent::ApplicationActivate), 77},
    {sipName_ApplicationActivated, static_cast<int>( ::QEvent::ApplicationActivated), 77},
    {sipName_ApplicationDeactivate, static_cast<int>( ::QEvent::ApplicationDeactivate), 77},
    {sipName_ApplicationDeactivated, static_cast<int>( ::QEvent::ApplicationDeactivated), 77},
    {sipName_ApplicationFontChange, static_cast<int>( ::QEvent::ApplicationFontChange), 77},
    {sipName_ApplicationLayoutDirectionChange, static_cast<int>( ::QEvent::ApplicationLayoutDirectionChange), 77},
    {sipName_ApplicationPaletteChange, static_cast<int>( ::QEvent::ApplicationPaletteChange), 77},
    {sipName_ApplicationStateChange, static_cast<int>( ::QEvent::ApplicationStateChange), 77},
    {sipName_ApplicationWindowIconChange, static_cast<int>( ::QEvent::ApplicationWindowIconChange), 77},
    {sipName_ChildAdded, static_cast<int>( ::QEvent::ChildAdded), 77},
    {sipName_ChildPolished, static_cast<int>( ::QEvent::ChildPolished), 77},
    {sipName_ChildRemoved, static_cast<int>( ::QEvent::ChildRemoved), 77},
    {sipName_Clipboard, static_cast<int>( ::QEvent::Clipboard), 77},
    {sipName_Close, static_cast<int>( ::QEvent::Close), 77},
    {sipName_CloseSoftwareInputPanel, static_cast<int>( ::QEvent::CloseSoftwareInputPanel), 77},
    {sipName_ContentsRectChange, static_cast<int>( ::QEvent::ContentsRectChange), 77},
    {sipName_ContextMenu, static_cast<int>( ::QEvent::ContextMenu), 77},
    {sipName_CursorChange, static_cast<int>( ::QEvent::CursorChange), 77},
    {sipName_DeferredDelete, static_cast<int>( ::QEvent::DeferredDelete), 77},
    {sipName_DragEnter, static_cast<int>( ::QEvent::DragEnter), 77},
    {sipName_DragLeave, static_cast<int>( ::QEvent::DragLeave), 77},
    {sipName_DragMove, static_cast<int>( ::QEvent::DragMove), 77},
    {sipName_Drop, static_cast<int>( ::QEvent::Drop), 77},
    {sipName_DynamicPropertyChange, static_cast<int>( ::QEvent::DynamicPropertyChange), 77},
    {sipName_EnabledChange, static_cast<int>( ::QEvent::EnabledChange), 77},
    {sipName_Enter, static_cast<int>( ::QEvent::Enter), 77},
    {sipName_EnterWhatsThisMode, static_cast<int>( ::QEvent::EnterWhatsThisMode), 77},
    {sipName_Expose, static_cast<int>( ::QEvent::Expose), 77},
    {sipName_FileOpen, static_cast<int>( ::QEvent::FileOpen), 77},
    {sipName_FocusAboutToChange, static_cast<int>( ::QEvent::FocusAboutToChange), 77},
    {sipName_FocusIn, static_cast<int>( ::QEvent::FocusIn), 77},
    {sipName_FocusOut, static_cast<int>( ::QEvent::FocusOut), 77},
    {sipName_FontChange, static_cast<int>( ::QEvent::FontChange), 77},
    {sipName_Gesture, static_cast<int>( ::QEvent::Gesture), 77},
    {sipName_GestureOverride, static_cast<int>( ::QEvent::GestureOverride), 77},
    {sipName_GrabKeyboard, static_cast<int>( ::QEvent::GrabKeyboard), 77},
    {sipName_GrabMouse, static_cast<int>( ::QEvent::GrabMouse), 77},
    {sipName_GraphicsSceneContextMenu, static_cast<int>( ::QEvent::GraphicsSceneContextMenu), 77},
    {sipName_GraphicsSceneDragEnter, static_cast<int>( ::QEvent::GraphicsSceneDragEnter), 77},
    {sipName_GraphicsSceneDragLeave, static_cast<int>( ::QEvent::GraphicsSceneDragLeave), 77},
    {sipName_GraphicsSceneDragMove, static_cast<int>( ::QEvent::GraphicsSceneDragMove), 77},
    {sipName_GraphicsSceneDrop, static_cast<int>( ::QEvent::GraphicsSceneDrop), 77},
    {sipName_GraphicsSceneHelp, static_cast<int>( ::QEvent::GraphicsSceneHelp), 77},
    {sipName_GraphicsSceneHoverEnter, static_cast<int>( ::QEvent::GraphicsSceneHoverEnter), 77},
    {sipName_GraphicsSceneHoverLeave, static_cast<int>( ::QEvent::GraphicsSceneHoverLeave), 77},
    {sipName_GraphicsSceneHoverMove, static_cast<int>( ::QEvent::GraphicsSceneHoverMove), 77},
    {sipName_GraphicsSceneMouseDoubleClick, static_cast<int>( ::QEvent::GraphicsSceneMouseDoubleClick), 77},
    {sipName_GraphicsSceneMouseMove, static_cast<int>( ::QEvent::GraphicsSceneMouseMove), 77},
    {sipName_GraphicsSceneMousePress, static_cast<int>( ::QEvent::GraphicsSceneMousePress), 77},
    {sipName_GraphicsSceneMouseRelease, static_cast<int>( ::QEvent::GraphicsSceneMouseRelease), 77},
    {sipName_GraphicsSceneMove, static_cast<int>( ::QEvent::GraphicsSceneMove), 77},
    {sipName_GraphicsSceneResize, static_cast<int>( ::QEvent::GraphicsSceneResize), 77},
    {sipName_GraphicsSceneWheel, static_cast<int>( ::QEvent::GraphicsSceneWheel), 77},
    {sipName_Hide, static_cast<int>( ::QEvent::Hide), 77},
    {sipName_HideToParent, static_cast<int>( ::QEvent::HideToParent), 77},
    {sipName_HoverEnter, static_cast<int>( ::QEvent::HoverEnter), 77},
    {sipName_HoverLeave, static_cast<int>( ::QEvent::HoverLeave), 77},
    {sipName_HoverMove, static_cast<int>( ::QEvent::HoverMove), 77},
    {sipName_IconDrag, static_cast<int>( ::QEvent::IconDrag), 77},
    {sipName_IconTextChange, static_cast<int>( ::QEvent::IconTextChange), 77},
    {sipName_InputMethod, static_cast<int>( ::QEvent::InputMethod), 77},
    {sipName_InputMethodQuery, static_cast<int>( ::QEvent::InputMethodQuery), 77},
    {sipName_KeyPress, static_cast<int>( ::QEvent::KeyPress), 77},
    {sipName_KeyRelease, static_cast<int>( ::QEvent::KeyRelease), 77},
    {sipName_KeyboardLayoutChange, static_cast<int>( ::QEvent::KeyboardLayoutChange), 77},
    {sipName_LanguageChange, static_cast<int>( ::QEvent::LanguageChange), 77},
    {sipName_LayoutDirectionChange, static_cast<int>( ::QEvent::LayoutDirectionChange), 77},
    {sipName_LayoutRequest, static_cast<int>( ::QEvent::LayoutRequest), 77},
    {sipName_Leave, static_cast<int>( ::QEvent::Leave), 77},
    {sipName_LeaveWhatsThisMode, static_cast<int>( ::QEvent::LeaveWhatsThisMode), 77},
    {sipName_LocaleChange, static_cast<int>( ::QEvent::LocaleChange), 77},
    {sipName_MacSizeChange, static_cast<int>( ::QEvent::MacSizeChange), 77},
    {sipName_MaxUser, static_cast<int>( ::QEvent::MaxUser), 77},
    {sipName_MetaCall, static_cast<int>( ::QEvent::MetaCall), 77},
    {sipName_ModifiedChange, static_cast<int>( ::QEvent::ModifiedChange), 77},
    {sipName_MouseButtonDblClick, static_cast<int>( ::QEvent::MouseButtonDblClick), 77},
    {sipName_MouseButtonPress, static_cast<int>( ::QEvent::MouseButtonPress), 77},
    {sipName_MouseButtonRelease, static_cast<int>( ::QEvent::MouseButtonRelease), 77},
    {sipName_MouseMove, static_cast<int>( ::QEvent::MouseMove), 77},
    {sipName_MouseTrackingChange, static_cast<int>( ::QEvent::MouseTrackingChange), 77},
    {sipName_Move, static_cast<int>( ::QEvent::Move), 77},
    {sipName_NonClientAreaMouseButtonDblClick, static_cast<int>( ::QEvent::NonClientAreaMouseButtonDblClick), 77},
    {sipName_NonClientAreaMouseButtonPress, static_cast<int>( ::QEvent::NonClientAreaMouseButtonPress), 77},
    {sipName_NonClientAreaMouseButtonRelease, static_cast<int>( ::QEvent::NonClientAreaMouseButtonRelease), 77},
    {sipName_NonClientAreaMouseMove, static_cast<int>( ::QEvent::NonClientAreaMouseMove), 77},
    {sipName_None_, static_cast<int>( ::QEvent::None), 77},
    {sipName_OkRequest, static_cast<int>( ::QEvent::OkRequest), 77},
    {sipName_OrientationChange, static_cast<int>( ::QEvent::OrientationChange), 77},
    {sipName_Paint, static_cast<int>( ::QEvent::Paint), 77},
    {sipName_PaletteChange, static_cast<int>( ::QEvent::PaletteChange), 77},
    {sipName_ParentAboutToChange, static_cast<int>( ::QEvent::ParentAboutToChange), 77},
    {sipName_ParentChange, static_cast<int>( ::QEvent::ParentChange), 77},
    {sipName_PlatformPanel, static_cast<int>( ::QEvent::PlatformPanel), 77},
    {sipName_PlatformSurface, static_cast<int>( ::QEvent::PlatformSurface), 77},
    {sipName_Polish, static_cast<int>( ::QEvent::Polish), 77},
    {sipName_PolishRequest, static_cast<int>( ::QEvent::PolishRequest), 77},
    {sipName_QueryWhatsThis, static_cast<int>( ::QEvent::QueryWhatsThis), 77},
    {sipName_ReadOnlyChange, static_cast<int>( ::QEvent::ReadOnlyChange), 77},
    {sipName_RequestSoftwareInputPanel, static_cast<int>( ::QEvent::RequestSoftwareInputPanel), 77},
    {sipName_Resize, static_cast<int>( ::QEvent::Resize), 77},
    {sipName_Scroll, static_cast<int>( ::QEvent::Scroll), 77},
    {sipName_ScrollPrepare, static_cast<int>( ::QEvent::ScrollPrepare), 77},
    {sipName_Shortcut, static_cast<int>( ::QEvent::Shortcut), 77},
    {sipName_ShortcutOverride, static_cast<int>( ::QEvent::ShortcutOverride), 77},
    {sipName_Show, static_cast<int>( ::QEvent::Show), 77},
    {sipName_ShowToParent, static_cast<int>( ::QEvent::ShowToParent), 77},
    {sipName_SockAct, static_cast<int>( ::QEvent::SockAct), 77},
    {sipName_StateMachineSignal, static_cast<int>( ::QEvent::StateMachineSignal), 77},
    {sipName_StateMachineWrapped, static_cast<int>( ::QEvent::StateMachineWrapped), 77},
    {sipName_StatusTip, static_cast<int>( ::QEvent::StatusTip), 77},
    {sipName_StyleChange, static_cast<int>( ::QEvent::StyleChange), 77},
    {sipName_TabletEnterProximity, static_cast<int>( ::QEvent::TabletEnterProximity), 77},
    {sipName_TabletLeaveProximity, static_cast<int>( ::QEvent::TabletLeaveProximity), 77},
    {sipName_TabletMove, static_cast<int>( ::QEvent::TabletMove), 77},
    {sipName_TabletPress, static_cast<int>( ::QEvent::TabletPress), 77},
    {sipName_TabletRelease, static_cast<int>( ::QEvent::TabletRelease), 77},
    {sipName_TabletTrackingChange, static_cast<int>( ::QEvent::TabletTrackingChange), 77},
    {sipName_ThreadChange, static_cast<int>( ::QEvent::ThreadChange), 77},
    {sipName_Timer, static_cast<int>( ::QEvent::Timer), 77},
    {sipName_ToolBarChange, static_cast<int>( ::QEvent::ToolBarChange), 77},
    {sipName_ToolTip, static_cast<int>( ::QEvent::ToolTip), 77},
    {sipName_ToolTipChange, static_cast<int>( ::QEvent::ToolTipChange), 77},
    {sipName_TouchBegin, static_cast<int>( ::QEvent::TouchBegin), 77},
    {sipName_TouchCancel, static_cast<int>( ::QEvent::TouchCancel), 77},
    {sipName_TouchEnd, static_cast<int>( ::QEvent::TouchEnd), 77},
    {sipName_TouchUpdate, static_cast<int>( ::QEvent::TouchUpdate), 77},
    {sipName_UngrabKeyboard, static_cast<int>( ::QEvent::UngrabKeyboard), 77},
    {sipName_UngrabMouse, static_cast<int>( ::QEvent::UngrabMouse), 77},
    {sipName_UpdateLater, static_cast<int>( ::QEvent::UpdateLater), 77},
    {sipName_UpdateRequest, static_cast<int>( ::QEvent::UpdateRequest), 77},
    {sipName_User, static_cast<int>( ::QEvent::User), 77},
    {sipName_WhatsThis, static_cast<int>( ::QEvent::WhatsThis), 77},
    {sipName_WhatsThisClicked, static_cast<int>( ::QEvent::WhatsThisClicked), 77},
    {sipName_Wheel, static_cast<int>( ::QEvent::Wheel), 77},
    {sipName_WinEventAct, static_cast<int>( ::QEvent::WinEventAct), 77},
    {sipName_WinIdChange, static_cast<int>( ::QEvent::WinIdChange), 77},
    {sipName_WindowActivate, static_cast<int>( ::QEvent::WindowActivate), 77},
    {sipName_WindowBlocked, static_cast<int>( ::QEvent::WindowBlocked), 77},
    {sipName_WindowDeactivate, static_cast<int>( ::QEvent::WindowDeactivate), 77},
    {sipName_WindowIconChange, static_cast<int>( ::QEvent::WindowIconChange), 77},
    {sipName_WindowStateChange, static_cast<int>( ::QEvent::WindowStateChange), 77},
    {sipName_WindowTitleChange, static_cast<int>( ::QEvent::WindowTitleChange), 77},
    {sipName_WindowUnblocked, static_cast<int>( ::QEvent::WindowUnblocked), 77},
    {sipName_ZOrderChange, static_cast<int>( ::QEvent::ZOrderChange), 77},
};

PyDoc_STRVAR(doc_QEvent, "\1QEvent(QEvent.Type)\n"
"QEvent(QEvent)");


static pyqt5ClassPluginDef plugin_QEvent = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QEvent = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QEvent,
        {SIP_NULLPTR},
        &plugin_QEvent
    },
    {
        sipNameNr_QEvent,
        {0, 0, 1},
        7, methods_QEvent,
        148, enummembers_QEvent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QEvent,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QEvent,
    assign_QEvent,
    SIP_NULLPTR,
    copy_QEvent,
    release_QEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
