/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 31 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickFramebufferObjectRenderer.cpp"

#line 28 "sip/QtGui/qopenglframebufferobject.sip"
#include <qopenglframebufferobject.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickFramebufferObjectRenderer.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickFramebufferObjectRenderer.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQQuickFramebufferObjectRenderer.cpp"


class sipQQuickFramebufferObject_Renderer : public  ::QQuickFramebufferObject::Renderer
{
public:
    sipQQuickFramebufferObject_Renderer();
    sipQQuickFramebufferObject_Renderer(const  ::QQuickFramebufferObject::Renderer&);
    virtual ~sipQQuickFramebufferObject_Renderer();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void synchronize( ::QQuickFramebufferObject*) SIP_OVERRIDE;
     ::QOpenGLFramebufferObject* createFramebufferObject(const  ::QSize&) SIP_OVERRIDE;
    void render() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickFramebufferObject_Renderer(const sipQQuickFramebufferObject_Renderer &);
    sipQQuickFramebufferObject_Renderer &operator = (const sipQQuickFramebufferObject_Renderer &);

    char sipPyMethods[3];
};

sipQQuickFramebufferObject_Renderer::sipQQuickFramebufferObject_Renderer():  ::QQuickFramebufferObject::Renderer(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuickFramebufferObject_Renderer::sipQQuickFramebufferObject_Renderer(const  ::QQuickFramebufferObject::Renderer& a0):  ::QQuickFramebufferObject::Renderer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQuickFramebufferObject_Renderer::~sipQQuickFramebufferObject_Renderer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQQuickFramebufferObject_Renderer::synchronize( ::QQuickFramebufferObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_synchronize);

    if (!sipMeth)
    {
         ::QQuickFramebufferObject::Renderer::synchronize(a0);
        return;
    }

    extern void sipVH_QtQuick_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQuickFramebufferObject*);

    sipVH_QtQuick_28(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QOpenGLFramebufferObject* sipQQuickFramebufferObject_Renderer::createFramebufferObject(const  ::QSize& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_createFramebufferObject);

    if (!sipMeth)
        return  ::QQuickFramebufferObject::Renderer::createFramebufferObject(a0);

    extern  ::QOpenGLFramebufferObject* sipVH_QtQuick_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QSize&);

    return sipVH_QtQuick_27(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQuickFramebufferObject_Renderer::render()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,sipName_Renderer,sipName_render);

    if (!sipMeth)
        return;

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_render, "render(self)");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_render(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_render(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_Renderer, sipName_render);
                return SIP_NULLPTR;
            }

            sipCpp->render();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_render, doc_QQuickFramebufferObject_Renderer_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_createFramebufferObject, "createFramebufferObject(self, QSize) -> QOpenGLFramebufferObject");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_createFramebufferObject(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_createFramebufferObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSize* a0;
         ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp, sipType_QSize, &a0))
        {
             ::QOpenGLFramebufferObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQuickFramebufferObject::Renderer::createFramebufferObject(*a0) : sipCpp->createFramebufferObject(*a0));

            return sipConvertFromType(sipRes,sipType_QOpenGLFramebufferObject,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_createFramebufferObject, doc_QQuickFramebufferObject_Renderer_createFramebufferObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_synchronize, "synchronize(self, QQuickFramebufferObject)");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_synchronize(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_synchronize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQuickFramebufferObject* a0;
         ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp, sipType_QQuickFramebufferObject, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QQuickFramebufferObject::Renderer::synchronize(a0) : sipCpp->synchronize(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_synchronize, doc_QQuickFramebufferObject_Renderer_synchronize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_framebufferObject, "framebufferObject(self) -> QOpenGLFramebufferObject");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_framebufferObject(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_framebufferObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp))
        {
             ::QOpenGLFramebufferObject*sipRes;

            sipRes = sipCpp->framebufferObject();

            return sipConvertFromType(sipRes,sipType_QOpenGLFramebufferObject,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_framebufferObject, doc_QQuickFramebufferObject_Renderer_framebufferObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_update, "update(self)");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_update(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_update(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp))
        {
            sipCpp->update();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_update, doc_QQuickFramebufferObject_Renderer_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer_invalidateFramebufferObject, "invalidateFramebufferObject(self)");

extern "C" {static PyObject *meth_QQuickFramebufferObject_Renderer_invalidateFramebufferObject(PyObject *, PyObject *);}
static PyObject *meth_QQuickFramebufferObject_Renderer_invalidateFramebufferObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickFramebufferObject::Renderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QQuickFramebufferObject_Renderer, &sipCpp))
        {
            sipCpp->invalidateFramebufferObject();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Renderer, sipName_invalidateFramebufferObject, doc_QQuickFramebufferObject_Renderer_invalidateFramebufferObject);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQuickFramebufferObject_Renderer(void *, int);}
static void release_QQuickFramebufferObject_Renderer(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQQuickFramebufferObject_Renderer *>(sipCppV);
}


extern "C" {static void dealloc_QQuickFramebufferObject_Renderer(sipSimpleWrapper *);}
static void dealloc_QQuickFramebufferObject_Renderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQuickFramebufferObject_Renderer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickFramebufferObject_Renderer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQuickFramebufferObject_Renderer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickFramebufferObject_Renderer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQuickFramebufferObject_Renderer *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQuickFramebufferObject_Renderer();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QQuickFramebufferObject::Renderer* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuickFramebufferObject_Renderer, &a0))
        {
            sipCpp = new sipQQuickFramebufferObject_Renderer(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQuickFramebufferObject_Renderer[] = {
    {SIP_MLNAME_CAST(sipName_createFramebufferObject), meth_QQuickFramebufferObject_Renderer_createFramebufferObject, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_createFramebufferObject)},
    {SIP_MLNAME_CAST(sipName_framebufferObject), meth_QQuickFramebufferObject_Renderer_framebufferObject, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_framebufferObject)},
    {SIP_MLNAME_CAST(sipName_invalidateFramebufferObject), meth_QQuickFramebufferObject_Renderer_invalidateFramebufferObject, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_invalidateFramebufferObject)},
    {SIP_MLNAME_CAST(sipName_render), meth_QQuickFramebufferObject_Renderer_render, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_render)},
    {SIP_MLNAME_CAST(sipName_synchronize), meth_QQuickFramebufferObject_Renderer_synchronize, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_synchronize)},
    {SIP_MLNAME_CAST(sipName_update), meth_QQuickFramebufferObject_Renderer_update, METH_VARARGS, SIP_MLDOC_CAST(doc_QQuickFramebufferObject_Renderer_update)}
};

PyDoc_STRVAR(doc_QQuickFramebufferObject_Renderer, "\1QQuickFramebufferObject.Renderer()\n"
"QQuickFramebufferObject.Renderer(QQuickFramebufferObject.Renderer)");


static pyqt5ClassPluginDef plugin_QQuickFramebufferObject_Renderer = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickFramebufferObject_Renderer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickFramebufferObject__Renderer,
        {SIP_NULLPTR},
        &plugin_QQuickFramebufferObject_Renderer
    },
    {
        sipNameNr_Renderer,
        {3, 255, 0},
        6, methods_QQuickFramebufferObject_Renderer,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickFramebufferObject_Renderer,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuickFramebufferObject_Renderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQuickFramebufferObject_Renderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQuickFramebufferObject_Renderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
