/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"

#line 27 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurlquery.sip"
#include <qurlquery.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"
#line 100 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
#include <QHash>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"


PyDoc_STRVAR(doc_QUrl_url, "url(self, options: QUrl.FormattingOptions = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_url(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_url(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::FormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::FormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_FormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->url(*a0));
            sipReleaseType(a0,sipType_QUrl_FormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_url, doc_QUrl_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setUrl, "setUrl(self, str, mode: QUrl.ParsingMode = QUrl.TolerantMode)");

extern "C" {static PyObject *meth_QUrl_setUrl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setUrl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setUrl(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setUrl, doc_QUrl_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QUrl_isValid(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isValid, doc_QUrl_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QUrl_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isEmpty, doc_QUrl_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_clear, "clear(self)");

extern "C" {static PyObject *meth_QUrl_clear(PyObject *, PyObject *);}
static PyObject *meth_QUrl_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_clear, doc_QUrl_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setScheme, "setScheme(self, str)");

extern "C" {static PyObject *meth_QUrl_setScheme(PyObject *, PyObject *);}
static PyObject *meth_QUrl_setScheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setScheme(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setScheme, doc_QUrl_setScheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_scheme, "scheme(self) -> str");

extern "C" {static PyObject *meth_QUrl_scheme(PyObject *, PyObject *);}
static PyObject *meth_QUrl_scheme(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->scheme());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_scheme, doc_QUrl_scheme);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setAuthority, "setAuthority(self, str, mode: QUrl.ParsingMode = QUrl.TolerantMode)");

extern "C" {static PyObject *meth_QUrl_setAuthority(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setAuthority(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setAuthority(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setAuthority, doc_QUrl_setAuthority);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_authority, "authority(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_authority(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_authority(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->authority(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_authority, doc_QUrl_authority);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setUserInfo, "setUserInfo(self, str, mode: QUrl.ParsingMode = QUrl.TolerantMode)");

extern "C" {static PyObject *meth_QUrl_setUserInfo(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setUserInfo(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setUserInfo(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setUserInfo, doc_QUrl_setUserInfo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_userInfo, "userInfo(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_userInfo(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_userInfo(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->userInfo(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_userInfo, doc_QUrl_userInfo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setUserName, "setUserName(self, str, mode: QUrl.ParsingMode = QUrl.DecodedMode)");

extern "C" {static PyObject *meth_QUrl_setUserName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setUserName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::DecodedMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setUserName(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setUserName, doc_QUrl_setUserName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_userName, "userName(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_userName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_userName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->userName(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_userName, doc_QUrl_userName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setPassword, "setPassword(self, str, mode: QUrl.ParsingMode = QUrl.DecodedMode)");

extern "C" {static PyObject *meth_QUrl_setPassword(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setPassword(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::DecodedMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setPassword(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setPassword, doc_QUrl_setPassword);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_password, "password(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_password(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_password(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->password(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_password, doc_QUrl_password);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setHost, "setHost(self, str, mode: QUrl.ParsingMode = QUrl.DecodedMode)");

extern "C" {static PyObject *meth_QUrl_setHost(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setHost(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::DecodedMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setHost(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setHost, doc_QUrl_setHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_host, "host(self, Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_host(PyObject *, PyObject *);}
static PyObject *meth_QUrl_host(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->host(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_host, doc_QUrl_host);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setPort, "setPort(self, int)");

extern "C" {static PyObject *meth_QUrl_setPort(PyObject *, PyObject *);}
static PyObject *meth_QUrl_setPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QUrl, &sipCpp, &a0))
        {
            sipCpp->setPort(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setPort, doc_QUrl_setPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_port, "port(self, defaultPort: int = -1) -> int");

extern "C" {static PyObject *meth_QUrl_port(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_port(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_defaultPort,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QUrl, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->port(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_port, doc_QUrl_port);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setPath, "setPath(self, str, mode: QUrl.ParsingMode = QUrl.DecodedMode)");

extern "C" {static PyObject *meth_QUrl_setPath(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setPath(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::DecodedMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setPath(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setPath, doc_QUrl_setPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_path, "path(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_path(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_path(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->path(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_path, doc_QUrl_path);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setFragment, "setFragment(self, str, mode: QUrl.ParsingMode = QUrl.TolerantMode)");

extern "C" {static PyObject *meth_QUrl_setFragment(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setFragment(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setFragment(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setFragment, doc_QUrl_setFragment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fragment, "fragment(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_fragment(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_fragment(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->fragment(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fragment, doc_QUrl_fragment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_resolved, "resolved(self, QUrl) -> QUrl");

extern "C" {static PyObject *meth_QUrl_resolved(PyObject *, PyObject *);}
static PyObject *meth_QUrl_resolved(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl, &a0))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl(sipCpp->resolved(*a0));

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_resolved, doc_QUrl_resolved);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isRelative, "isRelative(self) -> bool");

extern "C" {static PyObject *meth_QUrl_isRelative(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isRelative(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRelative();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isRelative, doc_QUrl_isRelative);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isParentOf, "isParentOf(self, QUrl) -> bool");

extern "C" {static PyObject *meth_QUrl_isParentOf(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isParentOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isParentOf(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isParentOf, doc_QUrl_isParentOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromLocalFile, "fromLocalFile(str) -> QUrl");

extern "C" {static PyObject *meth_QUrl_fromLocalFile(PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromLocalFile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl( ::QUrl::fromLocalFile(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromLocalFile, doc_QUrl_fromLocalFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toLocalFile, "toLocalFile(self) -> str");

extern "C" {static PyObject *meth_QUrl_toLocalFile(PyObject *, PyObject *);}
static PyObject *meth_QUrl_toLocalFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toLocalFile());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toLocalFile, doc_QUrl_toLocalFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toString, "toString(self, options: QUrl.FormattingOptions = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_toString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_toString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::FormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::FormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_FormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toString(*a0));
            sipReleaseType(a0,sipType_QUrl_FormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toString, doc_QUrl_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toEncoded, "toEncoded(self, options: QUrl.FormattingOptions = QUrl.FullyEncoded) -> QByteArray");

extern "C" {static PyObject *meth_QUrl_toEncoded(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_toEncoded(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::FormattingOptions a0def = QUrl::FullyEncoded;
         ::QUrl::FormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_FormattingOptions, &a0, &a0State))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray(sipCpp->toEncoded(*a0));
            sipReleaseType(a0,sipType_QUrl_FormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toEncoded, doc_QUrl_toEncoded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromEncoded, "fromEncoded(Union[QByteArray, bytes, bytearray], mode: QUrl.ParsingMode = QUrl.TolerantMode) -> QUrl");

extern "C" {static PyObject *meth_QUrl_fromEncoded(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromEncoded(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|E", sipType_QByteArray, &a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl( ::QUrl::fromEncoded(*a0,a1));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromEncoded, doc_QUrl_fromEncoded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_detach, "detach(self)");

extern "C" {static PyObject *meth_QUrl_detach(PyObject *, PyObject *);}
static PyObject *meth_QUrl_detach(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            sipCpp->detach();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_detach, doc_QUrl_detach);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isDetached, "isDetached(self) -> bool");

extern "C" {static PyObject *meth_QUrl_isDetached(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isDetached(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDetached();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isDetached, doc_QUrl_isDetached);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromPercentEncoding, "fromPercentEncoding(Union[QByteArray, bytes, bytearray]) -> str");

extern "C" {static PyObject *meth_QUrl_fromPercentEncoding(PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromPercentEncoding(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QUrl::fromPercentEncoding(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromPercentEncoding, doc_QUrl_fromPercentEncoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toPercentEncoding, "toPercentEncoding(str, exclude: Union[QByteArray, bytes, bytearray] = QByteArray(), include: Union[QByteArray, bytes, bytearray] = QByteArray()) -> QByteArray");

extern "C" {static PyObject *meth_QUrl_toPercentEncoding(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_toPercentEncoding(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QByteArray& a1def = QByteArray();
        const  ::QByteArray* a1 = &a1def;
        int a1State = 0;
        const  ::QByteArray& a2def = QByteArray();
        const  ::QByteArray* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_exclude,
            sipName_include,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|J1J1", sipType_QString,&a0, &a0State, sipType_QByteArray, &a1, &a1State, sipType_QByteArray, &a2, &a2State))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray( ::QUrl::toPercentEncoding(*a0,*a1,*a2));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QByteArray *>(a1),sipType_QByteArray,a1State);
            sipReleaseType(const_cast< ::QByteArray *>(a2),sipType_QByteArray,a2State);

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toPercentEncoding, doc_QUrl_toPercentEncoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_hasQuery, "hasQuery(self) -> bool");

extern "C" {static PyObject *meth_QUrl_hasQuery(PyObject *, PyObject *);}
static PyObject *meth_QUrl_hasQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasQuery();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_hasQuery, doc_QUrl_hasQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_hasFragment, "hasFragment(self) -> bool");

extern "C" {static PyObject *meth_QUrl_hasFragment(PyObject *, PyObject *);}
static PyObject *meth_QUrl_hasFragment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFragment();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_hasFragment, doc_QUrl_hasFragment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QUrl_errorString(PyObject *, PyObject *);}
static PyObject *meth_QUrl_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_errorString, doc_QUrl_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromAce, "fromAce(Union[QByteArray, bytes, bytearray]) -> str");

extern "C" {static PyObject *meth_QUrl_fromAce(PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromAce(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::QUrl::fromAce(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromAce, doc_QUrl_fromAce);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toAce, "toAce(str) -> QByteArray");

extern "C" {static PyObject *meth_QUrl_toAce(PyObject *, PyObject *);}
static PyObject *meth_QUrl_toAce(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray( ::QUrl::toAce(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toAce, doc_QUrl_toAce);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_idnWhitelist, "idnWhitelist() -> List[str]");

extern "C" {static PyObject *meth_QUrl_idnWhitelist(PyObject *, PyObject *);}
static PyObject *meth_QUrl_idnWhitelist(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList( ::QUrl::idnWhitelist());

            return sipConvertFromNewType(sipRes,sipType_QStringList,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_idnWhitelist, doc_QUrl_idnWhitelist);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setIdnWhitelist, "setIdnWhitelist(Iterable[str])");

extern "C" {static PyObject *meth_QUrl_setIdnWhitelist(PyObject *, PyObject *);}
static PyObject *meth_QUrl_setIdnWhitelist(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QStringList,&a0, &a0State))
        {
             ::QUrl::setIdnWhitelist(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setIdnWhitelist, doc_QUrl_setIdnWhitelist);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromUserInput, "fromUserInput(str) -> QUrl\n"
"fromUserInput(str, str, options: Union[QUrl.UserInputResolutionOptions, QUrl.UserInputResolutionOption] = QUrl.DefaultResolution) -> QUrl");

extern "C" {static PyObject *meth_QUrl_fromUserInput(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromUserInput(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "J1", sipType_QString,&a0, &a0State))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl( ::QUrl::fromUserInput(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QString* a1;
        int a1State = 0;
         ::QUrl::UserInputResolutionOptions a2def = QUrl::DefaultResolution;
         ::QUrl::UserInputResolutionOptions* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1J1|J1", sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State, sipType_QUrl_UserInputResolutionOptions, &a2, &a2State))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl( ::QUrl::fromUserInput(*a0,*a1,*a2));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);
            sipReleaseType(a2,sipType_QUrl_UserInputResolutionOptions,a2State);

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromUserInput, doc_QUrl_fromUserInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_swap, "swap(self, QUrl)");

extern "C" {static PyObject *meth_QUrl_swap(PyObject *, PyObject *);}
static PyObject *meth_QUrl_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl* a0;
         ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_swap, doc_QUrl_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_topLevelDomain, "topLevelDomain(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_topLevelDomain(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_topLevelDomain(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->topLevelDomain(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_topLevelDomain, doc_QUrl_topLevelDomain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_isLocalFile, "isLocalFile(self) -> bool");

extern "C" {static PyObject *meth_QUrl_isLocalFile(PyObject *, PyObject *);}
static PyObject *meth_QUrl_isLocalFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUrl, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLocalFile();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_isLocalFile, doc_QUrl_isLocalFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toDisplayString, "toDisplayString(self, options: QUrl.FormattingOptions = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_toDisplayString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_toDisplayString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::FormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::FormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_FormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toDisplayString(*a0));
            sipReleaseType(a0,sipType_QUrl_FormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toDisplayString, doc_QUrl_toDisplayString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_setQuery, "setQuery(self, str, mode: QUrl.ParsingMode = QUrl.TolerantMode)\n"
"setQuery(self, QUrlQuery)");

extern "C" {static PyObject *meth_QUrl_setQuery(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_setQuery(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;
         ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QUrl, &sipCpp, sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp->setQuery(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QUrlQuery* a0;
         ::QUrl *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrlQuery, &a0))
        {
            sipCpp->setQuery(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_setQuery, doc_QUrl_setQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_query, "query(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.PrettyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_query(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_query(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::PrettyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->query(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_query, doc_QUrl_query);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_toStringList, "toStringList(Iterable[QUrl], options: QUrl.FormattingOptions = QUrl.PrettyDecoded) -> List[str]");

extern "C" {static PyObject *meth_QUrl_toStringList(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_toStringList(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QUrl>* a0;
        int a0State = 0;
         ::QUrl::FormattingOptions a1def = QUrl::PrettyDecoded;
         ::QUrl::FormattingOptions* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|J1", sipType_QList_0100QUrl,&a0, &a0State, sipType_QUrl_FormattingOptions, &a1, &a1State))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList( ::QUrl::toStringList(*a0,*a1));
            sipReleaseType(const_cast<QList< ::QUrl> *>(a0),sipType_QList_0100QUrl,a0State);
            sipReleaseType(a1,sipType_QUrl_FormattingOptions,a1State);

            return sipConvertFromNewType(sipRes,sipType_QStringList,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_toStringList, doc_QUrl_toStringList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fromStringList, "fromStringList(Iterable[str], mode: QUrl.ParsingMode = QUrl.TolerantMode) -> List[QUrl]");

extern "C" {static PyObject *meth_QUrl_fromStringList(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_fromStringList(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStringList* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J1|E", sipType_QStringList,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            QList< ::QUrl>*sipRes;

            sipRes = new QList< ::QUrl>( ::QUrl::fromStringList(*a0,a1));
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            return sipConvertFromNewType(sipRes,sipType_QList_0100QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fromStringList, doc_QUrl_fromStringList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_adjusted, "adjusted(self, QUrl.FormattingOptions) -> QUrl");

extern "C" {static PyObject *meth_QUrl_adjusted(PyObject *, PyObject *);}
static PyObject *meth_QUrl_adjusted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::FormattingOptions* a0;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_FormattingOptions, &a0, &a0State))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl(sipCpp->adjusted(*a0));
            sipReleaseType(a0,sipType_QUrl_FormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_adjusted, doc_QUrl_adjusted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_fileName, "fileName(self, options: Union[QUrl.ComponentFormattingOptions, QUrl.ComponentFormattingOption] = QUrl.FullyDecoded) -> str");

extern "C" {static PyObject *meth_QUrl_fileName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QUrl_fileName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QUrl::ComponentFormattingOptions a0def = QUrl::FullyDecoded;
         ::QUrl::ComponentFormattingOptions* a0 = &a0def;
        int a0State = 0;
        const  ::QUrl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl_ComponentFormattingOptions, &a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->fileName(*a0));
            sipReleaseType(a0,sipType_QUrl_ComponentFormattingOptions,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_fileName, doc_QUrl_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUrl_matches, "matches(self, QUrl, QUrl.FormattingOptions) -> bool");

extern "C" {static PyObject *meth_QUrl_matches(PyObject *, PyObject *);}
static PyObject *meth_QUrl_matches(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
         ::QUrl::FormattingOptions* a1;
        int a1State = 0;
        const  ::QUrl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QUrl, &sipCpp, sipType_QUrl, &a0, sipType_QUrl_FormattingOptions, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->matches(*a0,*a1);
            sipReleaseType(a1,sipType_QUrl_FormattingOptions,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUrl, sipName_matches, doc_QUrl_matches);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QUrl___ge__(PyObject *,PyObject *);}
static PyObject *slot_QUrl___ge__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp-> ::QUrl::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtCore, ge_slot, sipType_QUrl, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QUrl___ne__(PyObject *,PyObject *);}
static PyObject *slot_QUrl___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QUrl::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QUrl, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QUrl___eq__(PyObject *,PyObject *);}
static PyObject *slot_QUrl___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QUrl::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QUrl, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QUrl___lt__(PyObject *,PyObject *);}
static PyObject *slot_QUrl___lt__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QUrl::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtCore, lt_slot, sipType_QUrl, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QUrl___repr__(PyObject *);}
static PyObject *slot_QUrl___repr__(PyObject *sipSelf)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
        PyObject *uni = qpycore_PyObject_FromQString(sipCpp->toString());
        
        if (uni)
        {
        #if PY_MAJOR_VERSION >= 3
            sipRes = PyUnicode_FromFormat("PyQt5.QtCore.QUrl(%R)", uni);
        #else
            sipRes = PyString_FromFormat("PyQt5.QtCore.QUrl(");
            PyString_ConcatAndDel(&sipRes, PyObject_Repr(uni));
            PyString_ConcatAndDel(&sipRes, PyString_FromString(")"));
        #endif
        
            Py_DECREF(uni);
        }
#line 1965 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static long slot_QUrl___hash__(PyObject *);}
static long slot_QUrl___hash__(PyObject *sipSelf)
{
     ::QUrl *sipCpp = reinterpret_cast< ::QUrl *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QUrl));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 117 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qurl.sip"
        sipRes = qHash(*sipCpp);
#line 1990 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQUrl.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QUrl(void *, int);}
static void release_QUrl(void *sipCppV, int)
{
    delete reinterpret_cast< ::QUrl *>(sipCppV);
}


extern "C" {static void *array_QUrl(Py_ssize_t);}
static void *array_QUrl(Py_ssize_t sipNrElem)
{
    return new  ::QUrl[sipNrElem];
}


extern "C" {static void assign_QUrl(void *, SIP_SSIZE_T, void *);}
static void assign_QUrl(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QUrl *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QUrl *>(sipSrc);
}


extern "C" {static void *copy_QUrl(const void *, SIP_SSIZE_T);}
static void *copy_QUrl(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QUrl(reinterpret_cast<const  ::QUrl *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QUrl(sipSimpleWrapper *);}
static void dealloc_QUrl(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QUrl(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QUrl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QUrl(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QUrl *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QUrl();

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QUrl::ParsingMode a1 = QUrl::TolerantMode;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|E", sipType_QString,&a0, &a0State, sipType_QUrl_ParsingMode, &a1))
        {
            sipCpp = new  ::QUrl(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipCpp;
        }
    }

    {
        const  ::QUrl* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QUrl, &a0))
        {
            sipCpp = new  ::QUrl(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QUrl[] = {
    {(void *)slot_QUrl___ge__, ge_slot},
    {(void *)slot_QUrl___ne__, ne_slot},
    {(void *)slot_QUrl___eq__, eq_slot},
    {(void *)slot_QUrl___lt__, lt_slot},
    {(void *)slot_QUrl___repr__, repr_slot},
    {(void *)slot_QUrl___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QUrl[] = {
    {SIP_MLNAME_CAST(sipName_adjusted), meth_QUrl_adjusted, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_adjusted)},
    {SIP_MLNAME_CAST(sipName_authority), SIP_MLMETH_CAST(meth_QUrl_authority), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_authority)},
    {SIP_MLNAME_CAST(sipName_clear), meth_QUrl_clear, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_clear)},
    {SIP_MLNAME_CAST(sipName_detach), meth_QUrl_detach, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_detach)},
    {SIP_MLNAME_CAST(sipName_errorString), meth_QUrl_errorString, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_errorString)},
    {SIP_MLNAME_CAST(sipName_fileName), SIP_MLMETH_CAST(meth_QUrl_fileName), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_fileName)},
    {SIP_MLNAME_CAST(sipName_fragment), SIP_MLMETH_CAST(meth_QUrl_fragment), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_fragment)},
    {SIP_MLNAME_CAST(sipName_fromAce), meth_QUrl_fromAce, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_fromAce)},
    {SIP_MLNAME_CAST(sipName_fromEncoded), SIP_MLMETH_CAST(meth_QUrl_fromEncoded), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_fromEncoded)},
    {SIP_MLNAME_CAST(sipName_fromLocalFile), meth_QUrl_fromLocalFile, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_fromLocalFile)},
    {SIP_MLNAME_CAST(sipName_fromPercentEncoding), meth_QUrl_fromPercentEncoding, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_fromPercentEncoding)},
    {SIP_MLNAME_CAST(sipName_fromStringList), SIP_MLMETH_CAST(meth_QUrl_fromStringList), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_fromStringList)},
    {SIP_MLNAME_CAST(sipName_fromUserInput), SIP_MLMETH_CAST(meth_QUrl_fromUserInput), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_fromUserInput)},
    {SIP_MLNAME_CAST(sipName_hasFragment), meth_QUrl_hasFragment, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_hasFragment)},
    {SIP_MLNAME_CAST(sipName_hasQuery), meth_QUrl_hasQuery, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_hasQuery)},
    {SIP_MLNAME_CAST(sipName_host), meth_QUrl_host, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_host)},
    {SIP_MLNAME_CAST(sipName_idnWhitelist), meth_QUrl_idnWhitelist, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_idnWhitelist)},
    {SIP_MLNAME_CAST(sipName_isDetached), meth_QUrl_isDetached, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isDetached)},
    {SIP_MLNAME_CAST(sipName_isEmpty), meth_QUrl_isEmpty, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isEmpty)},
    {SIP_MLNAME_CAST(sipName_isLocalFile), meth_QUrl_isLocalFile, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isLocalFile)},
    {SIP_MLNAME_CAST(sipName_isParentOf), meth_QUrl_isParentOf, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isParentOf)},
    {SIP_MLNAME_CAST(sipName_isRelative), meth_QUrl_isRelative, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isRelative)},
    {SIP_MLNAME_CAST(sipName_isValid), meth_QUrl_isValid, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_isValid)},
    {SIP_MLNAME_CAST(sipName_matches), meth_QUrl_matches, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_matches)},
    {SIP_MLNAME_CAST(sipName_password), SIP_MLMETH_CAST(meth_QUrl_password), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_password)},
    {SIP_MLNAME_CAST(sipName_path), SIP_MLMETH_CAST(meth_QUrl_path), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_path)},
    {SIP_MLNAME_CAST(sipName_port), SIP_MLMETH_CAST(meth_QUrl_port), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_port)},
    {SIP_MLNAME_CAST(sipName_query), SIP_MLMETH_CAST(meth_QUrl_query), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_query)},
    {SIP_MLNAME_CAST(sipName_resolved), meth_QUrl_resolved, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_resolved)},
    {SIP_MLNAME_CAST(sipName_scheme), meth_QUrl_scheme, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_scheme)},
    {SIP_MLNAME_CAST(sipName_setAuthority), SIP_MLMETH_CAST(meth_QUrl_setAuthority), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setAuthority)},
    {SIP_MLNAME_CAST(sipName_setFragment), SIP_MLMETH_CAST(meth_QUrl_setFragment), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setFragment)},
    {SIP_MLNAME_CAST(sipName_setHost), SIP_MLMETH_CAST(meth_QUrl_setHost), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setHost)},
    {SIP_MLNAME_CAST(sipName_setIdnWhitelist), meth_QUrl_setIdnWhitelist, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_setIdnWhitelist)},
    {SIP_MLNAME_CAST(sipName_setPassword), SIP_MLMETH_CAST(meth_QUrl_setPassword), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setPassword)},
    {SIP_MLNAME_CAST(sipName_setPath), SIP_MLMETH_CAST(meth_QUrl_setPath), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setPath)},
    {SIP_MLNAME_CAST(sipName_setPort), meth_QUrl_setPort, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_setPort)},
    {SIP_MLNAME_CAST(sipName_setQuery), SIP_MLMETH_CAST(meth_QUrl_setQuery), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setQuery)},
    {SIP_MLNAME_CAST(sipName_setScheme), meth_QUrl_setScheme, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_setScheme)},
    {SIP_MLNAME_CAST(sipName_setUrl), SIP_MLMETH_CAST(meth_QUrl_setUrl), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setUrl)},
    {SIP_MLNAME_CAST(sipName_setUserInfo), SIP_MLMETH_CAST(meth_QUrl_setUserInfo), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setUserInfo)},
    {SIP_MLNAME_CAST(sipName_setUserName), SIP_MLMETH_CAST(meth_QUrl_setUserName), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_setUserName)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QUrl_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_swap)},
    {SIP_MLNAME_CAST(sipName_toAce), meth_QUrl_toAce, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_toAce)},
    {SIP_MLNAME_CAST(sipName_toDisplayString), SIP_MLMETH_CAST(meth_QUrl_toDisplayString), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_toDisplayString)},
    {SIP_MLNAME_CAST(sipName_toEncoded), SIP_MLMETH_CAST(meth_QUrl_toEncoded), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_toEncoded)},
    {SIP_MLNAME_CAST(sipName_toLocalFile), meth_QUrl_toLocalFile, METH_VARARGS, SIP_MLDOC_CAST(doc_QUrl_toLocalFile)},
    {SIP_MLNAME_CAST(sipName_toPercentEncoding), SIP_MLMETH_CAST(meth_QUrl_toPercentEncoding), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_toPercentEncoding)},
    {SIP_MLNAME_CAST(sipName_toString), SIP_MLMETH_CAST(meth_QUrl_toString), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_toString)},
    {SIP_MLNAME_CAST(sipName_toStringList), SIP_MLMETH_CAST(meth_QUrl_toStringList), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_toStringList)},
    {SIP_MLNAME_CAST(sipName_topLevelDomain), SIP_MLMETH_CAST(meth_QUrl_topLevelDomain), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_topLevelDomain)},
    {SIP_MLNAME_CAST(sipName_url), SIP_MLMETH_CAST(meth_QUrl_url), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_url)},
    {SIP_MLNAME_CAST(sipName_userInfo), SIP_MLMETH_CAST(meth_QUrl_userInfo), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_userInfo)},
    {SIP_MLNAME_CAST(sipName_userName), SIP_MLMETH_CAST(meth_QUrl_userName), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QUrl_userName)}
};

static sipEnumMemberDef enummembers_QUrl[] = {
    {sipName_AssumeLocalFile, static_cast<int>( ::QUrl::AssumeLocalFile), 316},
    {sipName_DecodeReserved, static_cast<int>( ::QUrl::DecodeReserved), 311},
    {sipName_DecodedMode, static_cast<int>( ::QUrl::DecodedMode), 314},
    {sipName_DefaultResolution, static_cast<int>( ::QUrl::DefaultResolution), 316},
    {sipName_EncodeDelimiters, static_cast<int>( ::QUrl::EncodeDelimiters), 311},
    {sipName_EncodeReserved, static_cast<int>( ::QUrl::EncodeReserved), 311},
    {sipName_EncodeSpaces, static_cast<int>( ::QUrl::EncodeSpaces), 311},
    {sipName_EncodeUnicode, static_cast<int>( ::QUrl::EncodeUnicode), 311},
    {sipName_FullyDecoded, static_cast<int>( ::QUrl::FullyDecoded), 311},
    {sipName_FullyEncoded, static_cast<int>( ::QUrl::FullyEncoded), 311},
    {sipName_None_, static_cast<int>( ::QUrl::None), 315},
    {sipName_NormalizePathSegments, static_cast<int>( ::QUrl::NormalizePathSegments), 315},
    {sipName_PreferLocalFile, static_cast<int>( ::QUrl::PreferLocalFile), 315},
    {sipName_PrettyDecoded, static_cast<int>( ::QUrl::PrettyDecoded), 311},
    {sipName_RemoveAuthority, static_cast<int>( ::QUrl::RemoveAuthority), 315},
    {sipName_RemoveFilename, static_cast<int>( ::QUrl::RemoveFilename), 315},
    {sipName_RemoveFragment, static_cast<int>( ::QUrl::RemoveFragment), 315},
    {sipName_RemovePassword, static_cast<int>( ::QUrl::RemovePassword), 315},
    {sipName_RemovePath, static_cast<int>( ::QUrl::RemovePath), 315},
    {sipName_RemovePort, static_cast<int>( ::QUrl::RemovePort), 315},
    {sipName_RemoveQuery, static_cast<int>( ::QUrl::RemoveQuery), 315},
    {sipName_RemoveScheme, static_cast<int>( ::QUrl::RemoveScheme), 315},
    {sipName_RemoveUserInfo, static_cast<int>( ::QUrl::RemoveUserInfo), 315},
    {sipName_StrictMode, static_cast<int>( ::QUrl::StrictMode), 314},
    {sipName_StripTrailingSlash, static_cast<int>( ::QUrl::StripTrailingSlash), 315},
    {sipName_TolerantMode, static_cast<int>( ::QUrl::TolerantMode), 314},
};

PyDoc_STRVAR(doc_QUrl, "\1QUrl()\n"
"QUrl(str, mode: QUrl.ParsingMode = QUrl.TolerantMode)\n"
"QUrl(QUrl)");


static pyqt5ClassPluginDef plugin_QUrl = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QUrl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QUrl,
        {SIP_NULLPTR},
        &plugin_QUrl
    },
    {
        sipNameNr_QUrl,
        {0, 0, 1},
        54, methods_QUrl,
        26, enummembers_QUrl,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QUrl,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QUrl,
    init_type_QUrl,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QUrl,
    assign_QUrl,
    array_QUrl,
    copy_QUrl,
    release_QUrl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
