/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 207 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorConstants.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorConstants.cpp"


extern "C" {static PyObject *varget_QColorConstants_Black(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Black(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Black);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Blue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Blue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Blue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Color0(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Color0(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Color0);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Color1(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Color1(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Color1);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Cyan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Cyan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Cyan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkBlue(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkBlue(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkBlue);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkCyan(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkCyan(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkCyan);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkGray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkGray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkGray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkGreen(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkGreen(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkGreen);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkMagenta(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkMagenta(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkMagenta);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkRed(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkRed(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkRed);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_DarkYellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_DarkYellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::DarkYellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Gray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Gray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Gray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Green(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Green(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Green);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_LightGray(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_LightGray(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::LightGray);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Magenta(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Magenta(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Magenta);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Red(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Red(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Red);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Transparent(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Transparent(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Transparent);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_White(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_White(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::White);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QColorConstants_Yellow(void *, PyObject *, PyObject *);}
static PyObject *varget_QColorConstants_Yellow(void *, PyObject *, PyObject *)
{
    const  ::QColor*sipVal;

    sipVal = new  ::QColor( ::QColorConstants::Yellow);

    return sipConvertFromNewType(const_cast< ::QColor *>(sipVal), sipType_QColor, SIP_NULLPTR);
}

sipVariableDef variables_QColorConstants[] = {
    {ClassVariable, sipName_Black, (PyMethodDef *)varget_QColorConstants_Black, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Blue, (PyMethodDef *)varget_QColorConstants_Blue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Color0, (PyMethodDef *)varget_QColorConstants_Color0, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Color1, (PyMethodDef *)varget_QColorConstants_Color1, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Cyan, (PyMethodDef *)varget_QColorConstants_Cyan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkBlue, (PyMethodDef *)varget_QColorConstants_DarkBlue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkCyan, (PyMethodDef *)varget_QColorConstants_DarkCyan, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkGray, (PyMethodDef *)varget_QColorConstants_DarkGray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkGreen, (PyMethodDef *)varget_QColorConstants_DarkGreen, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkMagenta, (PyMethodDef *)varget_QColorConstants_DarkMagenta, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkRed, (PyMethodDef *)varget_QColorConstants_DarkRed, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DarkYellow, (PyMethodDef *)varget_QColorConstants_DarkYellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Gray, (PyMethodDef *)varget_QColorConstants_Gray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Green, (PyMethodDef *)varget_QColorConstants_Green, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_LightGray, (PyMethodDef *)varget_QColorConstants_LightGray, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Magenta, (PyMethodDef *)varget_QColorConstants_Magenta, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Red, (PyMethodDef *)varget_QColorConstants_Red, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Transparent, (PyMethodDef *)varget_QColorConstants_Transparent, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_White, (PyMethodDef *)varget_QColorConstants_White, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Yellow, (PyMethodDef *)varget_QColorConstants_Yellow, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


static pyqt5ClassPluginDef plugin_QColorConstants = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QColorConstants = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QColorConstants,
        {SIP_NULLPTR},
        &plugin_QColorConstants
    },
    {
        sipNameNr_QColorConstants,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        20, variables_QColorConstants,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
