/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qapplication.sip"
#include <qapplication.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"

#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qdesktopwidget.sip"
#include <qdesktopwidget.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qfont.sip"
#include <qfont.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qinputmethod.sip"
#include <qinputmethod.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qstylehints.sip"
#include <qstylehints.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qclipboard.sip"
#include <qclipboard.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 102 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qabstractnativeeventfilter.sip"
#include <qabstractnativeeventfilter.h>
#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qabstracteventdispatcher.sip"
#include <qabstracteventdispatcher.h>
#line 108 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qtranslator.sip"
#include <qtranslator.h>
#line 111 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 114 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qeventloop.sip"
#include <qeventloop.h>
#line 117 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 30 "sip/QtCore/qcoreapplication.sip"
#include <qcoreapplication.h>
#line 120 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 137 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 140 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 143 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 146 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 149 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 152 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 155 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 158 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 161 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"


class sipQApplication : public  ::QApplication
{
public:
    sipQApplication(int&,char**,int);
    virtual ~sipQApplication();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool notify( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQApplication(const sipQApplication &);
    sipQApplication &operator = (const sipQApplication &);

    char sipPyMethods[8];
};

sipQApplication::sipQApplication(int& a0,char**a1,int a2):  ::QApplication(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQApplication::~sipQApplication()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQApplication::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf,sipType_QApplication);

    return  ::QApplication::metaObject();
}

int sipQApplication::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QApplication::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf,sipType_QApplication,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQApplication::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QApplication, _clname, &sipCpp) ? sipCpp :  ::QApplication::qt_metacast(_clname));
}

bool sipQApplication::notify( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_notify);

    if (!sipMeth)
        return  ::QApplication::notify(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQApplication::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QApplication::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQApplication::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QApplication::eventFilter(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQApplication::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QApplication::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQApplication::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QApplication::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQApplication::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QApplication::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQApplication::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QApplication::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQApplication::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QApplication::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QApplication_style, "style() -> QStyle");

extern "C" {static PyObject *meth_QApplication_style(PyObject *, PyObject *);}
static PyObject *meth_QApplication_style(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QStyle*sipRes;

            sipRes =  ::QApplication::style();

            return sipConvertFromType(sipRes,sipType_QStyle,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_style, doc_QApplication_style);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setStyle, "setStyle(QStyle)\n"
"setStyle(str) -> QStyle");

extern "C" {static PyObject *meth_QApplication_setStyle(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setStyle(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QStyle* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J:", sipType_QStyle, &a0))
        {
             ::QApplication::setStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QStyle*sipRes;

            sipRes =  ::QApplication::setStyle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromType(sipRes,sipType_QStyle,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setStyle, doc_QApplication_setStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_colorSpec, "colorSpec() -> int");

extern "C" {static PyObject *meth_QApplication_colorSpec(PyObject *, PyObject *);}
static PyObject *meth_QApplication_colorSpec(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::colorSpec();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_colorSpec, doc_QApplication_colorSpec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setColorSpec, "setColorSpec(int)");

extern "C" {static PyObject *meth_QApplication_setColorSpec(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setColorSpec(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setColorSpec(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setColorSpec, doc_QApplication_setColorSpec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_palette, "palette() -> QPalette\n"
"palette(QWidget) -> QPalette\n"
"palette(str) -> QPalette");

extern "C" {static PyObject *meth_QApplication_palette(PyObject *, PyObject *);}
static PyObject *meth_QApplication_palette(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QPalette*sipRes;

            sipRes = new  ::QPalette( ::QApplication::palette());

            return sipConvertFromNewType(sipRes,sipType_QPalette,SIP_NULLPTR);
        }
    }

    {
        const  ::QWidget* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QWidget, &a0))
        {
             ::QPalette*sipRes;

            sipRes = new  ::QPalette( ::QApplication::palette(a0));

            return sipConvertFromNewType(sipRes,sipType_QPalette,SIP_NULLPTR);
        }
    }

    {
        const char* a0;
        PyObject *a0Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "AA", &a0Keep, &a0))
        {
             ::QPalette*sipRes;

            sipRes = new  ::QPalette( ::QApplication::palette(a0));
            Py_DECREF(a0Keep);

            return sipConvertFromNewType(sipRes,sipType_QPalette,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_palette, doc_QApplication_palette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setPalette, "setPalette(QPalette, className: str = None)");

extern "C" {static PyObject *meth_QApplication_setPalette(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QApplication_setPalette(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPalette* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_className,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J9|AA", sipType_QPalette, &a0, &a1Keep, &a1))
        {
             ::QApplication::setPalette(*a0,a1);
            Py_XDECREF(a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setPalette, doc_QApplication_setPalette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_font, "font() -> QFont\n"
"font(QWidget) -> QFont\n"
"font(str) -> QFont");

extern "C" {static PyObject *meth_QApplication_font(PyObject *, PyObject *);}
static PyObject *meth_QApplication_font(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QFont*sipRes;

            sipRes = new  ::QFont( ::QApplication::font());

            return sipConvertFromNewType(sipRes,sipType_QFont,SIP_NULLPTR);
        }
    }

    {
        const  ::QWidget* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QWidget, &a0))
        {
             ::QFont*sipRes;

            sipRes = new  ::QFont( ::QApplication::font(a0));

            return sipConvertFromNewType(sipRes,sipType_QFont,SIP_NULLPTR);
        }
    }

    {
        const char* a0;
        PyObject *a0Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "AA", &a0Keep, &a0))
        {
             ::QFont*sipRes;

            sipRes = new  ::QFont( ::QApplication::font(a0));
            Py_DECREF(a0Keep);

            return sipConvertFromNewType(sipRes,sipType_QFont,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_font, doc_QApplication_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setFont, "setFont(QFont, className: str = None)");

extern "C" {static PyObject *meth_QApplication_setFont(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QApplication_setFont(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QFont* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_className,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J9|AA", sipType_QFont, &a0, &a1Keep, &a1))
        {
             ::QApplication::setFont(*a0,a1);
            Py_XDECREF(a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setFont, doc_QApplication_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_fontMetrics, "fontMetrics() -> QFontMetrics");

extern "C" {static PyObject *meth_QApplication_fontMetrics(PyObject *, PyObject *);}
static PyObject *meth_QApplication_fontMetrics(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QFontMetrics*sipRes;

            sipRes = new  ::QFontMetrics( ::QApplication::fontMetrics());

            return sipConvertFromNewType(sipRes,sipType_QFontMetrics,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_fontMetrics, doc_QApplication_fontMetrics);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setWindowIcon, "setWindowIcon(QIcon)");

extern "C" {static PyObject *meth_QApplication_setWindowIcon(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setWindowIcon(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QIcon, &a0))
        {
             ::QApplication::setWindowIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setWindowIcon, doc_QApplication_setWindowIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_windowIcon, "windowIcon() -> QIcon");

extern "C" {static PyObject *meth_QApplication_windowIcon(PyObject *, PyObject *);}
static PyObject *meth_QApplication_windowIcon(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QIcon*sipRes;

            sipRes = new  ::QIcon( ::QApplication::windowIcon());

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_windowIcon, doc_QApplication_windowIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_allWidgets, "allWidgets() -> List[QWidget]");

extern "C" {static PyObject *meth_QApplication_allWidgets(PyObject *, PyObject *);}
static PyObject *meth_QApplication_allWidgets(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidgetList*sipRes;

            sipRes = new  ::QWidgetList( ::QApplication::allWidgets());

            return sipConvertFromNewType(sipRes,sipType_QList_0101QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_allWidgets, doc_QApplication_allWidgets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_topLevelWidgets, "topLevelWidgets() -> List[QWidget]");

extern "C" {static PyObject *meth_QApplication_topLevelWidgets(PyObject *, PyObject *);}
static PyObject *meth_QApplication_topLevelWidgets(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidgetList*sipRes;

            sipRes = new  ::QWidgetList( ::QApplication::topLevelWidgets());

            return sipConvertFromNewType(sipRes,sipType_QList_0101QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_topLevelWidgets, doc_QApplication_topLevelWidgets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_desktop, "desktop() -> QDesktopWidget");

extern "C" {static PyObject *meth_QApplication_desktop(PyObject *, PyObject *);}
static PyObject *meth_QApplication_desktop(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QDesktopWidget*sipRes;

            sipRes =  ::QApplication::desktop();

            return sipConvertFromType(sipRes,sipType_QDesktopWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_desktop, doc_QApplication_desktop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_activePopupWidget, "activePopupWidget() -> QWidget");

extern "C" {static PyObject *meth_QApplication_activePopupWidget(PyObject *, PyObject *);}
static PyObject *meth_QApplication_activePopupWidget(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::activePopupWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_activePopupWidget, doc_QApplication_activePopupWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_activeModalWidget, "activeModalWidget() -> QWidget");

extern "C" {static PyObject *meth_QApplication_activeModalWidget(PyObject *, PyObject *);}
static PyObject *meth_QApplication_activeModalWidget(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::activeModalWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_activeModalWidget, doc_QApplication_activeModalWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_focusWidget, "focusWidget() -> QWidget");

extern "C" {static PyObject *meth_QApplication_focusWidget(PyObject *, PyObject *);}
static PyObject *meth_QApplication_focusWidget(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::focusWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_focusWidget, doc_QApplication_focusWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_activeWindow, "activeWindow() -> QWidget");

extern "C" {static PyObject *meth_QApplication_activeWindow(PyObject *, PyObject *);}
static PyObject *meth_QApplication_activeWindow(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::activeWindow();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_activeWindow, doc_QApplication_activeWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setActiveWindow, "setActiveWindow(QWidget)");

extern "C" {static PyObject *meth_QApplication_setActiveWindow(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setActiveWindow(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QWidget, &a0))
        {
             ::QApplication::setActiveWindow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setActiveWindow, doc_QApplication_setActiveWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_widgetAt, "widgetAt(QPoint) -> QWidget\n"
"widgetAt(int, int) -> QWidget");

extern "C" {static PyObject *meth_QApplication_widgetAt(PyObject *, PyObject *);}
static PyObject *meth_QApplication_widgetAt(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QPoint, &a0))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::widgetAt(*a0);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "ii", &a0, &a1))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::widgetAt(a0,a1);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_widgetAt, doc_QApplication_widgetAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_topLevelAt, "topLevelAt(QPoint) -> QWidget\n"
"topLevelAt(int, int) -> QWidget");

extern "C" {static PyObject *meth_QApplication_topLevelAt(PyObject *, PyObject *);}
static PyObject *meth_QApplication_topLevelAt(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QPoint, &a0))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::topLevelAt(*a0);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "ii", &a0, &a1))
        {
             ::QWidget*sipRes;

            sipRes =  ::QApplication::topLevelAt(a0,a1);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_topLevelAt, doc_QApplication_topLevelAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_beep, "beep()");

extern "C" {static PyObject *meth_QApplication_beep(PyObject *, PyObject *);}
static PyObject *meth_QApplication_beep(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QApplication::beep();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_beep, doc_QApplication_beep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_alert, "alert(QWidget, msecs: int = 0)");

extern "C" {static PyObject *meth_QApplication_alert(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QApplication_alert(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        int a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "J8|i", sipType_QWidget, &a0, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
             ::QApplication::alert(a0,a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_alert, doc_QApplication_alert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setCursorFlashTime, "setCursorFlashTime(int)");

extern "C" {static PyObject *meth_QApplication_setCursorFlashTime(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setCursorFlashTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setCursorFlashTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setCursorFlashTime, doc_QApplication_setCursorFlashTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_cursorFlashTime, "cursorFlashTime() -> int");

extern "C" {static PyObject *meth_QApplication_cursorFlashTime(PyObject *, PyObject *);}
static PyObject *meth_QApplication_cursorFlashTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::cursorFlashTime();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_cursorFlashTime, doc_QApplication_cursorFlashTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setDoubleClickInterval, "setDoubleClickInterval(int)");

extern "C" {static PyObject *meth_QApplication_setDoubleClickInterval(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setDoubleClickInterval(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setDoubleClickInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setDoubleClickInterval, doc_QApplication_setDoubleClickInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_doubleClickInterval, "doubleClickInterval() -> int");

extern "C" {static PyObject *meth_QApplication_doubleClickInterval(PyObject *, PyObject *);}
static PyObject *meth_QApplication_doubleClickInterval(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::doubleClickInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_doubleClickInterval, doc_QApplication_doubleClickInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setKeyboardInputInterval, "setKeyboardInputInterval(int)");

extern "C" {static PyObject *meth_QApplication_setKeyboardInputInterval(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setKeyboardInputInterval(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setKeyboardInputInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setKeyboardInputInterval, doc_QApplication_setKeyboardInputInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_keyboardInputInterval, "keyboardInputInterval() -> int");

extern "C" {static PyObject *meth_QApplication_keyboardInputInterval(PyObject *, PyObject *);}
static PyObject *meth_QApplication_keyboardInputInterval(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::keyboardInputInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_keyboardInputInterval, doc_QApplication_keyboardInputInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setWheelScrollLines, "setWheelScrollLines(int)");

extern "C" {static PyObject *meth_QApplication_setWheelScrollLines(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setWheelScrollLines(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setWheelScrollLines(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setWheelScrollLines, doc_QApplication_setWheelScrollLines);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_wheelScrollLines, "wheelScrollLines() -> int");

extern "C" {static PyObject *meth_QApplication_wheelScrollLines(PyObject *, PyObject *);}
static PyObject *meth_QApplication_wheelScrollLines(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::wheelScrollLines();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_wheelScrollLines, doc_QApplication_wheelScrollLines);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setGlobalStrut, "setGlobalStrut(QSize)");

extern "C" {static PyObject *meth_QApplication_setGlobalStrut(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setGlobalStrut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QSize, &a0))
        {
             ::QApplication::setGlobalStrut(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setGlobalStrut, doc_QApplication_setGlobalStrut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_globalStrut, "globalStrut() -> QSize");

extern "C" {static PyObject *meth_QApplication_globalStrut(PyObject *, PyObject *);}
static PyObject *meth_QApplication_globalStrut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize( ::QApplication::globalStrut());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_globalStrut, doc_QApplication_globalStrut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setStartDragTime, "setStartDragTime(int)");

extern "C" {static PyObject *meth_QApplication_setStartDragTime(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setStartDragTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setStartDragTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setStartDragTime, doc_QApplication_setStartDragTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_startDragTime, "startDragTime() -> int");

extern "C" {static PyObject *meth_QApplication_startDragTime(PyObject *, PyObject *);}
static PyObject *meth_QApplication_startDragTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::startDragTime();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_startDragTime, doc_QApplication_startDragTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setStartDragDistance, "setStartDragDistance(int)");

extern "C" {static PyObject *meth_QApplication_setStartDragDistance(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setStartDragDistance(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
             ::QApplication::setStartDragDistance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setStartDragDistance, doc_QApplication_setStartDragDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_startDragDistance, "startDragDistance() -> int");

extern "C" {static PyObject *meth_QApplication_startDragDistance(PyObject *, PyObject *);}
static PyObject *meth_QApplication_startDragDistance(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes =  ::QApplication::startDragDistance();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_startDragDistance, doc_QApplication_startDragDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_isEffectEnabled, "isEffectEnabled(Qt.UIEffect) -> bool");

extern "C" {static PyObject *meth_QApplication_isEffectEnabled(PyObject *, PyObject *);}
static PyObject *meth_QApplication_isEffectEnabled(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::UIEffect a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_Qt_UIEffect, &a0))
        {
            bool sipRes;

            sipRes =  ::QApplication::isEffectEnabled(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_isEffectEnabled, doc_QApplication_isEffectEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setEffectEnabled, "setEffectEnabled(Qt.UIEffect, enabled: bool = True)");

extern "C" {static PyObject *meth_QApplication_setEffectEnabled(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QApplication_setEffectEnabled(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::UIEffect a0;
        bool a1 = 1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "E|b", sipType_Qt_UIEffect, &a0, &a1))
        {
             ::QApplication::setEffectEnabled(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setEffectEnabled, doc_QApplication_setEffectEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_exec_, "exec_() -> int");

extern "C" {static PyObject *meth_QApplication_exec_(PyObject *, PyObject *);}
static PyObject *meth_QApplication_exec_(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipCallHook("__pyQtPreEventLoopHook__");

            Py_BEGIN_ALLOW_THREADS
            sipRes =  ::QApplication::exec();
            Py_END_ALLOW_THREADS


            sipCallHook("__pyQtPostEventLoopHook__");
            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_exec_, doc_QApplication_exec_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_exec, "exec() -> int");

extern "C" {static PyObject *meth_QApplication_exec(PyObject *, PyObject *);}
static PyObject *meth_QApplication_exec(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipCallHook("__pyQtPreEventLoopHook__");

            Py_BEGIN_ALLOW_THREADS
            sipRes =  ::QApplication::exec();
            Py_END_ALLOW_THREADS


            sipCallHook("__pyQtPostEventLoopHook__");
            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_exec, doc_QApplication_exec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_notify, "notify(self, QObject, QEvent) -> bool");

extern "C" {static PyObject *meth_QApplication_notify(PyObject *, PyObject *);}
static PyObject *meth_QApplication_notify(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QObject* a0;
         ::QEvent* a1;
         ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J8", &sipSelf, sipType_QApplication, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QApplication::notify(a0,a1) : sipCpp->notify(a0,a1));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_notify, doc_QApplication_notify);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_autoSipEnabled, "autoSipEnabled(self) -> bool");

extern "C" {static PyObject *meth_QApplication_autoSipEnabled(PyObject *, PyObject *);}
static PyObject *meth_QApplication_autoSipEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QApplication, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoSipEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_autoSipEnabled, doc_QApplication_autoSipEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_styleSheet, "styleSheet(self) -> str");

extern "C" {static PyObject *meth_QApplication_styleSheet(PyObject *, PyObject *);}
static PyObject *meth_QApplication_styleSheet(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QApplication, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->styleSheet());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_styleSheet, doc_QApplication_styleSheet);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_aboutQt, "aboutQt()");

extern "C" {static PyObject *meth_QApplication_aboutQt(PyObject *, PyObject *);}
static PyObject *meth_QApplication_aboutQt(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QApplication::aboutQt();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_aboutQt, doc_QApplication_aboutQt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_closeAllWindows, "closeAllWindows()");

extern "C" {static PyObject *meth_QApplication_closeAllWindows(PyObject *, PyObject *);}
static PyObject *meth_QApplication_closeAllWindows(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QApplication::closeAllWindows();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_closeAllWindows, doc_QApplication_closeAllWindows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setAutoSipEnabled, "setAutoSipEnabled(self, bool)");

extern "C" {static PyObject *meth_QApplication_setAutoSipEnabled(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setAutoSipEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QApplication, &sipCpp, &a0))
        {
            sipCpp->setAutoSipEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setAutoSipEnabled, doc_QApplication_setAutoSipEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_setStyleSheet, "setStyleSheet(self, str)");

extern "C" {static PyObject *meth_QApplication_setStyleSheet(PyObject *, PyObject *);}
static PyObject *meth_QApplication_setStyleSheet(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QApplication, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setStyleSheet(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_setStyleSheet, doc_QApplication_setStyleSheet);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QApplication_event, "event(self, QEvent) -> bool");

extern "C" {static PyObject *meth_QApplication_event(PyObject *, PyObject *);}
static PyObject *meth_QApplication_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
         ::QApplication *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QApplication, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QApplication::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QApplication, sipName_event, doc_QApplication_event);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QApplication(void *, const sipTypeDef *);}
static void *cast_QApplication(void *sipCppV, const sipTypeDef *targetType)
{
     ::QApplication *sipCpp = reinterpret_cast< ::QApplication *>(sipCppV);

    if (targetType == sipType_QGuiApplication)
        return static_cast< ::QGuiApplication *>(sipCpp);

    if (targetType == sipType_QCoreApplication)
        return static_cast< ::QCoreApplication *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QApplication(void *, int);}
static void release_QApplication(void *sipCppV, int)
{
     ::QApplication *sipCpp = reinterpret_cast< ::QApplication *>(sipCppV);

#line 231 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qapplication.sip"
        pyqt5_qtwidgets_cleanup_qobjects();
#line 1819 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"

    Py_BEGIN_ALLOW_THREADS

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();

    Py_END_ALLOW_THREADS
}


extern "C" {static void dealloc_QApplication(sipSimpleWrapper *);}
static void dealloc_QApplication(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQApplication *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QApplication(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QApplication(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QApplication(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQApplication *sipCpp = SIP_NULLPTR;

    {
        PyObject * a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "T", &PyList_Type, &a0))
        {
            int sipIsErr = 0;

#line 206 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qapplication.sip"
        // The Python interface is a list of argument strings that is modified.
        
        int argc;
        char **argv;
        
        // Convert the list.
        if ((argv = pyqt5_qtwidgets_from_argv_list(a0, argc)) == NULL)
            sipIsErr = 1;
        else
        {
            // Create it now the arguments are right.
            static int nargc;
            nargc = argc;
        
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQApplication(nargc, argv, QCoreApplication::ApplicationFlags);
            Py_END_ALLOW_THREADS
        
            // Now modify the original list.
            pyqt5_qtwidgets_update_argv_list(a0, argc, argv);
        }
#line 1879 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQApplication.cpp"

            if (sipIsErr)
            {
                if (sipUnused)
                {
                    Py_XDECREF(*sipUnused);
                }

                sipAddException(sipErrorFail, sipParseErr);
                return SIP_NULLPTR;
            }

            sipCpp->sipPySelf = sipSelf;

            sipCallHook("__pyQtQAppHook__");

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QApplication[] = {{18, 1, 1}};


static PyMethodDef methods_QApplication[] = {
    {SIP_MLNAME_CAST(sipName_aboutQt), meth_QApplication_aboutQt, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_aboutQt)},
    {SIP_MLNAME_CAST(sipName_activeModalWidget), meth_QApplication_activeModalWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_activeModalWidget)},
    {SIP_MLNAME_CAST(sipName_activePopupWidget), meth_QApplication_activePopupWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_activePopupWidget)},
    {SIP_MLNAME_CAST(sipName_activeWindow), meth_QApplication_activeWindow, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_activeWindow)},
    {SIP_MLNAME_CAST(sipName_alert), SIP_MLMETH_CAST(meth_QApplication_alert), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QApplication_alert)},
    {SIP_MLNAME_CAST(sipName_allWidgets), meth_QApplication_allWidgets, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_allWidgets)},
    {SIP_MLNAME_CAST(sipName_autoSipEnabled), meth_QApplication_autoSipEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_autoSipEnabled)},
    {SIP_MLNAME_CAST(sipName_beep), meth_QApplication_beep, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_beep)},
    {SIP_MLNAME_CAST(sipName_closeAllWindows), meth_QApplication_closeAllWindows, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_closeAllWindows)},
    {SIP_MLNAME_CAST(sipName_colorSpec), meth_QApplication_colorSpec, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_colorSpec)},
    {SIP_MLNAME_CAST(sipName_cursorFlashTime), meth_QApplication_cursorFlashTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_cursorFlashTime)},
    {SIP_MLNAME_CAST(sipName_desktop), meth_QApplication_desktop, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_desktop)},
    {SIP_MLNAME_CAST(sipName_doubleClickInterval), meth_QApplication_doubleClickInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_doubleClickInterval)},
    {SIP_MLNAME_CAST(sipName_event), meth_QApplication_event, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_event)},
    {SIP_MLNAME_CAST(sipName_exec), meth_QApplication_exec, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_exec)},
    {SIP_MLNAME_CAST(sipName_exec_), meth_QApplication_exec_, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_exec_)},
    {SIP_MLNAME_CAST(sipName_focusWidget), meth_QApplication_focusWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_focusWidget)},
    {SIP_MLNAME_CAST(sipName_font), meth_QApplication_font, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_font)},
    {SIP_MLNAME_CAST(sipName_fontMetrics), meth_QApplication_fontMetrics, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_fontMetrics)},
    {SIP_MLNAME_CAST(sipName_globalStrut), meth_QApplication_globalStrut, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_globalStrut)},
    {SIP_MLNAME_CAST(sipName_isEffectEnabled), meth_QApplication_isEffectEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_isEffectEnabled)},
    {SIP_MLNAME_CAST(sipName_keyboardInputInterval), meth_QApplication_keyboardInputInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_keyboardInputInterval)},
    {SIP_MLNAME_CAST(sipName_notify), meth_QApplication_notify, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_notify)},
    {SIP_MLNAME_CAST(sipName_palette), meth_QApplication_palette, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_palette)},
    {SIP_MLNAME_CAST(sipName_setActiveWindow), meth_QApplication_setActiveWindow, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setActiveWindow)},
    {SIP_MLNAME_CAST(sipName_setAutoSipEnabled), meth_QApplication_setAutoSipEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setAutoSipEnabled)},
    {SIP_MLNAME_CAST(sipName_setColorSpec), meth_QApplication_setColorSpec, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setColorSpec)},
    {SIP_MLNAME_CAST(sipName_setCursorFlashTime), meth_QApplication_setCursorFlashTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setCursorFlashTime)},
    {SIP_MLNAME_CAST(sipName_setDoubleClickInterval), meth_QApplication_setDoubleClickInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setDoubleClickInterval)},
    {SIP_MLNAME_CAST(sipName_setEffectEnabled), SIP_MLMETH_CAST(meth_QApplication_setEffectEnabled), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QApplication_setEffectEnabled)},
    {SIP_MLNAME_CAST(sipName_setFont), SIP_MLMETH_CAST(meth_QApplication_setFont), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QApplication_setFont)},
    {SIP_MLNAME_CAST(sipName_setGlobalStrut), meth_QApplication_setGlobalStrut, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setGlobalStrut)},
    {SIP_MLNAME_CAST(sipName_setKeyboardInputInterval), meth_QApplication_setKeyboardInputInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setKeyboardInputInterval)},
    {SIP_MLNAME_CAST(sipName_setPalette), SIP_MLMETH_CAST(meth_QApplication_setPalette), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QApplication_setPalette)},
    {SIP_MLNAME_CAST(sipName_setStartDragDistance), meth_QApplication_setStartDragDistance, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setStartDragDistance)},
    {SIP_MLNAME_CAST(sipName_setStartDragTime), meth_QApplication_setStartDragTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setStartDragTime)},
    {SIP_MLNAME_CAST(sipName_setStyle), meth_QApplication_setStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setStyle)},
    {SIP_MLNAME_CAST(sipName_setStyleSheet), meth_QApplication_setStyleSheet, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setStyleSheet)},
    {SIP_MLNAME_CAST(sipName_setWheelScrollLines), meth_QApplication_setWheelScrollLines, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setWheelScrollLines)},
    {SIP_MLNAME_CAST(sipName_setWindowIcon), meth_QApplication_setWindowIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_setWindowIcon)},
    {SIP_MLNAME_CAST(sipName_startDragDistance), meth_QApplication_startDragDistance, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_startDragDistance)},
    {SIP_MLNAME_CAST(sipName_startDragTime), meth_QApplication_startDragTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_startDragTime)},
    {SIP_MLNAME_CAST(sipName_style), meth_QApplication_style, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_style)},
    {SIP_MLNAME_CAST(sipName_styleSheet), meth_QApplication_styleSheet, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_styleSheet)},
    {SIP_MLNAME_CAST(sipName_topLevelAt), meth_QApplication_topLevelAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_topLevelAt)},
    {SIP_MLNAME_CAST(sipName_topLevelWidgets), meth_QApplication_topLevelWidgets, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_topLevelWidgets)},
    {SIP_MLNAME_CAST(sipName_wheelScrollLines), meth_QApplication_wheelScrollLines, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_wheelScrollLines)},
    {SIP_MLNAME_CAST(sipName_widgetAt), meth_QApplication_widgetAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_widgetAt)},
    {SIP_MLNAME_CAST(sipName_windowIcon), meth_QApplication_windowIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QApplication_windowIcon)}
};

static sipEnumMemberDef enummembers_QApplication[] = {
    {sipName_CustomColor, static_cast<int>( ::QApplication::CustomColor), 33},
    {sipName_ManyColor, static_cast<int>( ::QApplication::ManyColor), 33},
    {sipName_NormalColor, static_cast<int>( ::QApplication::NormalColor), 33},
};

PyDoc_STRVAR(doc_QApplication, "\1QApplication(List[str])");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QApplication[] = {
    {"focusChanged(QWidget*,QWidget*)", "\1focusChanged(self, QWidget, QWidget)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QApplication = {
    & ::QApplication::staticMetaObject,
    0,
    signals_QApplication,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QApplication = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QApplication,
        {SIP_NULLPTR},
        &plugin_QApplication
    },
    {
        sipNameNr_QApplication,
        {0, 0, 1},
        49, methods_QApplication,
        3, enummembers_QApplication,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QApplication,
    -1,
    -1,
    supers_QApplication,
    SIP_NULLPTR,
    init_type_QApplication,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QApplication,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QApplication,
    cast_QApplication,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
