/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 388 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"

#line 388 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 388 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qtabbar.sip"
#include <qtabbar.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyleOptionTab.cpp"


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyleOptionTab(void *, const sipTypeDef *);}
static void *cast_QStyleOptionTab(void *sipCppV, const sipTypeDef *targetType)
{
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipCppV);

    if (targetType == sipType_QStyleOption)
        return static_cast< ::QStyleOption *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyleOptionTab(void *, int);}
static void release_QStyleOptionTab(void *sipCppV, int)
{
    delete reinterpret_cast< ::QStyleOptionTab *>(sipCppV);
}


extern "C" {static void *array_QStyleOptionTab(Py_ssize_t);}
static void *array_QStyleOptionTab(Py_ssize_t sipNrElem)
{
    return new  ::QStyleOptionTab[sipNrElem];
}


extern "C" {static void assign_QStyleOptionTab(void *, SIP_SSIZE_T, void *);}
static void assign_QStyleOptionTab(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QStyleOptionTab *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QStyleOptionTab *>(sipSrc);
}


extern "C" {static void *copy_QStyleOptionTab(const void *, SIP_SSIZE_T);}
static void *copy_QStyleOptionTab(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QStyleOptionTab(reinterpret_cast<const  ::QStyleOptionTab *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QStyleOptionTab(sipSimpleWrapper *);}
static void dealloc_QStyleOptionTab(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyleOptionTab(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QStyleOptionTab(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStyleOptionTab(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QStyleOptionTab *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QStyleOptionTab();

            return sipCpp;
        }
    }

    {
        const  ::QStyleOptionTab* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QStyleOptionTab, &a0))
        {
            sipCpp = new  ::QStyleOptionTab(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyleOptionTab[] = {{315, 255, 1}};

static sipEnumMemberDef enummembers_QStyleOptionTab[] = {
    {sipName_Beginning, static_cast<int>( ::QStyleOptionTab::Beginning), 381},
    {sipName_End, static_cast<int>( ::QStyleOptionTab::End), 381},
    {sipName_HasFrame, static_cast<int>( ::QStyleOptionTab::HasFrame), 379},
    {sipName_LeftCornerWidget, static_cast<int>( ::QStyleOptionTab::LeftCornerWidget), 374},
    {sipName_Middle, static_cast<int>( ::QStyleOptionTab::Middle), 381},
    {sipName_NextIsSelected, static_cast<int>( ::QStyleOptionTab::NextIsSelected), 376},
    {sipName_NoCornerWidgets, static_cast<int>( ::QStyleOptionTab::NoCornerWidgets), 374},
    {sipName_None_, static_cast<int>( ::QStyleOptionTab::None), 379},
    {sipName_NotAdjacent, static_cast<int>( ::QStyleOptionTab::NotAdjacent), 376},
    {sipName_OnlyOneTab, static_cast<int>( ::QStyleOptionTab::OnlyOneTab), 381},
    {sipName_PreviousIsSelected, static_cast<int>( ::QStyleOptionTab::PreviousIsSelected), 376},
    {sipName_RightCornerWidget, static_cast<int>( ::QStyleOptionTab::RightCornerWidget), 374},
    {sipName_Type, static_cast<int>( ::QStyleOptionTab::Type), 377},
    {sipName_Version, static_cast<int>( ::QStyleOptionTab::Version), 378},
};


extern "C" {static PyObject *varget_QStyleOptionTab_cornerWidgets(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_cornerWidgets(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QStyleOptionTab::CornerWidgets*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -103);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->cornerWidgets;

    sipPy = sipConvertFromType(sipVal, sipType_QStyleOptionTab_CornerWidgets, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -102, sipPySelf);
        sipKeepReference(sipPySelf, -103, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_cornerWidgets(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_cornerWidgets(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QStyleOptionTab::CornerWidgets*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QStyleOptionTab::CornerWidgets *>(sipForceConvertToType(sipPy, sipType_QStyleOptionTab_CornerWidgets, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->cornerWidgets = *sipVal;

    sipReleaseType(sipVal, sipType_QStyleOptionTab_CornerWidgets, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_documentMode(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_documentMode(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipCpp->documentMode;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionTab_documentMode(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_documentMode(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->documentMode = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_features(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_features(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QStyleOptionTab::TabFeatures*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -105);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->features;

    sipPy = sipConvertFromType(sipVal, sipType_QStyleOptionTab_TabFeatures, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -104, sipPySelf);
        sipKeepReference(sipPySelf, -105, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_features(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_features(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QStyleOptionTab::TabFeatures*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QStyleOptionTab::TabFeatures *>(sipForceConvertToType(sipPy, sipType_QStyleOptionTab_TabFeatures, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->features = *sipVal;

    sipReleaseType(sipVal, sipType_QStyleOptionTab_TabFeatures, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_icon(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_icon(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QIcon*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -106);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->icon;

    sipPy = sipConvertFromType(sipVal, sipType_QIcon, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -19, sipPySelf);
        sipKeepReference(sipPySelf, -106, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_icon(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_icon(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QIcon*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QIcon *>(sipForceConvertToType(sipPy, sipType_QIcon, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->icon = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_iconSize(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_iconSize(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -107);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->iconSize;

    sipPy = sipConvertFromType(sipVal, sipType_QSize, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -29, sipPySelf);
        sipKeepReference(sipPySelf, -107, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_iconSize(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_iconSize(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QSize *>(sipForceConvertToType(sipPy, sipType_QSize, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->iconSize = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_leftButtonSize(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_leftButtonSize(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -108);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->leftButtonSize;

    sipPy = sipConvertFromType(sipVal, sipType_QSize, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -30, sipPySelf);
        sipKeepReference(sipPySelf, -108, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_leftButtonSize(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_leftButtonSize(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QSize *>(sipForceConvertToType(sipPy, sipType_QSize, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->leftButtonSize = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_position(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_position(void *sipSelf, PyObject *, PyObject *)
{
     ::QStyleOptionTab::TabPosition sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipCpp->position;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QStyleOptionTab_TabPosition);
}


extern "C" {static int varset_QStyleOptionTab_position(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_position(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QStyleOptionTab::TabPosition sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = ( ::QStyleOptionTab::TabPosition)sipConvertToEnum(sipPy, sipType_QStyleOptionTab_TabPosition);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->position = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_rightButtonSize(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_rightButtonSize(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -109);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->rightButtonSize;

    sipPy = sipConvertFromType(sipVal, sipType_QSize, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -31, sipPySelf);
        sipKeepReference(sipPySelf, -109, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QStyleOptionTab_rightButtonSize(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_rightButtonSize(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QSize*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QSize *>(sipForceConvertToType(sipPy, sipType_QSize, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->rightButtonSize = *sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_row(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_row(void *sipSelf, PyObject *, PyObject *)
{
    int sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipCpp->row;

    return SIPLong_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionTab_row(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_row(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipLong_AsInt(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->row = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_selectedPosition(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_selectedPosition(void *sipSelf, PyObject *, PyObject *)
{
     ::QStyleOptionTab::SelectedPosition sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipCpp->selectedPosition;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QStyleOptionTab_SelectedPosition);
}


extern "C" {static int varset_QStyleOptionTab_selectedPosition(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_selectedPosition(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QStyleOptionTab::SelectedPosition sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = ( ::QStyleOptionTab::SelectedPosition)sipConvertToEnum(sipPy, sipType_QStyleOptionTab_SelectedPosition);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->selectedPosition = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_shape(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_shape(void *sipSelf, PyObject *, PyObject *)
{
     ::QTabBar::Shape sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = sipCpp->shape;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QTabBar_Shape);
}


extern "C" {static int varset_QStyleOptionTab_shape(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_shape(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QTabBar::Shape sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = ( ::QTabBar::Shape)sipConvertToEnum(sipPy, sipType_QTabBar_Shape);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->shape = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionTab_text(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionTab_text(void *sipSelf, PyObject *, PyObject *)
{
     ::QString*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    sipVal = &sipCpp->text;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QStyleOptionTab_text(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionTab_text(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QString*sipVal;
     ::QStyleOptionTab *sipCpp = reinterpret_cast< ::QStyleOptionTab *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->text = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}

sipVariableDef variables_QStyleOptionTab[] = {
    {InstanceVariable, sipName_cornerWidgets, (PyMethodDef *)varget_QStyleOptionTab_cornerWidgets, (PyMethodDef *)varset_QStyleOptionTab_cornerWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_documentMode, (PyMethodDef *)varget_QStyleOptionTab_documentMode, (PyMethodDef *)varset_QStyleOptionTab_documentMode, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_features, (PyMethodDef *)varget_QStyleOptionTab_features, (PyMethodDef *)varset_QStyleOptionTab_features, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_icon, (PyMethodDef *)varget_QStyleOptionTab_icon, (PyMethodDef *)varset_QStyleOptionTab_icon, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_iconSize, (PyMethodDef *)varget_QStyleOptionTab_iconSize, (PyMethodDef *)varset_QStyleOptionTab_iconSize, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_leftButtonSize, (PyMethodDef *)varget_QStyleOptionTab_leftButtonSize, (PyMethodDef *)varset_QStyleOptionTab_leftButtonSize, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_position, (PyMethodDef *)varget_QStyleOptionTab_position, (PyMethodDef *)varset_QStyleOptionTab_position, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_rightButtonSize, (PyMethodDef *)varget_QStyleOptionTab_rightButtonSize, (PyMethodDef *)varset_QStyleOptionTab_rightButtonSize, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_row, (PyMethodDef *)varget_QStyleOptionTab_row, (PyMethodDef *)varset_QStyleOptionTab_row, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_selectedPosition, (PyMethodDef *)varget_QStyleOptionTab_selectedPosition, (PyMethodDef *)varset_QStyleOptionTab_selectedPosition, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_shape, (PyMethodDef *)varget_QStyleOptionTab_shape, (PyMethodDef *)varset_QStyleOptionTab_shape, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_text, (PyMethodDef *)varget_QStyleOptionTab_text, (PyMethodDef *)varset_QStyleOptionTab_text, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QStyleOptionTab, "\1QStyleOptionTab()\n"
"QStyleOptionTab(QStyleOptionTab)");


static pyqt5ClassPluginDef plugin_QStyleOptionTab = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyleOptionTab,
        {SIP_NULLPTR},
        &plugin_QStyleOptionTab
    },
    {
        sipNameNr_QStyleOptionTab,
        {0, 0, 1},
        0, SIP_NULLPTR,
        14, enummembers_QStyleOptionTab,
        12, variables_QStyleOptionTab,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStyleOptionTab,
    -1,
    -1,
    supers_QStyleOptionTab,
    SIP_NULLPTR,
    init_type_QStyleOptionTab,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QStyleOptionTab,
    assign_QStyleOptionTab,
    array_QStyleOptionTab,
    copy_QStyleOptionTab,
    release_QStyleOptionTab,
    cast_QStyleOptionTab,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
