/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qtimeline.sip"
#include <qtimeline.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qeasingcurve.sip"
#include <qeasingcurve.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 235 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 247 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 27 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 149 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipQtCoreQTimeLine.cpp"


class sipQTimeLine : public  ::QTimeLine
{
public:
    sipQTimeLine(int, ::QObject*);
    virtual ~sipQTimeLine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
     ::qreal valueForTime(int) const SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTimeLine(const sipQTimeLine &);
    sipQTimeLine &operator = (const sipQTimeLine &);

    char sipPyMethods[8];
};

sipQTimeLine::sipQTimeLine(int a0, ::QObject*a1):  ::QTimeLine(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTimeLine::~sipQTimeLine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQTimeLine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf,sipType_QTimeLine);

    return  ::QTimeLine::metaObject();
}

int sipQTimeLine::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QTimeLine::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf,sipType_QTimeLine,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQTimeLine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QTimeLine, _clname, &sipCpp) ? sipCpp :  ::QTimeLine::qt_metacast(_clname));
}

 ::qreal sipQTimeLine::valueForTime(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,SIP_NULLPTR,sipName_valueForTime);

    if (!sipMeth)
        return  ::QTimeLine::valueForTime(a0);

    extern  ::qreal sipVH_QtCore_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtCore_65(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQTimeLine::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QTimeLine::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQTimeLine::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QTimeLine::eventFilter(a0,a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

void sipQTimeLine::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QTimeLine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQTimeLine::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QTimeLine::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQTimeLine::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QTimeLine::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQTimeLine::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QTimeLine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQTimeLine::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QTimeLine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QTimeLine_state, "state(self) -> QTimeLine.State");

extern "C" {static PyObject *meth_QTimeLine_state(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
             ::QTimeLine::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTimeLine_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_state, doc_QTimeLine_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_loopCount, "loopCount(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_loopCount(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_loopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loopCount();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_loopCount, doc_QTimeLine_loopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setLoopCount, "setLoopCount(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setLoopCount(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setLoopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setLoopCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setLoopCount, doc_QTimeLine_setLoopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_direction, "direction(self) -> QTimeLine.Direction");

extern "C" {static PyObject *meth_QTimeLine_direction(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_direction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
             ::QTimeLine::Direction sipRes;

            sipRes = sipCpp->direction();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTimeLine_Direction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_direction, doc_QTimeLine_direction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setDirection, "setDirection(self, QTimeLine.Direction)");

extern "C" {static PyObject *meth_QTimeLine_setDirection(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine::Direction a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTimeLine, &sipCpp, sipType_QTimeLine_Direction, &a0))
        {
            sipCpp->setDirection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setDirection, doc_QTimeLine_setDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_duration(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->duration();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_duration, doc_QTimeLine_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setDuration, "setDuration(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setDuration(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setDuration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setDuration, doc_QTimeLine_setDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_startFrame, "startFrame(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_startFrame(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_startFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startFrame();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_startFrame, doc_QTimeLine_startFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setStartFrame, "setStartFrame(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setStartFrame(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setStartFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setStartFrame(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setStartFrame, doc_QTimeLine_setStartFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_endFrame, "endFrame(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_endFrame(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_endFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->endFrame();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_endFrame, doc_QTimeLine_endFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setEndFrame, "setEndFrame(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setEndFrame(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setEndFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setEndFrame(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setEndFrame, doc_QTimeLine_setEndFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setFrameRange, "setFrameRange(self, int, int)");

extern "C" {static PyObject *meth_QTimeLine_setFrameRange(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setFrameRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTimeLine, &sipCpp, &a0, &a1))
        {
            sipCpp->setFrameRange(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setFrameRange, doc_QTimeLine_setFrameRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_updateInterval, "updateInterval(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_updateInterval(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_updateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->updateInterval();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_updateInterval, doc_QTimeLine_updateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setUpdateInterval, "setUpdateInterval(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setUpdateInterval(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setUpdateInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setUpdateInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setUpdateInterval, doc_QTimeLine_setUpdateInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_curveShape, "curveShape(self) -> QTimeLine.CurveShape");

extern "C" {static PyObject *meth_QTimeLine_curveShape(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_curveShape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
             ::QTimeLine::CurveShape sipRes;

            sipRes = sipCpp->curveShape();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTimeLine_CurveShape);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_curveShape, doc_QTimeLine_curveShape);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setCurveShape, "setCurveShape(self, QTimeLine.CurveShape)");

extern "C" {static PyObject *meth_QTimeLine_setCurveShape(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setCurveShape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine::CurveShape a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTimeLine, &sipCpp, sipType_QTimeLine_CurveShape, &a0))
        {
            sipCpp->setCurveShape(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setCurveShape, doc_QTimeLine_setCurveShape);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_currentTime, "currentTime(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_currentTime(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_currentTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentTime();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_currentTime, doc_QTimeLine_currentTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_currentFrame, "currentFrame(self) -> int");

extern "C" {static PyObject *meth_QTimeLine_currentFrame(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_currentFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentFrame();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_currentFrame, doc_QTimeLine_currentFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_currentValue, "currentValue(self) -> float");

extern "C" {static PyObject *meth_QTimeLine_currentValue(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_currentValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->currentValue();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_currentValue, doc_QTimeLine_currentValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_frameForTime, "frameForTime(self, int) -> int");

extern "C" {static PyObject *meth_QTimeLine_frameForTime(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_frameForTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->frameForTime(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_frameForTime, doc_QTimeLine_frameForTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_valueForTime, "valueForTime(self, int) -> float");

extern "C" {static PyObject *meth_QTimeLine_valueForTime(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_valueForTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
             ::qreal sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QTimeLine::valueForTime(a0) : sipCpp->valueForTime(a0));

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_valueForTime, doc_QTimeLine_valueForTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_resume, "resume(self)");

extern "C" {static PyObject *meth_QTimeLine_resume(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            sipCpp->resume();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_resume, doc_QTimeLine_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setCurrentTime, "setCurrentTime(self, int)");

extern "C" {static PyObject *meth_QTimeLine_setCurrentTime(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setCurrentTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setCurrentTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setCurrentTime, doc_QTimeLine_setCurrentTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setPaused, "setPaused(self, bool)");

extern "C" {static PyObject *meth_QTimeLine_setPaused(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setPaused(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QTimeLine, &sipCpp, &a0))
        {
            sipCpp->setPaused(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setPaused, doc_QTimeLine_setPaused);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_start, "start(self)");

extern "C" {static PyObject *meth_QTimeLine_start(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_start, doc_QTimeLine_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_stop, "stop(self)");

extern "C" {static PyObject *meth_QTimeLine_stop(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_stop, doc_QTimeLine_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_toggleDirection, "toggleDirection(self)");

extern "C" {static PyObject *meth_QTimeLine_toggleDirection(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_toggleDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
            sipCpp->toggleDirection();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_toggleDirection, doc_QTimeLine_toggleDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_timerEvent, "timerEvent(self, QTimerEvent)");

extern "C" {static PyObject *meth_QTimeLine_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QTimerEvent* a0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QTimeLine, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QTimeLine::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_timerEvent, doc_QTimeLine_timerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_easingCurve, "easingCurve(self) -> QEasingCurve");

extern "C" {static PyObject *meth_QTimeLine_easingCurve(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_easingCurve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTimeLine, &sipCpp))
        {
             ::QEasingCurve*sipRes;

            sipRes = new  ::QEasingCurve(sipCpp->easingCurve());

            return sipConvertFromNewType(sipRes,sipType_QEasingCurve,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_easingCurve, doc_QTimeLine_easingCurve);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTimeLine_setEasingCurve, "setEasingCurve(self, Union[QEasingCurve, QEasingCurve.Type])");

extern "C" {static PyObject *meth_QTimeLine_setEasingCurve(PyObject *, PyObject *);}
static PyObject *meth_QTimeLine_setEasingCurve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QEasingCurve* a0;
        int a0State = 0;
         ::QTimeLine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTimeLine, &sipCpp, sipType_QEasingCurve, &a0, &a0State))
        {
            sipCpp->setEasingCurve(*a0);
            sipReleaseType(const_cast< ::QEasingCurve *>(a0),sipType_QEasingCurve,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTimeLine, sipName_setEasingCurve, doc_QTimeLine_setEasingCurve);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTimeLine(void *, const sipTypeDef *);}
static void *cast_QTimeLine(void *sipCppV, const sipTypeDef *targetType)
{
     ::QTimeLine *sipCpp = reinterpret_cast< ::QTimeLine *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTimeLine(void *, int);}
static void release_QTimeLine(void *sipCppV, int)
{
     ::QTimeLine *sipCpp = reinterpret_cast< ::QTimeLine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QTimeLine(Py_ssize_t);}
static void *array_QTimeLine(Py_ssize_t sipNrElem)
{
    return new  ::QTimeLine[sipNrElem];
}


extern "C" {static void dealloc_QTimeLine(sipSimpleWrapper *);}
static void dealloc_QTimeLine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTimeLine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTimeLine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTimeLine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTimeLine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQTimeLine *sipCpp = SIP_NULLPTR;

    {
        int a0 = 1000;
         ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_duration,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|iJH", &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQTimeLine(a0,a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTimeLine[] = {{191, 255, 1}};


static PyMethodDef methods_QTimeLine[] = {
    {SIP_MLNAME_CAST(sipName_currentFrame), meth_QTimeLine_currentFrame, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_currentFrame)},
    {SIP_MLNAME_CAST(sipName_currentTime), meth_QTimeLine_currentTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_currentTime)},
    {SIP_MLNAME_CAST(sipName_currentValue), meth_QTimeLine_currentValue, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_currentValue)},
    {SIP_MLNAME_CAST(sipName_curveShape), meth_QTimeLine_curveShape, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_curveShape)},
    {SIP_MLNAME_CAST(sipName_direction), meth_QTimeLine_direction, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_direction)},
    {SIP_MLNAME_CAST(sipName_duration), meth_QTimeLine_duration, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_duration)},
    {SIP_MLNAME_CAST(sipName_easingCurve), meth_QTimeLine_easingCurve, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_easingCurve)},
    {SIP_MLNAME_CAST(sipName_endFrame), meth_QTimeLine_endFrame, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_endFrame)},
    {SIP_MLNAME_CAST(sipName_frameForTime), meth_QTimeLine_frameForTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_frameForTime)},
    {SIP_MLNAME_CAST(sipName_loopCount), meth_QTimeLine_loopCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_loopCount)},
    {SIP_MLNAME_CAST(sipName_resume), meth_QTimeLine_resume, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_resume)},
    {SIP_MLNAME_CAST(sipName_setCurrentTime), meth_QTimeLine_setCurrentTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setCurrentTime)},
    {SIP_MLNAME_CAST(sipName_setCurveShape), meth_QTimeLine_setCurveShape, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setCurveShape)},
    {SIP_MLNAME_CAST(sipName_setDirection), meth_QTimeLine_setDirection, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setDirection)},
    {SIP_MLNAME_CAST(sipName_setDuration), meth_QTimeLine_setDuration, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setDuration)},
    {SIP_MLNAME_CAST(sipName_setEasingCurve), meth_QTimeLine_setEasingCurve, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setEasingCurve)},
    {SIP_MLNAME_CAST(sipName_setEndFrame), meth_QTimeLine_setEndFrame, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setEndFrame)},
    {SIP_MLNAME_CAST(sipName_setFrameRange), meth_QTimeLine_setFrameRange, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setFrameRange)},
    {SIP_MLNAME_CAST(sipName_setLoopCount), meth_QTimeLine_setLoopCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setLoopCount)},
    {SIP_MLNAME_CAST(sipName_setPaused), meth_QTimeLine_setPaused, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setPaused)},
    {SIP_MLNAME_CAST(sipName_setStartFrame), meth_QTimeLine_setStartFrame, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setStartFrame)},
    {SIP_MLNAME_CAST(sipName_setUpdateInterval), meth_QTimeLine_setUpdateInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_setUpdateInterval)},
    {SIP_MLNAME_CAST(sipName_start), meth_QTimeLine_start, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_start)},
    {SIP_MLNAME_CAST(sipName_startFrame), meth_QTimeLine_startFrame, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_startFrame)},
    {SIP_MLNAME_CAST(sipName_state), meth_QTimeLine_state, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_state)},
    {SIP_MLNAME_CAST(sipName_stop), meth_QTimeLine_stop, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_stop)},
    {SIP_MLNAME_CAST(sipName_timerEvent), meth_QTimeLine_timerEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_timerEvent)},
    {SIP_MLNAME_CAST(sipName_toggleDirection), meth_QTimeLine_toggleDirection, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_toggleDirection)},
    {SIP_MLNAME_CAST(sipName_updateInterval), meth_QTimeLine_updateInterval, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_updateInterval)},
    {SIP_MLNAME_CAST(sipName_valueForTime), meth_QTimeLine_valueForTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QTimeLine_valueForTime)}
};

static sipEnumMemberDef enummembers_QTimeLine[] = {
    {sipName_Backward, static_cast<int>( ::QTimeLine::Backward), 300},
    {sipName_CosineCurve, static_cast<int>( ::QTimeLine::CosineCurve), 299},
    {sipName_EaseInCurve, static_cast<int>( ::QTimeLine::EaseInCurve), 299},
    {sipName_EaseInOutCurve, static_cast<int>( ::QTimeLine::EaseInOutCurve), 299},
    {sipName_EaseOutCurve, static_cast<int>( ::QTimeLine::EaseOutCurve), 299},
    {sipName_Forward, static_cast<int>( ::QTimeLine::Forward), 300},
    {sipName_LinearCurve, static_cast<int>( ::QTimeLine::LinearCurve), 299},
    {sipName_NotRunning, static_cast<int>( ::QTimeLine::NotRunning), 301},
    {sipName_Paused, static_cast<int>( ::QTimeLine::Paused), 301},
    {sipName_Running, static_cast<int>( ::QTimeLine::Running), 301},
    {sipName_SineCurve, static_cast<int>( ::QTimeLine::SineCurve), 299},
};

PyDoc_STRVAR(doc_QTimeLine, "\1QTimeLine(duration: int = 1000, parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QTimeLine[] = {
    {"valueChanged(qreal)", "\1valueChanged(self, float)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QTimeLine::State)", "\1stateChanged(self, QTimeLine.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"frameChanged(int)", "\1frameChanged(self, int)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QTimeLine = {
    & ::QTimeLine::staticMetaObject,
    0,
    signals_QTimeLine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QTimeLine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTimeLine,
        {SIP_NULLPTR},
        &plugin_QTimeLine
    },
    {
        sipNameNr_QTimeLine,
        {0, 0, 1},
        30, methods_QTimeLine,
        11, enummembers_QTimeLine,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTimeLine,
    -1,
    -1,
    supers_QTimeLine,
    SIP_NULLPTR,
    init_type_QTimeLine,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QTimeLine,
    SIP_NULLPTR,
    array_QTimeLine,
    SIP_NULLPTR,
    release_QTimeLine,
    cast_QTimeLine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
