/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 619 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQDragLeaveEvent.cpp"

#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQDragLeaveEvent.cpp"


class sipQDragLeaveEvent : public  ::QDragLeaveEvent
{
public:
    sipQDragLeaveEvent();
    sipQDragLeaveEvent(const  ::QDragLeaveEvent&);
    ~sipQDragLeaveEvent();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDragLeaveEvent(const sipQDragLeaveEvent &);
    sipQDragLeaveEvent &operator = (const sipQDragLeaveEvent &);
};

sipQDragLeaveEvent::sipQDragLeaveEvent():  ::QDragLeaveEvent(), sipPySelf(SIP_NULLPTR)
{
}

sipQDragLeaveEvent::sipQDragLeaveEvent(const  ::QDragLeaveEvent& a0):  ::QDragLeaveEvent(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQDragLeaveEvent::~sipQDragLeaveEvent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDragLeaveEvent(void *, const sipTypeDef *);}
static void *cast_QDragLeaveEvent(void *sipCppV, const sipTypeDef *targetType)
{
     ::QDragLeaveEvent *sipCpp = reinterpret_cast< ::QDragLeaveEvent *>(sipCppV);

    if (targetType == sipType_QEvent)
        return static_cast< ::QEvent *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDragLeaveEvent(void *, int);}
static void release_QDragLeaveEvent(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDragLeaveEvent *>(sipCppV);
    else
        delete reinterpret_cast< ::QDragLeaveEvent *>(sipCppV);
}


extern "C" {static void *array_QDragLeaveEvent(Py_ssize_t);}
static void *array_QDragLeaveEvent(Py_ssize_t sipNrElem)
{
    return new  ::QDragLeaveEvent[sipNrElem];
}


extern "C" {static void assign_QDragLeaveEvent(void *, SIP_SSIZE_T, void *);}
static void assign_QDragLeaveEvent(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDragLeaveEvent *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDragLeaveEvent *>(sipSrc);
}


extern "C" {static void *copy_QDragLeaveEvent(const void *, SIP_SSIZE_T);}
static void *copy_QDragLeaveEvent(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QDragLeaveEvent(reinterpret_cast<const  ::QDragLeaveEvent *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDragLeaveEvent(sipSimpleWrapper *);}
static void dealloc_QDragLeaveEvent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDragLeaveEvent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDragLeaveEvent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDragLeaveEvent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDragLeaveEvent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDragLeaveEvent *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDragLeaveEvent();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QDragLeaveEvent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDragLeaveEvent, &a0))
        {
            sipCpp = new sipQDragLeaveEvent(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDragLeaveEvent[] = {{6, 0, 1}};

PyDoc_STRVAR(doc_QDragLeaveEvent, "\1QDragLeaveEvent()\n"
"QDragLeaveEvent(QDragLeaveEvent)");


static pyqt5ClassPluginDef plugin_QDragLeaveEvent = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QDragLeaveEvent = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDragLeaveEvent,
        {SIP_NULLPTR},
        &plugin_QDragLeaveEvent
    },
    {
        sipNameNr_QDragLeaveEvent,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDragLeaveEvent,
    -1,
    -1,
    supers_QDragLeaveEvent,
    SIP_NULLPTR,
    init_type_QDragLeaveEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QDragLeaveEvent,
    assign_QDragLeaveEvent,
    array_QDragLeaveEvent,
    copy_QDragLeaveEvent,
    release_QDragLeaveEvent,
    cast_QDragLeaveEvent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
