/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 650 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 555 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 318 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpen.sip"
#include <qpen.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 532 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 618 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 500 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 433 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 146 "sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 28 "sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQTextTableCellFormat.cpp"


PyDoc_STRVAR(doc_QTextTableCellFormat_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QTextTableCellFormat_isValid(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_isValid, doc_QTextTableCellFormat_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setTopPadding, "setTopPadding(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setTopPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setTopPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setTopPadding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setTopPadding, doc_QTextTableCellFormat_setTopPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_topPadding, "topPadding(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_topPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_topPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->topPadding();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_topPadding, doc_QTextTableCellFormat_topPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBottomPadding, "setBottomPadding(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBottomPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBottomPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setBottomPadding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBottomPadding, doc_QTextTableCellFormat_setBottomPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_bottomPadding, "bottomPadding(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_bottomPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_bottomPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->bottomPadding();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_bottomPadding, doc_QTextTableCellFormat_bottomPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setLeftPadding, "setLeftPadding(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setLeftPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setLeftPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setLeftPadding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setLeftPadding, doc_QTextTableCellFormat_setLeftPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_leftPadding, "leftPadding(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_leftPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_leftPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->leftPadding();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_leftPadding, doc_QTextTableCellFormat_leftPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setRightPadding, "setRightPadding(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setRightPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setRightPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setRightPadding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setRightPadding, doc_QTextTableCellFormat_setRightPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_rightPadding, "rightPadding(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_rightPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_rightPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->rightPadding();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_rightPadding, doc_QTextTableCellFormat_rightPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setPadding, "setPadding(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setPadding(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setPadding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setPadding(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setPadding, doc_QTextTableCellFormat_setPadding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setTopBorder, "setTopBorder(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setTopBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setTopBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setTopBorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setTopBorder, doc_QTextTableCellFormat_setTopBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_topBorder, "topBorder(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_topBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_topBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->topBorder();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_topBorder, doc_QTextTableCellFormat_topBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBottomBorder, "setBottomBorder(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBottomBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBottomBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setBottomBorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBottomBorder, doc_QTextTableCellFormat_setBottomBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_bottomBorder, "bottomBorder(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_bottomBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_bottomBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->bottomBorder();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_bottomBorder, doc_QTextTableCellFormat_bottomBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setLeftBorder, "setLeftBorder(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setLeftBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setLeftBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setLeftBorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setLeftBorder, doc_QTextTableCellFormat_setLeftBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_leftBorder, "leftBorder(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_leftBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_leftBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->leftBorder();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_leftBorder, doc_QTextTableCellFormat_leftBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setRightBorder, "setRightBorder(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setRightBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setRightBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setRightBorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setRightBorder, doc_QTextTableCellFormat_setRightBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_rightBorder, "rightBorder(self) -> float");

extern "C" {static PyObject *meth_QTextTableCellFormat_rightBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_rightBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->rightBorder();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_rightBorder, doc_QTextTableCellFormat_rightBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBorder, "setBorder(self, float)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBorder(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBorder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, &a0))
        {
            sipCpp->setBorder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBorder, doc_QTextTableCellFormat_setBorder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setTopBorderStyle, "setTopBorderStyle(self, QTextFrameFormat.BorderStyle)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setTopBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setTopBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFrameFormat::BorderStyle a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QTextFrameFormat_BorderStyle, &a0))
        {
            sipCpp->setTopBorderStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setTopBorderStyle, doc_QTextTableCellFormat_setTopBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_topBorderStyle, "topBorderStyle(self) -> QTextFrameFormat.BorderStyle");

extern "C" {static PyObject *meth_QTextTableCellFormat_topBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_topBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QTextFrameFormat::BorderStyle sipRes;

            sipRes = sipCpp->topBorderStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTextFrameFormat_BorderStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_topBorderStyle, doc_QTextTableCellFormat_topBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBottomBorderStyle, "setBottomBorderStyle(self, QTextFrameFormat.BorderStyle)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBottomBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBottomBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFrameFormat::BorderStyle a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QTextFrameFormat_BorderStyle, &a0))
        {
            sipCpp->setBottomBorderStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBottomBorderStyle, doc_QTextTableCellFormat_setBottomBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_bottomBorderStyle, "bottomBorderStyle(self) -> QTextFrameFormat.BorderStyle");

extern "C" {static PyObject *meth_QTextTableCellFormat_bottomBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_bottomBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QTextFrameFormat::BorderStyle sipRes;

            sipRes = sipCpp->bottomBorderStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTextFrameFormat_BorderStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_bottomBorderStyle, doc_QTextTableCellFormat_bottomBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setLeftBorderStyle, "setLeftBorderStyle(self, QTextFrameFormat.BorderStyle)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setLeftBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setLeftBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFrameFormat::BorderStyle a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QTextFrameFormat_BorderStyle, &a0))
        {
            sipCpp->setLeftBorderStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setLeftBorderStyle, doc_QTextTableCellFormat_setLeftBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_leftBorderStyle, "leftBorderStyle(self) -> QTextFrameFormat.BorderStyle");

extern "C" {static PyObject *meth_QTextTableCellFormat_leftBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_leftBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QTextFrameFormat::BorderStyle sipRes;

            sipRes = sipCpp->leftBorderStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTextFrameFormat_BorderStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_leftBorderStyle, doc_QTextTableCellFormat_leftBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setRightBorderStyle, "setRightBorderStyle(self, QTextFrameFormat.BorderStyle)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setRightBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setRightBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFrameFormat::BorderStyle a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QTextFrameFormat_BorderStyle, &a0))
        {
            sipCpp->setRightBorderStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setRightBorderStyle, doc_QTextTableCellFormat_setRightBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_rightBorderStyle, "rightBorderStyle(self) -> QTextFrameFormat.BorderStyle");

extern "C" {static PyObject *meth_QTextTableCellFormat_rightBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_rightBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QTextFrameFormat::BorderStyle sipRes;

            sipRes = sipCpp->rightBorderStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTextFrameFormat_BorderStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_rightBorderStyle, doc_QTextTableCellFormat_rightBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBorderStyle, "setBorderStyle(self, QTextFrameFormat.BorderStyle)");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBorderStyle(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBorderStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFrameFormat::BorderStyle a0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QTextFrameFormat_BorderStyle, &a0))
        {
            sipCpp->setBorderStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBorderStyle, doc_QTextTableCellFormat_setBorderStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setTopBorderBrush, "setTopBorderBrush(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTextTableCellFormat_setTopBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setTopBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setTopBorderBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setTopBorderBrush, doc_QTextTableCellFormat_setTopBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_topBorderBrush, "topBorderBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QTextTableCellFormat_topBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_topBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->topBorderBrush());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_topBorderBrush, doc_QTextTableCellFormat_topBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBottomBorderBrush, "setBottomBorderBrush(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBottomBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBottomBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBottomBorderBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBottomBorderBrush, doc_QTextTableCellFormat_setBottomBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_bottomBorderBrush, "bottomBorderBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QTextTableCellFormat_bottomBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_bottomBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->bottomBorderBrush());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_bottomBorderBrush, doc_QTextTableCellFormat_bottomBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setLeftBorderBrush, "setLeftBorderBrush(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTextTableCellFormat_setLeftBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setLeftBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLeftBorderBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setLeftBorderBrush, doc_QTextTableCellFormat_setLeftBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_leftBorderBrush, "leftBorderBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QTextTableCellFormat_leftBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_leftBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->leftBorderBrush());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_leftBorderBrush, doc_QTextTableCellFormat_leftBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setRightBorderBrush, "setRightBorderBrush(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTextTableCellFormat_setRightBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setRightBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setRightBorderBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setRightBorderBrush, doc_QTextTableCellFormat_setRightBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_rightBorderBrush, "rightBorderBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QTextTableCellFormat_rightBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_rightBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextTableCellFormat, &sipCpp))
        {
             ::QBrush*sipRes;

            sipRes = new  ::QBrush(sipCpp->rightBorderBrush());

            return sipConvertFromNewType(sipRes,sipType_QBrush,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_rightBorderBrush, doc_QTextTableCellFormat_rightBorderBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextTableCellFormat_setBorderBrush, "setBorderBrush(self, Union[QBrush, QColor, Qt.GlobalColor, QGradient])");

extern "C" {static PyObject *meth_QTextTableCellFormat_setBorderBrush(PyObject *, PyObject *);}
static PyObject *meth_QTextTableCellFormat_setBorderBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBrush* a0;
        int a0State = 0;
         ::QTextTableCellFormat *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextTableCellFormat, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBorderBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0),sipType_QBrush,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextTableCellFormat, sipName_setBorderBrush, doc_QTextTableCellFormat_setBorderBrush);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTextTableCellFormat(void *, const sipTypeDef *);}
static void *cast_QTextTableCellFormat(void *sipCppV, const sipTypeDef *targetType)
{
     ::QTextTableCellFormat *sipCpp = reinterpret_cast< ::QTextTableCellFormat *>(sipCppV);

    if (targetType == sipType_QTextCharFormat)
        return static_cast< ::QTextCharFormat *>(sipCpp);

    if (targetType == sipType_QTextFormat)
        return static_cast< ::QTextFormat *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTextTableCellFormat(void *, int);}
static void release_QTextTableCellFormat(void *sipCppV, int)
{
    delete reinterpret_cast< ::QTextTableCellFormat *>(sipCppV);
}


extern "C" {static void *array_QTextTableCellFormat(Py_ssize_t);}
static void *array_QTextTableCellFormat(Py_ssize_t sipNrElem)
{
    return new  ::QTextTableCellFormat[sipNrElem];
}


extern "C" {static void assign_QTextTableCellFormat(void *, SIP_SSIZE_T, void *);}
static void assign_QTextTableCellFormat(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QTextTableCellFormat *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QTextTableCellFormat *>(sipSrc);
}


extern "C" {static void *copy_QTextTableCellFormat(const void *, SIP_SSIZE_T);}
static void *copy_QTextTableCellFormat(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QTextTableCellFormat(reinterpret_cast<const  ::QTextTableCellFormat *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QTextTableCellFormat(sipSimpleWrapper *);}
static void dealloc_QTextTableCellFormat(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTextTableCellFormat(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QTextTableCellFormat(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTextTableCellFormat(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QTextTableCellFormat *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QTextTableCellFormat();

            return sipCpp;
        }
    }

    {
        const  ::QTextTableCellFormat* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QTextTableCellFormat, &a0))
        {
            sipCpp = new  ::QTextTableCellFormat(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTextTableCellFormat[] = {{294, 255, 1}};


static PyMethodDef methods_QTextTableCellFormat[] = {
    {SIP_MLNAME_CAST(sipName_bottomBorder), meth_QTextTableCellFormat_bottomBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_bottomBorder)},
    {SIP_MLNAME_CAST(sipName_bottomBorderBrush), meth_QTextTableCellFormat_bottomBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_bottomBorderBrush)},
    {SIP_MLNAME_CAST(sipName_bottomBorderStyle), meth_QTextTableCellFormat_bottomBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_bottomBorderStyle)},
    {SIP_MLNAME_CAST(sipName_bottomPadding), meth_QTextTableCellFormat_bottomPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_bottomPadding)},
    {SIP_MLNAME_CAST(sipName_isValid), meth_QTextTableCellFormat_isValid, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_isValid)},
    {SIP_MLNAME_CAST(sipName_leftBorder), meth_QTextTableCellFormat_leftBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_leftBorder)},
    {SIP_MLNAME_CAST(sipName_leftBorderBrush), meth_QTextTableCellFormat_leftBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_leftBorderBrush)},
    {SIP_MLNAME_CAST(sipName_leftBorderStyle), meth_QTextTableCellFormat_leftBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_leftBorderStyle)},
    {SIP_MLNAME_CAST(sipName_leftPadding), meth_QTextTableCellFormat_leftPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_leftPadding)},
    {SIP_MLNAME_CAST(sipName_rightBorder), meth_QTextTableCellFormat_rightBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_rightBorder)},
    {SIP_MLNAME_CAST(sipName_rightBorderBrush), meth_QTextTableCellFormat_rightBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_rightBorderBrush)},
    {SIP_MLNAME_CAST(sipName_rightBorderStyle), meth_QTextTableCellFormat_rightBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_rightBorderStyle)},
    {SIP_MLNAME_CAST(sipName_rightPadding), meth_QTextTableCellFormat_rightPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_rightPadding)},
    {SIP_MLNAME_CAST(sipName_setBorder), meth_QTextTableCellFormat_setBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBorder)},
    {SIP_MLNAME_CAST(sipName_setBorderBrush), meth_QTextTableCellFormat_setBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBorderBrush)},
    {SIP_MLNAME_CAST(sipName_setBorderStyle), meth_QTextTableCellFormat_setBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBorderStyle)},
    {SIP_MLNAME_CAST(sipName_setBottomBorder), meth_QTextTableCellFormat_setBottomBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBottomBorder)},
    {SIP_MLNAME_CAST(sipName_setBottomBorderBrush), meth_QTextTableCellFormat_setBottomBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBottomBorderBrush)},
    {SIP_MLNAME_CAST(sipName_setBottomBorderStyle), meth_QTextTableCellFormat_setBottomBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBottomBorderStyle)},
    {SIP_MLNAME_CAST(sipName_setBottomPadding), meth_QTextTableCellFormat_setBottomPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setBottomPadding)},
    {SIP_MLNAME_CAST(sipName_setLeftBorder), meth_QTextTableCellFormat_setLeftBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setLeftBorder)},
    {SIP_MLNAME_CAST(sipName_setLeftBorderBrush), meth_QTextTableCellFormat_setLeftBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setLeftBorderBrush)},
    {SIP_MLNAME_CAST(sipName_setLeftBorderStyle), meth_QTextTableCellFormat_setLeftBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setLeftBorderStyle)},
    {SIP_MLNAME_CAST(sipName_setLeftPadding), meth_QTextTableCellFormat_setLeftPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setLeftPadding)},
    {SIP_MLNAME_CAST(sipName_setPadding), meth_QTextTableCellFormat_setPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setPadding)},
    {SIP_MLNAME_CAST(sipName_setRightBorder), meth_QTextTableCellFormat_setRightBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setRightBorder)},
    {SIP_MLNAME_CAST(sipName_setRightBorderBrush), meth_QTextTableCellFormat_setRightBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setRightBorderBrush)},
    {SIP_MLNAME_CAST(sipName_setRightBorderStyle), meth_QTextTableCellFormat_setRightBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setRightBorderStyle)},
    {SIP_MLNAME_CAST(sipName_setRightPadding), meth_QTextTableCellFormat_setRightPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setRightPadding)},
    {SIP_MLNAME_CAST(sipName_setTopBorder), meth_QTextTableCellFormat_setTopBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setTopBorder)},
    {SIP_MLNAME_CAST(sipName_setTopBorderBrush), meth_QTextTableCellFormat_setTopBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setTopBorderBrush)},
    {SIP_MLNAME_CAST(sipName_setTopBorderStyle), meth_QTextTableCellFormat_setTopBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setTopBorderStyle)},
    {SIP_MLNAME_CAST(sipName_setTopPadding), meth_QTextTableCellFormat_setTopPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_setTopPadding)},
    {SIP_MLNAME_CAST(sipName_topBorder), meth_QTextTableCellFormat_topBorder, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_topBorder)},
    {SIP_MLNAME_CAST(sipName_topBorderBrush), meth_QTextTableCellFormat_topBorderBrush, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_topBorderBrush)},
    {SIP_MLNAME_CAST(sipName_topBorderStyle), meth_QTextTableCellFormat_topBorderStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_topBorderStyle)},
    {SIP_MLNAME_CAST(sipName_topPadding), meth_QTextTableCellFormat_topPadding, METH_VARARGS, SIP_MLDOC_CAST(doc_QTextTableCellFormat_topPadding)}
};

PyDoc_STRVAR(doc_QTextTableCellFormat, "\1QTextTableCellFormat()\n"
"QTextTableCellFormat(QTextTableCellFormat)");


static pyqt5ClassPluginDef plugin_QTextTableCellFormat = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QTextTableCellFormat = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTextTableCellFormat,
        {SIP_NULLPTR},
        &plugin_QTextTableCellFormat
    },
    {
        sipNameNr_QTextTableCellFormat,
        {0, 0, 1},
        37, methods_QTextTableCellFormat,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTextTableCellFormat,
    -1,
    -1,
    supers_QTextTableCellFormat,
    SIP_NULLPTR,
    init_type_QTextTableCellFormat,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QTextTableCellFormat,
    assign_QTextTableCellFormat,
    array_QTextTableCellFormat,
    copy_QTextTableCellFormat,
    release_QTextTableCellFormat,
    cast_QTextTableCellFormat,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
