/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 49 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 61 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 64 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 70 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 73 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 76 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 79 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 82 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 85 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 88 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 91 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGTexture.cpp"


class sipQSGTexture : public  ::QSGTexture
{
public:
    sipQSGTexture();
    virtual ~sipQSGTexture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void bind() SIP_OVERRIDE;
     ::QSGTexture* removedFromAtlas() const SIP_OVERRIDE;
    bool isAtlasTexture() const SIP_OVERRIDE;
     ::QRectF normalizedTextureSubRect() const SIP_OVERRIDE;
    bool hasMipmaps() const SIP_OVERRIDE;
    bool hasAlphaChannel() const SIP_OVERRIDE;
     ::QSize textureSize() const SIP_OVERRIDE;
    int textureId() const SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSGTexture(const sipQSGTexture &);
    sipQSGTexture &operator = (const sipQSGTexture &);

    char sipPyMethods[15];
};

sipQSGTexture::sipQSGTexture():  ::QSGTexture(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSGTexture::~sipQSGTexture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSGTexture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQuick_qt_metaobject(sipPySelf,sipType_QSGTexture);

    return  ::QSGTexture::metaObject();
}

int sipQSGTexture::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QSGTexture::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQuick_qt_metacall(sipPySelf,sipType_QSGTexture,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSGTexture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQuick_qt_metacast(sipPySelf, sipType_QSGTexture, _clname, &sipCpp) ? sipCpp :  ::QSGTexture::qt_metacast(_clname));
}

void sipQSGTexture::bind()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,sipName_QSGTexture,sipName_bind);

    if (!sipMeth)
        return;

    extern void sipVH_QtQuick_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQuick_6(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSGTexture* sipQSGTexture::removedFromAtlas() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,SIP_NULLPTR,sipName_removedFromAtlas);

    if (!sipMeth)
        return  ::QSGTexture::removedFromAtlas();

    extern  ::QSGTexture* sipVH_QtQuick_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_59(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSGTexture::isAtlasTexture() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,SIP_NULLPTR,sipName_isAtlasTexture);

    if (!sipMeth)
        return  ::QSGTexture::isAtlasTexture();

    extern bool sipVH_QtQuick_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_9(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QRectF sipQSGTexture::normalizedTextureSubRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,SIP_NULLPTR,sipName_normalizedTextureSubRect);

    if (!sipMeth)
        return  ::QSGTexture::normalizedTextureSubRect();

    extern  ::QRectF sipVH_QtQuick_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_57(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSGTexture::hasMipmaps() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,sipName_QSGTexture,sipName_hasMipmaps);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtQuick_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_9(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSGTexture::hasAlphaChannel() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,sipName_QSGTexture,sipName_hasAlphaChannel);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtQuick_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_9(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSize sipQSGTexture::textureSize() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[6]),sipPySelf,sipName_QSGTexture,sipName_textureSize);

    if (!sipMeth)
        return  ::QSize();

    extern  ::QSize sipVH_QtQuick_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_30(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQSGTexture::textureId() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[7]),sipPySelf,sipName_QSGTexture,sipName_textureId);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtQuick_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_31(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSGTexture::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QSGTexture::event(a0);

    extern bool sipVH_QtQuick_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtQuick_5(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSGTexture::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QSGTexture::eventFilter(a0,a1);

    extern bool sipVH_QtQuick_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtQuick_4(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSGTexture::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QSGTexture::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtQuick_3(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSGTexture::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QSGTexture::childEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtQuick_2(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSGTexture::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QSGTexture::customEvent(a0);
        return;
    }

    extern void sipVH_QtQuick_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtQuick_1(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSGTexture::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QSGTexture::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSGTexture::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QSGTexture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQuick_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQuick_0(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSGTexture_textureId, "textureId(self) -> int");

extern "C" {static PyObject *meth_QSGTexture_textureId(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_textureId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTexture, sipName_textureId);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->textureId();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_textureId, doc_QSGTexture_textureId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_textureSize, "textureSize(self) -> QSize");

extern "C" {static PyObject *meth_QSGTexture_textureSize(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_textureSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSize*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTexture, sipName_textureSize);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QSize(sipCpp->textureSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_textureSize, doc_QSGTexture_textureSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_hasAlphaChannel, "hasAlphaChannel(self) -> bool");

extern "C" {static PyObject *meth_QSGTexture_hasAlphaChannel(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_hasAlphaChannel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTexture, sipName_hasAlphaChannel);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hasAlphaChannel();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_hasAlphaChannel, doc_QSGTexture_hasAlphaChannel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_hasMipmaps, "hasMipmaps(self) -> bool");

extern "C" {static PyObject *meth_QSGTexture_hasMipmaps(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_hasMipmaps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTexture, sipName_hasMipmaps);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hasMipmaps();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_hasMipmaps, doc_QSGTexture_hasMipmaps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_normalizedTextureSubRect, "normalizedTextureSubRect(self) -> QRectF");

extern "C" {static PyObject *meth_QSGTexture_normalizedTextureSubRect(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_normalizedTextureSubRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF((sipSelfWasArg ? sipCpp-> ::QSGTexture::normalizedTextureSubRect() : sipCpp->normalizedTextureSubRect()));

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_normalizedTextureSubRect, doc_QSGTexture_normalizedTextureSubRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_isAtlasTexture, "isAtlasTexture(self) -> bool");

extern "C" {static PyObject *meth_QSGTexture_isAtlasTexture(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_isAtlasTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGTexture::isAtlasTexture() : sipCpp->isAtlasTexture());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_isAtlasTexture, doc_QSGTexture_isAtlasTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_removedFromAtlas, "removedFromAtlas(self) -> QSGTexture");

extern "C" {static PyObject *meth_QSGTexture_removedFromAtlas(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_removedFromAtlas(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGTexture::removedFromAtlas() : sipCpp->removedFromAtlas());

            return sipConvertFromType(sipRes,sipType_QSGTexture,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_removedFromAtlas, doc_QSGTexture_removedFromAtlas);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_bind, "bind(self)");

extern "C" {static PyObject *meth_QSGTexture_bind(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_bind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QSGTexture, sipName_bind);
                return SIP_NULLPTR;
            }

            sipCpp->bind();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_bind, doc_QSGTexture_bind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_updateBindOptions, "updateBindOptions(self, force: bool = False)");

extern "C" {static PyObject *meth_QSGTexture_updateBindOptions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_updateBindOptions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 0;
         ::QSGTexture *sipCpp;

        static const char *sipKwdList[] = {
            sipName_force,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QSGTexture, &sipCpp, &a0))
        {
            sipCpp->updateBindOptions(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_updateBindOptions, doc_QSGTexture_updateBindOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_setMipmapFiltering, "setMipmapFiltering(self, QSGTexture.Filtering)");

extern "C" {static PyObject *meth_QSGTexture_setMipmapFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_setMipmapFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::Filtering a0;
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QSGTexture_Filtering, &a0))
        {
            sipCpp->setMipmapFiltering(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_setMipmapFiltering, doc_QSGTexture_setMipmapFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_mipmapFiltering, "mipmapFiltering(self) -> QSGTexture.Filtering");

extern "C" {static PyObject *meth_QSGTexture_mipmapFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_mipmapFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::Filtering sipRes;

            sipRes = sipCpp->mipmapFiltering();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_Filtering);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_mipmapFiltering, doc_QSGTexture_mipmapFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_setFiltering, "setFiltering(self, QSGTexture.Filtering)");

extern "C" {static PyObject *meth_QSGTexture_setFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_setFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::Filtering a0;
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QSGTexture_Filtering, &a0))
        {
            sipCpp->setFiltering(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_setFiltering, doc_QSGTexture_setFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_filtering, "filtering(self) -> QSGTexture.Filtering");

extern "C" {static PyObject *meth_QSGTexture_filtering(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_filtering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::Filtering sipRes;

            sipRes = sipCpp->filtering();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_Filtering);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_filtering, doc_QSGTexture_filtering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_setHorizontalWrapMode, "setHorizontalWrapMode(self, QSGTexture.WrapMode)");

extern "C" {static PyObject *meth_QSGTexture_setHorizontalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_setHorizontalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::WrapMode a0;
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QSGTexture_WrapMode, &a0))
        {
            sipCpp->setHorizontalWrapMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_setHorizontalWrapMode, doc_QSGTexture_setHorizontalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_horizontalWrapMode, "horizontalWrapMode(self) -> QSGTexture.WrapMode");

extern "C" {static PyObject *meth_QSGTexture_horizontalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_horizontalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::WrapMode sipRes;

            sipRes = sipCpp->horizontalWrapMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_horizontalWrapMode, doc_QSGTexture_horizontalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_setVerticalWrapMode, "setVerticalWrapMode(self, QSGTexture.WrapMode)");

extern "C" {static PyObject *meth_QSGTexture_setVerticalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_setVerticalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::WrapMode a0;
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QSGTexture_WrapMode, &a0))
        {
            sipCpp->setVerticalWrapMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_setVerticalWrapMode, doc_QSGTexture_setVerticalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_verticalWrapMode, "verticalWrapMode(self) -> QSGTexture.WrapMode");

extern "C" {static PyObject *meth_QSGTexture_verticalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_verticalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::WrapMode sipRes;

            sipRes = sipCpp->verticalWrapMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_verticalWrapMode, doc_QSGTexture_verticalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_convertToNormalizedSourceRect, "convertToNormalizedSourceRect(self, QRectF) -> QRectF");

extern "C" {static PyObject *meth_QSGTexture_convertToNormalizedSourceRect(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_convertToNormalizedSourceRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QRectF, &a0))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF(sipCpp->convertToNormalizedSourceRect(*a0));

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_convertToNormalizedSourceRect, doc_QSGTexture_convertToNormalizedSourceRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_setAnisotropyLevel, "setAnisotropyLevel(self, QSGTexture.AnisotropyLevel)");

extern "C" {static PyObject *meth_QSGTexture_setAnisotropyLevel(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_setAnisotropyLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::AnisotropyLevel a0;
         ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGTexture, &sipCpp, sipType_QSGTexture_AnisotropyLevel, &a0))
        {
            sipCpp->setAnisotropyLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_setAnisotropyLevel, doc_QSGTexture_setAnisotropyLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_anisotropyLevel, "anisotropyLevel(self) -> QSGTexture.AnisotropyLevel");

extern "C" {static PyObject *meth_QSGTexture_anisotropyLevel(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_anisotropyLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::AnisotropyLevel sipRes;

            sipRes = sipCpp->anisotropyLevel();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_AnisotropyLevel);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_anisotropyLevel, doc_QSGTexture_anisotropyLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_comparisonKey, "comparisonKey(self) -> int");

extern "C" {static PyObject *meth_QSGTexture_comparisonKey(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_comparisonKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->comparisonKey();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_comparisonKey, doc_QSGTexture_comparisonKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGTexture_nativeTexture, "nativeTexture(self) -> QSGTexture.NativeTexture");

extern "C" {static PyObject *meth_QSGTexture_nativeTexture(PyObject *, PyObject *);}
static PyObject *meth_QSGTexture_nativeTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGTexture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGTexture, &sipCpp))
        {
             ::QSGTexture::NativeTexture*sipRes;

            sipRes = new  ::QSGTexture::NativeTexture(sipCpp->nativeTexture());

            return sipConvertFromNewType(sipRes,sipType_QSGTexture_NativeTexture,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGTexture, sipName_nativeTexture, doc_QSGTexture_nativeTexture);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGTexture(void *, const sipTypeDef *);}
static void *cast_QSGTexture(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSGTexture *sipCpp = reinterpret_cast< ::QSGTexture *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGTexture(void *, int);}
static void release_QSGTexture(void *sipCppV, int)
{
     ::QSGTexture *sipCpp = reinterpret_cast< ::QSGTexture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QSGTexture(sipSimpleWrapper *);}
static void dealloc_QSGTexture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSGTexture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGTexture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSGTexture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGTexture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSGTexture *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSGTexture();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGTexture[] = {{4, 0, 1}};


static PyMethodDef methods_QSGTexture[] = {
    {SIP_MLNAME_CAST(sipName_anisotropyLevel), meth_QSGTexture_anisotropyLevel, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_anisotropyLevel)},
    {SIP_MLNAME_CAST(sipName_bind), meth_QSGTexture_bind, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_bind)},
    {SIP_MLNAME_CAST(sipName_comparisonKey), meth_QSGTexture_comparisonKey, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_comparisonKey)},
    {SIP_MLNAME_CAST(sipName_convertToNormalizedSourceRect), meth_QSGTexture_convertToNormalizedSourceRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_convertToNormalizedSourceRect)},
    {SIP_MLNAME_CAST(sipName_filtering), meth_QSGTexture_filtering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_filtering)},
    {SIP_MLNAME_CAST(sipName_hasAlphaChannel), meth_QSGTexture_hasAlphaChannel, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_hasAlphaChannel)},
    {SIP_MLNAME_CAST(sipName_hasMipmaps), meth_QSGTexture_hasMipmaps, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_hasMipmaps)},
    {SIP_MLNAME_CAST(sipName_horizontalWrapMode), meth_QSGTexture_horizontalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_horizontalWrapMode)},
    {SIP_MLNAME_CAST(sipName_isAtlasTexture), meth_QSGTexture_isAtlasTexture, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_isAtlasTexture)},
    {SIP_MLNAME_CAST(sipName_mipmapFiltering), meth_QSGTexture_mipmapFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_mipmapFiltering)},
    {SIP_MLNAME_CAST(sipName_nativeTexture), meth_QSGTexture_nativeTexture, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_nativeTexture)},
    {SIP_MLNAME_CAST(sipName_normalizedTextureSubRect), meth_QSGTexture_normalizedTextureSubRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_normalizedTextureSubRect)},
    {SIP_MLNAME_CAST(sipName_removedFromAtlas), meth_QSGTexture_removedFromAtlas, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_removedFromAtlas)},
    {SIP_MLNAME_CAST(sipName_setAnisotropyLevel), meth_QSGTexture_setAnisotropyLevel, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_setAnisotropyLevel)},
    {SIP_MLNAME_CAST(sipName_setFiltering), meth_QSGTexture_setFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_setFiltering)},
    {SIP_MLNAME_CAST(sipName_setHorizontalWrapMode), meth_QSGTexture_setHorizontalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_setHorizontalWrapMode)},
    {SIP_MLNAME_CAST(sipName_setMipmapFiltering), meth_QSGTexture_setMipmapFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_setMipmapFiltering)},
    {SIP_MLNAME_CAST(sipName_setVerticalWrapMode), meth_QSGTexture_setVerticalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_setVerticalWrapMode)},
    {SIP_MLNAME_CAST(sipName_textureId), meth_QSGTexture_textureId, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_textureId)},
    {SIP_MLNAME_CAST(sipName_textureSize), meth_QSGTexture_textureSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_textureSize)},
    {SIP_MLNAME_CAST(sipName_updateBindOptions), SIP_MLMETH_CAST(meth_QSGTexture_updateBindOptions), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QSGTexture_updateBindOptions)},
    {SIP_MLNAME_CAST(sipName_verticalWrapMode), meth_QSGTexture_verticalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGTexture_verticalWrapMode)}
};

static sipEnumMemberDef enummembers_QSGTexture[] = {
    {sipName_Anisotropy16x, static_cast<int>( ::QSGTexture::Anisotropy16x), 103},
    {sipName_Anisotropy2x, static_cast<int>( ::QSGTexture::Anisotropy2x), 103},
    {sipName_Anisotropy4x, static_cast<int>( ::QSGTexture::Anisotropy4x), 103},
    {sipName_Anisotropy8x, static_cast<int>( ::QSGTexture::Anisotropy8x), 103},
    {sipName_AnisotropyNone, static_cast<int>( ::QSGTexture::AnisotropyNone), 103},
    {sipName_ClampToEdge, static_cast<int>( ::QSGTexture::ClampToEdge), 106},
    {sipName_Linear, static_cast<int>( ::QSGTexture::Linear), 104},
    {sipName_MirroredRepeat, static_cast<int>( ::QSGTexture::MirroredRepeat), 106},
    {sipName_Nearest, static_cast<int>( ::QSGTexture::Nearest), 104},
    {sipName_None_, static_cast<int>( ::QSGTexture::None), 104},
    {sipName_Repeat, static_cast<int>( ::QSGTexture::Repeat), 106},
};

PyDoc_STRVAR(doc_QSGTexture, "\1QSGTexture()");


static pyqt5ClassPluginDef plugin_QSGTexture = {
    & ::QSGTexture::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGTexture = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGTexture,
        {SIP_NULLPTR},
        &plugin_QSGTexture
    },
    {
        sipNameNr_QSGTexture,
        {0, 0, 1},
        22, methods_QSGTexture,
        11, enummembers_QSGTexture,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGTexture,
    -1,
    -1,
    supers_QSGTexture,
    SIP_NULLPTR,
    init_type_QSGTexture,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGTexture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSGTexture,
    cast_QSGTexture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
