/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qauthenticator.sip"
#include <qauthenticator.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 166 "sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"


class sipQAbstractSocket : public  ::QAbstractSocket
{
public:
    sipQAbstractSocket( ::QAbstractSocket::SocketType, ::QObject*);
    virtual ~sipQAbstractSocket();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void resume() SIP_OVERRIDE;
     ::QVariant socketOption( ::QAbstractSocket::SocketOption) SIP_OVERRIDE;
    void setSocketOption( ::QAbstractSocket::SocketOption,const  ::QVariant&) SIP_OVERRIDE;
    bool waitForDisconnected(int) SIP_OVERRIDE;
    bool waitForConnected(int) SIP_OVERRIDE;
     ::qintptr socketDescriptor() const SIP_OVERRIDE;
    bool setSocketDescriptor( ::qintptr, ::QAbstractSocket::SocketState, ::QIODevice::OpenMode) SIP_OVERRIDE;
    void setReadBufferSize( ::qint64) SIP_OVERRIDE;
    void disconnectFromHost() SIP_OVERRIDE;
    void connectToHost(const  ::QHostAddress&, ::quint16, ::QIODevice::OpenMode) SIP_OVERRIDE;
    void connectToHost(const  ::QString&, ::quint16, ::QIODevice::OpenMode, ::QAbstractSocket::NetworkLayerProtocol) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool isSequential() const SIP_OVERRIDE;
    bool open( ::QIODevice::OpenMode) SIP_OVERRIDE;
    void close() SIP_OVERRIDE;
     ::qint64 pos() const SIP_OVERRIDE;
     ::qint64 size() const SIP_OVERRIDE;
    bool seek( ::qint64) SIP_OVERRIDE;
    bool atEnd() const SIP_OVERRIDE;
    bool reset() SIP_OVERRIDE;
     ::qint64 bytesAvailable() const SIP_OVERRIDE;
     ::qint64 bytesToWrite() const SIP_OVERRIDE;
    bool canReadLine() const SIP_OVERRIDE;
    bool waitForReadyRead(int) SIP_OVERRIDE;
    bool waitForBytesWritten(int) SIP_OVERRIDE;
     ::qint64 readData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 readLineData(char*, ::qint64) SIP_OVERRIDE;
     ::qint64 writeData(const char*,PY_LONG_LONG) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractSocket(const sipQAbstractSocket &);
    sipQAbstractSocket &operator = (const sipQAbstractSocket &);

    char sipPyMethods[34];
};

sipQAbstractSocket::sipQAbstractSocket( ::QAbstractSocket::SocketType a0, ::QObject*a1):  ::QAbstractSocket(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractSocket::~sipQAbstractSocket()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstractSocket::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf,sipType_QAbstractSocket);

    return  ::QAbstractSocket::metaObject();
}

int sipQAbstractSocket::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QAbstractSocket::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf,sipType_QAbstractSocket,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstractSocket::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QAbstractSocket, _clname, &sipCpp) ? sipCpp :  ::QAbstractSocket::qt_metacast(_clname));
}

void sipQAbstractSocket::resume()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_resume);

    if (!sipMeth)
    {
         ::QAbstractSocket::resume();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipQAbstractSocket::socketOption( ::QAbstractSocket::SocketOption a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_socketOption);

    if (!sipMeth)
        return  ::QAbstractSocket::socketOption(a0);

    extern  ::QVariant sipVH_QtNetwork_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QAbstractSocket::SocketOption);

    return sipVH_QtNetwork_27(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::setSocketOption( ::QAbstractSocket::SocketOption a0,const  ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_setSocketOption);

    if (!sipMeth)
    {
         ::QAbstractSocket::setSocketOption(a0,a1);
        return;
    }

    extern void sipVH_QtNetwork_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QAbstractSocket::SocketOption,const  ::QVariant&);

    sipVH_QtNetwork_26(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAbstractSocket::waitForDisconnected(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_waitForDisconnected);

    if (!sipMeth)
        return  ::QAbstractSocket::waitForDisconnected(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSocket::waitForConnected(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_waitForConnected);

    if (!sipMeth)
        return  ::QAbstractSocket::waitForConnected(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::qintptr sipQAbstractSocket::socketDescriptor() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,SIP_NULLPTR,sipName_socketDescriptor);

    if (!sipMeth)
        return  ::QAbstractSocket::socketDescriptor();

    extern  ::qintptr sipVH_QtNetwork_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_25(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::setSocketDescriptor( ::qintptr a0, ::QAbstractSocket::SocketState a1, ::QIODevice::OpenMode a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_setSocketDescriptor);

    if (!sipMeth)
        return  ::QAbstractSocket::setSocketDescriptor(a0,a1,a2);

    extern bool sipVH_QtNetwork_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qintptr, ::QAbstractSocket::SocketState, ::QIODevice::OpenMode);

    return sipVH_QtNetwork_24(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQAbstractSocket::setReadBufferSize( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_setReadBufferSize);

    if (!sipMeth)
    {
         ::QAbstractSocket::setReadBufferSize(a0);
        return;
    }

    extern void sipVH_QtNetwork_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    sipVH_QtNetwork_23(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::disconnectFromHost()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_disconnectFromHost);

    if (!sipMeth)
    {
         ::QAbstractSocket::disconnectFromHost();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSocket::connectToHost(const  ::QHostAddress& a0, ::quint16 a1, ::QIODevice::OpenMode a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_connectToHost);

    if (!sipMeth)
    {
         ::QAbstractSocket::connectToHost(a0,a1,a2);
        return;
    }

    extern void sipVH_QtNetwork_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QHostAddress&, ::quint16, ::QIODevice::OpenMode);

    sipVH_QtNetwork_22(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQAbstractSocket::connectToHost(const  ::QString& a0, ::quint16 a1, ::QIODevice::OpenMode a2, ::QAbstractSocket::NetworkLayerProtocol a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,SIP_NULLPTR,sipName_connectToHost);

    if (!sipMeth)
    {
         ::QAbstractSocket::connectToHost(a0,a1,a2,a3);
        return;
    }

    extern void sipVH_QtNetwork_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QString&, ::quint16, ::QIODevice::OpenMode, ::QAbstractSocket::NetworkLayerProtocol);

    sipVH_QtNetwork_21(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQAbstractSocket::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QAbstractSocket::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QAbstractSocket::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QAbstractSocket::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QAbstractSocket::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QAbstractSocket::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSocket::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QAbstractSocket::eventFilter(a0,a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAbstractSocket::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[17],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QAbstractSocket::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSocket::isSequential() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[18]),sipPySelf,SIP_NULLPTR,sipName_isSequential);

    if (!sipMeth)
        return  ::QAbstractSocket::isSequential();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::open( ::QIODevice::OpenMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[19],sipPySelf,SIP_NULLPTR,sipName_open);

    if (!sipMeth)
        return  ::QAbstractSocket::open(a0);

    extern bool sipVH_QtNetwork_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QIODevice::OpenMode);

    return sipVH_QtNetwork_20(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSocket::close()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_close);

    if (!sipMeth)
    {
         ::QAbstractSocket::close();
        return;
    }

    extern void sipVH_QtNetwork_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtNetwork_13(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQAbstractSocket::pos() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[21]),sipPySelf,SIP_NULLPTR,sipName_pos);

    if (!sipMeth)
        return  ::QAbstractSocket::pos();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQAbstractSocket::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[22]),sipPySelf,SIP_NULLPTR,sipName_size);

    if (!sipMeth)
        return  ::QAbstractSocket::size();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::seek( ::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_seek);

    if (!sipMeth)
        return  ::QAbstractSocket::seek(a0);

    extern bool sipVH_QtNetwork_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::qint64);

    return sipVH_QtNetwork_19(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSocket::atEnd() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[24]),sipPySelf,SIP_NULLPTR,sipName_atEnd);

    if (!sipMeth)
        return  ::QAbstractSocket::atEnd();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_reset);

    if (!sipMeth)
        return  ::QAbstractSocket::reset();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQAbstractSocket::bytesAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[26]),sipPySelf,SIP_NULLPTR,sipName_bytesAvailable);

    if (!sipMeth)
        return  ::QAbstractSocket::bytesAvailable();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::qint64 sipQAbstractSocket::bytesToWrite() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[27]),sipPySelf,SIP_NULLPTR,sipName_bytesToWrite);

    if (!sipMeth)
        return  ::QAbstractSocket::bytesToWrite();

    extern  ::qint64 sipVH_QtNetwork_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_10(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::canReadLine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[28]),sipPySelf,SIP_NULLPTR,sipName_canReadLine);

    if (!sipMeth)
        return  ::QAbstractSocket::canReadLine();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSocket::waitForReadyRead(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[29],sipPySelf,SIP_NULLPTR,sipName_waitForReadyRead);

    if (!sipMeth)
        return  ::QAbstractSocket::waitForReadyRead(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSocket::waitForBytesWritten(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[30],sipPySelf,SIP_NULLPTR,sipName_waitForBytesWritten);

    if (!sipMeth)
        return  ::QAbstractSocket::waitForBytesWritten(a0);

    extern bool sipVH_QtNetwork_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtNetwork_17(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::qint64 sipQAbstractSocket::readData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[31],sipPySelf,SIP_NULLPTR,sipName_readData);

    if (!sipMeth)
        return  ::QAbstractSocket::readData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_16(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQAbstractSocket::readLineData(char*a0, ::qint64 a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[32],sipPySelf,SIP_NULLPTR,sipName_readLineData);

    if (!sipMeth)
        return  ::QAbstractSocket::readLineData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, char*, ::qint64);

    return sipVH_QtNetwork_15(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::qint64 sipQAbstractSocket::writeData(const char*a0,PY_LONG_LONG a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[33],sipPySelf,SIP_NULLPTR,sipName_writeData);

    if (!sipMeth)
        return  ::QAbstractSocket::writeData(a0,a1);

    extern  ::qint64 sipVH_QtNetwork_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const char*,PY_LONG_LONG);

    return sipVH_QtNetwork_14(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}


PyDoc_STRVAR(doc_QAbstractSocket_connectToHost, "connectToHost(self, str, int, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite, protocol: QAbstractSocket.NetworkLayerProtocol = QAbstractSocket.AnyIPProtocol)\n"
"connectToHost(self, Union[QHostAddress, QHostAddress.SpecialAddress], int, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite)");

extern "C" {static PyObject *meth_QAbstractSocket_connectToHost(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_connectToHost(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QString* a0;
        int a0State = 0;
         ::quint16 a1;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket::NetworkLayerProtocol a3 = QAbstractSocket::AnyIPProtocol;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
            sipName_protocol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1t|J1E", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QString,&a0, &a0State, &a1, sipType_QIODevice_OpenMode, &a2, &a2State, sipType_QAbstractSocket_NetworkLayerProtocol, &a3))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::connectToHost(*a0,a1,*a2,a3) : sipCpp->connectToHost(*a0,a1,*a2,a3));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QHostAddress* a0;
        int a0State = 0;
         ::quint16 a1;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1t|J1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QHostAddress, &a0, &a0State, &a1, sipType_QIODevice_OpenMode, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::connectToHost(*a0,a1,*a2) : sipCpp->connectToHost(*a0,a1,*a2));
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_connectToHost, doc_QAbstractSocket_connectToHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_disconnectFromHost, "disconnectFromHost(self)");

extern "C" {static PyObject *meth_QAbstractSocket_disconnectFromHost(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_disconnectFromHost(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::disconnectFromHost() : sipCpp->disconnectFromHost());
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_disconnectFromHost, doc_QAbstractSocket_disconnectFromHost);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_isValid(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_isValid, doc_QAbstractSocket_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_bytesAvailable, "bytesAvailable(self) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_bytesAvailable(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_bytesAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::bytesAvailable() : sipCpp->bytesAvailable());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_bytesAvailable, doc_QAbstractSocket_bytesAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_bytesToWrite, "bytesToWrite(self) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_bytesToWrite(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_bytesToWrite(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::bytesToWrite() : sipCpp->bytesToWrite());

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_bytesToWrite, doc_QAbstractSocket_bytesToWrite);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_canReadLine, "canReadLine(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_canReadLine(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_canReadLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::canReadLine() : sipCpp->canReadLine());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_canReadLine, doc_QAbstractSocket_canReadLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_localPort, "localPort(self) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_localPort(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_localPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::quint16 sipRes;

            sipRes = sipCpp->localPort();

#if PY_MAJOR_VERSION >= 3
            return PyLong_FromUnsignedLong(sipRes);
#else
            return PyInt_FromLong(sipRes);
#endif
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_localPort, doc_QAbstractSocket_localPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_localAddress, "localAddress(self) -> QHostAddress");

extern "C" {static PyObject *meth_QAbstractSocket_localAddress(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_localAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QHostAddress*sipRes;

            sipRes = new  ::QHostAddress(sipCpp->localAddress());

            return sipConvertFromNewType(sipRes,sipType_QHostAddress,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_localAddress, doc_QAbstractSocket_localAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_peerPort, "peerPort(self) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_peerPort(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_peerPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::quint16 sipRes;

            sipRes = sipCpp->peerPort();

#if PY_MAJOR_VERSION >= 3
            return PyLong_FromUnsignedLong(sipRes);
#else
            return PyInt_FromLong(sipRes);
#endif
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_peerPort, doc_QAbstractSocket_peerPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_peerAddress, "peerAddress(self) -> QHostAddress");

extern "C" {static PyObject *meth_QAbstractSocket_peerAddress(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_peerAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QHostAddress*sipRes;

            sipRes = new  ::QHostAddress(sipCpp->peerAddress());

            return sipConvertFromNewType(sipRes,sipType_QHostAddress,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_peerAddress, doc_QAbstractSocket_peerAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_peerName, "peerName(self) -> str");

extern "C" {static PyObject *meth_QAbstractSocket_peerName(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_peerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->peerName());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_peerName, doc_QAbstractSocket_peerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_readBufferSize, "readBufferSize(self) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_readBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_readBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::qint64 sipRes;

            sipRes = sipCpp->readBufferSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_readBufferSize, doc_QAbstractSocket_readBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setReadBufferSize, "setReadBufferSize(self, int)");

extern "C" {static PyObject *meth_QAbstractSocket_setReadBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setReadBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::setReadBufferSize(a0) : sipCpp->setReadBufferSize(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setReadBufferSize, doc_QAbstractSocket_setReadBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_abort, "abort(self)");

extern "C" {static PyObject *meth_QAbstractSocket_abort(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            sipCpp->abort();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_abort, doc_QAbstractSocket_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setSocketDescriptor, "setSocketDescriptor(self, sip.voidptr, state: QAbstractSocket.SocketState = QAbstractSocket.ConnectedState, mode: Union[QIODevice.OpenMode, QIODevice.OpenModeFlag] = QIODevice.ReadWrite) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_setSocketDescriptor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setSocketDescriptor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qintptr* a0;
        int a0State = 0;
         ::QAbstractSocket::SocketState a1 = QAbstractSocket::ConnectedState;
         ::QIODevice::OpenMode a2def = QIODevice::ReadWrite;
         ::QIODevice::OpenMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_state,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|EJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_qintptr,&a0, &a0State, sipType_QAbstractSocket_SocketState, &a1, sipType_QIODevice_OpenMode, &a2, &a2State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::setSocketDescriptor(*a0,a1,*a2) : sipCpp->setSocketDescriptor(*a0,a1,*a2));
            sipReleaseType(a0,sipType_qintptr,a0State);
            sipReleaseType(a2,sipType_QIODevice_OpenMode,a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setSocketDescriptor, doc_QAbstractSocket_setSocketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_socketDescriptor, "socketDescriptor(self) -> sip.voidptr");

extern "C" {static PyObject *meth_QAbstractSocket_socketDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_socketDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::qintptr*sipRes;

            sipRes = new  ::qintptr((sipSelfWasArg ? sipCpp-> ::QAbstractSocket::socketDescriptor() : sipCpp->socketDescriptor()));

            return sipConvertFromNewType(sipRes,sipType_qintptr,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_socketDescriptor, doc_QAbstractSocket_socketDescriptor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_socketType, "socketType(self) -> QAbstractSocket.SocketType");

extern "C" {static PyObject *meth_QAbstractSocket_socketType(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_socketType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QAbstractSocket::SocketType sipRes;

            sipRes = sipCpp->socketType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_socketType, doc_QAbstractSocket_socketType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_state, "state(self) -> QAbstractSocket.SocketState");

extern "C" {static PyObject *meth_QAbstractSocket_state(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QAbstractSocket::SocketState sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_state, doc_QAbstractSocket_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_error, "error(self) -> QAbstractSocket.SocketError");

extern "C" {static PyObject *meth_QAbstractSocket_error(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QAbstractSocket::SocketError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_error, doc_QAbstractSocket_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_close, "close(self)");

extern "C" {static PyObject *meth_QAbstractSocket_close(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::close() : sipCpp->close());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_close, doc_QAbstractSocket_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_isSequential, "isSequential(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_isSequential(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_isSequential(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::isSequential() : sipCpp->isSequential());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_isSequential, doc_QAbstractSocket_isSequential);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_atEnd, "atEnd(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_atEnd(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_atEnd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::atEnd() : sipCpp->atEnd());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_atEnd, doc_QAbstractSocket_atEnd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_flush, "flush(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_flush(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_flush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->flush();
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_flush, doc_QAbstractSocket_flush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_waitForConnected, "waitForConnected(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_waitForConnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_waitForConnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::waitForConnected(a0) : sipCpp->waitForConnected(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_waitForConnected, doc_QAbstractSocket_waitForConnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_waitForReadyRead, "waitForReadyRead(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_waitForReadyRead(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_waitForReadyRead(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::waitForReadyRead(a0) : sipCpp->waitForReadyRead(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_waitForReadyRead, doc_QAbstractSocket_waitForReadyRead);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_waitForBytesWritten, "waitForBytesWritten(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_waitForBytesWritten(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_waitForBytesWritten(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::waitForBytesWritten(a0) : sipCpp->waitForBytesWritten(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_waitForBytesWritten, doc_QAbstractSocket_waitForBytesWritten);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_waitForDisconnected, "waitForDisconnected(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_waitForDisconnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_waitForDisconnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = 30000;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::waitForDisconnected(a0) : sipCpp->waitForDisconnected(a0));
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_waitForDisconnected, doc_QAbstractSocket_waitForDisconnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setProxy, "setProxy(self, QNetworkProxy)");

extern "C" {static PyObject *meth_QAbstractSocket_setProxy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkProxy* a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QNetworkProxy, &a0))
        {
            sipCpp->setProxy(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setProxy, doc_QAbstractSocket_setProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_proxy, "proxy(self) -> QNetworkProxy");

extern "C" {static PyObject *meth_QAbstractSocket_proxy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_proxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QNetworkProxy*sipRes;

            sipRes = new  ::QNetworkProxy(sipCpp->proxy());

            return sipConvertFromNewType(sipRes,sipType_QNetworkProxy,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_proxy, doc_QAbstractSocket_proxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_readData, "readData(self, int) -> bytes");

extern "C" {static PyObject *meth_QAbstractSocket_readData(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_readData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pn", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 181 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
        // Return the data read or None if there was an error.
        if (a0 < 0)
        {
            PyErr_SetString(PyExc_ValueError, "maximum length of data to be read cannot be negative");
            sipIsErr = 1;
        }
        else
        {
            char *s = new char[a0];
            qint64 len;
        
            Py_BEGIN_ALLOW_THREADS
        #if defined(SIP_PROTECTED_IS_PUBLIC)
            len = sipSelfWasArg ? sipCpp->QAbstractSocket::readData(s, a0) : sipCpp->readData(s, a0);
        #else
            len = sipCpp->sipProtectVirt_readData(sipSelfWasArg, s, a0);
        #endif
            Py_END_ALLOW_THREADS
        
            if (len < 0)
            {
                Py_INCREF(Py_None);
                sipRes = Py_None;
            }
            else
            {
                sipRes = SIPBytes_FromStringAndSize(s, len);
        
                if (!sipRes)
                    sipIsErr = 1;
            }
        
            delete[] s;
        }
#line 1702 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_readData, doc_QAbstractSocket_readData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_readLineData, "readLineData(self, int) -> bytes");

extern "C" {static PyObject *meth_QAbstractSocket_readLineData(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_readLineData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::qint64 a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pn", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 219 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
        // Return the data read or None if there was an error.
        if (a0 < 0)
        {
            PyErr_SetString(PyExc_ValueError, "maximum length of data to be read cannot be negative");
            sipIsErr = 1;
        }
        else
        {
            char *s = new char[a0];
            qint64 len;
        
            Py_BEGIN_ALLOW_THREADS
        #if defined(SIP_PROTECTED_IS_PUBLIC)
            len = sipSelfWasArg ? sipCpp->QAbstractSocket::readLineData(s, a0) : sipCpp->readLineData(s, a0);
        #else
            len = sipCpp->sipProtectVirt_readLineData(sipSelfWasArg, s, a0);
        #endif
            Py_END_ALLOW_THREADS
        
            if (len < 0)
            {
                Py_INCREF(Py_None);
                sipRes = Py_None;
            }
            else
            {
                sipRes = SIPBytes_FromStringAndSize(s, len);
        
                if (!sipRes)
                    sipIsErr = 1;
            }
        
            delete[] s;
        }
#line 1770 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQAbstractSocket.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_readLineData, doc_QAbstractSocket_readLineData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_writeData, "writeData(self, bytes) -> int");

extern "C" {static PyObject *meth_QAbstractSocket_writeData(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_writeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const char* a0;
        SIP_SSIZE_T a1;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pk", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0, &a1))
        {
             ::qint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::writeData(a0,(PY_LONG_LONG)a1) : sipCpp->writeData(a0,(PY_LONG_LONG)a1));
            Py_END_ALLOW_THREADS

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_writeData, doc_QAbstractSocket_writeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setSocketState, "setSocketState(self, QAbstractSocket.SocketState)");

extern "C" {static PyObject *meth_QAbstractSocket_setSocketState(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setSocketState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket::SocketState a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QAbstractSocket_SocketState, &a0))
        {
            sipCpp->setSocketState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setSocketState, doc_QAbstractSocket_setSocketState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setSocketError, "setSocketError(self, QAbstractSocket.SocketError)");

extern "C" {static PyObject *meth_QAbstractSocket_setSocketError(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setSocketError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket::SocketError a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QAbstractSocket_SocketError, &a0))
        {
            sipCpp->setSocketError(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setSocketError, doc_QAbstractSocket_setSocketError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setLocalPort, "setLocalPort(self, int)");

extern "C" {static PyObject *meth_QAbstractSocket_setLocalPort(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setLocalPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::quint16 a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pt", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            sipCpp->setLocalPort(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setLocalPort, doc_QAbstractSocket_setLocalPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setLocalAddress, "setLocalAddress(self, Union[QHostAddress, QHostAddress.SpecialAddress])");

extern "C" {static PyObject *meth_QAbstractSocket_setLocalAddress(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setLocalAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QHostAddress, &a0, &a0State))
        {
            sipCpp->setLocalAddress(*a0);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setLocalAddress, doc_QAbstractSocket_setLocalAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setPeerPort, "setPeerPort(self, int)");

extern "C" {static PyObject *meth_QAbstractSocket_setPeerPort(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setPeerPort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::quint16 a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pt", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0))
        {
            sipCpp->setPeerPort(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setPeerPort, doc_QAbstractSocket_setPeerPort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setPeerAddress, "setPeerAddress(self, Union[QHostAddress, QHostAddress.SpecialAddress])");

extern "C" {static PyObject *meth_QAbstractSocket_setPeerAddress(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setPeerAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QHostAddress, &a0, &a0State))
        {
            sipCpp->setPeerAddress(*a0);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setPeerAddress, doc_QAbstractSocket_setPeerAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setPeerName, "setPeerName(self, str)");

extern "C" {static PyObject *meth_QAbstractSocket_setPeerName(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setPeerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setPeerName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setPeerName, doc_QAbstractSocket_setPeerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setSocketOption, "setSocketOption(self, QAbstractSocket.SocketOption, Any)");

extern "C" {static PyObject *meth_QAbstractSocket_setSocketOption(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setSocketOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket::SocketOption a0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QAbstractSocket_SocketOption, &a0, sipType_QVariant, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::setSocketOption(a0,*a1) : sipCpp->setSocketOption(a0,*a1));
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setSocketOption, doc_QAbstractSocket_setSocketOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_socketOption, "socketOption(self, QAbstractSocket.SocketOption) -> Any");

extern "C" {static PyObject *meth_QAbstractSocket_socketOption(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_socketOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket::SocketOption a0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QAbstractSocket_SocketOption, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QAbstractSocket::socketOption(a0) : sipCpp->socketOption(a0)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_socketOption, doc_QAbstractSocket_socketOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_resume, "resume(self)");

extern "C" {static PyObject *meth_QAbstractSocket_resume(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
            Py_BEGIN_ALLOW_THREADS
            (sipSelfWasArg ? sipCpp-> ::QAbstractSocket::resume() : sipCpp->resume());
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_resume, doc_QAbstractSocket_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_pauseMode, "pauseMode(self) -> QAbstractSocket.PauseModes");

extern "C" {static PyObject *meth_QAbstractSocket_pauseMode(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_pauseMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QAbstractSocket::PauseModes*sipRes;

            sipRes = new  ::QAbstractSocket::PauseModes(sipCpp->pauseMode());

            return sipConvertFromNewType(sipRes,sipType_QAbstractSocket_PauseModes,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_pauseMode, doc_QAbstractSocket_pauseMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setPauseMode, "setPauseMode(self, Union[QAbstractSocket.PauseModes, QAbstractSocket.PauseMode])");

extern "C" {static PyObject *meth_QAbstractSocket_setPauseMode(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setPauseMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket::PauseModes* a0;
        int a0State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QAbstractSocket_PauseModes, &a0, &a0State))
        {
            sipCpp->setPauseMode(*a0);
            sipReleaseType(a0,sipType_QAbstractSocket_PauseModes,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setPauseMode, doc_QAbstractSocket_setPauseMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_bind, "bind(self, Union[QHostAddress, QHostAddress.SpecialAddress], port: int = 0, mode: Union[QAbstractSocket.BindMode, QAbstractSocket.BindFlag] = QAbstractSocket.DefaultForPlatform) -> bool\n"
"bind(self, port: int = 0, mode: Union[QAbstractSocket.BindMode, QAbstractSocket.BindFlag] = QAbstractSocket.DefaultForPlatform) -> bool");

extern "C" {static PyObject *meth_QAbstractSocket_bind(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_bind(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;
         ::quint16 a1 = 0;
         ::QAbstractSocket::BindMode a2def = QAbstractSocket::DefaultForPlatform;
         ::QAbstractSocket::BindMode* a2 = &a2def;
        int a2State = 0;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_port,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|tJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QHostAddress, &a0, &a0State, &a1, sipType_QAbstractSocket_BindMode, &a2, &a2State))
        {
            bool sipRes;

            sipRes = sipCpp->bind(*a0,a1,*a2);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);
            sipReleaseType(a2,sipType_QAbstractSocket_BindMode,a2State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
         ::quint16 a0 = 0;
         ::QAbstractSocket::BindMode a1def = QAbstractSocket::DefaultForPlatform;
         ::QAbstractSocket::BindMode* a1 = &a1def;
        int a1State = 0;
         ::QAbstractSocket *sipCpp;

        static const char *sipKwdList[] = {
            sipName_port,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|tJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, &a0, sipType_QAbstractSocket_BindMode, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->bind(a0,*a1);
            sipReleaseType(a1,sipType_QAbstractSocket_BindMode,a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_bind, doc_QAbstractSocket_bind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_protocolTag, "protocolTag(self) -> str");

extern "C" {static PyObject *meth_QAbstractSocket_protocolTag(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_protocolTag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSocket, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->protocolTag());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_protocolTag, doc_QAbstractSocket_protocolTag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSocket_setProtocolTag, "setProtocolTag(self, str)");

extern "C" {static PyObject *meth_QAbstractSocket_setProtocolTag(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSocket_setProtocolTag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QAbstractSocket *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractSocket, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setProtocolTag(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSocket, sipName_setProtocolTag, doc_QAbstractSocket_setProtocolTag);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractSocket(void *, const sipTypeDef *);}
static void *cast_QAbstractSocket(void *sipCppV, const sipTypeDef *targetType)
{
     ::QAbstractSocket *sipCpp = reinterpret_cast< ::QAbstractSocket *>(sipCppV);

    if (targetType == sipType_QIODevice)
        return static_cast< ::QIODevice *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractSocket(void *, int);}
static void release_QAbstractSocket(void *sipCppV, int)
{
     ::QAbstractSocket *sipCpp = reinterpret_cast< ::QAbstractSocket *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAbstractSocket(sipSimpleWrapper *);}
static void dealloc_QAbstractSocket(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractSocket *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractSocket(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractSocket(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractSocket(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstractSocket *sipCpp = SIP_NULLPTR;

    {
         ::QAbstractSocket::SocketType a0;
         ::QObject* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "EJH", sipType_QAbstractSocket_SocketType, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQAbstractSocket(a0,a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractSocket[] = {{8, 0, 1}};


static PyMethodDef methods_QAbstractSocket[] = {
    {SIP_MLNAME_CAST(sipName_abort), meth_QAbstractSocket_abort, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_abort)},
    {SIP_MLNAME_CAST(sipName_atEnd), meth_QAbstractSocket_atEnd, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_atEnd)},
    {SIP_MLNAME_CAST(sipName_bind), SIP_MLMETH_CAST(meth_QAbstractSocket_bind), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_bind)},
    {SIP_MLNAME_CAST(sipName_bytesAvailable), meth_QAbstractSocket_bytesAvailable, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_bytesAvailable)},
    {SIP_MLNAME_CAST(sipName_bytesToWrite), meth_QAbstractSocket_bytesToWrite, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_bytesToWrite)},
    {SIP_MLNAME_CAST(sipName_canReadLine), meth_QAbstractSocket_canReadLine, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_canReadLine)},
    {SIP_MLNAME_CAST(sipName_close), meth_QAbstractSocket_close, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_close)},
    {SIP_MLNAME_CAST(sipName_connectToHost), SIP_MLMETH_CAST(meth_QAbstractSocket_connectToHost), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_connectToHost)},
    {SIP_MLNAME_CAST(sipName_disconnectFromHost), meth_QAbstractSocket_disconnectFromHost, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_disconnectFromHost)},
    {SIP_MLNAME_CAST(sipName_error), meth_QAbstractSocket_error, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_error)},
    {SIP_MLNAME_CAST(sipName_flush), meth_QAbstractSocket_flush, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_flush)},
    {SIP_MLNAME_CAST(sipName_isSequential), meth_QAbstractSocket_isSequential, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_isSequential)},
    {SIP_MLNAME_CAST(sipName_isValid), meth_QAbstractSocket_isValid, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_isValid)},
    {SIP_MLNAME_CAST(sipName_localAddress), meth_QAbstractSocket_localAddress, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_localAddress)},
    {SIP_MLNAME_CAST(sipName_localPort), meth_QAbstractSocket_localPort, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_localPort)},
    {SIP_MLNAME_CAST(sipName_pauseMode), meth_QAbstractSocket_pauseMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_pauseMode)},
    {SIP_MLNAME_CAST(sipName_peerAddress), meth_QAbstractSocket_peerAddress, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_peerAddress)},
    {SIP_MLNAME_CAST(sipName_peerName), meth_QAbstractSocket_peerName, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_peerName)},
    {SIP_MLNAME_CAST(sipName_peerPort), meth_QAbstractSocket_peerPort, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_peerPort)},
    {SIP_MLNAME_CAST(sipName_protocolTag), meth_QAbstractSocket_protocolTag, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_protocolTag)},
    {SIP_MLNAME_CAST(sipName_proxy), meth_QAbstractSocket_proxy, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_proxy)},
    {SIP_MLNAME_CAST(sipName_readBufferSize), meth_QAbstractSocket_readBufferSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_readBufferSize)},
    {SIP_MLNAME_CAST(sipName_readData), meth_QAbstractSocket_readData, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_readData)},
    {SIP_MLNAME_CAST(sipName_readLineData), meth_QAbstractSocket_readLineData, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_readLineData)},
    {SIP_MLNAME_CAST(sipName_resume), meth_QAbstractSocket_resume, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_resume)},
    {SIP_MLNAME_CAST(sipName_setLocalAddress), meth_QAbstractSocket_setLocalAddress, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setLocalAddress)},
    {SIP_MLNAME_CAST(sipName_setLocalPort), meth_QAbstractSocket_setLocalPort, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setLocalPort)},
    {SIP_MLNAME_CAST(sipName_setPauseMode), meth_QAbstractSocket_setPauseMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setPauseMode)},
    {SIP_MLNAME_CAST(sipName_setPeerAddress), meth_QAbstractSocket_setPeerAddress, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setPeerAddress)},
    {SIP_MLNAME_CAST(sipName_setPeerName), meth_QAbstractSocket_setPeerName, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setPeerName)},
    {SIP_MLNAME_CAST(sipName_setPeerPort), meth_QAbstractSocket_setPeerPort, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setPeerPort)},
    {SIP_MLNAME_CAST(sipName_setProtocolTag), meth_QAbstractSocket_setProtocolTag, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setProtocolTag)},
    {SIP_MLNAME_CAST(sipName_setProxy), meth_QAbstractSocket_setProxy, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setProxy)},
    {SIP_MLNAME_CAST(sipName_setReadBufferSize), meth_QAbstractSocket_setReadBufferSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setReadBufferSize)},
    {SIP_MLNAME_CAST(sipName_setSocketDescriptor), SIP_MLMETH_CAST(meth_QAbstractSocket_setSocketDescriptor), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_setSocketDescriptor)},
    {SIP_MLNAME_CAST(sipName_setSocketError), meth_QAbstractSocket_setSocketError, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setSocketError)},
    {SIP_MLNAME_CAST(sipName_setSocketOption), meth_QAbstractSocket_setSocketOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setSocketOption)},
    {SIP_MLNAME_CAST(sipName_setSocketState), meth_QAbstractSocket_setSocketState, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_setSocketState)},
    {SIP_MLNAME_CAST(sipName_socketDescriptor), meth_QAbstractSocket_socketDescriptor, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_socketDescriptor)},
    {SIP_MLNAME_CAST(sipName_socketOption), meth_QAbstractSocket_socketOption, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_socketOption)},
    {SIP_MLNAME_CAST(sipName_socketType), meth_QAbstractSocket_socketType, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_socketType)},
    {SIP_MLNAME_CAST(sipName_state), meth_QAbstractSocket_state, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_state)},
    {SIP_MLNAME_CAST(sipName_waitForBytesWritten), SIP_MLMETH_CAST(meth_QAbstractSocket_waitForBytesWritten), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_waitForBytesWritten)},
    {SIP_MLNAME_CAST(sipName_waitForConnected), SIP_MLMETH_CAST(meth_QAbstractSocket_waitForConnected), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_waitForConnected)},
    {SIP_MLNAME_CAST(sipName_waitForDisconnected), SIP_MLMETH_CAST(meth_QAbstractSocket_waitForDisconnected), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_waitForDisconnected)},
    {SIP_MLNAME_CAST(sipName_waitForReadyRead), SIP_MLMETH_CAST(meth_QAbstractSocket_waitForReadyRead), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QAbstractSocket_waitForReadyRead)},
    {SIP_MLNAME_CAST(sipName_writeData), meth_QAbstractSocket_writeData, METH_VARARGS, SIP_MLDOC_CAST(doc_QAbstractSocket_writeData)}
};

static sipEnumMemberDef enummembers_QAbstractSocket[] = {
    {sipName_AddressInUseError, static_cast<int>( ::QAbstractSocket::AddressInUseError), 7},
    {sipName_AnyIPProtocol, static_cast<int>( ::QAbstractSocket::AnyIPProtocol), 4},
    {sipName_BoundState, static_cast<int>( ::QAbstractSocket::BoundState), 9},
    {sipName_ClosingState, static_cast<int>( ::QAbstractSocket::ClosingState), 9},
    {sipName_ConnectedState, static_cast<int>( ::QAbstractSocket::ConnectedState), 9},
    {sipName_ConnectingState, static_cast<int>( ::QAbstractSocket::ConnectingState), 9},
    {sipName_ConnectionRefusedError, static_cast<int>( ::QAbstractSocket::ConnectionRefusedError), 7},
    {sipName_DatagramTooLargeError, static_cast<int>( ::QAbstractSocket::DatagramTooLargeError), 7},
    {sipName_DefaultForPlatform, static_cast<int>( ::QAbstractSocket::DefaultForPlatform), 2},
    {sipName_DontShareAddress, static_cast<int>( ::QAbstractSocket::DontShareAddress), 2},
    {sipName_HostLookupState, static_cast<int>( ::QAbstractSocket::HostLookupState), 9},
    {sipName_HostNotFoundError, static_cast<int>( ::QAbstractSocket::HostNotFoundError), 7},
    {sipName_IPv4Protocol, static_cast<int>( ::QAbstractSocket::IPv4Protocol), 4},
    {sipName_IPv6Protocol, static_cast<int>( ::QAbstractSocket::IPv6Protocol), 4},
    {sipName_KeepAliveOption, static_cast<int>( ::QAbstractSocket::KeepAliveOption), 8},
    {sipName_ListeningState, static_cast<int>( ::QAbstractSocket::ListeningState), 9},
    {sipName_LowDelayOption, static_cast<int>( ::QAbstractSocket::LowDelayOption), 8},
    {sipName_MulticastLoopbackOption, static_cast<int>( ::QAbstractSocket::MulticastLoopbackOption), 8},
    {sipName_MulticastTtlOption, static_cast<int>( ::QAbstractSocket::MulticastTtlOption), 8},
    {sipName_NetworkError, static_cast<int>( ::QAbstractSocket::NetworkError), 7},
    {sipName_OperationError, static_cast<int>( ::QAbstractSocket::OperationError), 7},
    {sipName_PathMtuSocketOption, static_cast<int>( ::QAbstractSocket::PathMtuSocketOption), 8},
    {sipName_PauseNever, static_cast<int>( ::QAbstractSocket::PauseNever), 5},
    {sipName_PauseOnSslErrors, static_cast<int>( ::QAbstractSocket::PauseOnSslErrors), 5},
    {sipName_ProxyAuthenticationRequiredError, static_cast<int>( ::QAbstractSocket::ProxyAuthenticationRequiredError), 7},
    {sipName_ProxyConnectionClosedError, static_cast<int>( ::QAbstractSocket::ProxyConnectionClosedError), 7},
    {sipName_ProxyConnectionRefusedError, static_cast<int>( ::QAbstractSocket::ProxyConnectionRefusedError), 7},
    {sipName_ProxyConnectionTimeoutError, static_cast<int>( ::QAbstractSocket::ProxyConnectionTimeoutError), 7},
    {sipName_ProxyNotFoundError, static_cast<int>( ::QAbstractSocket::ProxyNotFoundError), 7},
    {sipName_ProxyProtocolError, static_cast<int>( ::QAbstractSocket::ProxyProtocolError), 7},
    {sipName_ReceiveBufferSizeSocketOption, static_cast<int>( ::QAbstractSocket::ReceiveBufferSizeSocketOption), 8},
    {sipName_RemoteHostClosedError, static_cast<int>( ::QAbstractSocket::RemoteHostClosedError), 7},
    {sipName_ReuseAddressHint, static_cast<int>( ::QAbstractSocket::ReuseAddressHint), 2},
    {sipName_SctpSocket, static_cast<int>( ::QAbstractSocket::SctpSocket), 10},
    {sipName_SendBufferSizeSocketOption, static_cast<int>( ::QAbstractSocket::SendBufferSizeSocketOption), 8},
    {sipName_ShareAddress, static_cast<int>( ::QAbstractSocket::ShareAddress), 2},
    {sipName_SocketAccessError, static_cast<int>( ::QAbstractSocket::SocketAccessError), 7},
    {sipName_SocketAddressNotAvailableError, static_cast<int>( ::QAbstractSocket::SocketAddressNotAvailableError), 7},
    {sipName_SocketResourceError, static_cast<int>( ::QAbstractSocket::SocketResourceError), 7},
    {sipName_SocketTimeoutError, static_cast<int>( ::QAbstractSocket::SocketTimeoutError), 7},
    {sipName_SslHandshakeFailedError, static_cast<int>( ::QAbstractSocket::SslHandshakeFailedError), 7},
    {sipName_SslInternalError, static_cast<int>( ::QAbstractSocket::SslInternalError), 7},
    {sipName_SslInvalidUserDataError, static_cast<int>( ::QAbstractSocket::SslInvalidUserDataError), 7},
    {sipName_TcpSocket, static_cast<int>( ::QAbstractSocket::TcpSocket), 10},
    {sipName_TemporaryError, static_cast<int>( ::QAbstractSocket::TemporaryError), 7},
    {sipName_TypeOfServiceOption, static_cast<int>( ::QAbstractSocket::TypeOfServiceOption), 8},
    {sipName_UdpSocket, static_cast<int>( ::QAbstractSocket::UdpSocket), 10},
    {sipName_UnconnectedState, static_cast<int>( ::QAbstractSocket::UnconnectedState), 9},
    {sipName_UnfinishedSocketOperationError, static_cast<int>( ::QAbstractSocket::UnfinishedSocketOperationError), 7},
    {sipName_UnknownNetworkLayerProtocol, static_cast<int>( ::QAbstractSocket::UnknownNetworkLayerProtocol), 4},
    {sipName_UnknownSocketError, static_cast<int>( ::QAbstractSocket::UnknownSocketError), 7},
    {sipName_UnknownSocketType, static_cast<int>( ::QAbstractSocket::UnknownSocketType), 10},
    {sipName_UnsupportedSocketOperationError, static_cast<int>( ::QAbstractSocket::UnsupportedSocketOperationError), 7},
};

PyDoc_STRVAR(doc_QAbstractSocket, "\1QAbstractSocket(QAbstractSocket.SocketType, QObject)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAbstractSocket[] = {
    {"proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)", "\1proxyAuthenticationRequired(self, QNetworkProxy, QAuthenticator)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QAbstractSocket::SocketError)", "\1errorOccurred(self, QAbstractSocket.SocketError)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QAbstractSocket::SocketState)", "\1stateChanged(self, QAbstractSocket.SocketState)", SIP_NULLPTR, SIP_NULLPTR},
    {"disconnected()", "\1disconnected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"connected()", "\1connected(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hostFound()", "\1hostFound(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QAbstractSocket::SocketError)", "\1error(self, QAbstractSocket.SocketError)", &methods_QAbstractSocket[9], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAbstractSocket = {
    & ::QAbstractSocket::staticMetaObject,
    0,
    signals_QAbstractSocket,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QAbstractSocket = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractSocket,
        {SIP_NULLPTR},
        &plugin_QAbstractSocket
    },
    {
        sipNameNr_QAbstractSocket,
        {0, 0, 1},
        47, methods_QAbstractSocket,
        53, enummembers_QAbstractSocket,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractSocket,
    -1,
    -1,
    supers_QAbstractSocket,
    SIP_NULLPTR,
    init_type_QAbstractSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QAbstractSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAbstractSocket,
    cast_QAbstractSocket,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
