/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlincubator.sip"
#include <qqmlincubator.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubationController.cpp"

#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlIncubationController.cpp"


class sipQQmlIncubationController : public  ::QQmlIncubationController
{
public:
    sipQQmlIncubationController();
    virtual ~sipQQmlIncubationController();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void incubatingObjectCountChanged(int) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlIncubationController(const sipQQmlIncubationController &);
    sipQQmlIncubationController &operator = (const sipQQmlIncubationController &);

    char sipPyMethods[1];
};

sipQQmlIncubationController::sipQQmlIncubationController():  ::QQmlIncubationController(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlIncubationController::~sipQQmlIncubationController()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQQmlIncubationController::incubatingObjectCountChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_incubatingObjectCountChanged);

    if (!sipMeth)
    {
         ::QQmlIncubationController::incubatingObjectCountChanged(a0);
        return;
    }

    extern void sipVH_QtQml_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtQml_15(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlIncubationController_engine, "engine(self) -> QQmlEngine");

extern "C" {static PyObject *meth_QQmlIncubationController_engine(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubationController_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubationController, &sipCpp))
        {
             ::QQmlEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes,sipType_QQmlEngine,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubationController, sipName_engine, doc_QQmlIncubationController_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubationController_incubatingObjectCount, "incubatingObjectCount(self) -> int");

extern "C" {static PyObject *meth_QQmlIncubationController_incubatingObjectCount(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubationController_incubatingObjectCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlIncubationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlIncubationController, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->incubatingObjectCount();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubationController, sipName_incubatingObjectCount, doc_QQmlIncubationController_incubatingObjectCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubationController_incubateFor, "incubateFor(self, int)");

extern "C" {static PyObject *meth_QQmlIncubationController_incubateFor(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubationController_incubateFor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QQmlIncubationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QQmlIncubationController, &sipCpp, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->incubateFor(a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubationController, sipName_incubateFor, doc_QQmlIncubationController_incubateFor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlIncubationController_incubatingObjectCountChanged, "incubatingObjectCountChanged(self, int)");

extern "C" {static PyObject *meth_QQmlIncubationController_incubatingObjectCountChanged(PyObject *, PyObject *);}
static PyObject *meth_QQmlIncubationController_incubatingObjectCountChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
         ::QQmlIncubationController *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QQmlIncubationController, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QQmlIncubationController::incubatingObjectCountChanged(a0) : sipCpp->incubatingObjectCountChanged(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlIncubationController, sipName_incubatingObjectCountChanged, doc_QQmlIncubationController_incubatingObjectCountChanged);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlIncubationController(void *, int);}
static void release_QQmlIncubationController(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQQmlIncubationController *>(sipCppV);
    else
        delete reinterpret_cast< ::QQmlIncubationController *>(sipCppV);
}


extern "C" {static void *array_QQmlIncubationController(Py_ssize_t);}
static void *array_QQmlIncubationController(Py_ssize_t sipNrElem)
{
    return new  ::QQmlIncubationController[sipNrElem];
}


extern "C" {static void dealloc_QQmlIncubationController(sipSimpleWrapper *);}
static void dealloc_QQmlIncubationController(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlIncubationController *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlIncubationController(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlIncubationController(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlIncubationController(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQmlIncubationController *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQmlIncubationController();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQmlIncubationController[] = {
    {SIP_MLNAME_CAST(sipName_engine), meth_QQmlIncubationController_engine, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubationController_engine)},
    {SIP_MLNAME_CAST(sipName_incubateFor), meth_QQmlIncubationController_incubateFor, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubationController_incubateFor)},
    {SIP_MLNAME_CAST(sipName_incubatingObjectCount), meth_QQmlIncubationController_incubatingObjectCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubationController_incubatingObjectCount)},
    {SIP_MLNAME_CAST(sipName_incubatingObjectCountChanged), meth_QQmlIncubationController_incubatingObjectCountChanged, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlIncubationController_incubatingObjectCountChanged)}
};

PyDoc_STRVAR(doc_QQmlIncubationController, "\1QQmlIncubationController()");


static pyqt5ClassPluginDef plugin_QQmlIncubationController = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlIncubationController = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlIncubationController,
        {SIP_NULLPTR},
        &plugin_QQmlIncubationController
    },
    {
        sipNameNr_QQmlIncubationController,
        {0, 0, 1},
        4, methods_QQmlIncubationController,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlIncubationController,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQmlIncubationController,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlIncubationController,
    SIP_NULLPTR,
    array_QQmlIncubationController,
    SIP_NULLPTR,
    release_QQmlIncubationController,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
