/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector2d.sip"
#include <qvector2d.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"

#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"
#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector4d.sip"
#include <qvector4d.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"


PyDoc_STRVAR(doc_QVector2D_length, "length(self) -> float");

extern "C" {static PyObject *meth_QVector2D_length(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_length(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->length();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_length, doc_QVector2D_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_lengthSquared, "lengthSquared(self) -> float");

extern "C" {static PyObject *meth_QVector2D_lengthSquared(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_lengthSquared(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->lengthSquared();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_lengthSquared, doc_QVector2D_lengthSquared);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_normalized, "normalized(self) -> QVector2D");

extern "C" {static PyObject *meth_QVector2D_normalized(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_normalized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D(sipCpp->normalized());

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_normalized, doc_QVector2D_normalized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_normalize, "normalize(self)");

extern "C" {static PyObject *meth_QVector2D_normalize(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_normalize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            sipCpp->normalize();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_normalize, doc_QVector2D_normalize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_dotProduct, "dotProduct(QVector2D, QVector2D) -> float");

extern "C" {static PyObject *meth_QVector2D_dotProduct(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_dotProduct(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
            float sipRes;

            sipRes =  ::QVector2D::dotProduct(*a0,*a1);

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_dotProduct, doc_QVector2D_dotProduct);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_toVector3D, "toVector3D(self) -> QVector3D");

extern "C" {static PyObject *meth_QVector2D_toVector3D(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_toVector3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
             ::QVector3D*sipRes;

            sipRes = new  ::QVector3D(sipCpp->toVector3D());

            return sipConvertFromNewType(sipRes,sipType_QVector3D,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_toVector3D, doc_QVector2D_toVector3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_toVector4D, "toVector4D(self) -> QVector4D");

extern "C" {static PyObject *meth_QVector2D_toVector4D(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_toVector4D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
             ::QVector4D*sipRes;

            sipRes = new  ::QVector4D(sipCpp->toVector4D());

            return sipConvertFromNewType(sipRes,sipType_QVector4D,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_toVector4D, doc_QVector2D_toVector4D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QVector2D_isNull(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_isNull, doc_QVector2D_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_x, "x(self) -> float");

extern "C" {static PyObject *meth_QVector2D_x(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_x(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->x();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_x, doc_QVector2D_x);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_y, "y(self) -> float");

extern "C" {static PyObject *meth_QVector2D_y(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_y(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->y();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_y, doc_QVector2D_y);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_setX, "setX(self, float)");

extern "C" {static PyObject *meth_QVector2D_setX(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_setX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
         ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QVector2D, &sipCpp, &a0))
        {
            sipCpp->setX(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_setX, doc_QVector2D_setX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_setY, "setY(self, float)");

extern "C" {static PyObject *meth_QVector2D_setY(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_setY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
         ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QVector2D, &sipCpp, &a0))
        {
            sipCpp->setY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_setY, doc_QVector2D_setY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_toPoint, "toPoint(self) -> QPoint");

extern "C" {static PyObject *meth_QVector2D_toPoint(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_toPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->toPoint());

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_toPoint, doc_QVector2D_toPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_toPointF, "toPointF(self) -> QPointF");

extern "C" {static PyObject *meth_QVector2D_toPointF(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_toPointF(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVector2D, &sipCpp))
        {
             ::QPointF*sipRes;

            sipRes = new  ::QPointF(sipCpp->toPointF());

            return sipConvertFromNewType(sipRes,sipType_QPointF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_toPointF, doc_QVector2D_toPointF);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_distanceToPoint, "distanceToPoint(self, QVector2D) -> float");

extern "C" {static PyObject *meth_QVector2D_distanceToPoint(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_distanceToPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QVector2D, &sipCpp, sipType_QVector2D, &a0))
        {
            float sipRes;

            sipRes = sipCpp->distanceToPoint(*a0);

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_distanceToPoint, doc_QVector2D_distanceToPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVector2D_distanceToLine, "distanceToLine(self, QVector2D, QVector2D) -> float");

extern "C" {static PyObject *meth_QVector2D_distanceToLine(PyObject *, PyObject *);}
static PyObject *meth_QVector2D_distanceToLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;
        const  ::QVector2D *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QVector2D, &sipCpp, sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
            float sipRes;

            sipRes = sipCpp->distanceToLine(*a0,*a1);

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName_distanceToLine, doc_QVector2D_distanceToLine);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QVector2D___eq__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QVector2D, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QVector2D___ne__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QVector2D, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QVector2D___div__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___div__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        float a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9f", sipType_QVector2D, &a0, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 / a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 / *a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, div_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QVector2D___add__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___add__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 + *a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, add_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QVector2D___sub__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___sub__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 - *a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, sub_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QVector2D___mul__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___mul__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "fJ9", &a0, sipType_QVector2D, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    {
        const  ::QVector2D* a0;
        float a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9f", sipType_QVector2D, &a0, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 * a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, mul_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QVector2D___neg__(PyObject *);}
static PyObject *slot_QVector2D___neg__(PyObject *sipSelf)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
             ::QVector2D*sipRes;

            sipRes = new  ::QVector2D(-(*sipCpp));

            return sipConvertFromNewType(sipRes,sipType_QVector2D,SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QVector2D___getitem__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___getitem__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            float sipRes;

            sipRes = (*sipCpp)[a0];

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVector2D, sipName___getitem__, SIP_NULLPTR);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QVector2D___idiv__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___idiv__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QVector2D)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1f", &a0))
        {
            sipCpp-> ::QVector2D::operator/=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            sipCpp-> ::QVector2D::operator/=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QVector2D___imul__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___imul__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QVector2D)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1f", &a0))
        {
            sipCpp-> ::QVector2D::operator*=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            sipCpp-> ::QVector2D::operator*=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QVector2D___isub__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___isub__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QVector2D)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            sipCpp-> ::QVector2D::operator-=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QVector2D___iadd__(PyObject *,PyObject *);}
static PyObject *slot_QVector2D___iadd__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QVector2D)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVector2D* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVector2D, &a0))
        {
            sipCpp-> ::QVector2D::operator+=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QVector2D___repr__(PyObject *);}
static PyObject *slot_QVector2D___repr__(PyObject *sipSelf)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QVector2D));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector2d.sip"
        PyObject *x = PyFloat_FromDouble(sipCpp->x());
        PyObject *y = PyFloat_FromDouble(sipCpp->y());
        
        if (x && y)
        {
        #if PY_MAJOR_VERSION >= 3
            sipRes = PyUnicode_FromFormat("PyQt5.QtGui.QVector2D(%R, %R)", x, y);
        #else
            sipRes = PyString_FromString("PyQt5.QtGui.QVector2D(");
            PyString_ConcatAndDel(&sipRes, PyObject_Repr(x));
            PyString_ConcatAndDel(&sipRes, PyString_FromString(", "));
            PyString_ConcatAndDel(&sipRes, PyObject_Repr(y));
            PyString_ConcatAndDel(&sipRes, PyString_FromString(")"));
        #endif
        }
        
        Py_XDECREF(x);
        Py_XDECREF(y);
#line 966 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QVector2D(void *, int);}
static void release_QVector2D(void *sipCppV, int)
{
    delete reinterpret_cast< ::QVector2D *>(sipCppV);
}


extern "C" {static PyObject *pickle_QVector2D(void *);}
static PyObject *pickle_QVector2D(void *sipCppV)
{
     ::QVector2D *sipCpp = reinterpret_cast< ::QVector2D *>(sipCppV);
    PyObject *sipRes;

#line 34 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector2d.sip"
    sipRes = Py_BuildValue((char *)"dd", (double)sipCpp->x(), (double)sipCpp->y());
#line 992 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQVector2D.cpp"

    return sipRes;
}


extern "C" {static void *array_QVector2D(Py_ssize_t);}
static void *array_QVector2D(Py_ssize_t sipNrElem)
{
    return new  ::QVector2D[sipNrElem];
}


extern "C" {static void assign_QVector2D(void *, SIP_SSIZE_T, void *);}
static void assign_QVector2D(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QVector2D *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QVector2D *>(sipSrc);
}


extern "C" {static void *copy_QVector2D(const void *, SIP_SSIZE_T);}
static void *copy_QVector2D(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QVector2D(reinterpret_cast<const  ::QVector2D *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QVector2D(sipSimpleWrapper *);}
static void dealloc_QVector2D(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QVector2D(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QVector2D(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QVector2D(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QVector2D *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QVector2D();

            return sipCpp;
        }
    }

    {
        float a0;
        float a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "ff", &a0, &a1))
        {
            sipCpp = new  ::QVector2D(a0,a1);

            return sipCpp;
        }
    }

    {
        const  ::QPoint* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPoint, &a0))
        {
            sipCpp = new  ::QVector2D(*a0);

            return sipCpp;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QPointF, &a0, &a0State))
        {
            sipCpp = new  ::QVector2D(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return sipCpp;
        }
    }

    {
        const  ::QVector3D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector3D, &a0))
        {
            sipCpp = new  ::QVector2D(*a0);

            return sipCpp;
        }
    }

    {
        const  ::QVector4D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector4D, &a0))
        {
            sipCpp = new  ::QVector2D(*a0);

            return sipCpp;
        }
    }

    {
        const  ::QVector2D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector2D, &a0))
        {
            sipCpp = new  ::QVector2D(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QVector2D[] = {
    {(void *)slot_QVector2D___eq__, eq_slot},
    {(void *)slot_QVector2D___ne__, ne_slot},
    {(void *)slot_QVector2D___div__, div_slot},
    {(void *)slot_QVector2D___add__, add_slot},
    {(void *)slot_QVector2D___sub__, sub_slot},
    {(void *)slot_QVector2D___mul__, mul_slot},
    {(void *)slot_QVector2D___neg__, neg_slot},
    {(void *)slot_QVector2D___getitem__, getitem_slot},
    {(void *)slot_QVector2D___idiv__, idiv_slot},
    {(void *)slot_QVector2D___imul__, imul_slot},
    {(void *)slot_QVector2D___isub__, isub_slot},
    {(void *)slot_QVector2D___iadd__, iadd_slot},
    {(void *)slot_QVector2D___repr__, repr_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QVector2D[] = {
    {SIP_MLNAME_CAST(sipName_distanceToLine), meth_QVector2D_distanceToLine, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_distanceToLine)},
    {SIP_MLNAME_CAST(sipName_distanceToPoint), meth_QVector2D_distanceToPoint, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_distanceToPoint)},
    {SIP_MLNAME_CAST(sipName_dotProduct), meth_QVector2D_dotProduct, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_dotProduct)},
    {SIP_MLNAME_CAST(sipName_isNull), meth_QVector2D_isNull, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_isNull)},
    {SIP_MLNAME_CAST(sipName_length), meth_QVector2D_length, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_length)},
    {SIP_MLNAME_CAST(sipName_lengthSquared), meth_QVector2D_lengthSquared, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_lengthSquared)},
    {SIP_MLNAME_CAST(sipName_normalize), meth_QVector2D_normalize, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_normalize)},
    {SIP_MLNAME_CAST(sipName_normalized), meth_QVector2D_normalized, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_normalized)},
    {SIP_MLNAME_CAST(sipName_setX), meth_QVector2D_setX, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_setX)},
    {SIP_MLNAME_CAST(sipName_setY), meth_QVector2D_setY, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_setY)},
    {SIP_MLNAME_CAST(sipName_toPoint), meth_QVector2D_toPoint, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_toPoint)},
    {SIP_MLNAME_CAST(sipName_toPointF), meth_QVector2D_toPointF, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_toPointF)},
    {SIP_MLNAME_CAST(sipName_toVector3D), meth_QVector2D_toVector3D, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_toVector3D)},
    {SIP_MLNAME_CAST(sipName_toVector4D), meth_QVector2D_toVector4D, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_toVector4D)},
    {SIP_MLNAME_CAST(sipName_x), meth_QVector2D_x, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_x)},
    {SIP_MLNAME_CAST(sipName_y), meth_QVector2D_y, METH_VARARGS, SIP_MLDOC_CAST(doc_QVector2D_y)}
};

PyDoc_STRVAR(doc_QVector2D, "\1QVector2D()\n"
"QVector2D(float, float)\n"
"QVector2D(QPoint)\n"
"QVector2D(Union[QPointF, QPoint])\n"
"QVector2D(QVector3D)\n"
"QVector2D(QVector4D)\n"
"QVector2D(QVector2D)");


static pyqt5ClassPluginDef plugin_QVector2D = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QVector2D = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QVector2D,
        {SIP_NULLPTR},
        &plugin_QVector2D
    },
    {
        sipNameNr_QVector2D,
        {0, 0, 1},
        16, methods_QVector2D,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QVector2D,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QVector2D,
    init_type_QVector2D,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QVector2D,
    assign_QVector2D,
    array_QVector2D,
    copy_QVector2D,
    release_QVector2D,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    pickle_QVector2D,
    SIP_NULLPTR,
    SIP_NULLPTR
};
