/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworksession.sip"
#include <qnetworksession.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkconfiguration.sip"
#include <qnetworkconfiguration.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworksession.sip"
#include <qnetworksession.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkinterface.sip"
#include <qnetworkinterface.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkQNetworkSession.cpp"


class sipQNetworkSession : public  ::QNetworkSession
{
public:
    sipQNetworkSession(const  ::QNetworkConfiguration&, ::QObject*);
    virtual ~sipQNetworkSession();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQNetworkSession(const sipQNetworkSession &);
    sipQNetworkSession &operator = (const sipQNetworkSession &);

    char sipPyMethods[7];
};

sipQNetworkSession::sipQNetworkSession(const  ::QNetworkConfiguration& a0, ::QObject*a1):  ::QNetworkSession(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQNetworkSession::~sipQNetworkSession()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQNetworkSession::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf,sipType_QNetworkSession);

    return  ::QNetworkSession::metaObject();
}

int sipQNetworkSession::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QNetworkSession::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf,sipType_QNetworkSession,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQNetworkSession::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QNetworkSession, _clname, &sipCpp) ? sipCpp :  ::QNetworkSession::qt_metacast(_clname));
}

bool sipQNetworkSession::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QNetworkSession::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQNetworkSession::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QNetworkSession::eventFilter(a0,a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQNetworkSession::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QNetworkSession::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkSession::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QNetworkSession::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkSession::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QNetworkSession::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkSession::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QNetworkSession::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQNetworkSession::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QNetworkSession::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QNetworkSession_isOpen, "isOpen(self) -> bool");

extern "C" {static PyObject *meth_QNetworkSession_isOpen(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_isOpen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isOpen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_isOpen, doc_QNetworkSession_isOpen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_configuration, "configuration(self) -> QNetworkConfiguration");

extern "C" {static PyObject *meth_QNetworkSession_configuration(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_configuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QNetworkConfiguration*sipRes;

            sipRes = new  ::QNetworkConfiguration(sipCpp->configuration());

            return sipConvertFromNewType(sipRes,sipType_QNetworkConfiguration,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_configuration, doc_QNetworkSession_configuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_interface, "interface(self) -> QNetworkInterface");

extern "C" {static PyObject *meth_QNetworkSession_interface(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_interface(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QNetworkInterface*sipRes;

            sipRes = new  ::QNetworkInterface(sipCpp->interface());

            return sipConvertFromNewType(sipRes,sipType_QNetworkInterface,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_interface, doc_QNetworkSession_interface);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_state, "state(self) -> QNetworkSession.State");

extern "C" {static PyObject *meth_QNetworkSession_state(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QNetworkSession::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNetworkSession_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_state, doc_QNetworkSession_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_error, "error(self) -> QNetworkSession.SessionError");

extern "C" {static PyObject *meth_QNetworkSession_error(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QNetworkSession::SessionError sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QNetworkSession_SessionError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_error, doc_QNetworkSession_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QNetworkSession_errorString(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_errorString, doc_QNetworkSession_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_sessionProperty, "sessionProperty(self, str) -> Any");

extern "C" {static PyObject *meth_QNetworkSession_sessionProperty(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_sessionProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QNetworkSession, &sipCpp, sipType_QString,&a0, &a0State))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant(sipCpp->sessionProperty(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_sessionProperty, doc_QNetworkSession_sessionProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_setSessionProperty, "setSessionProperty(self, str, Any)");

extern "C" {static PyObject *meth_QNetworkSession_setSessionProperty(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_setSessionProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QVariant* a1;
        int a1State = 0;
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QNetworkSession, &sipCpp, sipType_QString,&a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setSessionProperty(*a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1),sipType_QVariant,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_setSessionProperty, doc_QNetworkSession_setSessionProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_bytesWritten, "bytesWritten(self) -> int");

extern "C" {static PyObject *meth_QNetworkSession_bytesWritten(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_bytesWritten(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::quint64 sipRes;

            sipRes = sipCpp->bytesWritten();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_bytesWritten, doc_QNetworkSession_bytesWritten);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_bytesReceived, "bytesReceived(self) -> int");

extern "C" {static PyObject *meth_QNetworkSession_bytesReceived(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_bytesReceived(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::quint64 sipRes;

            sipRes = sipCpp->bytesReceived();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_bytesReceived, doc_QNetworkSession_bytesReceived);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_activeTime, "activeTime(self) -> int");

extern "C" {static PyObject *meth_QNetworkSession_activeTime(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_activeTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::quint64 sipRes;

            sipRes = sipCpp->activeTime();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_activeTime, doc_QNetworkSession_activeTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_waitForOpened, "waitForOpened(self, msecs: int = 30000) -> bool");

extern "C" {static PyObject *meth_QNetworkSession_waitForOpened(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_waitForOpened(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 30000;
         ::QNetworkSession *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QNetworkSession, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForOpened(a0);
            Py_END_ALLOW_THREADS

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_waitForOpened, doc_QNetworkSession_waitForOpened);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_open, "open(self)");

extern "C" {static PyObject *meth_QNetworkSession_open(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_open(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->open();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_open, doc_QNetworkSession_open);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_close, "close(self)");

extern "C" {static PyObject *meth_QNetworkSession_close(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->close();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_close, doc_QNetworkSession_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_stop, "stop(self)");

extern "C" {static PyObject *meth_QNetworkSession_stop(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_stop, doc_QNetworkSession_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_migrate, "migrate(self)");

extern "C" {static PyObject *meth_QNetworkSession_migrate(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_migrate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->migrate();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_migrate, doc_QNetworkSession_migrate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_ignore, "ignore(self)");

extern "C" {static PyObject *meth_QNetworkSession_ignore(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_ignore(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->ignore();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_ignore, doc_QNetworkSession_ignore);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_accept, "accept(self)");

extern "C" {static PyObject *meth_QNetworkSession_accept(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_accept(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->accept();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_accept, doc_QNetworkSession_accept);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_reject, "reject(self)");

extern "C" {static PyObject *meth_QNetworkSession_reject(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_reject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
            sipCpp->reject();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_reject, doc_QNetworkSession_reject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_connectNotify, "connectNotify(self, QMetaMethod)");

extern "C" {static PyObject *meth_QNetworkSession_connectNotify(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_connectNotify(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkSession, &sipCpp, sipType_QMetaMethod, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkSession::connectNotify(*a0) : sipCpp->connectNotify(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_connectNotify, doc_QNetworkSession_connectNotify);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_disconnectNotify, "disconnectNotify(self, QMetaMethod)");

extern "C" {static PyObject *meth_QNetworkSession_disconnectNotify(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_disconnectNotify(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
         ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QNetworkSession, &sipCpp, sipType_QMetaMethod, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QNetworkSession::disconnectNotify(*a0) : sipCpp->disconnectNotify(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_disconnectNotify, doc_QNetworkSession_disconnectNotify);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QNetworkSession_usagePolicies, "usagePolicies(self) -> QNetworkSession.UsagePolicies");

extern "C" {static PyObject *meth_QNetworkSession_usagePolicies(PyObject *, PyObject *);}
static PyObject *meth_QNetworkSession_usagePolicies(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QNetworkSession *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QNetworkSession, &sipCpp))
        {
             ::QNetworkSession::UsagePolicies*sipRes;

            sipRes = new  ::QNetworkSession::UsagePolicies(sipCpp->usagePolicies());

            return sipConvertFromNewType(sipRes,sipType_QNetworkSession_UsagePolicies,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QNetworkSession, sipName_usagePolicies, doc_QNetworkSession_usagePolicies);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QNetworkSession(void *, const sipTypeDef *);}
static void *cast_QNetworkSession(void *sipCppV, const sipTypeDef *targetType)
{
     ::QNetworkSession *sipCpp = reinterpret_cast< ::QNetworkSession *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QNetworkSession(void *, int);}
static void release_QNetworkSession(void *sipCppV, int)
{
     ::QNetworkSession *sipCpp = reinterpret_cast< ::QNetworkSession *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QNetworkSession(sipSimpleWrapper *);}
static void dealloc_QNetworkSession(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQNetworkSession *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QNetworkSession(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QNetworkSession(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QNetworkSession(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQNetworkSession *sipCpp = SIP_NULLPTR;

    {
        const  ::QNetworkConfiguration* a0;
         ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QNetworkConfiguration, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQNetworkSession(*a0,a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QNetworkSession[] = {{12, 0, 1}};


static PyMethodDef methods_QNetworkSession[] = {
    {SIP_MLNAME_CAST(sipName_accept), meth_QNetworkSession_accept, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_accept)},
    {SIP_MLNAME_CAST(sipName_activeTime), meth_QNetworkSession_activeTime, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_activeTime)},
    {SIP_MLNAME_CAST(sipName_bytesReceived), meth_QNetworkSession_bytesReceived, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_bytesReceived)},
    {SIP_MLNAME_CAST(sipName_bytesWritten), meth_QNetworkSession_bytesWritten, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_bytesWritten)},
    {SIP_MLNAME_CAST(sipName_close), meth_QNetworkSession_close, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_close)},
    {SIP_MLNAME_CAST(sipName_configuration), meth_QNetworkSession_configuration, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_configuration)},
    {SIP_MLNAME_CAST(sipName_connectNotify), meth_QNetworkSession_connectNotify, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_connectNotify)},
    {SIP_MLNAME_CAST(sipName_disconnectNotify), meth_QNetworkSession_disconnectNotify, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_disconnectNotify)},
    {SIP_MLNAME_CAST(sipName_error), meth_QNetworkSession_error, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_error)},
    {SIP_MLNAME_CAST(sipName_errorString), meth_QNetworkSession_errorString, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_errorString)},
    {SIP_MLNAME_CAST(sipName_ignore), meth_QNetworkSession_ignore, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_ignore)},
    {SIP_MLNAME_CAST(sipName_interface), meth_QNetworkSession_interface, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_interface)},
    {SIP_MLNAME_CAST(sipName_isOpen), meth_QNetworkSession_isOpen, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_isOpen)},
    {SIP_MLNAME_CAST(sipName_migrate), meth_QNetworkSession_migrate, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_migrate)},
    {SIP_MLNAME_CAST(sipName_open), meth_QNetworkSession_open, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_open)},
    {SIP_MLNAME_CAST(sipName_reject), meth_QNetworkSession_reject, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_reject)},
    {SIP_MLNAME_CAST(sipName_sessionProperty), meth_QNetworkSession_sessionProperty, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_sessionProperty)},
    {SIP_MLNAME_CAST(sipName_setSessionProperty), meth_QNetworkSession_setSessionProperty, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_setSessionProperty)},
    {SIP_MLNAME_CAST(sipName_state), meth_QNetworkSession_state, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_state)},
    {SIP_MLNAME_CAST(sipName_stop), meth_QNetworkSession_stop, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_stop)},
    {SIP_MLNAME_CAST(sipName_usagePolicies), meth_QNetworkSession_usagePolicies, METH_VARARGS, SIP_MLDOC_CAST(doc_QNetworkSession_usagePolicies)},
    {SIP_MLNAME_CAST(sipName_waitForOpened), SIP_MLMETH_CAST(meth_QNetworkSession_waitForOpened), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QNetworkSession_waitForOpened)}
};

static sipEnumMemberDef enummembers_QNetworkSession[] = {
    {sipName_Closing, static_cast<int>( ::QNetworkSession::Closing), 101},
    {sipName_Connected, static_cast<int>( ::QNetworkSession::Connected), 101},
    {sipName_Connecting, static_cast<int>( ::QNetworkSession::Connecting), 101},
    {sipName_Disconnected, static_cast<int>( ::QNetworkSession::Disconnected), 101},
    {sipName_Invalid, static_cast<int>( ::QNetworkSession::Invalid), 101},
    {sipName_InvalidConfigurationError, static_cast<int>( ::QNetworkSession::InvalidConfigurationError), 100},
    {sipName_NoBackgroundTrafficPolicy, static_cast<int>( ::QNetworkSession::NoBackgroundTrafficPolicy), 103},
    {sipName_NoPolicy, static_cast<int>( ::QNetworkSession::NoPolicy), 103},
    {sipName_NotAvailable, static_cast<int>( ::QNetworkSession::NotAvailable), 101},
    {sipName_OperationNotSupportedError, static_cast<int>( ::QNetworkSession::OperationNotSupportedError), 100},
    {sipName_Roaming, static_cast<int>( ::QNetworkSession::Roaming), 101},
    {sipName_RoamingError, static_cast<int>( ::QNetworkSession::RoamingError), 100},
    {sipName_SessionAbortedError, static_cast<int>( ::QNetworkSession::SessionAbortedError), 100},
    {sipName_UnknownSessionError, static_cast<int>( ::QNetworkSession::UnknownSessionError), 100},
};

PyDoc_STRVAR(doc_QNetworkSession, "\1QNetworkSession(QNetworkConfiguration, parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QNetworkSession[] = {
    {"usagePoliciesChanged(QNetworkSession::UsagePolicies)", "\1usagePoliciesChanged(self, Union[QNetworkSession.UsagePolicies, QNetworkSession.UsagePolicy])", SIP_NULLPTR, SIP_NULLPTR},
    {"newConfigurationActivated()", "\1newConfigurationActivated(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"preferredConfigurationChanged(QNetworkConfiguration,bool)", "\1preferredConfigurationChanged(self, QNetworkConfiguration, bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"closed()", "\1closed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"opened()", "\1opened(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QNetworkSession::State)", "\1stateChanged(self, QNetworkSession.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QNetworkSession::SessionError)", "\1error(self, QNetworkSession.SessionError)", &methods_QNetworkSession[8], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QNetworkSession = {
    & ::QNetworkSession::staticMetaObject,
    0,
    signals_QNetworkSession,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QNetworkSession = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QNetworkSession,
        {SIP_NULLPTR},
        &plugin_QNetworkSession
    },
    {
        sipNameNr_QNetworkSession,
        {0, 0, 1},
        22, methods_QNetworkSession,
        14, enummembers_QNetworkSession,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QNetworkSession,
    -1,
    -1,
    supers_QNetworkSession,
    SIP_NULLPTR,
    init_type_QNetworkSession,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QNetworkSession,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QNetworkSession,
    cast_QNetworkSession,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
