/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorSpace.cpp"

#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorSpace.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolortransform.sip"
#include <qcolortransform.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorSpace.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQColorSpace.cpp"


PyDoc_STRVAR(doc_QColorSpace_swap, "swap(self, QColorSpace)");

extern "C" {static PyObject *meth_QColorSpace_swap(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QColorSpace* a0;
         ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QColorSpace, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_swap, doc_QColorSpace_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_primaries, "primaries(self) -> QColorSpace.Primaries");

extern "C" {static PyObject *meth_QColorSpace_primaries(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_primaries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace, &sipCpp))
        {
             ::QColorSpace::Primaries sipRes;

            sipRes = sipCpp->primaries();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QColorSpace_Primaries);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_primaries, doc_QColorSpace_primaries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_transferFunction, "transferFunction(self) -> QColorSpace.TransferFunction");

extern "C" {static PyObject *meth_QColorSpace_transferFunction(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_transferFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace, &sipCpp))
        {
             ::QColorSpace::TransferFunction sipRes;

            sipRes = sipCpp->transferFunction();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QColorSpace_TransferFunction);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_transferFunction, doc_QColorSpace_transferFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_gamma, "gamma(self) -> float");

extern "C" {static PyObject *meth_QColorSpace_gamma(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_gamma(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->gamma();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_gamma, doc_QColorSpace_gamma);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_setTransferFunction, "setTransferFunction(self, QColorSpace.TransferFunction, gamma: float = 0)");

extern "C" {static PyObject *meth_QColorSpace_setTransferFunction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_setTransferFunction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QColorSpace::TransferFunction a0;
        float a1 = 0;
         ::QColorSpace *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_gamma,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|f", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QColorSpace_TransferFunction, &a0, &a1))
        {
            sipCpp->setTransferFunction(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_setTransferFunction, doc_QColorSpace_setTransferFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_withTransferFunction, "withTransferFunction(self, QColorSpace.TransferFunction, gamma: float = 0) -> QColorSpace");

extern "C" {static PyObject *meth_QColorSpace_withTransferFunction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_withTransferFunction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QColorSpace::TransferFunction a0;
        float a1 = 0;
        const  ::QColorSpace *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_gamma,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|f", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QColorSpace_TransferFunction, &a0, &a1))
        {
             ::QColorSpace*sipRes;

            sipRes = new  ::QColorSpace(sipCpp->withTransferFunction(a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QColorSpace,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_withTransferFunction, doc_QColorSpace_withTransferFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_setPrimaries, "setPrimaries(self, QColorSpace.Primaries)\n"
"setPrimaries(self, Union[QPointF, QPoint], Union[QPointF, QPoint], Union[QPointF, QPoint], Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QColorSpace_setPrimaries(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_setPrimaries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QColorSpace::Primaries a0;
         ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QColorSpace_Primaries, &a0))
        {
            sipCpp->setPrimaries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPointF* a1;
        int a1State = 0;
        const  ::QPointF* a2;
        int a2State = 0;
        const  ::QPointF* a3;
        int a3State = 0;
         ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1J1", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State, sipType_QPointF, &a2, &a2State, sipType_QPointF, &a3, &a3State))
        {
            sipCpp->setPrimaries(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1),sipType_QPointF,a1State);
            sipReleaseType(const_cast< ::QPointF *>(a2),sipType_QPointF,a2State);
            sipReleaseType(const_cast< ::QPointF *>(a3),sipType_QPointF,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_setPrimaries, doc_QColorSpace_setPrimaries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QColorSpace_isValid(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_isValid, doc_QColorSpace_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_fromIccProfile, "fromIccProfile(Union[QByteArray, bytes, bytearray]) -> QColorSpace");

extern "C" {static PyObject *meth_QColorSpace_fromIccProfile(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_fromIccProfile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
             ::QColorSpace*sipRes;

            sipRes = new  ::QColorSpace( ::QColorSpace::fromIccProfile(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_QColorSpace,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_fromIccProfile, doc_QColorSpace_fromIccProfile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_iccProfile, "iccProfile(self) -> QByteArray");

extern "C" {static PyObject *meth_QColorSpace_iccProfile(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_iccProfile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QColorSpace, &sipCpp))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray(sipCpp->iccProfile());

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_iccProfile, doc_QColorSpace_iccProfile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QColorSpace_transformationToColorSpace, "transformationToColorSpace(self, QColorSpace) -> QColorTransform");

extern "C" {static PyObject *meth_QColorSpace_transformationToColorSpace(PyObject *, PyObject *);}
static PyObject *meth_QColorSpace_transformationToColorSpace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace* a0;
        const  ::QColorSpace *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QColorSpace, &sipCpp, sipType_QColorSpace, &a0))
        {
             ::QColorTransform*sipRes;

            sipRes = new  ::QColorTransform(sipCpp->transformationToColorSpace(*a0));

            return sipConvertFromNewType(sipRes,sipType_QColorTransform,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QColorSpace, sipName_transformationToColorSpace, doc_QColorSpace_transformationToColorSpace);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QColorSpace___eq__(PyObject *,PyObject *);}
static PyObject *slot_QColorSpace___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QColorSpace *sipCpp = reinterpret_cast< ::QColorSpace *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QColorSpace));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QColorSpace, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QColorSpace, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QColorSpace___ne__(PyObject *,PyObject *);}
static PyObject *slot_QColorSpace___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QColorSpace *sipCpp = reinterpret_cast< ::QColorSpace *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QColorSpace));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QColorSpace* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QColorSpace, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QColorSpace, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QColorSpace(void *, int);}
static void release_QColorSpace(void *sipCppV, int)
{
    delete reinterpret_cast< ::QColorSpace *>(sipCppV);
}


extern "C" {static void *array_QColorSpace(Py_ssize_t);}
static void *array_QColorSpace(Py_ssize_t sipNrElem)
{
    return new  ::QColorSpace[sipNrElem];
}


extern "C" {static void assign_QColorSpace(void *, SIP_SSIZE_T, void *);}
static void assign_QColorSpace(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QColorSpace *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QColorSpace *>(sipSrc);
}


extern "C" {static void *copy_QColorSpace(const void *, SIP_SSIZE_T);}
static void *copy_QColorSpace(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QColorSpace(reinterpret_cast<const  ::QColorSpace *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QColorSpace(sipSimpleWrapper *);}
static void dealloc_QColorSpace(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QColorSpace(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QColorSpace(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QColorSpace(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QColorSpace *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QColorSpace();

            return sipCpp;
        }
    }

    {
         ::QColorSpace::NamedColorSpace a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "E", sipType_QColorSpace_NamedColorSpace, &a0))
        {
            sipCpp = new  ::QColorSpace(a0);

            return sipCpp;
        }
    }

    {
         ::QColorSpace::Primaries a0;
         ::QColorSpace::TransferFunction a1;
        float a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_gamma,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "EE|f", sipType_QColorSpace_Primaries, &a0, sipType_QColorSpace_TransferFunction, &a1, &a2))
        {
            sipCpp = new  ::QColorSpace(a0,a1,a2);

            return sipCpp;
        }
    }

    {
         ::QColorSpace::Primaries a0;
        float a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "Ef", sipType_QColorSpace_Primaries, &a0, &a1))
        {
            sipCpp = new  ::QColorSpace(a0,a1);

            return sipCpp;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPointF* a1;
        int a1State = 0;
        const  ::QPointF* a2;
        int a2State = 0;
        const  ::QPointF* a3;
        int a3State = 0;
         ::QColorSpace::TransferFunction a4;
        float a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_gamma,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1J1J1J1E|f", sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State, sipType_QPointF, &a2, &a2State, sipType_QPointF, &a3, &a3State, sipType_QColorSpace_TransferFunction, &a4, &a5))
        {
            sipCpp = new  ::QColorSpace(*a0,*a1,*a2,*a3,a4,a5);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1),sipType_QPointF,a1State);
            sipReleaseType(const_cast< ::QPointF *>(a2),sipType_QPointF,a2State);
            sipReleaseType(const_cast< ::QPointF *>(a3),sipType_QPointF,a3State);

            return sipCpp;
        }
    }

    {
        const  ::QColorSpace* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QColorSpace, &a0))
        {
            sipCpp = new  ::QColorSpace(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QColorSpace[] = {
    {(void *)slot_QColorSpace___eq__, eq_slot},
    {(void *)slot_QColorSpace___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QColorSpace[] = {
    {SIP_MLNAME_CAST(sipName_fromIccProfile), meth_QColorSpace_fromIccProfile, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_fromIccProfile)},
    {SIP_MLNAME_CAST(sipName_gamma), meth_QColorSpace_gamma, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_gamma)},
    {SIP_MLNAME_CAST(sipName_iccProfile), meth_QColorSpace_iccProfile, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_iccProfile)},
    {SIP_MLNAME_CAST(sipName_isValid), meth_QColorSpace_isValid, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_isValid)},
    {SIP_MLNAME_CAST(sipName_primaries), meth_QColorSpace_primaries, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_primaries)},
    {SIP_MLNAME_CAST(sipName_setPrimaries), meth_QColorSpace_setPrimaries, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_setPrimaries)},
    {SIP_MLNAME_CAST(sipName_setTransferFunction), SIP_MLMETH_CAST(meth_QColorSpace_setTransferFunction), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QColorSpace_setTransferFunction)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QColorSpace_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_swap)},
    {SIP_MLNAME_CAST(sipName_transferFunction), meth_QColorSpace_transferFunction, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_transferFunction)},
    {SIP_MLNAME_CAST(sipName_transformationToColorSpace), meth_QColorSpace_transformationToColorSpace, METH_VARARGS, SIP_MLDOC_CAST(doc_QColorSpace_transformationToColorSpace)},
    {SIP_MLNAME_CAST(sipName_withTransferFunction), SIP_MLMETH_CAST(meth_QColorSpace_withTransferFunction), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QColorSpace_withTransferFunction)}
};

static sipEnumMemberDef enummembers_QColorSpace[] = {
    {sipName_AdobeRgb, static_cast<int>(::QColorSpace::Primaries::AdobeRgb), 19},
    {sipName_AdobeRgb, static_cast<int>( ::QColorSpace::AdobeRgb), 18},
    {sipName_Custom, static_cast<int>(::QColorSpace::TransferFunction::Custom), 20},
    {sipName_Custom, static_cast<int>(::QColorSpace::Primaries::Custom), 19},
    {sipName_DciP3D65, static_cast<int>(::QColorSpace::Primaries::DciP3D65), 19},
    {sipName_DisplayP3, static_cast<int>( ::QColorSpace::DisplayP3), 18},
    {sipName_Gamma, static_cast<int>(::QColorSpace::TransferFunction::Gamma), 20},
    {sipName_Linear, static_cast<int>(::QColorSpace::TransferFunction::Linear), 20},
    {sipName_ProPhotoRgb, static_cast<int>(::QColorSpace::TransferFunction::ProPhotoRgb), 20},
    {sipName_ProPhotoRgb, static_cast<int>(::QColorSpace::Primaries::ProPhotoRgb), 19},
    {sipName_ProPhotoRgb, static_cast<int>( ::QColorSpace::ProPhotoRgb), 18},
    {sipName_SRgb, static_cast<int>(::QColorSpace::TransferFunction::SRgb), 20},
    {sipName_SRgb, static_cast<int>(::QColorSpace::Primaries::SRgb), 19},
    {sipName_SRgb, static_cast<int>( ::QColorSpace::SRgb), 18},
    {sipName_SRgbLinear, static_cast<int>( ::QColorSpace::SRgbLinear), 18},
};

PyDoc_STRVAR(doc_QColorSpace, "\1QColorSpace()\n"
"QColorSpace(QColorSpace.NamedColorSpace)\n"
"QColorSpace(QColorSpace.Primaries, QColorSpace.TransferFunction, gamma: float = 0)\n"
"QColorSpace(QColorSpace.Primaries, float)\n"
"QColorSpace(Union[QPointF, QPoint], Union[QPointF, QPoint], Union[QPointF, QPoint], Union[QPointF, QPoint], QColorSpace.TransferFunction, gamma: float = 0)\n"
"QColorSpace(QColorSpace)");


static pyqt5ClassPluginDef plugin_QColorSpace = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QColorSpace = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QColorSpace,
        {SIP_NULLPTR},
        &plugin_QColorSpace
    },
    {
        sipNameNr_QColorSpace,
        {0, 0, 1},
        11, methods_QColorSpace,
        15, enummembers_QColorSpace,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QColorSpace,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QColorSpace,
    init_type_QColorSpace,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QColorSpace,
    assign_QColorSpace,
    array_QColorSpace,
    copy_QColorSpace,
    release_QColorSpace,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
