/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexturematerial.sip"
#include <qsgtexturematerial.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"
#line 158 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickQSGOpaqueTextureMaterial.cpp"


class sipQSGOpaqueTextureMaterial : public  ::QSGOpaqueTextureMaterial
{
public:
    sipQSGOpaqueTextureMaterial();
    virtual ~sipQSGOpaqueTextureMaterial();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
     ::QSGMaterialType* type() const SIP_OVERRIDE;
     ::QSGMaterialShader* createShader() const SIP_OVERRIDE;
    int compare(const  ::QSGMaterial*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSGOpaqueTextureMaterial(const sipQSGOpaqueTextureMaterial &);
    sipQSGOpaqueTextureMaterial &operator = (const sipQSGOpaqueTextureMaterial &);

    char sipPyMethods[3];
};

sipQSGOpaqueTextureMaterial::sipQSGOpaqueTextureMaterial():  ::QSGOpaqueTextureMaterial(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSGOpaqueTextureMaterial::~sipQSGOpaqueTextureMaterial()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

 ::QSGMaterialType* sipQSGOpaqueTextureMaterial::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,SIP_NULLPTR,sipName_type);

    if (!sipMeth)
        return  ::QSGOpaqueTextureMaterial::type();

    extern  ::QSGMaterialType* sipVH_QtQuick_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_53(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSGMaterialShader* sipQSGOpaqueTextureMaterial::createShader() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,SIP_NULLPTR,sipName_createShader);

    if (!sipMeth)
        return  ::QSGOpaqueTextureMaterial::createShader();

    extern  ::QSGMaterialShader* sipVH_QtQuick_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtQuick_54(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQSGOpaqueTextureMaterial::compare(const  ::QSGMaterial*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,SIP_NULLPTR,sipName_compare);

    if (!sipMeth)
        return  ::QSGOpaqueTextureMaterial::compare(a0);

    extern int sipVH_QtQuick_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QSGMaterial*);

    return sipVH_QtQuick_55(sipGILState, sipImportedVirtErrorHandlers_QtQuick_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_type, "type(self) -> QSGMaterialType");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_type(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGMaterialType*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGOpaqueTextureMaterial::type() : sipCpp->type());

            return sipConvertFromType(sipRes,sipType_QSGMaterialType,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_type, doc_QSGOpaqueTextureMaterial_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_createShader, "createShader(self) -> QSGMaterialShader");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_createShader(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_createShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGMaterialShader*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGOpaqueTextureMaterial::createShader() : sipCpp->createShader());

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialShader,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_createShader, doc_QSGOpaqueTextureMaterial_createShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_compare, "compare(self, QSGMaterial) -> int");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_compare(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_compare(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QSGMaterial* a0;
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGMaterial, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QSGOpaqueTextureMaterial::compare(a0) : sipCpp->compare(a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_compare, doc_QSGOpaqueTextureMaterial_compare);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setTexture, "setTexture(self, QSGTexture)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setTexture(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture* a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture, &a0))
        {
            sipCpp->setTexture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setTexture, doc_QSGOpaqueTextureMaterial_setTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_texture, "texture(self) -> QSGTexture");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_texture(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_texture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture*sipRes;

            sipRes = sipCpp->texture();

            return sipConvertFromType(sipRes,sipType_QSGTexture,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_texture, doc_QSGOpaqueTextureMaterial_texture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setMipmapFiltering, "setMipmapFiltering(self, QSGTexture.Filtering)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setMipmapFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setMipmapFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::Filtering a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture_Filtering, &a0))
        {
            sipCpp->setMipmapFiltering(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setMipmapFiltering, doc_QSGOpaqueTextureMaterial_setMipmapFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_mipmapFiltering, "mipmapFiltering(self) -> QSGTexture.Filtering");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_mipmapFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_mipmapFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture::Filtering sipRes;

            sipRes = sipCpp->mipmapFiltering();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_Filtering);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_mipmapFiltering, doc_QSGOpaqueTextureMaterial_mipmapFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setFiltering, "setFiltering(self, QSGTexture.Filtering)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setFiltering(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setFiltering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::Filtering a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture_Filtering, &a0))
        {
            sipCpp->setFiltering(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setFiltering, doc_QSGOpaqueTextureMaterial_setFiltering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_filtering, "filtering(self) -> QSGTexture.Filtering");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_filtering(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_filtering(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture::Filtering sipRes;

            sipRes = sipCpp->filtering();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_Filtering);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_filtering, doc_QSGOpaqueTextureMaterial_filtering);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setHorizontalWrapMode, "setHorizontalWrapMode(self, QSGTexture.WrapMode)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setHorizontalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setHorizontalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::WrapMode a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture_WrapMode, &a0))
        {
            sipCpp->setHorizontalWrapMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setHorizontalWrapMode, doc_QSGOpaqueTextureMaterial_setHorizontalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_horizontalWrapMode, "horizontalWrapMode(self) -> QSGTexture.WrapMode");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_horizontalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_horizontalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture::WrapMode sipRes;

            sipRes = sipCpp->horizontalWrapMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_horizontalWrapMode, doc_QSGOpaqueTextureMaterial_horizontalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setVerticalWrapMode, "setVerticalWrapMode(self, QSGTexture.WrapMode)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setVerticalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setVerticalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::WrapMode a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture_WrapMode, &a0))
        {
            sipCpp->setVerticalWrapMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setVerticalWrapMode, doc_QSGOpaqueTextureMaterial_setVerticalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_verticalWrapMode, "verticalWrapMode(self) -> QSGTexture.WrapMode");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_verticalWrapMode(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_verticalWrapMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture::WrapMode sipRes;

            sipRes = sipCpp->verticalWrapMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_WrapMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_verticalWrapMode, doc_QSGOpaqueTextureMaterial_verticalWrapMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_setAnisotropyLevel, "setAnisotropyLevel(self, QSGTexture.AnisotropyLevel)");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_setAnisotropyLevel(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_setAnisotropyLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGTexture::AnisotropyLevel a0;
         ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp, sipType_QSGTexture_AnisotropyLevel, &a0))
        {
            sipCpp->setAnisotropyLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_setAnisotropyLevel, doc_QSGOpaqueTextureMaterial_setAnisotropyLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial_anisotropyLevel, "anisotropyLevel(self) -> QSGTexture.AnisotropyLevel");

extern "C" {static PyObject *meth_QSGOpaqueTextureMaterial_anisotropyLevel(PyObject *, PyObject *);}
static PyObject *meth_QSGOpaqueTextureMaterial_anisotropyLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSGOpaqueTextureMaterial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSGOpaqueTextureMaterial, &sipCpp))
        {
             ::QSGTexture::AnisotropyLevel sipRes;

            sipRes = sipCpp->anisotropyLevel();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSGTexture_AnisotropyLevel);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSGOpaqueTextureMaterial, sipName_anisotropyLevel, doc_QSGOpaqueTextureMaterial_anisotropyLevel);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSGOpaqueTextureMaterial(void *, const sipTypeDef *);}
static void *cast_QSGOpaqueTextureMaterial(void *sipCppV, const sipTypeDef *targetType)
{
     ::QSGOpaqueTextureMaterial *sipCpp = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(sipCppV);

    if (targetType == sipType_QSGMaterial)
        return static_cast< ::QSGMaterial *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSGOpaqueTextureMaterial(void *, int);}
static void release_QSGOpaqueTextureMaterial(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQSGOpaqueTextureMaterial *>(sipCppV);
    else
        delete reinterpret_cast< ::QSGOpaqueTextureMaterial *>(sipCppV);
}


extern "C" {static void *array_QSGOpaqueTextureMaterial(Py_ssize_t);}
static void *array_QSGOpaqueTextureMaterial(Py_ssize_t sipNrElem)
{
    return new  ::QSGOpaqueTextureMaterial[sipNrElem];
}


extern "C" {static void dealloc_QSGOpaqueTextureMaterial(sipSimpleWrapper *);}
static void dealloc_QSGOpaqueTextureMaterial(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSGOpaqueTextureMaterial *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSGOpaqueTextureMaterial(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSGOpaqueTextureMaterial(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSGOpaqueTextureMaterial(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSGOpaqueTextureMaterial *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSGOpaqueTextureMaterial();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSGOpaqueTextureMaterial[] = {{58, 255, 1}};


static PyMethodDef methods_QSGOpaqueTextureMaterial[] = {
    {SIP_MLNAME_CAST(sipName_anisotropyLevel), meth_QSGOpaqueTextureMaterial_anisotropyLevel, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_anisotropyLevel)},
    {SIP_MLNAME_CAST(sipName_compare), meth_QSGOpaqueTextureMaterial_compare, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_compare)},
    {SIP_MLNAME_CAST(sipName_createShader), meth_QSGOpaqueTextureMaterial_createShader, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_createShader)},
    {SIP_MLNAME_CAST(sipName_filtering), meth_QSGOpaqueTextureMaterial_filtering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_filtering)},
    {SIP_MLNAME_CAST(sipName_horizontalWrapMode), meth_QSGOpaqueTextureMaterial_horizontalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_horizontalWrapMode)},
    {SIP_MLNAME_CAST(sipName_mipmapFiltering), meth_QSGOpaqueTextureMaterial_mipmapFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_mipmapFiltering)},
    {SIP_MLNAME_CAST(sipName_setAnisotropyLevel), meth_QSGOpaqueTextureMaterial_setAnisotropyLevel, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setAnisotropyLevel)},
    {SIP_MLNAME_CAST(sipName_setFiltering), meth_QSGOpaqueTextureMaterial_setFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setFiltering)},
    {SIP_MLNAME_CAST(sipName_setHorizontalWrapMode), meth_QSGOpaqueTextureMaterial_setHorizontalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setHorizontalWrapMode)},
    {SIP_MLNAME_CAST(sipName_setMipmapFiltering), meth_QSGOpaqueTextureMaterial_setMipmapFiltering, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setMipmapFiltering)},
    {SIP_MLNAME_CAST(sipName_setTexture), meth_QSGOpaqueTextureMaterial_setTexture, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setTexture)},
    {SIP_MLNAME_CAST(sipName_setVerticalWrapMode), meth_QSGOpaqueTextureMaterial_setVerticalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_setVerticalWrapMode)},
    {SIP_MLNAME_CAST(sipName_texture), meth_QSGOpaqueTextureMaterial_texture, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_texture)},
    {SIP_MLNAME_CAST(sipName_type), meth_QSGOpaqueTextureMaterial_type, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_type)},
    {SIP_MLNAME_CAST(sipName_verticalWrapMode), meth_QSGOpaqueTextureMaterial_verticalWrapMode, METH_VARARGS, SIP_MLDOC_CAST(doc_QSGOpaqueTextureMaterial_verticalWrapMode)}
};

PyDoc_STRVAR(doc_QSGOpaqueTextureMaterial, "\1QSGOpaqueTextureMaterial()");


static pyqt5ClassPluginDef plugin_QSGOpaqueTextureMaterial = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QSGOpaqueTextureMaterial = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSGOpaqueTextureMaterial,
        {SIP_NULLPTR},
        &plugin_QSGOpaqueTextureMaterial
    },
    {
        sipNameNr_QSGOpaqueTextureMaterial,
        {0, 0, 1},
        15, methods_QSGOpaqueTextureMaterial,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSGOpaqueTextureMaterial,
    -1,
    -1,
    supers_QSGOpaqueTextureMaterial,
    SIP_NULLPTR,
    init_type_QSGOpaqueTextureMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QSGOpaqueTextureMaterial,
    SIP_NULLPTR,
    array_QSGOpaqueTextureMaterial,
    SIP_NULLPTR,
    release_QSGOpaqueTextureMaterial,
    cast_QSGOpaqueTextureMaterial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
