/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qactiongroup.sip"
#include <qactiongroup.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQActionGroup.cpp"


class sipQActionGroup : public  ::QActionGroup
{
public:
    sipQActionGroup( ::QObject*);
    virtual ~sipQActionGroup();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQActionGroup(const sipQActionGroup &);
    sipQActionGroup &operator = (const sipQActionGroup &);

    char sipPyMethods[7];
};

sipQActionGroup::sipQActionGroup( ::QObject*a0):  ::QActionGroup(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQActionGroup::~sipQActionGroup()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQActionGroup::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf,sipType_QActionGroup);

    return  ::QActionGroup::metaObject();
}

int sipQActionGroup::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QActionGroup::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf,sipType_QActionGroup,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQActionGroup::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QActionGroup, _clname, &sipCpp) ? sipCpp :  ::QActionGroup::qt_metacast(_clname));
}

bool sipQActionGroup::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QActionGroup::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQActionGroup::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QActionGroup::eventFilter(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQActionGroup::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QActionGroup::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQActionGroup::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QActionGroup::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQActionGroup::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QActionGroup::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQActionGroup::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QActionGroup::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQActionGroup::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QActionGroup::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QActionGroup_addAction, "addAction(self, QAction) -> QAction\n"
"addAction(self, str) -> QAction\n"
"addAction(self, QIcon, str) -> QAction");

extern "C" {static PyObject *meth_QActionGroup_addAction(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_addAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QActionGroup, &sipCpp, sipType_QAction, &a0))
        {
             ::QAction*sipRes;

            sipRes = sipCpp->addAction(a0);

            return sipConvertFromType(sipRes,sipType_QAction,SIP_NULLPTR);
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QActionGroup, &sipCpp, sipType_QString,&a0, &a0State))
        {
             ::QAction*sipRes;

            sipRes = sipCpp->addAction(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromType(sipRes,sipType_QAction,sipSelf);
        }
    }

    {
        const  ::QIcon* a0;
        const  ::QString* a1;
        int a1State = 0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QActionGroup, &sipCpp, sipType_QIcon, &a0, sipType_QString,&a1, &a1State))
        {
             ::QAction*sipRes;

            sipRes = sipCpp->addAction(*a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            return sipConvertFromType(sipRes,sipType_QAction,sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_addAction, doc_QActionGroup_addAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_removeAction, "removeAction(self, QAction)");

extern "C" {static PyObject *meth_QActionGroup_removeAction(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_removeAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_QActionGroup, &sipCpp, sipType_QAction, &a0))
        {
            sipCpp->removeAction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_removeAction, doc_QActionGroup_removeAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_actions, "actions(self) -> List[QAction]");

extern "C" {static PyObject *meth_QActionGroup_actions(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_actions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
            QList< ::QAction*>*sipRes;

            sipRes = new QList< ::QAction*>(sipCpp->actions());

            return sipConvertFromNewType(sipRes,sipType_QList_0101QAction,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_actions, doc_QActionGroup_actions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_checkedAction, "checkedAction(self) -> QAction");

extern "C" {static PyObject *meth_QActionGroup_checkedAction(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_checkedAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
             ::QAction*sipRes;

            sipRes = sipCpp->checkedAction();

            return sipConvertFromType(sipRes,sipType_QAction,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_checkedAction, doc_QActionGroup_checkedAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_isExclusive, "isExclusive(self) -> bool");

extern "C" {static PyObject *meth_QActionGroup_isExclusive(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_isExclusive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isExclusive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_isExclusive, doc_QActionGroup_isExclusive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_QActionGroup_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_isEnabled, doc_QActionGroup_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QActionGroup_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_isVisible, doc_QActionGroup_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_setEnabled, "setEnabled(self, bool)");

extern "C" {static PyObject *meth_QActionGroup_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QActionGroup, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_setEnabled, doc_QActionGroup_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_setDisabled, "setDisabled(self, bool)");

extern "C" {static PyObject *meth_QActionGroup_setDisabled(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_setDisabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QActionGroup, &sipCpp, &a0))
        {
            sipCpp->setDisabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_setDisabled, doc_QActionGroup_setDisabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_setVisible, "setVisible(self, bool)");

extern "C" {static PyObject *meth_QActionGroup_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QActionGroup, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_setVisible, doc_QActionGroup_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_setExclusive, "setExclusive(self, bool)");

extern "C" {static PyObject *meth_QActionGroup_setExclusive(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_setExclusive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QActionGroup, &sipCpp, &a0))
        {
            sipCpp->setExclusive(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_setExclusive, doc_QActionGroup_setExclusive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_exclusionPolicy, "exclusionPolicy(self) -> QActionGroup.ExclusionPolicy");

extern "C" {static PyObject *meth_QActionGroup_exclusionPolicy(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_exclusionPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QActionGroup, &sipCpp))
        {
             ::QActionGroup::ExclusionPolicy sipRes;

            sipRes = sipCpp->exclusionPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QActionGroup_ExclusionPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_exclusionPolicy, doc_QActionGroup_exclusionPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QActionGroup_setExclusionPolicy, "setExclusionPolicy(self, QActionGroup.ExclusionPolicy)");

extern "C" {static PyObject *meth_QActionGroup_setExclusionPolicy(PyObject *, PyObject *);}
static PyObject *meth_QActionGroup_setExclusionPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QActionGroup::ExclusionPolicy a0;
         ::QActionGroup *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QActionGroup, &sipCpp, sipType_QActionGroup_ExclusionPolicy, &a0))
        {
            sipCpp->setExclusionPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QActionGroup, sipName_setExclusionPolicy, doc_QActionGroup_setExclusionPolicy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QActionGroup(void *, const sipTypeDef *);}
static void *cast_QActionGroup(void *sipCppV, const sipTypeDef *targetType)
{
     ::QActionGroup *sipCpp = reinterpret_cast< ::QActionGroup *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QActionGroup(void *, int);}
static void release_QActionGroup(void *sipCppV, int)
{
     ::QActionGroup *sipCpp = reinterpret_cast< ::QActionGroup *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QActionGroup(sipSimpleWrapper *);}
static void dealloc_QActionGroup(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQActionGroup *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QActionGroup(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QActionGroup(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QActionGroup(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQActionGroup *sipCpp = SIP_NULLPTR;

    {
         ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQActionGroup(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QActionGroup[] = {{34, 0, 1}};


static PyMethodDef methods_QActionGroup[] = {
    {SIP_MLNAME_CAST(sipName_actions), meth_QActionGroup_actions, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_actions)},
    {SIP_MLNAME_CAST(sipName_addAction), meth_QActionGroup_addAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_addAction)},
    {SIP_MLNAME_CAST(sipName_checkedAction), meth_QActionGroup_checkedAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_checkedAction)},
    {SIP_MLNAME_CAST(sipName_exclusionPolicy), meth_QActionGroup_exclusionPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_exclusionPolicy)},
    {SIP_MLNAME_CAST(sipName_isEnabled), meth_QActionGroup_isEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_isEnabled)},
    {SIP_MLNAME_CAST(sipName_isExclusive), meth_QActionGroup_isExclusive, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_isExclusive)},
    {SIP_MLNAME_CAST(sipName_isVisible), meth_QActionGroup_isVisible, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_isVisible)},
    {SIP_MLNAME_CAST(sipName_removeAction), meth_QActionGroup_removeAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_removeAction)},
    {SIP_MLNAME_CAST(sipName_setDisabled), meth_QActionGroup_setDisabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_setDisabled)},
    {SIP_MLNAME_CAST(sipName_setEnabled), meth_QActionGroup_setEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_setEnabled)},
    {SIP_MLNAME_CAST(sipName_setExclusionPolicy), meth_QActionGroup_setExclusionPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_setExclusionPolicy)},
    {SIP_MLNAME_CAST(sipName_setExclusive), meth_QActionGroup_setExclusive, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_setExclusive)},
    {SIP_MLNAME_CAST(sipName_setVisible), meth_QActionGroup_setVisible, METH_VARARGS, SIP_MLDOC_CAST(doc_QActionGroup_setVisible)}
};

static sipEnumMemberDef enummembers_QActionGroup[] = {
    {sipName_Exclusive, static_cast<int>(::QActionGroup::ExclusionPolicy::Exclusive), 31},
    {sipName_ExclusiveOptional, static_cast<int>(::QActionGroup::ExclusionPolicy::ExclusiveOptional), 31},
    {sipName_None, static_cast<int>(::QActionGroup::ExclusionPolicy::None), 31},
};

PyDoc_STRVAR(doc_QActionGroup, "\1QActionGroup(QObject)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QActionGroup[] = {
    {"hovered(QAction*)", "\1hovered(self, QAction)", SIP_NULLPTR, SIP_NULLPTR},
    {"triggered(QAction*)", "\1triggered(self, QAction)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QActionGroup = {
    & ::QActionGroup::staticMetaObject,
    0,
    signals_QActionGroup,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QActionGroup = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QActionGroup,
        {SIP_NULLPTR},
        &plugin_QActionGroup
    },
    {
        sipNameNr_QActionGroup,
        {0, 0, 1},
        13, methods_QActionGroup,
        3, enummembers_QActionGroup,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QActionGroup,
    -1,
    -1,
    supers_QActionGroup,
    SIP_NULLPTR,
    init_type_QActionGroup,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QActionGroup,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QActionGroup,
    cast_QActionGroup,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
