/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlcomponent.sip"
#include <qqmlcomponent.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"

#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 24 "sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlincubator.sip"
#include <qqmlincubator.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQml/qqmlerror.sip"
#include <qqmlerror.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQml/sipQtQmlQQmlComponent.cpp"


class sipQQmlComponent : public  ::QQmlComponent
{
public:
    sipQQmlComponent( ::QQmlEngine*, ::QObject*);
    sipQQmlComponent( ::QQmlEngine*,const  ::QString&, ::QObject*);
    sipQQmlComponent( ::QQmlEngine*,const  ::QString&, ::QQmlComponent::CompilationMode, ::QObject*);
    sipQQmlComponent( ::QQmlEngine*,const  ::QUrl&, ::QObject*);
    sipQQmlComponent( ::QQmlEngine*,const  ::QUrl&, ::QQmlComponent::CompilationMode, ::QObject*);
    sipQQmlComponent( ::QObject*);
    virtual ~sipQQmlComponent();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void completeCreate() SIP_OVERRIDE;
     ::QObject* beginCreate( ::QQmlContext*) SIP_OVERRIDE;
     ::QObject* create( ::QQmlContext*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlComponent(const sipQQmlComponent &);
    sipQQmlComponent &operator = (const sipQQmlComponent &);

    char sipPyMethods[10];
};

sipQQmlComponent::sipQQmlComponent( ::QQmlEngine*a0, ::QObject*a1):  ::QQmlComponent(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::sipQQmlComponent( ::QQmlEngine*a0,const  ::QString& a1, ::QObject*a2):  ::QQmlComponent(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::sipQQmlComponent( ::QQmlEngine*a0,const  ::QString& a1, ::QQmlComponent::CompilationMode a2, ::QObject*a3):  ::QQmlComponent(a0,a1,a2,a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::sipQQmlComponent( ::QQmlEngine*a0,const  ::QUrl& a1, ::QObject*a2):  ::QQmlComponent(a0,a1,a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::sipQQmlComponent( ::QQmlEngine*a0,const  ::QUrl& a1, ::QQmlComponent::CompilationMode a2, ::QObject*a3):  ::QQmlComponent(a0,a1,a2,a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::sipQQmlComponent( ::QObject*a0):  ::QQmlComponent(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlComponent::~sipQQmlComponent()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQmlComponent::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQml_qt_metaobject(sipPySelf,sipType_QQmlComponent);

    return  ::QQmlComponent::metaObject();
}

int sipQQmlComponent::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QQmlComponent::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQml_qt_metacall(sipPySelf,sipType_QQmlComponent,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQmlComponent::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQml_qt_metacast(sipPySelf, sipType_QQmlComponent, _clname, &sipCpp) ? sipCpp :  ::QQmlComponent::qt_metacast(_clname));
}

void sipQQmlComponent::completeCreate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,SIP_NULLPTR,sipName_completeCreate);

    if (!sipMeth)
    {
         ::QQmlComponent::completeCreate();
        return;
    }

    extern void sipVH_QtQml_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQml_8(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QObject* sipQQmlComponent::beginCreate( ::QQmlContext*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,SIP_NULLPTR,sipName_beginCreate);

    if (!sipMeth)
        return  ::QQmlComponent::beginCreate(a0);

    extern  ::QObject* sipVH_QtQml_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQmlContext*);

    return sipVH_QtQml_7(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QObject* sipQQmlComponent::create( ::QQmlContext*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_create);

    if (!sipMeth)
        return  ::QQmlComponent::create(a0);

    extern  ::QObject* sipVH_QtQml_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QQmlContext*);

    return sipVH_QtQml_7(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQmlComponent::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QQmlComponent::event(a0);

    extern bool sipVH_QtQml_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtQml_5(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQmlComponent::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QQmlComponent::eventFilter(a0,a1);

    extern bool sipVH_QtQml_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtQml_4(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQmlComponent::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QQmlComponent::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQml_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtQml_3(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlComponent::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QQmlComponent::childEvent(a0);
        return;
    }

    extern void sipVH_QtQml_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtQml_2(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlComponent::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QQmlComponent::customEvent(a0);
        return;
    }

    extern void sipVH_QtQml_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtQml_1(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlComponent::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QQmlComponent::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlComponent::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QQmlComponent::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlComponent_status, "status(self) -> QQmlComponent.Status");

extern "C" {static PyObject *meth_QQmlComponent_status(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
             ::QQmlComponent::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QQmlComponent_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_status, doc_QQmlComponent_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QQmlComponent_isNull(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_isNull, doc_QQmlComponent_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_isReady, "isReady(self) -> bool");

extern "C" {static PyObject *meth_QQmlComponent_isReady(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_isReady(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReady();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_isReady, doc_QQmlComponent_isReady);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_isError, "isError(self) -> bool");

extern "C" {static PyObject *meth_QQmlComponent_isError(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_isError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isError();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_isError, doc_QQmlComponent_isError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_isLoading, "isLoading(self) -> bool");

extern "C" {static PyObject *meth_QQmlComponent_isLoading(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_isLoading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLoading();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_isLoading, doc_QQmlComponent_isLoading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_errors, "errors(self) -> List[QQmlError]");

extern "C" {static PyObject *meth_QQmlComponent_errors(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_errors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            QList< ::QQmlError>*sipRes;

            sipRes = new QList< ::QQmlError>(sipCpp->errors());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QQmlError,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_errors, doc_QQmlComponent_errors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_progress, "progress(self) -> float");

extern "C" {static PyObject *meth_QQmlComponent_progress(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_progress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->progress();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_progress, doc_QQmlComponent_progress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QQmlComponent_url(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
             ::QUrl*sipRes;

            sipRes = new  ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes,sipType_QUrl,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_url, doc_QQmlComponent_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_create, "create(self, context: QQmlContext = None) -> QObject\n"
"create(self, QQmlIncubator, context: QQmlContext = None, forContext: QQmlContext = None)");

extern "C" {static PyObject *meth_QQmlComponent_create(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_create(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQmlContext* a0 = 0;
         ::QQmlComponent *sipCpp;

        static const char *sipKwdList[] = {
            sipName_context,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J8", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QQmlContext, &a0))
        {
             ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQmlComponent::create(a0) : sipCpp->create(a0));

            return sipConvertFromType(sipRes,sipType_QObject,Py_None);
        }
    }

    {
         ::QQmlIncubator* a0;
         ::QQmlContext* a1 = 0;
         ::QQmlContext* a2 = 0;
         ::QQmlComponent *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_context,
            sipName_forContext,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J8J8", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QQmlIncubator, &a0, sipType_QQmlContext, &a1, sipType_QQmlContext, &a2))
        {
            sipCpp->create(*a0,a1,a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_create, doc_QQmlComponent_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_createWithInitialProperties, "createWithInitialProperties(self, Dict[str, Any], context: QQmlContext = None) -> QObject");

extern "C" {static PyObject *meth_QQmlComponent_createWithInitialProperties(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_createWithInitialProperties(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QVariantMap* a0;
        int a0State = 0;
         ::QQmlContext* a1 = 0;
         ::QQmlComponent *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_context,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J8", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QVariantMap,&a0, &a0State, sipType_QQmlContext, &a1))
        {
             ::QObject*sipRes;

            sipRes = sipCpp->createWithInitialProperties(*a0,a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a0),sipType_QVariantMap,a0State);

            return sipConvertFromType(sipRes,sipType_QObject,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_createWithInitialProperties, doc_QQmlComponent_createWithInitialProperties);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_beginCreate, "beginCreate(self, QQmlContext) -> QObject");

extern "C" {static PyObject *meth_QQmlComponent_beginCreate(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_beginCreate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQmlContext* a0;
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QQmlContext, &a0))
        {
             ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QQmlComponent::beginCreate(a0) : sipCpp->beginCreate(a0));

            return sipConvertFromType(sipRes,sipType_QObject,Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_beginCreate, doc_QQmlComponent_beginCreate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_completeCreate, "completeCreate(self)");

extern "C" {static PyObject *meth_QQmlComponent_completeCreate(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_completeCreate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::QQmlComponent::completeCreate() : sipCpp->completeCreate());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_completeCreate, doc_QQmlComponent_completeCreate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_creationContext, "creationContext(self) -> QQmlContext");

extern "C" {static PyObject *meth_QQmlComponent_creationContext(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_creationContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
             ::QQmlContext*sipRes;

            sipRes = sipCpp->creationContext();

            return sipConvertFromType(sipRes,sipType_QQmlContext,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_creationContext, doc_QQmlComponent_creationContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_loadUrl, "loadUrl(self, QUrl)\n"
"loadUrl(self, QUrl, QQmlComponent.CompilationMode)");

extern "C" {static PyObject *meth_QQmlComponent_loadUrl(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_loadUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QUrl* a0;
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->loadUrl(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QUrl* a0;
         ::QQmlComponent::CompilationMode a1;
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9E", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QUrl, &a0, sipType_QQmlComponent_CompilationMode, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->loadUrl(*a0,a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_loadUrl, doc_QQmlComponent_loadUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_setData, "setData(self, Union[QByteArray, bytes, bytearray], QUrl)");

extern "C" {static PyObject *meth_QQmlComponent_setData(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const  ::QUrl* a1;
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp->setData(*a0,*a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_setData, doc_QQmlComponent_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_engine, "engine(self) -> QQmlEngine");

extern "C" {static PyObject *meth_QQmlComponent_engine(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlComponent, &sipCpp))
        {
             ::QQmlEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes,sipType_QQmlEngine,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_engine, doc_QQmlComponent_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlComponent_setInitialProperties, "setInitialProperties(self, QObject, Dict[str, Any])");

extern "C" {static PyObject *meth_QQmlComponent_setInitialProperties(PyObject *, PyObject *);}
static PyObject *meth_QQmlComponent_setInitialProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QObject* a0;
        const  ::QVariantMap* a1;
        int a1State = 0;
         ::QQmlComponent *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QQmlComponent, &sipCpp, sipType_QObject, &a0, sipType_QVariantMap,&a1, &a1State))
        {
            sipCpp->setInitialProperties(a0,*a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1),sipType_QVariantMap,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlComponent, sipName_setInitialProperties, doc_QQmlComponent_setInitialProperties);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQmlComponent(void *, const sipTypeDef *);}
static void *cast_QQmlComponent(void *sipCppV, const sipTypeDef *targetType)
{
     ::QQmlComponent *sipCpp = reinterpret_cast< ::QQmlComponent *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlComponent(void *, int);}
static void release_QQmlComponent(void *sipCppV, int)
{
     ::QQmlComponent *sipCpp = reinterpret_cast< ::QQmlComponent *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QQmlComponent(Py_ssize_t);}
static void *array_QQmlComponent(Py_ssize_t sipNrElem)
{
    return new  ::QQmlComponent[sipNrElem];
}


extern "C" {static void dealloc_QQmlComponent(sipSimpleWrapper *);}
static void dealloc_QQmlComponent(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlComponent *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlComponent(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlComponent(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlComponent(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQmlComponent *sipCpp = SIP_NULLPTR;

    {
         ::QQmlEngine* a0;
         ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QQmlEngine, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQQmlComponent(a0,a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QQmlEngine* a0;
        const  ::QString* a1;
        int a1State = 0;
         ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8J1|JH", sipType_QQmlEngine, &a0, sipType_QString,&a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQQmlComponent(a0,*a1,a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QQmlEngine* a0;
        const  ::QString* a1;
        int a1State = 0;
         ::QQmlComponent::CompilationMode a2;
         ::QObject* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8J1E|JH", sipType_QQmlEngine, &a0, sipType_QString,&a1, &a1State, sipType_QQmlComponent_CompilationMode, &a2, sipType_QObject, &a3, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQQmlComponent(a0,*a1,a2,a3);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QQmlEngine* a0;
        const  ::QUrl* a1;
         ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8J9|JH", sipType_QQmlEngine, &a0, sipType_QUrl, &a1, sipType_QObject, &a2, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQQmlComponent(a0,*a1,a2);
            Py_END_ALLOW_THREADS

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QQmlEngine* a0;
        const  ::QUrl* a1;
         ::QQmlComponent::CompilationMode a2;
         ::QObject* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8J9E|JH", sipType_QQmlEngine, &a0, sipType_QUrl, &a1, sipType_QQmlComponent_CompilationMode, &a2, sipType_QObject, &a3, sipOwner))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp = new sipQQmlComponent(a0,*a1,a2,a3);
            Py_END_ALLOW_THREADS

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
         ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQQmlComponent(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQmlComponent[] = {{9, 0, 1}};


static PyMethodDef methods_QQmlComponent[] = {
    {SIP_MLNAME_CAST(sipName_beginCreate), meth_QQmlComponent_beginCreate, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_beginCreate)},
    {SIP_MLNAME_CAST(sipName_completeCreate), meth_QQmlComponent_completeCreate, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_completeCreate)},
    {SIP_MLNAME_CAST(sipName_create), SIP_MLMETH_CAST(meth_QQmlComponent_create), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QQmlComponent_create)},
    {SIP_MLNAME_CAST(sipName_createWithInitialProperties), SIP_MLMETH_CAST(meth_QQmlComponent_createWithInitialProperties), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QQmlComponent_createWithInitialProperties)},
    {SIP_MLNAME_CAST(sipName_creationContext), meth_QQmlComponent_creationContext, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_creationContext)},
    {SIP_MLNAME_CAST(sipName_engine), meth_QQmlComponent_engine, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_engine)},
    {SIP_MLNAME_CAST(sipName_errors), meth_QQmlComponent_errors, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_errors)},
    {SIP_MLNAME_CAST(sipName_isError), meth_QQmlComponent_isError, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_isError)},
    {SIP_MLNAME_CAST(sipName_isLoading), meth_QQmlComponent_isLoading, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_isLoading)},
    {SIP_MLNAME_CAST(sipName_isNull), meth_QQmlComponent_isNull, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_isNull)},
    {SIP_MLNAME_CAST(sipName_isReady), meth_QQmlComponent_isReady, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_isReady)},
    {SIP_MLNAME_CAST(sipName_loadUrl), meth_QQmlComponent_loadUrl, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_loadUrl)},
    {SIP_MLNAME_CAST(sipName_progress), meth_QQmlComponent_progress, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_progress)},
    {SIP_MLNAME_CAST(sipName_setData), meth_QQmlComponent_setData, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_setData)},
    {SIP_MLNAME_CAST(sipName_setInitialProperties), meth_QQmlComponent_setInitialProperties, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_setInitialProperties)},
    {SIP_MLNAME_CAST(sipName_status), meth_QQmlComponent_status, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_status)},
    {SIP_MLNAME_CAST(sipName_url), meth_QQmlComponent_url, METH_VARARGS, SIP_MLDOC_CAST(doc_QQmlComponent_url)}
};

static sipEnumMemberDef enummembers_QQmlComponent[] = {
    {sipName_Asynchronous, static_cast<int>( ::QQmlComponent::Asynchronous), 14},
    {sipName_Error, static_cast<int>( ::QQmlComponent::Error), 15},
    {sipName_Loading, static_cast<int>( ::QQmlComponent::Loading), 15},
    {sipName_Null, static_cast<int>( ::QQmlComponent::Null), 15},
    {sipName_PreferSynchronous, static_cast<int>( ::QQmlComponent::PreferSynchronous), 14},
    {sipName_Ready, static_cast<int>( ::QQmlComponent::Ready), 15},
};

PyDoc_STRVAR(doc_QQmlComponent, "\1QQmlComponent(QQmlEngine, parent: QObject = None)\n"
"QQmlComponent(QQmlEngine, str, parent: QObject = None)\n"
"QQmlComponent(QQmlEngine, str, QQmlComponent.CompilationMode, parent: QObject = None)\n"
"QQmlComponent(QQmlEngine, QUrl, parent: QObject = None)\n"
"QQmlComponent(QQmlEngine, QUrl, QQmlComponent.CompilationMode, parent: QObject = None)\n"
"QQmlComponent(parent: QObject = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QQmlComponent[] = {
    {"progressChanged(qreal)", "\1progressChanged(self, float)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(QQmlComponent::Status)", "\1statusChanged(self, QQmlComponent.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QQmlComponent = {
    & ::QQmlComponent::staticMetaObject,
    0,
    signals_QQmlComponent,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlComponent = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlComponent,
        {SIP_NULLPTR},
        &plugin_QQmlComponent
    },
    {
        sipNameNr_QQmlComponent,
        {0, 0, 1},
        17, methods_QQmlComponent,
        6, enummembers_QQmlComponent,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlComponent,
    -1,
    -1,
    supers_QQmlComponent,
    SIP_NULLPTR,
    init_type_QQmlComponent,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QQmlComponent,
    SIP_NULLPTR,
    array_QQmlComponent,
    SIP_NULLPTR,
    release_QQmlComponent,
    cast_QQmlComponent,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
