/*
 * Module code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 32 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhstspolicy.sip"
#include <qhstspolicy.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qlocalserver.sip"
#include <qlocalserver.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkconfigmanager.sip"
#include <qnetworkconfigmanager.h>
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkinterface.sip"
#include <qnetworkinterface.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractnetworkcache.sip"
#include <qabstractnetworkcache.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 68 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 74 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 77 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 166 "sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 80 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qlocalsocket.sip"
#include <qlocalsocket.h>
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 195 "sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkcookie.sip"
#include <qnetworkcookie.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 91 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslconfiguration.sip"
#include <qsslconfiguration.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslerror.sip"
#include <qsslerror.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qtcpsocket.sip"
#include <qtcpsocket.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qauthenticator.sip"
#include <qauthenticator.h>
#line 137 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 140 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 143 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 146 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 149 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 94 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 152 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 155 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 158 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostinfo.sip"
#include <qhostinfo.h>
#line 161 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhstspolicy.sip"
#include <qhstspolicy.h>
#line 164 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhttp2configuration.sip"
#include <qhttp2configuration.h>
#line 167 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhttpmultipart.sip"
#include <qhttpmultipart.h>
#line 170 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhttpmultipart.sip"
#include <qhttpmultipart.h>
#line 173 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qlocalserver.sip"
#include <qlocalserver.h>
#line 176 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkconfigmanager.sip"
#include <qnetworkconfigmanager.h>
#line 179 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkconfiguration.sip"
#include <qnetworkconfiguration.h>
#line 182 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkconfiguration.sip"
#include <qnetworkconfiguration.h>
#line 185 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkcookiejar.sip"
#include <qnetworkcookiejar.h>
#line 188 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkdatagram.sip"
#include <qnetworkdatagram.h>
#line 191 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkdiskcache.sip"
#include <qnetworkdiskcache.h>
#line 194 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkinterface.sip"
#include <qnetworkinterface.h>
#line 197 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkinterface.sip"
#include <qnetworkinterface.h>
#line 200 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworkproxy.sip"
#include <qnetworkproxy.h>
#line 203 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qnetworksession.sip"
#include <qnetworksession.h>
#line 206 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 67 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qocspresponse.sip"
#include <qocspresponse.h>
#line 209 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qssl.sip"
#include <qssl.h>
#line 212 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcertificate.sip"
#include <qsslcertificate.h>
#line 215 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcertificateextension.sip"
#include <qsslcertificateextension.h>
#line 218 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslcipher.sip"
#include <qsslcipher.h>
#line 221 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qssldiffiehellmanparameters.sip"
#include <qssldiffiehellmanparameters.h>
#line 224 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslellipticcurve.sip"
#include <qsslellipticcurve.h>
#line 227 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslkey.sip"
#include <qsslkey.h>
#line 230 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslpresharedkeyauthenticator.sip"
#include <qsslpresharedkeyauthenticator.h>
#line 233 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qsslsocket.sip"
#include <qsslsocket.h>
#line 236 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qtcpserver.sip"
#include <qtcpserver.h>
#line 239 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qudpsocket.sip"
#include <qudpsocket.h>
#line 242 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtNetwork[] = {
    'Q', 'M', 'u', 'l', 't', 'i', 'M', 'a', 'p', '<', 'Q', 'S', 's', 'l', ':', ':', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'N', 'a', 'm', 'e', 'E', 'n', 't', 'r', 'y', 'T', 'y', 'p', 'e', ',', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'Q', 'S', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'H', 'a', 's', 'h', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', ',', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', '>', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'd', 'd', 'r', 'e', 's', 's', 'E', 'n', 't', 'r', 'y', ':', ':', 'D', 'n', 's', 'E', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'T', 'i', 'm', 'e', 'o', 'u', 't', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'S', 'e', 'r', 'v', 'e', 'r', 'C', 'i', 'p', 'h', 'e', 'r', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'E', 'm', 'i', 't', 'A', 'l', 'l', 'U', 'p', 'l', 'o', 'a', 'd', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 'S', 'i', 'g', 'n', 'a', 'l', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'i', 's', 'S', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'S', 't', 'o', 'r', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'L', 'a', 'y', 'e', 'r', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'a', 'i', 'r', '<', 'Q', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', ',', 'Q', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', '>', ' ', '>', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'S', 'e', 'r', 'v', 'e', 'r', 'N', 'a', 'm', 'e', 'I', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'A', 'u', 't', 'h', 'o', 'r', 'i', 't', 'y', 'I', 's', 's', 'u', 'e', 'r', 'S', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 'M', 'i', 's', 'm', 'a', 't', 'c', 'h', 0,
    'U', 'n', 'a', 'b', 'l', 'e', 'T', 'o', 'D', 'e', 'c', 'r', 'y', 'p', 't', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'L', 'e', 'g', 'a', 'c', 'y', 'R', 'e', 'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 's', 'l', 'D', 'i', 'f', 'f', 'i', 'e', 'H', 'e', 'l', 'l', 'm', 'a', 'n', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'S', 'e', 's', 's', 'i', 'o', 'n', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 'c', 'e', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'S', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'S', 't', 'o', 'r', 'e', 0,
    'p', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    'U', 'n', 'a', 'b', 'l', 'e', 'T', 'o', 'G', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'I', 's', 's', 'u', 'e', 'r', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', 'd', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'C', 'a', 'c', 'h', 'e', 'L', 'o', 'a', 'd', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    's', 'e', 't', 'S', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'N', 'o', 't', 'P', 'e', 'r', 'm', 'i', 't', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'B', 'e', 'a', 'r', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'S', 't', 'a', 't', 'e', 'F', 'l', 'a', 'g', 's', 0,
    's', 'e', 't', 'S', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'A', 'u', 't', 'o', 'D', 'e', 'l', 'e', 't', 'e', 'R', 'e', 'p', 'l', 'y', 'O', 'n', 'F', 'i', 'n', 'i', 's', 'h', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'N', 'o', 't', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'F', 'l', 'a', 'g', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'S', 't', 'a', 't', 'e', 'F', 'l', 'a', 'g', 0,
    'i', 's', 'S', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', ':', ':', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', ':', ':', 'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'F', 'l', 'a', 'g', 0,
    'P', 'r', 'o', 'x', 'y', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', '>', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'a', 'd', 'd', 'S', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'H', 'o', 's', 't', 's', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'a', 'b', 'l', 'e', 'T', 'o', 'V', 'e', 'r', 'i', 'f', 'y', 'F', 'i', 'r', 's', 't', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', ':', ':', 'P', 'a', 't', 't', 'e', 'r', 'n', 'S', 'y', 'n', 't', 'a', 'x', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'S', 'e', 's', 's', 'i', 'o', 'n', 'S', 'h', 'a', 'r', 'i', 'n', 'g', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'S', 'e', 's', 's', 'i', 'o', 'n', 'T', 'i', 'c', 'k', 'e', 't', 's', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'E', 'm', 'p', 't', 'y', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 's', 0,
    'Q', 'S', 's', 'l', ':', ':', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'N', 'a', 'm', 'e', 'E', 'n', 't', 'r', 'y', 'T', 'y', 'p', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', ':', ':', 'U', 's', 'a', 'g', 'e', 'P', 'o', 'l', 'i', 'c', 'i', 'e', 's', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'T', 'i', 'm', 'e', 'o', 'u', 't', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 0,
    'O', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 'L', 'e', 'n', 'g', 't', 'h', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 't', 't', 'p', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'i', 'n', 'g', 'W', 'a', 's', 'U', 's', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 't', 't', 'p', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'i', 'n', 'g', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'D', 'o', 'N', 'o', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'U', 'p', 'l', 'o', 'a', 'd', 'D', 'a', 't', 'a', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'c', 'h', 'e', 'm', 'e', 's', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'L', 'o', 'c', 'a', 'l', 'S', 'o', 'c', 'k', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'L', 'o', 'c', 'a', 'l', 'S', 'o', 'c', 'k', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'o', 'c', 'k', 'e', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'N', 'o', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'n', 's', 'M', 'a', 'i', 'l', 'E', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'Q', 'S', 's', 'l', 'P', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'o', 'r', 0,
    'U', 'n', 'a', 'b', 'l', 'e', 'T', 'o', 'D', 'e', 'c', 'o', 'd', 'e', 'I', 's', 's', 'u', 'e', 'r', 'P', 'u', 'b', 'l', 'i', 'c', 'K', 'e', 'y', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'n', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'u', 's', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', ':', ':', 'S', 'e', 's', 's', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'K', 'n', 'o', 'w', 'n', 'H', 'e', 'a', 'd', 'e', 'r', 's', 0,
    'i', 'g', 'n', 'o', 'r', 'e', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', 's', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', 'Q', 'u', 'e', 'r', 'y', ':', ':', 'Q', 'u', 'e', 'r', 'y', 'T', 'y', 'p', 'e', 0,
    'R', 'e', 'c', 'e', 'i', 'v', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'n', 's', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    's', 's', 'l', 'L', 'i', 'b', 'r', 'a', 'r', 'y', 'B', 'u', 'i', 'l', 'd', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 's', 'l', 'L', 'i', 'b', 'r', 'a', 'r', 'y', 'B', 'u', 'i', 'l', 'd', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'S', 'e', 'l', 'f', 'S', 'i', 'g', 'n', 'e', 'd', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'I', 'n', 'C', 'h', 'a', 'i', 'n', 0,
    'U', 'n', 'a', 'b', 'l', 'e', 'T', 'o', 'G', 'e', 't', 'I', 's', 's', 'u', 'e', 'r', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', ':', ':', 'S', 'u', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'f', 'o', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', ':', ':', 'U', 's', 'a', 'g', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'L', 'o', 'a', 'd', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'u', 's', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'N', 'o', 't', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    's', 't', 'r', 'i', 'c', 't', 'T', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'H', 'o', 's', 't', 's', 0,
    's', 'e', 't', 'H', 'u', 'f', 'f', 'm', 'a', 'n', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', ':', ':', 'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', ':', ':', 'S', 'p', 'e', 'c', 'i', 'a', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'd', 'd', 'r', 'e', 's', 's', 'E', 'n', 't', 'r', 'y', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'n', 's', 'D', 'o', 'm', 'a', 'i', 'n', 'N', 'a', 'm', 'e', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'O', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'C', 'a', 'n', 'n', 'o', 't', 'B', 'e', 'T', 'r', 'u', 's', 't', 'e', 'd', 0,
    'Q', 'S', 's', 'l', 'D', 'i', 'f', 'f', 'i', 'e', 'H', 'e', 'l', 'l', 'm', 'a', 'n', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    's', 'e', 't', 'P', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 'H', 'i', 'n', 't', 0,
    'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 'N', 'o', 'n', 'e', 0,
    'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 'D', 'i', 's', 'a', 'b', 'l', 'e', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'p', 'l', 'y', ':', ':', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', ':', ':', 'T', 'y', 'p', 'e', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'r', 'o', 'm', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'e', 'r', 'v', 'e', 'r', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'H', 't', 't', 'p', 'M', 'u', 'l', 't', 'i', 'P', 'a', 'r', 't', ':', ':', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'e', 's', 's', 'i', 'o', 'n', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'P', 'a', 'u', 's', 'e', 'M', 'o', 'd', 'e', 's', 0,
    'p', 'r', 'o', 'x', 'y', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    'P', 'r', 'o', 'x', 'y', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'i', 'm', 'e', 'o', 'u', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 'x', 'y', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'e', 'f', 'u', 's', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'L', 'a', 'y', 'e', 'r', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'S', 's', 'l', 'E', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'C', 'u', 'r', 'v', 'e', '>', 0,
    'Q', 'S', 's', 'l', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'P', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'M', 'o', 'd', 'e', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'i', 'f', 'f', 'i', 'e', 'H', 'e', 'l', 'l', 'm', 'a', 'n', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'D', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', 'N', 'a', 'm', 'e', 'Q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'r', 0,
    'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 's', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'i', 'e', 'd', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 's', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'o', 'k', 'i', 'e', 'S', 'a', 'v', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'o', 'k', 'i', 'e', 'L', 'o', 'a', 'd', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'S', 'o', 'u', 'r', 'c', 'e', 'I', 's', 'F', 'r', 'o', 'm', 'C', 'a', 'c', 'h', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'a', 'r', 'g', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'P', 'r', 'o', 'x', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'e', 'r', 'v', 'e', 'r', ':', ':', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 't', 'r', 'e', 'a', 'm', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'P', 'a', 'u', 's', 'e', 'M', 'o', 'd', 'e', 0,
    'S', 'e', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'P', 'r', 'o', 'x', 'y', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'l', 'o', 's', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', ',', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', '>', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'P', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'O', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'C', 'e', 'r', 't', 'I', 'd', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'T', 'i', 'c', 'k', 'e', 't', 'L', 'i', 'f', 'e', 'T', 'i', 'm', 'e', 'H', 'i', 'n', 't', 0,
    'N', 'o', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'T', 'r', 'a', 'f', 'f', 'i', 'c', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'n', 'e', 'w', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', ':', ':', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'C', 'a', 'c', 'h', 'e', 'S', 'a', 'v', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'a', 'c', 'h', 'e', 'L', 'o', 'a', 'd', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 't', 't', 'p', 'R', 'e', 'a', 's', 'o', 'n', 'P', 'h', 'r', 'a', 's', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', 'F', 'a', 'i', 'l', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'U', 's', 'e', 'S', 'y', 's', 't', 'e', 'm', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'C', 'a', 'n', 'S', 't', 'a', 'r', 't', 'A', 'n', 'd', 'S', 't', 'o', 'p', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 's', 0,
    'h', 'u', 'f', 'f', 'm', 'a', 'n', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 't', 'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'B', 'i', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'B', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'n', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    'n', 'e', 'w', 'S', 'e', 's', 's', 'i', 'o', 'n', 'T', 'i', 'c', 'k', 'e', 't', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    'a', 'd', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'S', 't', 'a', 't', 'u', 's', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'p', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'C', 'h', 'a', 'i', 'n', 0,
    'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'S', 'a', 'm', 'e', 'O', 'r', 'i', 'g', 'i', 'n', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'N', 'o', 'L', 'e', 's', 's', 'S', 'a', 'f', 'e', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'F', 'o', 'l', 'l', 'o', 'w', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'D', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 'L', 'o', 'o', 'k', 'u', 'p', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', ':', ':', 'P', 'r', 'o', 'x', 'y', 'T', 'y', 'p', 'e', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'x', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'Q', 'H', 's', 't', 's', 'P', 'o', 'l', 'i', 'c', 'y', ':', ':', 'P', 'o', 'l', 'i', 'c', 'y', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'H', 'o', 's', 't', 'I', 'n', 'f', 'o', ':', ':', 'H', 'o', 's', 't', 'I', 'n', 'f', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'P', 'a', 'i', 'r', '<', 'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', ',', 'i', 'n', 't', '>', 0,
    's', 's', 'l', 'L', 'i', 'b', 'r', 'a', 'r', 'y', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 's', 'l', 'L', 'i', 'b', 'r', 'a', 'r', 'y', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 'B', 'y', 't', 'e', 's', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'a', 'd', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'd', 'i', 'f', 'f', 'i', 'e', 'H', 'e', 'l', 'l', 'm', 'a', 'n', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'C', 'u', 'r', 'v', 'e', 's', 0,
    's', 'e', 't', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 's', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 0,
    'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 't', 't', 'p', 'S', 't', 'a', 't', 'u', 's', 'C', 'o', 'd', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'U', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'u', 's', 'e', 's', 'S', 'y', 's', 't', 'e', 'm', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'c', 't', 'p', 'L', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'S', 'c', 't', 'p', 'T', 'u', 'n', 'n', 'e', 'l', 'i', 'n', 'g', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'T', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'o', 'n', 'U', 'n', 'i', 't', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'o', 'k', 'i', 'e', ':', ':', 'R', 'a', 'w', 'F', 'o', 'r', 'm', 0,
    'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 'R', 'o', 'a', 'm', 'i', 'n', 'g', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'o', 'u', 't', 'i', 'n', 'g', 0,
    's', 't', 'r', 'e', 'a', 'm', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'Q', 'H', 's', 't', 's', 'P', 'o', 'l', 'i', 'c', 'y', ':', ':', 'P', 'o', 'l', 'i', 'c', 'y', 'F', 'l', 'a', 'g', 0,
    'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'n', 'c', 'e', 'l', 'l', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'L', 'o', 'o', 'p', 'b', 'a', 'c', 'k', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'S', 's', 'l', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 's', 'l', 'H', 'a', 'n', 'd', 's', 'h', 'a', 'k', 'e', 'F', 'a', 'i', 'l', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'O', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', '>', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'B', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', 'e', 'd', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'N', 'o', 't', 'Y', 'e', 't', 'V', 'a', 'l', 'i', 'd', 0,
    's', 'e', 't', 'O', 'c', 's', 'p', 'S', 't', 'a', 'p', 'l', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'n', 'e', 'x', 't', 'N', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', 'd', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'O', 'r', 'g', 'a', 'n', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'U', 'n', 'i', 't', 'N', 'a', 'm', 'e', 0,
    'Q', 'O', 'c', 's', 'p', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'n', 'c', 'e', 'l', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'd', 'p', 'T', 'u', 'n', 'n', 'e', 'l', 'i', 'n', 'g', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'N', 'a', 'm', 'e', 'F', 'r', 'o', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'F', 'r', 'o', 'm', 'N', 'a', 'm', 'e', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'H', 'o', 's', 't', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 0,
    'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    'Q', 'D', 'n', 's', 'M', 'a', 'i', 'l', 'E', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'o', 'k', 'i', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'n', 's', 'T', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', '>', 0,
    's', 'e', 't', 'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 'B', 'y', 't', 'e', 's', 'W', 'r', 'i', 't', 't', 'e', 'n', 0,
    'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 'B', 'y', 't', 'e', 's', 'T', 'o', 'W', 'r', 'i', 't', 'e', 0,
    's', 't', 'a', 'r', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'i', 'o', 'n', 0,
    's', 't', 'a', 'r', 't', 'C', 'l', 'i', 'e', 'n', 't', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'O', 'c', 's', 'p', 'M', 'a', 'l', 'f', 'o', 'r', 'm', 'e', 'd', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'S', 'u', 'b', 'j', 'e', 'c', 't', 'I', 's', 's', 'u', 'e', 'r', 'M', 'i', 's', 'm', 'a', 't', 'c', 'h', 0,
    'S', 'e', 'l', 'f', 'S', 'i', 'g', 'n', 'e', 'd', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'N', 'o', 't', 'B', 'e', 'f', 'o', 'r', 'e', 'F', 'i', 'e', 'l', 'd', 0,
    'U', 'n', 's', 'a', 'f', 'e', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'I', 'n', 'p', 'u', 't', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 0,
    'l', 'o', 'c', 'a', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'C', 'h', 'a', 'i', 'n', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'f', 'o', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'Q', 'O', 'c', 's', 'p', 'R', 'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'a', 's', 'o', 'n', 0,
    's', 'e', 't', 'H', 't', 't', 'p', '2', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'H', 't', 't', 'p', '2', 'W', 'a', 's', 'U', 's', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 'T', 'T', 'P', '2', 'W', 'a', 's', 'U', 's', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 't', 't', 'p', '2', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'H', 'T', 'T', 'P', '2', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'I', 'f', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 'S', 'i', 'n', 'c', 'e', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'I', 'n', 's', 'e', 'c', 'u', 'r', 'e', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'o', 'o', 'M', 'a', 'n', 'y', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'n', 's', 'E', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'n', 'e', 'x', 't', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'x', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    'h', 'a', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 's', 'S', 'u', 'b', 'D', 'o', 'm', 'a', 'i', 'n', 's', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 't', 'V', '4', 'C', 'o', 'm', 'p', 'a', 't', 'T', 'o', 'I', 'P', 'v', '4', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 't', 'V', '4', 'M', 'a', 'p', 'p', 'e', 'd', 'T', 'o', 'I', 'P', 'v', '4', 0,
    'Q', 'D', 'n', 's', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 'T', 'o', 'o', 'L', 'a', 'r', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'R', 'e', 'm', 'o', 't', 'e', 'H', 'o', 's', 't', 'C', 'l', 'o', 's', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'a', 'c', 'h', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'a', 'c', 'h', 'e', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'H', 's', 't', 's', 'P', 'o', 'l', 'i', 'c', 'y', '>', 0,
    'a', 'd', 'd', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'O', 'c', 's', 'p', 'M', 'a', 'l', 'f', 'o', 'r', 'm', 'e', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'U', 'n', 't', 'r', 'u', 's', 't', 'e', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'N', 'o', 't', 'A', 'f', 't', 'e', 'r', 'F', 'i', 'e', 'l', 'd', 0,
    'b', 'a', 'c', 'k', 'e', 'n', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'y', 's', 't', 'e', 'm', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    'a', 'l', 'l', 'o', 'w', 'e', 'd', 'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's', 0,
    'p', 'e', 'e', 'r', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'C', 'h', 'a', 'i', 'n', 0,
    'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'i', 's', 's', 'u', 'e', 'r', 'I', 'n', 'f', 'o', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'Q', 'S', 's', 'l', ':', ':', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'C', 'e', 's', 's', 'a', 't', 'i', 'o', 'n', 'O', 'f', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'u', 's', 'a', 'g', 'e', 'P', 'o', 'l', 'i', 'c', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'O', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'i', 'n', 'g', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'H', 't', 't', 'p', '2', 'D', 'i', 'r', 'e', 'c', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'S', 'p', 'd', 'y', 'W', 'a', 's', 'U', 's', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'S', 'p', 'd', 'y', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'A', 'd', 'd', 'r', 'e', 's', 's', 'L', 'i', 'f', 'e', 't', 'i', 'm', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'd', 'd', 'r', 'e', 's', 's', 'E', 'n', 't', 'r', 'y', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'y', 's', 't', 'e', 'm', 'S', 'e', 's', 's', 'i', 'o', 'n', 'S', 'u', 'p', 'p', 'o', 'r', 't', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'D', 'e', 'l', 'e', 't', 'e', 'R', 'e', 'p', 'l', 'i', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'N', 'e', 'w', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'P', 'u', 's', 'h', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'U', 'n', 'i', 'q', 'u', 'e', 'L', 'o', 'c', 'a', 'l', 'U', 'n', 'i', 'c', 'a', 's', 't', 0,
    'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', 'N', 'a', 'm', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'Q', 'D', 'n', 's', 'D', 'o', 'm', 'a', 'i', 'n', 'N', 'a', 'm', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', '>', 0,
    'l', 'e', 'a', 'v', 'e', 'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'p', 'e', 'n', 'd', 'i', 'n', 'g', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 'S', 'i', 'z', 'e', 0,
    'h', 'a', 's', 'P', 'e', 'n', 'd', 'i', 'n', 'g', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 's', 0,
    'Q', 'S', 's', 'l', 'S', 'o', 'c', 'k', 'e', 't', ':', ':', 'S', 's', 'l', 'M', 'o', 'd', 'e', 0,
    'O', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'E', 'x', 'p', 'i', 'r', 'e', 'd', 0,
    'O', 'c', 's', 'p', 'N', 'o', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'F', 'o', 'u', 'n', 'd', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'R', 'e', 'j', 'e', 'c', 't', 'e', 'd', 0,
    'Q', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', ':', ':', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'o', 'c', 's', 'p', 'S', 't', 'a', 'p', 'l', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'H', 't', 't', 'p', '1', '_', '1', 0,
    'N', 'e', 'x', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'S', 'p', 'd', 'y', '3', '_', '0', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'S', 't', 'a', 't', 'e', 'O', 'r', 'P', 'r', 'o', 'v', 'i', 'n', 'c', 'e', 'N', 'a', 'm', 'e', 0,
    'S', 'e', 's', 's', 'i', 'o', 'n', 'A', 'b', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'e', 's', 's', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'u', 's', 't', 'o', 'm', 'V', 'e', 'r', 'b', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'L', 'e', 'n', 'g', 't', 'h', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'S', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'C', 'o', 'n', 't', 'e', 'n', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'A', 'c', 'c', 'e', 's', 's', 'D', 'e', 'n', 'i', 'e', 'd', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'y', 's', 't', 'e', 'm', 'P', 'r', 'o', 'x', 'y', 'F', 'o', 'r', 'Q', 'u', 'e', 'r', 'y', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'P', 'r', 'o', 'x', 'y', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'C', 'a', 'c', 'h', 'e', 'S', 'i', 'z', 'e', 0,
    'I', 'n', 't', 'e', 'r', 'n', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'P', 'o', 'i', 'n', 't', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'r', 'v', 'e', 'r', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'H', 't', 't', 'p', '2', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'i', 'l', 'E', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'a', 't', 'h', 'M', 't', 'u', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'T', 'y', 'p', 'e', 'O', 'f', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'D', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    's', 'e', 't', 'S', 'o', 'c', 'k', 'e', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 0,
    'S', 'o', 'c', 'k', 'e', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'B', 'y', 't', 'e', 's', 'W', 'r', 'i', 't', 't', 'e', 'n', 0,
    'm', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'j', 'o', 'i', 'n', 'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'G', 'r', 'o', 'u', 'p', 0,
    's', 's', 'l', 'H', 'a', 'n', 'd', 's', 'h', 'a', 'k', 'e', 'E', 'r', 'r', 'o', 'r', 's', 0,
    'P', 'a', 't', 'h', 'L', 'e', 'n', 'g', 't', 'h', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'R', 'e', 'v', 'o', 'k', 'e', 'd', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'E', 'x', 'p', 'i', 'r', 'e', 'd', 0,
    'e', 'p', 'h', 'e', 'm', 'e', 'r', 'a', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 'K', 'e', 'y', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'D', 'e', 'p', 't', 'h', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    'Q', 'S', 's', 'l', ':', ':', 'K', 'e', 'y', 'A', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', 0,
    'A', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'S', 'e', 's', 's', 'i', 'o', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'h', 't', 't', 'p', '2', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'L', 'a', 's', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'R', 'e', 'S', 'e', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', 'Q', 'u', 'e', 'r', 'y', 0,
    'i', 's', 'T', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 't', 'P', 'r', 'o', 'x', 'y', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'F', 'r', 'o', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'L', 'i', 'f', 'e', 't', 'i', 'm', 'e', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'i', 's', 'R', 'o', 'a', 'm', 'i', 'n', 'g', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'o', 'n', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'd', 'd', 'e', 'd', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    'i', 'n', 'c', 'o', 'm', 'i', 'n', 'g', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 'n', 'c', 'l', 'u', 'd', 'e', 's', 'S', 'u', 'b', 'D', 'o', 'm', 'a', 'i', 'n', 's', 0,
    'T', 'o', 'l', 'e', 'r', 'a', 'n', 't', 'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'h', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'S', 'e', 'r', 'v', 'e', 'r', 'R', 'e', 'f', 'u', 's', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'e', 'r', 'v', 'e', 'r', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'r', 'P', 'l', 'a', 't', 'f', 'o', 'r', 'm', 0,
    'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 'T', 't', 'l', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'H', 'o', 's', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'o', 'c', 'k', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 'x', 'y', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 'x', 'y', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'o', 'c', 'k', 'e', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 's', 'l', 'C', 'i', 'p', 'h', 'e', 'r', '>', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'i', 'p', 'h', 'e', 'r', 's', 0,
    'O', 'c', 's', 'p', 'S', 't', 'a', 't', 'u', 's', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'O', 'c', 's', 'p', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'P', 'e', 'e', 'r', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', 'E', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'C', 'u', 'r', 'v', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'a', 'd', 'd', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    's', 'e', 't', 'E', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'C', 'u', 'r', 'v', 'e', 's', 0,
    's', 'e', 't', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'k', 'e', 'y', 'E', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'i', 's', 's', 'u', 'e', 'r', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    'Q', 'S', 's', 'l', ':', ':', 'S', 's', 'l', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'Q', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 'D', 'i', 'g', 'e', 's', 't', 'o', 'r', 0,
    'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'S', 't', 'a', 't', 'u', 's', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'N', 'a', 'm', 'e', 0,
    'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'i', 'n', 'g', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'I', 'f', 'N', 'o', 'n', 'e', 'M', 'a', 't', 'c', 'h', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'r', 'o', 'x', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'r', 'o', 'x', 'y', 'T', 'i', 'm', 'e', 'o', 'u', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'a', 'c', 'h', 'i', 'n', 'g', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'h', 'u', 'm', 'a', 'n', 'R', 'e', 'a', 'd', 'a', 'b', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'F', 'r', 'o', 'm', 'N', 'a', 'm', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'L', 'i', 'f', 'e', 't', 'i', 'm', 'e', 0,
    's', 'e', 't', 'D', 'n', 's', 'E', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'D', 'i', 's', 'k', 'C', 'a', 'c', 'h', 'e', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'C', 'o', 'o', 'k', 'i', 'e', 's', 'F', 'r', 'o', 'm', 'U', 'r', 'l', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'o', 'k', 'i', 'e', 'J', 'a', 'r', 0,
    'h', 'a', 's', 'S', 'a', 'm', 'e', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    'a', 'l', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'a', 'u', 't', 'o', 'D', 'e', 'l', 'e', 't', 'e', 'R', 'e', 'p', 'l', 'i', 'e', 's', 0,
    's', 'e', 't', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 'n', 'd', 'C', 'u', 's', 't', 'o', 'm', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'W', 'o', 'r', 'l', 'd', 'A', 'c', 'c', 'e', 's', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'O', 't', 'h', 'e', 'r', 'A', 'c', 'c', 'e', 's', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'G', 'r', 'o', 'u', 'p', 'A', 'c', 'c', 'e', 's', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 'r', 'v', 'e', 'r', 'P', 'u', 's', 'h', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'S', 'u', 'b', 'D', 'o', 'm', 'a', 'i', 'n', 's', 0,
    'n', 'a', 'm', 'e', 's', 'e', 'r', 'v', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 'm', 'e', 'S', 'e', 'r', 'v', 'e', 'r', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'R', 'e', 'p', 'l', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'D', 'n', 's', 'L', 'o', 'o', 'k', 'u', 'p', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'D', 'n', 's', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'A', 'd', 'd', 'r', 'e', 's', 's', 'I', 'n', 'U', 's', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'o', 'c', 'k', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'E', 'r', 'r', 'o', 'r', 0,
    'H', 'o', 's', 't', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'o', 'c', 'k', 'e', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'E', 'x', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'D', 'a', 't', 'e', 0,
    'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', '>', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 0,
    'O', 'c', 's', 'p', 'U', 'n', 'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'd', 0,
    'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 'M', 'i', 's', 'm', 'a', 't', 'c', 'h', 0,
    'a', 'd', 'd', 'C', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'i', 'p', 'h', 'e', 'r', 's', 0,
    's', 'e', 't', 'S', 'e', 's', 's', 'i', 'o', 'n', 'T', 'i', 'c', 'k', 'e', 't', 0,
    'l', 'o', 'c', 'a', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'e', 'n', 'c', 'r', 'y', 'p', 't', 'i', 'o', 'n', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'S', 's', 'l', ':', ':', 'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'r', 'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'a', 's', 'o', 'n', 0,
    'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'C', 'o', 'n', 't', 'e', 'n', 't', 'G', 'o', 'n', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'P', 'r', 'o', 'x', 'y', 0,
    'H', 't', 't', 'p', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 'P', 'r', 'o', 'x', 'y', 0,
    'v', 'a', 'l', 'i', 'd', 'i', 't', 'y', 'L', 'i', 'f', 'e', 't', 'i', 'm', 'e', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'C', 'a', 'c', 'h', 'e', 'S', 'i', 'z', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 0,
    'N', 'a', 'm', 'e', 'A', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 'O', 'n', 'l', 'y', 0,
    'b', 'e', 'a', 'r', 'e', 'r', 'T', 'y', 'p', 'e', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 's', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'c', 'h', 'e', 'm', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'A', 'c', 'c', 'e', 's', 's', 'C', 'a', 'c', 'h', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'U', 's', 'e', 'r', 'A', 'c', 'c', 'e', 's', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'S', 't', 'r', 'i', 'c', 't', 'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 't', 'L', 'o', 'c', 'a', 'l', 'H', 'o', 's', 't', 0,
    'Q', 'D', 'n', 's', 'L', 'o', 'o', 'k', 'u', 'p', ':', ':', 'T', 'y', 'p', 'e', 0,
    'P', 'a', 'u', 's', 'e', 'O', 'n', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', 's', 0,
    'R', 'e', 'u', 's', 'e', 'A', 'd', 'd', 'r', 'e', 's', 's', 'H', 'i', 'n', 't', 0,
    'D', 'o', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    's', 'o', 'c', 'k', 'e', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 0,
    'U', 'n', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'S', 's', 'l', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'R', 'e', 'a', 'd', 'y', 'R', 'e', 'a', 'd', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'r', 'e', 'c', 'e', 'i', 'v', 'e', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 0,
    'r', 'e', 's', 'u', 'm', 'e', 'A', 'c', 'c', 'e', 'p', 't', 'i', 'n', 'g', 0,
    'p', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    'i', 's', 'T', 'l', 's', 'N', 'a', 'm', 'e', 'd', 'C', 'u', 'r', 'v', 'e', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'p', 'e', 'e', 'r', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'p', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'D', 'e', 'p', 't', 'h', 0,
    'Q', 'S', 's', 'l', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', ':', ':', 'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'D', 't', 'l', 's', 'V', '1', '_', '2', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'D', 't', 'l', 's', 'V', '1', '_', '0', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'S', 'e', 'c', 'u', 'r', 'e', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'd', 'e', 'r', 'i', 'v', 'e', 'K', 'e', 'y', 'P', 'b', 'k', 'd', 'f', '2', 0,
    'd', 'e', 'r', 'i', 'v', 'e', 'K', 'e', 'y', 'P', 'b', 'k', 'd', 'f', '1', 0,
    'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'H', 'o', 'l', 'd', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'S', 'e', 's', 's', 'i', 'o', 'n', 0,
    'U', 's', 'e', 'r', 'A', 'g', 'e', 'n', 't', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'S', 'e', 't', 'C', 'o', 'o', 'k', 'i', 'e', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'A', 'l', 'l', 'o', 'w', 'e', 'd', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'g', 'n', 'o', 'r', 'e', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', 's', 0,
    'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'F', 'a', 'i', 'l', 'u', 'r', 'e', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'F', 't', 'p', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 'P', 'r', 'o', 'x', 'y', 0,
    'h', 'a', 'r', 'd', 'w', 'a', 'r', 'e', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'i', 's', 'L', 'i', 'f', 'e', 't', 'i', 'm', 'e', 'K', 'n', 'o', 'w', 'n', 0,
    's', 'e', 't', 'P', 'r', 'e', 'f', 'i', 'x', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'P', 'o', 'r', 't', 0,
    'i', 's', 'S', 'e', 's', 's', 'i', 'o', 'n', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'B', 'l', 'u', 'e', 't', 'o', 'o', 't', 'h', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', 0,
    't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'x', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'C', 'u', 's', 't', 'o', 'm', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'e', 'e', 'r', 'C', 'l', 'o', 's', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'M', 'a', 'x', 'F', 'r', 'a', 'm', 'e', 'S', 'i', 'z', 'e', 0,
    'l', 'o', 'c', 'a', 'l', 'D', 'o', 'm', 'a', 'i', 'n', 'N', 'a', 'm', 'e', 0,
    'a', 'b', 'o', 'r', 't', 'H', 'o', 's', 't', 'L', 'o', 'o', 'k', 'u', 'p', 0,
    's', 'e', 't', 'S', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'K', 'e', 'e', 'p', 'A', 'l', 'i', 'v', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'H', 'o', 's', 't', 'L', 'o', 'o', 'k', 'u', 'p', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'o', 'c', 'k', 'e', 't', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'p', 'a', 'u', 's', 'e', 'A', 'c', 'c', 'e', 'p', 't', 'i', 'n', 'g', 0,
    'A', 'u', 't', 'o', 'V', 'e', 'r', 'i', 'f', 'y', 'P', 'e', 'e', 'r', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'i', 'p', 'h', 'e', 'r', 's', 0,
    'O', 'c', 's', 'p', 'S', 'i', 'g', 'R', 'e', 'q', 'u', 'r', 'e', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'e', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'C', 'u', 'r', 'v', 'e', 's', 0,
    'p', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'M', 'o', 'd', 'e', 0,
    'p', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'c', 'a', 'C', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', 0,
    'T', 'l', 's', 'V', '1', '_', '3', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'T', 'l', 's', 'V', '1', '_', '2', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'T', 'l', 's', 'V', '1', '_', '1', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'T', 'l', 's', 'V', '1', '_', '0', 'O', 'r', 'L', 'a', 't', 'e', 'r', 0,
    'I', 'p', 'A', 'd', 'd', 'r', 'e', 's', 's', 'E', 'n', 't', 'r', 'y', 0,
    'p', 'e', 'e', 'r', 'V', 'e', 'r', 'i', 'f', 'y', 'N', 'a', 'm', 'e', 0,
    'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'r', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 'P', 'a', 'i', 'r', 's', 0,
    'u', 'p', 'l', 'o', 'a', 'd', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'i', 's', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 'P', 'r', 'o', 'x', 'y', 0,
    'a', 'd', 'd', 'r', 'e', 's', 's', 'E', 'n', 't', 'r', 'i', 'e', 's', 0,
    'I', 's', 'P', 'o', 'i', 'n', 't', 'T', 'o', 'P', 'o', 'i', 'n', 't', 0,
    'd', 'n', 's', 'E', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'c', 'a', 'c', 'h', 'e', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 0,
    'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'i', 'm', 'e', 'o', 'u', 't', 0,
    'b', 'e', 'a', 'r', 'e', 'r', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'C', 'D', 'M', 'A', '2', '0', '0', '0', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'E', 't', 'h', 'e', 'r', 'n', 'e', 't', 0,
    'P', 'r', 'i', 'v', 'a', 't', 'e', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'D', 'a', 't', 'a', 'S', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 's', 0,
    'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'f', 'u', 'l', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'H', 't', 't', 'p', 'M', 'u', 'l', 't', 'i', 'P', 'a', 'r', 't', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'p', 'o', 'i', 'n', 't', 'e', 'r', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'Q', 'D', 'n', 's', 'T', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'T', 'a', 'g', 0,
    'L', 'o', 'w', 'D', 'e', 'l', 'a', 'y', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    's', 'e', 't', 'S', 'o', 'c', 'k', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'S', 'o', 'c', 'k', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    'r', 'e', 'a', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'L', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'e', 'x', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'D', 'a', 't', 'e', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    's', 'e', 't', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'b', 'y', 't', 'e', 's', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'w', 'r', 'i', 't', 'e', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 0,
    's', 'e', 'r', 'v', 'e', 'r', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'o', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 's', 0,
    'S', 's', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'S', 's', 'l', 'C', 'l', 'i', 'e', 'n', 't', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'o', 'm', 'S', 'h', 'o', 'r', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'T', 'i', 'c', 'k', 'e', 't', 0,
    't', 'e', 's', 't', 'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'i', 'v', 'a', 't', 'e', 'K', 'e', 'y', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'C', 'i', 'p', 'h', 'e', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'B', 'i', 't', 's', 0,
    'i', 's', 'B', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', 'e', 'd', 0,
    'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'D', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', ':', ':', 'K', 'e', 'y', 'T', 'y', 'p', 'e', 0,
    'Q', 'O', 'c', 's', 'p', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'R', 'e', 'm', 'o', 'v', 'e', 'F', 'r', 'o', 'm', 'C', 'R', 'L', 0,
    'K', 'e', 'y', 'C', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', 0,
    'u', 's', 'a', 'g', 'e', 'P', 'o', 'l', 'i', 'c', 'i', 'e', 's', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'O', 'p', 'e', 'n', 'e', 'd', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'A', 'l', 'w', 'a', 'y', 's', 'N', 'e', 't', 'w', 'o', 'r', 'k', 0,
    'I', 'f', 'M', 'a', 't', 'c', 'h', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'b', 'y', 't', 'e', 's', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'p', 'l', 'y', 0,
    'p', 'r', 'o', 'x', 'y', 'F', 'o', 'r', 'Q', 'u', 'e', 'r', 'y', 0,
    'r', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 'L', 'i', 's', 't', 0,
    'Q', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'P', 'r', 'o', 'x', 'y', 0,
    'a', 'l', 'l', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 's', 0,
    'D', 'n', 's', 'I', 'n', 'e', 'l', 'i', 'g', 'i', 'b', 'l', 'e', 0,
    's', 'e', 'n', 'd', 'e', 'r', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    's', 'e', 't', 'A', 'l', 'l', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'c', 'o', 'o', 'k', 'i', 'e', 's', 'F', 'o', 'r', 'U', 'r', 'l', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'P', 'u', 'b', 'l', 'i', 'c', 'P', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'F', 'o', 'r', 'c', 'e', 'd', 'R', 'o', 'a', 'm', 'i', 'n', 'g', 0,
    'N', 'o', 't', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'P', 'o', 's', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'H', 'e', 'a', 'd', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    's', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'n', 'e', 'w', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'o', 'd', 'y', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'l', 'o', 'c', 'a', 'l', 'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    't', 'o', 'I', 'P', 'v', '6', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    't', 'o', 'I', 'P', 'v', '4', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'L', 'o', 'c', 'a', 'l', 'H', 'o', 's', 't', 'I', 'P', 'v', '6', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 's', 'e', 'r', 'v', 'e', 'r', 0,
    'R', 'e', 's', 'o', 'l', 'v', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'H', 'o', 's', 't', 0,
    'A', 'n', 'y', 'I', 'P', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'S', 'a', 'v', 'e', 'T', 'o', 'D', 'i', 's', 'k', 0,
    's', 'e', 't', 'R', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 's', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'r', 'r', 'o', 'r', 'O', 'c', 'c', 'u', 'r', 'r', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'D', 'a', 't', 'a', 'g', 'r', 'a', 'm', 0,
    'p', 'r', 'e', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    'i', 'd', 'e', 'n', 't', 'i', 't', 'y', 'H', 'i', 'n', 't', 0,
    'O', 'c', 's', 'p', 'T', 'r', 'y', 'L', 'a', 't', 'e', 'r', 0,
    'N', 'o', 'S', 's', 'l', 'S', 'u', 'p', 'p', 'o', 'r', 't', 0,
    'f', 'r', 'o', 'm', 'L', 'o', 'n', 'g', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'S', 's', 'l', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'i', 'm', 'p', 'o', 'r', 't', 'P', 'k', 'c', 's', '1', '2', 0,
    'i', 's', 'S', 'e', 'l', 'f', 'S', 'i', 'g', 'n', 'e', 'd', 0,
    's', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'E', 'm', 'a', 'i', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'S', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 't', 'y', 'N', 'a', 'm', 'e', 0,
    'O', 'r', 'g', 'a', 'n', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'A', 'C', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', 0,
    'R', 'o', 'a', 'm', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'S', 'e', 'r', 'v', 'e', 'r', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'e', 'e', 'r', 'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'Q', 'u', 'e', 'r', 'y', 'T', 'y', 'p', 'e', 0,
    'h', 'a', 's', 'R', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'o', 'x', 'y', 0,
    'a', 'l', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 'e', 's', 0,
    'C', 'a', 'n', 'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 0,
    'C', 'a', 'n', 'B', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 0,
    'p', 'r', 'e', 'f', 'i', 'x', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'B', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 0,
    'f', 'i', 'l', 'e', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'o', 'k', 'i', 'e', 0,
    'p', 'a', 'r', 's', 'e', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'p', 'r', 'o', 'x', 'y', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    's', 'e', 't', 'C', 'o', 'o', 'k', 'i', 'e', 'J', 'a', 'r', 0,
    'P', 'u', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'G', 'e', 't', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'o', 'c', 'k', 'e', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'Q', 'L', 'o', 'c', 'a', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'F', 'o', 'r', 'm', 'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'R', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'm', 'a', 'x', 'F', 'r', 'a', 'm', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 'e', 's', 0,
    'H', 'o', 's', 't', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 0,
    'Q', 'H', 'o', 's', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    's', 'e', 't', 'P', 'a', 'u', 's', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'o', 'c', 'k', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'P', 'o', 'r', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'C', 'l', 'o', 's', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'I', 'P', 'v', '6', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'I', 'P', 'v', '4', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'H', 'i', 'g', 'h', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'b', 'y', 't', 'e', 's', 'W', 'r', 'i', 't', 't', 'e', 'n', 0,
    'b', 'y', 't', 'e', 's', 'T', 'o', 'W', 'r', 'i', 't', 'e', 0,
    'l', 'a', 's', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'L', 'i', 'n', 'e', 'D', 'a', 't', 'a', 0,
    'i', 's', 'S', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'm', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'S', 's', 'l', 0,
    'i', 's', 'E', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 0,
    's', 'e', 't', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'i', 's', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'f', 'o', 0,
    'C', 'o', 'u', 'n', 't', 'r', 'y', 'N', 'a', 'm', 'e', 0,
    'A', 'n', 'y', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'A', 'l', 'w', 'a', 'y', 's', 'C', 'a', 'c', 'h', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'C', 'a', 'c', 'h', 'e', 0,
    's', 'e', 't', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'S', 'o', 'c', 'k', 's', '5', 'P', 'r', 'o', 'x', 'y', 0,
    'i', 's', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 0,
    'i', 's', 'P', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', 0,
    'D', 'n', 's', 'E', 'l', 'i', 'g', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'H', 'o', 'p', 'L', 'i', 'm', 'i', 't', 0,
    's', 'e', 't', 'H', 't', 't', 'p', 'O', 'n', 'l', 'y', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'W', 'i', 'M', 'A', 'X', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'W', 'C', 'D', 'M', 'A', 0,
    's', 'e', 'r', 'v', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'L', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'B', 'o', 'u', 'n', 'd', 'a', 'r', 'y', 0,
    'R', 'e', 'l', 'a', 't', 'e', 'd', 'T', 'y', 'p', 'e', 0,
    'Q', 'H', 's', 't', 's', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'L', 'o', 'o', 'k', 'u', 'p', 'I', 'd', 0,
    's', 'e', 't', 'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    'i', 's', 'B', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 0,
    'i', 's', 'S', 'i', 't', 'e', 'L', 'o', 'c', 'a', 'l', 0,
    'i', 's', 'L', 'i', 'n', 'k', 'L', 'o', 'c', 'a', 'l', 0,
    'i', 's', 'M', 'u', 'l', 't', 'i', 'c', 'a', 's', 't', 0,
    'p', 'a', 'r', 's', 'e', 'S', 'u', 'b', 'n', 'e', 't', 0,
    't', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'R', 'e', 'c', 'o', 'r', 'd', 's', 0,
    'p', 'r', 'o', 't', 'o', 'c', 'o', 'l', 'T', 'a', 'g', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'P', 'e', 'e', 'r', 'P', 'o', 'r', 't', 0,
    'p', 'e', 'e', 'r', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'f', 'r', 'o', 'm', 'E', 'n', 'c', 'o', 'd', 'e', 'd', 0,
    's', 'e', 't', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    's', 'e', 't', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'L', 'o', 'w', 'P', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    'F', 'i', 'x', 'e', 'd', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 0,
    'c', 'a', 'n', 'R', 'e', 'a', 'd', 'L', 'i', 'n', 'e', 0,
    'Q', 'U', 'd', 'p', 'S', 'o', 'c', 'k', 'e', 't', 0,
    's', 'e', 'r', 'v', 'e', 'r', 'P', 'o', 'r', 't', 0,
    'Q', 'T', 'c', 'p', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'V', 'e', 'r', 'i', 'f', 'y', 'N', 'o', 'n', 'e', 0,
    'Q', 'S', 's', 'l', 'S', 'o', 'c', 'k', 'e', 't', 0,
    'Q', 'T', 'c', 'p', 'S', 'o', 'c', 'k', 'e', 't', 0,
    's', 'e', 't', 'C', 'i', 'p', 'h', 'e', 'r', 's', 0,
    'p', 'r', 'i', 'v', 'a', 't', 'e', 'K', 'e', 'y', 0,
    'Q', 'S', 's', 'l', 'C', 'i', 'p', 'h', 'e', 'r', 0,
    'i', 's', 'C', 'r', 'i', 't', 'i', 'c', 'a', 'l', 0,
    'p', 'a', 's', 's', 'P', 'h', 'r', 'a', 's', 'e', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'f', 'r', 'o', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'e', 'x', 'p', 'i', 'r', 'y', 'D', 'a', 't', 'e', 0,
    'i', 's', 's', 'u', 'e', 'r', 'I', 'n', 'f', 'o', 0,
    'C', 'o', 'm', 'm', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    'T', 'l', 's', 'V', '1', 'S', 's', 'l', 'V', '3', 0,
    'E', 'm', 'a', 'i', 'l', 'E', 'n', 't', 'r', 'y', 0,
    'S', 'u', 'p', 'e', 'r', 's', 'e', 'd', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'T', 'i', 'm', 'e', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', 0,
    'E', 'T', 'a', 'g', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'e', 'd', 0,
    'q', 'u', 'e', 'r', 'y', 'P', 'r', 'o', 'x', 'y', 0,
    'S', 'c', 't', 'p', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'U', 'r', 'l', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'I', 'e', 'e', 'e', '8', '0', '2', '1', '5', '4', 0,
    'I', 's', 'L', 'o', 'o', 'p', 'B', 'a', 'c', 'k', 0,
    's', 'e', 't', 'N', 'e', 't', 'm', 'a', 's', 'k', 0,
    's', 'e', 'n', 'd', 'e', 'r', 'P', 'o', 'r', 't', 0,
    'a', 'l', 'l', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'i', 's', 'H', 't', 't', 'p', 'O', 'n', 'l', 'y', 0,
    'b', 'e', 'a', 'r', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'E', 'V', 'D', 'O', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'H', 'S', 'P', 'A', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'W', 'L', 'A', 'N', 0,
    'D', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'd', 0,
    'U', 's', 'e', 'r', 'C', 'h', 'o', 'i', 'c', 'e', 0,
    'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    's', 'e', 'r', 'v', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'l', 'o', 'o', 'k', 'u', 'p', 'H', 'o', 's', 't', 0,
    'Q', '_', 'I', 'P', 'V', '6', 'A', 'D', 'D', 'R', 0,
    'i', 's', 'L', 'o', 'o', 'p', 'b', 'a', 'c', 'k', 0,
    'i', 's', 'I', 'n', 'S', 'u', 'b', 'n', 'e', 't', 0,
    's', 'e', 't', 'S', 'c', 'o', 'p', 'e', 'I', 'd', 0,
    's', 'e', 't', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'n', 'a', 'm', 'e', 's', 'e', 'r', 'v', 'e', 'r', 0,
    'Q', 'D', 'n', 's', 'L', 'o', 'o', 'k', 'u', 'p', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    't', 'i', 'm', 'e', 'T', 'o', 'L', 'i', 'v', 'e', 0,
    'P', 'a', 'u', 's', 'e', 'N', 'e', 'v', 'e', 'r', 0,
    's', 'o', 'c', 'k', 'e', 't', 'T', 'y', 'p', 'e', 0,
    'B', 'o', 'u', 'n', 'd', 'S', 't', 'a', 't', 'e', 0,
    'S', 'c', 't', 'p', 'S', 'o', 'c', 'k', 'e', 't', 0,
    's', 'a', 'v', 'e', 'T', 'o', 'D', 'i', 's', 'k', 0,
    'r', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 's', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'i', 's', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    '_', '_', 'r', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'Q', 'u', 'e', 'r', 'y', 'P', 'e', 'e', 'r', 0,
    'Q', 'S', 's', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'h', 'o', 'r', 't', 'N', 'a', 'm', 'e', 0,
    'p', 'u', 'b', 'l', 'i', 'c', 'K', 'e', 'y', 0,
    'a', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', 0,
    'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'r', 0,
    'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'q', 'u', 'e', 'r', 'y', 'T', 'y', 'p', 'e', 0,
    'r', 'a', 'w', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'H', 't', 't', 'p', 'P', 'r', 'o', 'x', 'y', 0,
    'I', 'e', 'e', 'e', '8', '0', '2', '1', '6', 0,
    'S', 'i', 'x', 'L', 'o', 'W', 'P', 'A', 'N', 0,
    'I', 'e', 'e', 'e', '8', '0', '2', '1', '1', 0,
    'I', 's', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 0,
    'm', 'a', 'k', 'e', 'R', 'e', 'p', 'l', 'y', 0,
    's', 'e', 't', 'S', 'e', 'n', 'd', 'e', 'r', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 0,
    't', 'o', 'R', 'a', 'w', 'F', 'o', 'r', 'm', 0,
    's', 'e', 't', 'D', 'o', 'm', 'a', 'i', 'n', 0,
    's', 'e', 't', 'S', 'e', 'c', 'u', 'r', 'e', 0,
    'B', 'e', 'a', 'r', 'e', 'r', 'L', 'T', 'E', 0,
    's', 's', 'l', 'E', 'r', 'r', 'o', 'r', 's', 0,
    'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', 0,
    'c', 'o', 'o', 'k', 'i', 'e', 'J', 'a', 'r', 0,
    'M', 'i', 'x', 'e', 'd', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'Q', 'H', 't', 't', 'p', 'P', 'a', 'r', 't', 0,
    'i', 's', 'E', 'x', 'p', 'i', 'r', 'e', 'd', 0,
    's', 'e', 't', 'E', 'x', 'p', 'i', 'r', 'y', 0,
    'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 's', 0,
    'Q', 'H', 'o', 's', 't', 'I', 'n', 'f', 'o', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'u', 's', 'e', 'M', 'o', 'd', 'e', 0,
    'h', 'o', 's', 't', 'F', 'o', 'u', 'n', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'P', 'o', 'r', 't', 0,
    'c', 'a', 'c', 'h', 'e', 'S', 'i', 'z', 'e', 0,
    'i', 's', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'w', 'r', 'i', 't', 'e', 'D', 'a', 't', 'a', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'i', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    'l', 'o', 'n', 'g', 'N', 'a', 'm', 'e', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'u', 's', 'e', 'd', 'B', 'i', 't', 's', 0,
    'f', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'f', 'r', 'o', 'm', 'P', 'a', 't', 'h', 0,
    'D', 't', 'l', 's', 'V', '1', '_', '2', 0,
    'D', 't', 'l', 's', 'V', '1', '_', '0', 0,
    'D', 'n', 's', 'E', 'n', 't', 'r', 'y', 0,
    'N', 'o', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'I', 'e', 'e', 'e', '1', '3', '9', '4', 0,
    'h', 'o', 'p', 'L', 'i', 'm', 'i', 't', 0,
    'i', 's', 'S', 'e', 'c', 'u', 'r', 'e', 0,
    'B', 'e', 'a', 'r', 'e', 'r', '4', 'G', 0,
    'B', 'e', 'a', 'r', 'e', 'r', '3', 'G', 0,
    'B', 'e', 'a', 'r', 'e', 'r', '2', 'G', 0,
    'i', 's', 'O', 'n', 'l', 'i', 'n', 'e', 0,
    's', 't', 'o', 'r', 'e', 'D', 'i', 'r', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 0,
    't', 'i', 'm', 'e', 'd', 'O', 'u', 't', 0,
    'b', 'o', 'u', 'n', 'd', 'a', 'r', 'y', 0,
    'f', 'r', 'o', 'm', 'N', 'a', 'm', 'e', 0,
    'l', 'o', 'o', 'k', 'u', 'p', 'I', 'd', 0,
    's', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 'x', 'y', 0,
    'p', 'e', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'p', 'e', 'e', 'r', 'P', 'o', 'r', 't', 0,
    'p', 'r', 'o', 't', 'o', 'c', 'o', 'l', 0,
    'h', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'W', 'i', 'l', 'd', 'c', 'a', 'r', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'p', 'r', 'i', 'o', 'r', 'i', 't', 'y', 0,
    't', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'r', 'e', 'a', 'd', 'D', 'a', 't', 'a', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    'Q', 'S', 's', 'l', 'K', 'e', 'y', 0,
    'c', 'i', 'p', 'h', 'e', 'r', 's', 0,
    'T', 'l', 's', 'V', '1', '_', '3', 0,
    'T', 'l', 's', 'V', '1', '_', '2', 0,
    'T', 'l', 's', 'V', '1', '_', '1', 0,
    'T', 'l', 's', 'V', '1', '_', '0', 0,
    'm', 'i', 'g', 'r', 'a', 't', 'e', 0,
    'C', 'l', 'o', 's', 'i', 'n', 'g', 0,
    'U', 's', 'e', 'r', 'M', 'a', 'x', 0,
    'm', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'N', 'o', 'P', 'r', 'o', 'x', 'y', 0,
    'V', 'i', 'r', 't', 'u', 'a', 'l', 0,
    'p', 'u', 'r', 'p', 'o', 's', 'e', 0,
    'D', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'B', 'o', 'd', 'y', 0,
    'i', 's', 'E', 'q', 'u', 'a', 'l', 0,
    'n', 'e', 't', 'm', 'a', 's', 'k', 0,
    's', 'c', 'o', 'p', 'e', 'I', 'd', 0,
    'A', 'n', 'y', 'I', 'P', 'v', '6', 0,
    'A', 'n', 'y', 'I', 'P', 'v', '4', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 0,
    's', 'e', 't', 'P', 'o', 'r', 't', 0,
    's', 'e', 't', 'H', 'o', 's', 't', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 0,
    'm', 'a', 'x', 'S', 'i', 'z', 'e', 0,
    'a', 'd', 'd', 'r', 'e', 's', 's', 0,
    't', 'i', 'm', 'e', 'o', 'u', 't', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'P', 'a', 't', 'h', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    'v', 'e', 'r', 'i', 'f', 'y', 0,
    't', 'o', 'T', 'e', 'x', 't', 0,
    'd', 'i', 'g', 'e', 's', 't', 0,
    'O', 'p', 'a', 'q', 'u', 'e', 0,
    'c', 'l', 'o', 's', 'e', 'd', 0,
    'o', 'p', 'e', 'n', 'e', 'd', 0,
    'r', 'e', 'j', 'e', 'c', 't', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 0,
    'P', 'h', 'o', 'n', 'e', 't', 0,
    'C', 'a', 'n', 'B', 'u', 's', 0,
    'e', 'x', 'p', 'i', 'r', 'e', 0,
    'd', 'o', 'm', 'a', 'i', 'n', 0,
    'A', 'c', 't', 'i', 'v', 'e', 0,
    'l', 'i', 's', 't', 'e', 'n', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 0,
    'e', 'x', 'p', 'i', 'r', 'y', 0,
    'l', 'o', 'o', 'k', 'u', 'p', 0,
    'w', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'U', 'r', 'l', 0,
    'i', 's', 'O', 'p', 'e', 'n', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'i', 'g', 'n', 'o', 'r', 'e', 0,
    'a', 'c', 'c', 'e', 'p', 't', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'v', 'a', 'l', 'u', 'e', 's', 0,
    's', 'y', 'n', 't', 'a', 'x', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    'r', 'e', 's', 'u', 'm', 'e', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    't', 'o', 'D', 'e', 'r', 0,
    't', 'o', 'P', 'e', 'm', 0,
    'S', 's', 'l', 'V', '2', 0,
    's', 'e', 't', 'I', 'p', 0,
    'c', 'a', 'c', 'h', 'e', 0,
    'C', 'N', 'A', 'M', 'E', 0,
    'r', 'e', 'a', 'l', 'm', 0,
    'p', 'r', 'o', 'x', 'y', 0,
    'a', 'b', 'o', 'r', 't', 0,
    'q', 'u', 'e', 'r', 'y', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'r', 'e', 's', 'e', 't', 0,
    'a', 't', 'E', 'n', 'd', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'f', 'l', 'u', 's', 'h', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'm', 's', 'e', 'c', 's', 0,
    's', 't', 'a', 't', 'e', 0,
    'Q', 'S', 's', 'l', 0,
    'G', 'o', 'o', 'd', 0,
    'W', 'i', 'f', 'i', 0,
    'F', 'd', 'd', 'i', 0,
    'S', 'l', 'i', 'p', 0,
    'I', 's', 'U', 'p', 0,
    'F', 'u', 'l', 'l', 0,
    'p', 'o', 's', 't', 0,
    'h', 'e', 'a', 'd', 0,
    'A', 'A', 'A', 'A', 0,
    'u', 's', 'e', 'r', 0,
    'b', 'i', 'n', 'd', 0,
    'h', 'o', 's', 't', 0,
    'p', 'a', 't', 'h', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    's', 'e', 'e', 'k', 0,
    'o', 'p', 'e', 'n', 0,
    's', 'i', 'z', 'e', 0,
    't', 'y', 'p', 'e', 0,
    's', 'w', 'a', 'p', 0,
    'd', 'a', 't', 'a', 0,
    's', 't', 'o', 'p', 0,
    'o', 'i', 'd', 0,
    'D', 's', 'a', 0,
    'R', 's', 'a', 0,
    'P', 'p', 'p', 0,
    'p', 'u', 't', 0,
    'A', 'n', 'y', 0,
    'T', 'X', 'T', 0,
    'S', 'R', 'V', 0,
    'P', 'T', 'R', 0,
    'A', 'N', 'Y', 0,
    'u', 'r', 'l', 0,
    'p', 'o', 's', 0,
    'D', 'h', 0,
    'E', 'c', 0,
    'N', 'S', 0,
    'M', 'X', 0,
};
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostinfo.sip"
// Imports from QtCore.
pyqt5_qtnetwork_get_connection_parts_t pyqt5_qtnetwork_get_connection_parts;
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qocspresponse.sip"
#include <qocspresponse.h>
#line 1310 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

void sipVH_QtNetwork_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::qintptr a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::qintptr(a0), sipType_qintptr, SIP_NULLPTR);
}

 ::QTcpSocket* sipVH_QtNetwork_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QTcpSocket* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QTcpSocket, &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const QList< ::QSslError>& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new QList< ::QSslError>(a0), sipType_QList_0100QSslError, SIP_NULLPTR);
}

void sipVH_QtNetwork_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSslConfiguration& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QSslConfiguration(a0), sipType_QSslConfiguration, SIP_NULLPTR);
}

void sipVH_QtNetwork_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSslConfiguration& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", &a0, sipType_QSslConfiguration, SIP_NULLPTR);
}

QList< ::QNetworkProxy> sipVH_QtNetwork_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QNetworkProxyQuery& a0)
{
    QList< ::QNetworkProxy> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QNetworkProxyQuery(a0), sipType_QNetworkProxyQuery, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QNetworkProxy, &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QNetworkCookie& a0,const  ::QUrl& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QNetworkCookie(a0), sipType_QNetworkCookie, SIP_NULLPTR, new  ::QUrl(a1), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QNetworkCookie& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QNetworkCookie(a0), sipType_QNetworkCookie, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const QList< ::QNetworkCookie>& a0,const  ::QUrl& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new QList< ::QNetworkCookie>(a0), sipType_QList_0100QNetworkCookie, SIP_NULLPTR, new  ::QUrl(a1), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QList< ::QNetworkCookie> sipVH_QtNetwork_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QUrl& a0)
{
    QList< ::QNetworkCookie> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QNetworkCookie, &sipRes);

    return sipRes;
}

 ::QNetworkReply* sipVH_QtNetwork_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QNetworkAccessManager::Operation a0,const  ::QNetworkRequest& a1, ::QIODevice*a2)
{
     ::QNetworkReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FND", a0, sipType_QNetworkAccessManager_Operation, new  ::QNetworkRequest(a1), sipType_QNetworkRequest, SIP_NULLPTR, a2, sipType_QIODevice, SIP_NULLPTR);

    int sipRc = sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H1", sipType_QNetworkReply, &sipRes);

    if (sipRc < 0)
        abort();

    return sipRes;
}

void sipVH_QtNetwork_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::quintptr a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::quintptr(a0), sipType_quintptr, SIP_NULLPTR);
}

 ::QLocalSocket* sipVH_QtNetwork_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QLocalSocket* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QLocalSocket, &sipRes);

    return sipRes;
}

 ::QVariant sipVH_QtNetwork_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QAbstractSocket::SocketOption a0)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QAbstractSocket_SocketOption);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QAbstractSocket::SocketOption a0,const  ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QAbstractSocket_SocketOption, new  ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

 ::qintptr sipVH_QtNetwork_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::qintptr sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_qintptr, &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::qintptr a0, ::QAbstractSocket::SocketState a1, ::QIODevice::OpenMode a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFN", new  ::qintptr(a0), sipType_qintptr, SIP_NULLPTR, a1, sipType_QAbstractSocket_SocketState, new  ::QIODevice::OpenMode(a2), sipType_QIODevice_OpenMode, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::qint64 a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "n", a0);
}

void sipVH_QtNetwork_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QHostAddress& a0, ::quint16 a1, ::QIODevice::OpenMode a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NtN", new  ::QHostAddress(a0), sipType_QHostAddress, SIP_NULLPTR, a1, new  ::QIODevice::OpenMode(a2), sipType_QIODevice_OpenMode, SIP_NULLPTR);
}

void sipVH_QtNetwork_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0, ::quint16 a1, ::QIODevice::OpenMode a2, ::QAbstractSocket::NetworkLayerProtocol a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NtNF", new  ::QString(a0), sipType_QString, SIP_NULLPTR, a1, new  ::QIODevice::OpenMode(a2), sipType_QIODevice_OpenMode, SIP_NULLPTR, a3, sipType_QAbstractSocket_NetworkLayerProtocol);
}

bool sipVH_QtNetwork_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QIODevice::OpenMode a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QIODevice::OpenMode(a0), sipType_QIODevice_OpenMode, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::qint64 a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "n", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::qint64 sipVH_QtNetwork_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, char*a0, ::qint64 a1)
{
     ::qint64 sipRes = 0;
    int sipIsErr = 0;

#line 206 "sip/QtCore/qiodevice.sip"
        PyObject *result = sipCallMethod(&sipIsErr, sipMethod, "n", a1);
        
        if (result != NULL)
        {
            PyObject *buf;
        
            sipParseResult(&sipIsErr, sipMethod, result, "O", &buf);
        
            if (buf == Py_None)
                sipRes = -1L;
            else if (!SIPBytes_Check(buf))
            {
                sipBadCatcherResult(sipMethod);
                sipIsErr = 1;
            }
            else
            {
                memcpy(a0, SIPBytes_AsString(buf), SIPBytes_Size(buf));
                sipRes = SIPBytes_Size(buf);
            }
        
            Py_DECREF(buf);
            Py_DECREF(result);
        }
#line 1540 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

 ::qint64 sipVH_QtNetwork_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, char*a0, ::qint64 a1)
{
     ::qint64 sipRes = 0;
    int sipIsErr = 0;

#line 271 "sip/QtCore/qiodevice.sip"
        PyObject *result = sipCallMethod(&sipIsErr, sipMethod, "n", a1);
        
        if (result != NULL)
        {
            PyObject *buf;
        
            sipParseResult(&sipIsErr, sipMethod, result, "O", &buf);
        
            if (buf == Py_None)
                sipRes = -1L;
            else if (!SIPBytes_Check(buf))
            {
                sipBadCatcherResult(sipMethod);
                sipIsErr = 1;
            }
            else
            {
                memcpy(a0, SIPBytes_AsString(buf), SIPBytes_Size(buf));
                sipRes = SIPBytes_Size(buf);
            }
        
            Py_DECREF(buf);
            Py_DECREF(result);
        }
#line 1582 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

 ::qint64 sipVH_QtNetwork_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0,PY_LONG_LONG a1)
{
     ::qint64 sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "g", a0, (SIP_SSIZE_T)a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "n", &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

void sipVH_QtNetwork_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QIODevice*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QIODevice, SIP_NULLPTR);
}

 ::QIODevice* sipVH_QtNetwork_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QNetworkCacheMetaData& a0)
{
     ::QIODevice* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QNetworkCacheMetaData(a0), sipType_QNetworkCacheMetaData, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QIODevice, &sipRes);

    return sipRes;
}

 ::qint64 sipVH_QtNetwork_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::qint64 sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "n", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QUrl& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QIODevice* sipVH_QtNetwork_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QUrl& a0)
{
     ::QIODevice* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QIODevice, &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QNetworkCacheMetaData& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QNetworkCacheMetaData(a0), sipType_QNetworkCacheMetaData, SIP_NULLPTR);
}

 ::QNetworkCacheMetaData sipVH_QtNetwork_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QUrl& a0)
{
     ::QNetworkCacheMetaData sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QNetworkCacheMetaData, &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetwork_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtNetwork_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtNetwork_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtNetwork_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtNetwork_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


extern "C" {static PyObject *slot___rshift__(PyObject *,PyObject *);}
static PyObject *slot___rshift__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDataStream* a0;
         ::QNetworkCacheMetaData* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QNetworkCacheMetaData, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QHostAddress* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QHostAddress, &a1, &a1State))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(a1,sipType_QHostAddress,a1State);

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot___lshift__(PyObject *,PyObject *);}
static PyObject *slot___lshift__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDataStream* a0;
        const  ::QNetworkCacheMetaData* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QNetworkCacheMetaData, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QHostAddress* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J1", sipType_QDataStream, &a0, sipType_QHostAddress, &a1, &a1State))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QHostAddress *>(a1),sipType_QHostAddress,a1State);

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotExtenderDef slotExtenders[] = {
    {(void *)slot___rshift__, rshift_slot, {0, 0, 0}},
    {(void *)slot___lshift__, lshift_slot, {0, 0, 0}},
    {SIP_NULLPTR, (sipPySlotType)0, {0, 0, 0}}
};


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QAbstractSocket(void **);}
static const sipTypeDef *sipSubClass_QAbstractSocket(void **sipCppRet)
{
     ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qabstractsocket.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QNetworkReply, &sipType_QNetworkReply, -1, 1},
        {sipName_QHttpMultiPart, &sipType_QHttpMultiPart, -1, 2},
        {sipName_QAbstractNetworkCache, &sipType_QAbstractNetworkCache, 12, 3},
        {sipName_QNetworkConfigurationManager, &sipType_QNetworkConfigurationManager, -1, 4},
        {sipName_QNetworkCookieJar, &sipType_QNetworkCookieJar, -1, 5},
        {sipName_QAbstractSocket, &sipType_QAbstractSocket, 13, 6},
        {sipName_QLocalSocket, &sipType_QLocalSocket, -1, 7},
        {sipName_QDnsLookup, &sipType_QDnsLookup, -1, 8},
        {sipName_QNetworkSession, &sipType_QNetworkSession, -1, 9},
        {sipName_QTcpServer, &sipType_QTcpServer, -1, 10},
        {sipName_QNetworkAccessManager, &sipType_QNetworkAccessManager, -1, 11},
        {sipName_QLocalServer, &sipType_QLocalServer, -1, -1},
        {sipName_QNetworkDiskCache, &sipType_QNetworkDiskCache, -1, -1},
        {sipName_QUdpSocket, &sipType_QUdpSocket, -1, 14},
        {sipName_QTcpSocket, &sipType_QTcpSocket, 15, -1},
    #if defined(SIP_FEATURE_PyQt_SSL)
        {sipName_QSslSocket, &sipType_QSslSocket, -1, -1},
    #else
        {0, 0, -1, -1},
    #endif
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1866 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QSsl_SslOption___or__(PyObject *,PyObject *);}
static PyObject *slot_QSsl_SslOption___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSsl::SslOption a0;
         ::QSsl::SslOptions* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSsl_SslOption, &a0, sipType_QSsl_SslOptions, &a1, &a1State))
        {
             ::QSsl::SslOptions*sipRes;

            sipRes = new  ::QSsl::SslOptions((a0 | *a1));
            sipReleaseType(a1,sipType_QSsl_SslOptions,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSsl_SslOptions,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSsl_SslOption[] = {
    {(void *)slot_QSsl_SslOption___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QNetworkInterface_InterfaceFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QNetworkInterface_InterfaceFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkInterface::InterfaceFlag a0;
         ::QNetworkInterface::InterfaceFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QNetworkInterface_InterfaceFlag, &a0, sipType_QNetworkInterface_InterfaceFlags, &a1, &a1State))
        {
             ::QNetworkInterface::InterfaceFlags*sipRes;

            sipRes = new  ::QNetworkInterface::InterfaceFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QNetworkInterface_InterfaceFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QNetworkInterface_InterfaceFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QNetworkInterface_InterfaceFlag[] = {
    {(void *)slot_QNetworkInterface_InterfaceFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QNetworkConfigurationManager_Capability___or__(PyObject *,PyObject *);}
static PyObject *slot_QNetworkConfigurationManager_Capability___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QNetworkConfigurationManager::Capability a0;
         ::QNetworkConfigurationManager::Capabilities* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QNetworkConfigurationManager_Capability, &a0, sipType_QNetworkConfigurationManager_Capabilities, &a1, &a1State))
        {
             ::QNetworkConfigurationManager::Capabilities*sipRes;

            sipRes = new  ::QNetworkConfigurationManager::Capabilities((a0 | *a1));
            sipReleaseType(a1,sipType_QNetworkConfigurationManager_Capabilities,a1State);

            return sipConvertFromNewType(sipRes,sipType_QNetworkConfigurationManager_Capabilities,SIP_NULLPTR);
        }
    }

    {
         ::QNetworkConfigurationManager::Capability a0;
         ::QNetworkConfigurationManager::Capability a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EE", sipType_QNetworkConfigurationManager_Capability, &a0, sipType_QNetworkConfigurationManager_Capability, &a1))
        {
             ::QNetworkConfigurationManager::Capabilities*sipRes;

            sipRes = new  ::QNetworkConfigurationManager::Capabilities((a0 | a1));

            return sipConvertFromNewType(sipRes,sipType_QNetworkConfigurationManager_Capabilities,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QNetworkConfigurationManager_Capability[] = {
    {(void *)slot_QNetworkConfigurationManager_Capability___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QLocalServer_SocketOption___or__(PyObject *,PyObject *);}
static PyObject *slot_QLocalServer_SocketOption___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLocalServer::SocketOption a0;
         ::QLocalServer::SocketOptions* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QLocalServer_SocketOption, &a0, sipType_QLocalServer_SocketOptions, &a1, &a1State))
        {
             ::QLocalServer::SocketOptions*sipRes;

            sipRes = new  ::QLocalServer::SocketOptions((a0 | *a1));
            sipReleaseType(a1,sipType_QLocalServer_SocketOptions,a1State);

            return sipConvertFromNewType(sipRes,sipType_QLocalServer_SocketOptions,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QLocalServer_SocketOption[] = {
    {(void *)slot_QLocalServer_SocketOption___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QHstsPolicy_PolicyFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QHstsPolicy_PolicyFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QHstsPolicy::PolicyFlag a0;
         ::QHstsPolicy::PolicyFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QHstsPolicy_PolicyFlag, &a0, sipType_QHstsPolicy_PolicyFlags, &a1, &a1State))
        {
             ::QHstsPolicy::PolicyFlags*sipRes;

            sipRes = new  ::QHstsPolicy::PolicyFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QHstsPolicy_PolicyFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QHstsPolicy_PolicyFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QHstsPolicy_PolicyFlag[] = {
    {(void *)slot_QHstsPolicy_PolicyFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QHostAddress_ConversionModeFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QHostAddress_ConversionModeFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QHostAddress::ConversionModeFlag a0;
         ::QHostAddress::ConversionMode* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QHostAddress_ConversionModeFlag, &a0, sipType_QHostAddress_ConversionMode, &a1, &a1State))
        {
             ::QHostAddress::ConversionMode*sipRes;

            sipRes = new  ::QHostAddress::ConversionMode((a0 | *a1));
            sipReleaseType(a1,sipType_QHostAddress_ConversionMode,a1State);

            return sipConvertFromNewType(sipRes,sipType_QHostAddress_ConversionMode,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QHostAddress_ConversionModeFlag[] = {
    {(void *)slot_QHostAddress_ConversionModeFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QHostAddress_SpecialAddress___eq__(PyObject *,PyObject *);}
static PyObject *slot_QHostAddress_SpecialAddress___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QHostAddress::SpecialAddress sipCpp = static_cast< ::QHostAddress::SpecialAddress>(sipConvertToEnum(sipSelf, sipType_QHostAddress_SpecialAddress));

    if (PyErr_Occurred())
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QHostAddress, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator==(sipCpp, *a0);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QHostAddress_SpecialAddress___ne__(PyObject *,PyObject *);}
static PyObject *slot_QHostAddress_SpecialAddress___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QHostAddress::SpecialAddress sipCpp = static_cast< ::QHostAddress::SpecialAddress>(sipConvertToEnum(sipSelf, sipType_QHostAddress_SpecialAddress));

    if (PyErr_Occurred())
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QHostAddress* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QHostAddress, &a0, &a0State))
        {
            bool sipRes;

            sipRes = operator!=(sipCpp, *a0);
            sipReleaseType(const_cast< ::QHostAddress *>(a0),sipType_QHostAddress,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QHostAddress_SpecialAddress[] = {
    {(void *)slot_QHostAddress_SpecialAddress___eq__, eq_slot},
    {(void *)slot_QHostAddress_SpecialAddress___ne__, ne_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QAbstractSocket_PauseMode___or__(PyObject *,PyObject *);}
static PyObject *slot_QAbstractSocket_PauseMode___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket::PauseMode a0;
         ::QAbstractSocket::PauseModes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QAbstractSocket_PauseMode, &a0, sipType_QAbstractSocket_PauseModes, &a1, &a1State))
        {
             ::QAbstractSocket::PauseModes*sipRes;

            sipRes = new  ::QAbstractSocket::PauseModes((a0 | *a1));
            sipReleaseType(a1,sipType_QAbstractSocket_PauseModes,a1State);

            return sipConvertFromNewType(sipRes,sipType_QAbstractSocket_PauseModes,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QAbstractSocket_PauseMode[] = {
    {(void *)slot_QAbstractSocket_PauseMode___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QAbstractSocket_BindFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QAbstractSocket_BindFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAbstractSocket::BindFlag a0;
         ::QAbstractSocket::BindMode* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QAbstractSocket_BindFlag, &a0, sipType_QAbstractSocket_BindMode, &a1, &a1State))
        {
             ::QAbstractSocket::BindMode*sipRes;

            sipRes = new  ::QAbstractSocket::BindMode((a0 | *a1));
            sipReleaseType(a1,sipType_QAbstractSocket_BindMode,a1State);

            return sipConvertFromNewType(sipRes,sipType_QAbstractSocket_BindMode,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QAbstractSocket_BindFlag[] = {
    {(void *)slot_QAbstractSocket_BindFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslSocket__PeerVerifyMode, {0}, 0}, sipNameNr_PeerVerifyMode, 131, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslSocket__SslMode, {0}, 0}, sipNameNr_SslMode, 131, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslError__SslError, {0}, 0}, sipNameNr_SslError, 127, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslDiffieHellmanParameters__Error, {0}, 0}, sipNameNr_Error, 124, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslConfiguration__NextProtocolNegotiationStatus, {0}, 0}, sipNameNr_NextProtocolNegotiationStatus, 122, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QSslCertificate__PatternSyntax, {0}, 0}, sipNameNr_PatternSyntax, 117, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSslCertificate__SubjectInfo, {0}, 0}, sipNameNr_SubjectInfo, 117, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__SslOption, {0}, 0}, sipNameNr_SslOption, 109, slots_QSsl_SslOption},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__SslProtocol, {0}, 0}, sipNameNr_SslProtocol, 109, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__AlternativeNameEntryType, {0}, 0}, sipNameNr_AlternativeNameEntryType, 109, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__KeyAlgorithm, {0}, 0}, sipNameNr_KeyAlgorithm, 109, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__EncodingFormat, {0}, 0}, sipNameNr_EncodingFormat, 109, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSsl__KeyType, {0}, 0}, sipNameNr_KeyType, 109, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QOcspRevocationReason, {0}, 0}, sipNameNr_QOcspRevocationReason, -1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QOcspCertificateStatus, {0}, 0}, sipNameNr_QOcspCertificateStatus, -1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkSession__UsagePolicy, {0}, 0}, sipNameNr_UsagePolicy, 99, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkSession__SessionError, {0}, 0}, sipNameNr_SessionError, 99, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkSession__State, {0}, 0}, sipNameNr_State, 99, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__TransferTimeoutConstant, {0}, 0}, sipNameNr_TransferTimeoutConstant, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__RedirectPolicy, {0}, 0}, sipNameNr_RedirectPolicy, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__Priority, {0}, 0}, sipNameNr_Priority, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__LoadControl, {0}, 0}, sipNameNr_LoadControl, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__CacheLoadControl, {0}, 0}, sipNameNr_CacheLoadControl, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__Attribute, {0}, 0}, sipNameNr_Attribute, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkRequest__KnownHeaders, {0}, 0}, sipNameNr_KnownHeaders, 91, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkReply__NetworkError, {0}, 0}, sipNameNr_NetworkError, 89, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkProxyQuery__QueryType, {0}, 0}, sipNameNr_QueryType, 87, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkProxy__Capability, {0}, 0}, sipNameNr_Capability, 82, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkProxy__ProxyType, {0}, 0}, sipNameNr_ProxyType, 82, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkInterface__InterfaceType, {0}, 0}, sipNameNr_InterfaceType, 78, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkInterface__InterfaceFlag, {0}, 0}, sipNameNr_InterfaceFlag, 78, slots_QNetworkInterface_InterfaceFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkAddressEntry__DnsEligibilityStatus, {0}, 0}, sipNameNr_DnsEligibilityStatus, 61, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkCookie__RawForm, {0}, 0}, sipNameNr_RawForm, 73, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkConfiguration__BearerType, {0}, 0}, sipNameNr_BearerType, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkConfiguration__StateFlag, {0}, 0}, sipNameNr_StateFlag, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkConfiguration__Purpose, {0}, 0}, sipNameNr_Purpose, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkConfiguration__Type, {0}, 0}, sipNameNr_Type, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkConfigurationManager__Capability, {0}, 0}, sipNameNr_Capability, 70, slots_QNetworkConfigurationManager_Capability},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkAccessManager__NetworkAccessibility, {0}, 0}, sipNameNr_NetworkAccessibility, 58, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QNetworkAccessManager__Operation, {0}, 0}, sipNameNr_Operation, 58, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QLocalSocket__LocalSocketState, {0}, 0}, sipNameNr_LocalSocketState, 53, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QLocalSocket__LocalSocketError, {0}, 0}, sipNameNr_LocalSocketError, 53, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QLocalServer__SocketOption, {0}, 0}, sipNameNr_SocketOption, 50, slots_QLocalServer_SocketOption},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QHttpMultiPart__ContentType, {0}, 0}, sipNameNr_ContentType, 31, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QHstsPolicy__PolicyFlag, {0}, 0}, sipNameNr_PolicyFlag, 27, slots_QHstsPolicy_PolicyFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QHostInfo__HostInfoError, {0}, 0}, sipNameNr_HostInfoError, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QHostAddress__ConversionModeFlag, {0}, 0}, sipNameNr_ConversionModeFlag, 21, slots_QHostAddress_ConversionModeFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QHostAddress__SpecialAddress, {0}, 0}, sipNameNr_SpecialAddress, 21, slots_QHostAddress_SpecialAddress},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QDnsLookup__Type, {0}, 0}, sipNameNr_Type, 14, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QDnsLookup__Error, {0}, 0}, sipNameNr_Error, 14, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__PauseMode, {0}, 0}, sipNameNr_PauseMode, 1, slots_QAbstractSocket_PauseMode},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__BindFlag, {0}, 0}, sipNameNr_BindFlag, 1, slots_QAbstractSocket_BindFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__SocketOption, {0}, 0}, sipNameNr_SocketOption, 1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__SocketState, {0}, 0}, sipNameNr_SocketState, 1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__SocketError, {0}, 0}, sipNameNr_SocketError, 1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__NetworkLayerProtocol, {0}, 0}, sipNameNr_NetworkLayerProtocol, 1, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QAbstractSocket__SocketType, {0}, 0}, sipNameNr_SocketType, 1, SIP_NULLPTR},
};

/* These are the enum members of all global enums. */
static sipEnumMemberDef enummembers[] = {
    {sipName_AffiliationChanged, static_cast<int>(::QOcspRevocationReason::AffiliationChanged), 106},
    {sipName_CACompromise, static_cast<int>(::QOcspRevocationReason::CACompromise), 106},
    {sipName_CertificateHold, static_cast<int>(::QOcspRevocationReason::CertificateHold), 106},
    {sipName_CessationOfOperation, static_cast<int>(::QOcspRevocationReason::CessationOfOperation), 106},
    {sipName_Good, static_cast<int>(::QOcspCertificateStatus::Good), 104},
    {sipName_KeyCompromise, static_cast<int>(::QOcspRevocationReason::KeyCompromise), 106},
    {sipName_None, static_cast<int>(::QOcspRevocationReason::None), 106},
    {sipName_RemoveFromCRL, static_cast<int>(::QOcspRevocationReason::RemoveFromCRL), 106},
    {sipName_Revoked, static_cast<int>(::QOcspCertificateStatus::Revoked), 104},
    {sipName_Superseded, static_cast<int>(::QOcspRevocationReason::Superseded), 106},
    {sipName_Unknown, static_cast<int>(::QOcspCertificateStatus::Unknown), 104},
    {sipName_Unspecified, static_cast<int>(::QOcspRevocationReason::Unspecified), 106},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtNetwork[] = {
    &sipTypeDef_QtNetwork_QAbstractNetworkCache.ctd_base,
    &sipTypeDef_QtNetwork_QAbstractSocket.ctd_base,
    &enumTypes[51].etd_base,
    &sipTypeDef_QtNetwork_QAbstractSocket_BindMode.ctd_base,
    &enumTypes[55].etd_base,
    &enumTypes[50].etd_base,
    &sipTypeDef_QtNetwork_QAbstractSocket_PauseModes.ctd_base,
    &enumTypes[54].etd_base,
    &enumTypes[52].etd_base,
    &enumTypes[53].etd_base,
    &enumTypes[56].etd_base,
    &sipTypeDef_QtNetwork_QAuthenticator.ctd_base,
    &sipTypeDef_QtNetwork_QDnsDomainNameRecord.ctd_base,
    &sipTypeDef_QtNetwork_QDnsHostAddressRecord.ctd_base,
    &sipTypeDef_QtNetwork_QDnsLookup.ctd_base,
    &enumTypes[49].etd_base,
    &enumTypes[48].etd_base,
    &sipTypeDef_QtNetwork_QDnsMailExchangeRecord.ctd_base,
    &sipTypeDef_QtNetwork_QDnsServiceRecord.ctd_base,
    &sipTypeDef_QtNetwork_QDnsTextRecord.ctd_base,
    &sipTypeDef_QtNetwork_QHash_0100QNetworkRequest_Attribute_0100QVariant.mtd_base,
    &sipTypeDef_QtNetwork_QHostAddress.ctd_base,
    &sipTypeDef_QtNetwork_QHostAddress_ConversionMode.ctd_base,
    &enumTypes[46].etd_base,
    &enumTypes[47].etd_base,
    &sipTypeDef_QtNetwork_QHostInfo.ctd_base,
    &enumTypes[45].etd_base,
    &sipTypeDef_QtNetwork_QHstsPolicy.ctd_base,
    &enumTypes[44].etd_base,
    &sipTypeDef_QtNetwork_QHstsPolicy_PolicyFlags.ctd_base,
    &sipTypeDef_QtNetwork_QHttp2Configuration.ctd_base,
    &sipTypeDef_QtNetwork_QHttpMultiPart.ctd_base,
    &enumTypes[43].etd_base,
    &sipTypeDef_QtNetwork_QHttpPart.ctd_base,
    &sipTypeDef_QtNetwork_QList_0100QDnsDomainNameRecord.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QDnsHostAddressRecord.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QDnsMailExchangeRecord.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QDnsServiceRecord.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QDnsTextRecord.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QHostAddress.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QNetworkAddressEntry.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QNetworkConfiguration.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QNetworkCookie.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QNetworkInterface.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QNetworkProxy.mtd_base,
    &sipTypeDef_QtNetwork_QList_0600QPair_0100QByteArray_0100QByteArray.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QSslCertificate.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QSslCertificateExtension.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QSslCipher.mtd_base,
    &sipTypeDef_QtNetwork_QList_0100QSslError.mtd_base,
    &sipTypeDef_QtNetwork_QLocalServer.ctd_base,
    &enumTypes[42].etd_base,
    &sipTypeDef_QtNetwork_QLocalServer_SocketOptions.ctd_base,
    &sipTypeDef_QtNetwork_QLocalSocket.ctd_base,
    &enumTypes[41].etd_base,
    &enumTypes[40].etd_base,
    &sipTypeDef_QtNetwork_QMap_0100QByteArray_0100QVariant.mtd_base,
    &sipTypeDef_QtNetwork_QMultiMap_0100QSsl_AlternativeNameEntryType_0100QString.mtd_base,
    &sipTypeDef_QtNetwork_QNetworkAccessManager.ctd_base,
    &enumTypes[38].etd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_QtNetwork_QNetworkAddressEntry.ctd_base,
    &enumTypes[31].etd_base,
    &sipTypeDef_QtNetwork_QNetworkCacheMetaData.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkConfiguration.ctd_base,
    &enumTypes[33].etd_base,
    &enumTypes[35].etd_base,
    &enumTypes[34].etd_base,
    &sipTypeDef_QtNetwork_QNetworkConfiguration_StateFlags.ctd_base,
    &enumTypes[36].etd_base,
    &sipTypeDef_QtNetwork_QNetworkConfigurationManager.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkConfigurationManager_Capabilities.ctd_base,
    &enumTypes[37].etd_base,
    &sipTypeDef_QtNetwork_QNetworkCookie.ctd_base,
    &enumTypes[32].etd_base,
    &sipTypeDef_QtNetwork_QNetworkCookieJar.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkDatagram.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkDiskCache.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkInterface.ctd_base,
    &enumTypes[30].etd_base,
    &sipTypeDef_QtNetwork_QNetworkInterface_InterfaceFlags.ctd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_QtNetwork_QNetworkProxy.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkProxy_Capabilities.ctd_base,
    &enumTypes[27].etd_base,
    &enumTypes[28].etd_base,
    &sipTypeDef_QtNetwork_QNetworkProxyFactory.ctd_base,
    &sipTypeDef_QtNetwork_QNetworkProxyQuery.ctd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_QtNetwork_QNetworkReply.ctd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_QtNetwork_QNetworkRequest.ctd_base,
    &enumTypes[23].etd_base,
    &enumTypes[22].etd_base,
    &enumTypes[24].etd_base,
    &enumTypes[21].etd_base,
    &enumTypes[20].etd_base,
    &enumTypes[19].etd_base,
    &enumTypes[18].etd_base,
    &sipTypeDef_QtNetwork_QNetworkSession.ctd_base,
    &enumTypes[16].etd_base,
    &enumTypes[17].etd_base,
    &sipTypeDef_QtNetwork_QNetworkSession_UsagePolicies.ctd_base,
    &enumTypes[15].etd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtNetwork_QOcspResponse.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtNetwork_QPair_0100QHostAddress_1800.mtd_base,
    &sipTypeDef_QtNetwork_QPasswordDigestor.ctd_base,
    &sipTypeDef_QtNetwork_QSsl.ctd_base,
    &enumTypes[9].etd_base,
    &enumTypes[11].etd_base,
    &enumTypes[10].etd_base,
    &enumTypes[12].etd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtNetwork_QSsl_SslOptions.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtNetwork_QSslCertificate.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtNetwork_QSslCertificateExtension.ctd_base,
    &sipTypeDef_QtNetwork_QSslCipher.ctd_base,
    &sipTypeDef_QtNetwork_QSslConfiguration.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtNetwork_QSslDiffieHellmanParameters.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtNetwork_QSslEllipticCurve.ctd_base,
    &sipTypeDef_QtNetwork_QSslError.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtNetwork_QSslKey.ctd_base,
    &sipTypeDef_QtNetwork_QSslPreSharedKeyAuthenticator.ctd_base,
    &sipTypeDef_QtNetwork_QSslSocket.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtNetwork_QTcpServer.ctd_base,
    &sipTypeDef_QtNetwork_QTcpSocket.ctd_base,
    &sipTypeDef_QtNetwork_QUdpSocket.ctd_base,
    &sipTypeDef_QtNetwork_QVector_0100QHstsPolicy.mtd_base,
    &sipTypeDef_QtNetwork_QVector_0100QOcspResponse.mtd_base,
    &sipTypeDef_QtNetwork_QVector_0100QSslEllipticCurve.mtd_base,
    &sipTypeDef_QtNetwork_Q_IPV6ADDR.mtd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QNetworkCacheMetaData::AttributesMap", "QHash<QNetworkRequest::Attribute,QVariant>"},
    {"QNetworkCacheMetaData::RawHeaderList", "QList<QPair<QByteArray,QByteArray> >"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtNetwork_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QCryptographicHash::Algorithm"},
    {"QDataStream"},
    {"QDateTime"},
    {"QDeadlineTimer"},
    {"QEvent"},
    {"QHash<QString,QVariant>"},
    {"QIODevice"},
    {"QIODevice::OpenMode"},
    {"QList<QByteArray>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QRegExp::PatternSyntax"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QUrl::ComponentFormattingOptions"},
    {"QUrl::ParsingMode"},
    {"QVariant"},
    {"qintptr"},
    {"quintptr"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNetwork_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtNetwork_QtCore, sipImportedVirtErrorHandlers_QtNetwork_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QAbstractSocket, {12, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtNetwork = {
    0,
    SIP_API_MINOR_NR,
    sipNameNr_PyQt5_QtNetwork,
    0,
    sipStrings_QtNetwork,
    importsTable,
    SIP_NULLPTR,
    141,
    sipExportedTypes_QtNetwork,
    SIP_NULLPTR,
    12,
    enummembers,
    2,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    slotExtenders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtNetwork;

sip_qt_metaobject_func sip_QtNetwork_qt_metaobject;
sip_qt_metacall_func sip_QtNetwork_qt_metacall;
sip_qt_metacast_func sip_QtNetwork_qt_metacast;


/* The Python module initialisation function. */
#if PY_MAJOR_VERSION >= 3
#define SIP_MODULE_ENTRY        PyInit_QtNetwork
#define SIP_MODULE_TYPE         PyObject *
#define SIP_MODULE_DISCARD(r)   Py_DECREF(r)
#define SIP_MODULE_RETURN(r)    return (r)
#else
#define SIP_MODULE_ENTRY        initQtNetwork
#define SIP_MODULE_TYPE         void
#define SIP_MODULE_DISCARD(r)
#define SIP_MODULE_RETURN(r)    return
#endif

#if defined(SIP_STATIC_MODULE)
extern "C" SIP_MODULE_TYPE SIP_MODULE_ENTRY()
#else
PyMODINIT_FUNC SIP_MODULE_ENTRY()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };

#if PY_MAJOR_VERSION >= 3
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtNetwork",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };
#endif

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
#if PY_MAJOR_VERSION >= 3
    sipModule = PyModule_Create(&sip_module_def);
#elif PY_VERSION_HEX >= 0x02050000
    sipModule = Py_InitModule(sipName_PyQt5_QtNetwork, sip_methods);
#else
    sipModule = Py_InitModule(const_cast<char *>(sipName_PyQt5_QtNetwork), sip_methods);
#endif

    if (sipModule == SIP_NULLPTR)
        SIP_MODULE_RETURN(SIP_NULLPTR);

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
#if PY_VERSION_HEX >= 0x02050000
    sip_sipmod = PyImport_ImportModule("PyQt5.sip");
#else
    sip_sipmod = PyImport_ImportModule(const_cast<char *>("PyQt5.sip"));
#endif

    if (sip_sipmod == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

#if defined(SIP_USE_PYCAPSULE)
    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
#else
    if (sip_capiobj == SIP_NULLPTR || !PyCObject_Check(sip_capiobj))
#endif
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

#if defined(SIP_USE_PYCAPSULE)
    sipAPI_QtNetwork = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));
#else
    sipAPI_QtNetwork = reinterpret_cast<const sipAPIDef *>(PyCObject_AsVoidPtr(sip_capiobj));
#endif

#if defined(SIP_USE_PYCAPSULE)
    if (sipAPI_QtNetwork == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#endif

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtNetwork,SIP_API_MAJOR_NR,SIP_API_MINOR_NR,0) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_QtNetwork_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtNetwork_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtNetwork_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtNetwork_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtNetwork,sipModuleDict) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#line 86 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtNetwork/qhostinfo.sip"
// Imports from QtCore.
pyqt5_qtnetwork_get_connection_parts = (pyqt5_qtnetwork_get_connection_parts_t)sipImportSymbol("pyqt5_get_connection_parts");
Q_ASSERT(pyqt5_qtnetwork_get_connection_parts);
#line 2700 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtNetwork/sipQtNetworkcmodule.cpp"

    SIP_MODULE_RETURN(sipModule);
}
