/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWidgetsAPI_H
#define _QtWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_SH_ItemView_PaintAlternatingRowColorsForEmptyArea 0
#define sipName_SH_ItemView_PaintAlternatingRowColorsForEmptyArea &sipStrings_QtWidgets[0]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionVersion 50
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionVersion &sipStrings_QtWidgets[50]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionVersion 97
#define sipName_QStyleOptionGraphicsItem__StyleOptionVersion &sipStrings_QtWidgets[97]
#define sipNameNr_SH_ItemView_MovementWithoutUpdatingSelection 142
#define sipName_SH_ItemView_MovementWithoutUpdatingSelection &sipStrings_QtWidgets[142]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionVersion 187
#define sipName_QStyleHintReturnVariant__StyleOptionVersion &sipStrings_QtWidgets[187]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionVersion 231
#define sipName_QStyleOptionProgressBar__StyleOptionVersion &sipStrings_QtWidgets[231]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionType 275
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionType &sipStrings_QtWidgets[275]
#define sipNameNr_SH_TextControl_FocusIndicatorTextCharFormat 319
#define sipName_SH_TextControl_FocusIndicatorTextCharFormat &sipStrings_QtWidgets[319]
#define sipNameNr_SH_ScrollBar_ScrollWhenPointerLeavesControl 363
#define sipName_SH_ScrollBar_ScrollWhenPointerLeavesControl &sipStrings_QtWidgets[363]
#define sipNameNr_QStyleOptionToolButton__ToolButtonFeatures 407
#define sipName_QStyleOptionToolButton__ToolButtonFeatures &sipStrings_QtWidgets[407]
#define sipNameNr_QStyleOptionToolButton__StyleOptionVersion 450
#define sipName_QStyleOptionToolButton__StyleOptionVersion &sipStrings_QtWidgets[450]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionVersion 493
#define sipName_QStyleOptionRubberBand__StyleOptionVersion &sipStrings_QtWidgets[493]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionVersion 536
#define sipName_QStyleOptionDockWidget__StyleOptionVersion &sipStrings_QtWidgets[536]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionVersion 579
#define sipName_QStyleOptionTabBarBase__StyleOptionVersion &sipStrings_QtWidgets[579]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionType 622
#define sipName_QStyleOptionGraphicsItem__StyleOptionType &sipStrings_QtWidgets[622]
#define sipNameNr_QStyleOptionToolButton__ToolButtonFeature 664
#define sipName_QStyleOptionToolButton__ToolButtonFeature &sipStrings_QtWidgets[664]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionVersion 706
#define sipName_QStyleOptionFocusRect__StyleOptionVersion &sipStrings_QtWidgets[706]
#define sipNameNr_SH_ItemView_ArrowKeysNavigateIntoChildren 748
#define sipName_SH_ItemView_ArrowKeysNavigateIntoChildren &sipStrings_QtWidgets[748]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionType 790
#define sipName_QStyleHintReturnVariant__StyleOptionType &sipStrings_QtWidgets[790]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionVersion 831
#define sipName_QStyleOptionSizeGrip__StyleOptionVersion &sipStrings_QtWidgets[831]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionVersion 872
#define sipName_QStyleOptionGroupBox__StyleOptionVersion &sipStrings_QtWidgets[872]
#define sipNameNr_QStyleHintReturnMask__StyleOptionVersion 913
#define sipName_QStyleHintReturnMask__StyleOptionVersion &sipStrings_QtWidgets[913]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionVersion 954
#define sipName_QStyleOptionTitleBar__StyleOptionVersion &sipStrings_QtWidgets[954]
#define sipNameNr_QStyleOptionComboBox__StyleOptionVersion 995
#define sipName_QStyleOptionComboBox__StyleOptionVersion &sipStrings_QtWidgets[995]
#define sipNameNr_QStyleOptionViewItem__StyleOptionVersion 1036
#define sipName_QStyleOptionViewItem__StyleOptionVersion &sipStrings_QtWidgets[1036]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionVersion 1077
#define sipName_QStyleOptionMenuItem__StyleOptionVersion &sipStrings_QtWidgets[1077]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionType 1118
#define sipName_QStyleOptionProgressBar__StyleOptionType &sipStrings_QtWidgets[1118]
#define sipNameNr_SH_Menu_SubMenuResetWhenReenteringParent 1159
#define sipName_SH_Menu_SubMenuResetWhenReenteringParent &sipStrings_QtWidgets[1159]
#define sipNameNr_SH_ScrollBar_MiddleClickAbsolutePosition 1200
#define sipName_SH_ScrollBar_MiddleClickAbsolutePosition &sipStrings_QtWidgets[1200]
#define sipNameNr_QAbstractItemView__DropIndicatorPosition 1241
#define sipName_QAbstractItemView__DropIndicatorPosition &sipStrings_QtWidgets[1241]
#define sipNameNr_QStyleOptionToolBar__StyleOptionVersion 1282
#define sipName_QStyleOptionToolBar__StyleOptionVersion &sipStrings_QtWidgets[1282]
#define sipNameNr_QStyleOptionToolButton__StyleOptionType 1322
#define sipName_QStyleOptionToolButton__StyleOptionType &sipStrings_QtWidgets[1322]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionVersion 1362
#define sipName_QStyleOptionSpinBox__StyleOptionVersion &sipStrings_QtWidgets[1362]
#define sipNameNr_QStyleOptionComplex__StyleOptionVersion 1402
#define sipName_QStyleOptionComplex__StyleOptionVersion &sipStrings_QtWidgets[1402]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionType 1442
#define sipName_QStyleOptionRubberBand__StyleOptionType &sipStrings_QtWidgets[1442]
#define sipNameNr_QStyleOptionToolBox__StyleOptionVersion 1482
#define sipName_QStyleOptionToolBox__StyleOptionVersion &sipStrings_QtWidgets[1482]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionType 1522
#define sipName_QStyleOptionDockWidget__StyleOptionType &sipStrings_QtWidgets[1522]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionType 1562
#define sipName_QStyleOptionTabBarBase__StyleOptionType &sipStrings_QtWidgets[1562]
#define sipNameNr_SH_Menu_SubMenuSloppySelectOtherActions 1602
#define sipName_SH_Menu_SubMenuSloppySelectOtherActions &sipStrings_QtWidgets[1602]
#define sipNameNr_SH_MessageBox_UseBorderForButtonSpacing 1642
#define sipName_SH_MessageBox_UseBorderForButtonSpacing &sipStrings_QtWidgets[1642]
#define sipNameNr_QCalendarWidget__HorizontalHeaderFormat 1682
#define sipName_QCalendarWidget__HorizontalHeaderFormat &sipStrings_QtWidgets[1682]
#define sipNameNr_QTreeWidgetItemIterator__IteratorFlags 1722
#define sipName_QTreeWidgetItemIterator__IteratorFlags &sipStrings_QtWidgets[1722]
#define sipNameNr_QStyleOptionSlider__StyleOptionVersion 1761
#define sipName_QStyleOptionSlider__StyleOptionVersion &sipStrings_QtWidgets[1761]
#define sipNameNr_QStyleOptionViewItem__ViewItemPosition 1800
#define sipName_QStyleOptionViewItem__ViewItemPosition &sipStrings_QtWidgets[1800]
#define sipNameNr_QStyleOptionViewItem__ViewItemFeatures 1839
#define sipName_QStyleOptionViewItem__ViewItemFeatures &sipStrings_QtWidgets[1839]
#define sipNameNr_QStyleOptionButton__StyleOptionVersion 1878
#define sipName_QStyleOptionButton__StyleOptionVersion &sipStrings_QtWidgets[1878]
#define sipNameNr_QStyleOptionHeader__StyleOptionVersion 1917
#define sipName_QStyleOptionHeader__StyleOptionVersion &sipStrings_QtWidgets[1917]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionType 1956
#define sipName_QStyleOptionFocusRect__StyleOptionType &sipStrings_QtWidgets[1956]
#define sipNameNr_SH_ScrollBar_LeftClickAbsolutePosition 1995
#define sipName_SH_ScrollBar_LeftClickAbsolutePosition &sipStrings_QtWidgets[1995]
#define sipNameNr_SH_GroupBox_TextLabelVerticalAlignment 2034
#define sipName_SH_GroupBox_TextLabelVerticalAlignment &sipStrings_QtWidgets[2034]
#define sipNameNr_QGraphicsSceneContextMenuEvent__Reason 2073
#define sipName_QGraphicsSceneContextMenuEvent__Reason &sipStrings_QtWidgets[2073]
#define sipNameNr_QTreeWidgetItemIterator__IteratorFlag 2112
#define sipName_QTreeWidgetItemIterator__IteratorFlag &sipStrings_QtWidgets[2112]
#define sipNameNr_QTreeWidgetItem__ChildIndicatorPolicy 2150
#define sipName_QTreeWidgetItem__ChildIndicatorPolicy &sipStrings_QtWidgets[2150]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionType 2188
#define sipName_QStyleOptionSizeGrip__StyleOptionType &sipStrings_QtWidgets[2188]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionType 2226
#define sipName_QStyleOptionGroupBox__StyleOptionType &sipStrings_QtWidgets[2226]
#define sipNameNr_QStyleHintReturnMask__StyleOptionType 2264
#define sipName_QStyleHintReturnMask__StyleOptionType &sipStrings_QtWidgets[2264]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionType 2302
#define sipName_QStyleOptionTitleBar__StyleOptionType &sipStrings_QtWidgets[2302]
#define sipNameNr_QStyleOptionComboBox__StyleOptionType 2340
#define sipName_QStyleOptionComboBox__StyleOptionType &sipStrings_QtWidgets[2340]
#define sipNameNr_QStyleOptionToolBox__SelectedPosition 2378
#define sipName_QStyleOptionToolBox__SelectedPosition &sipStrings_QtWidgets[2378]
#define sipNameNr_QStyleOptionViewItem__ViewItemFeature 2416
#define sipName_QStyleOptionViewItem__ViewItemFeature &sipStrings_QtWidgets[2416]
#define sipNameNr_QStyleOptionViewItem__StyleOptionType 2454
#define sipName_QStyleOptionViewItem__StyleOptionType &sipStrings_QtWidgets[2454]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionType 2492
#define sipName_QStyleOptionMenuItem__StyleOptionType &sipStrings_QtWidgets[2492]
#define sipNameNr_QStyleOptionTabV4__StyleOptionVersion 2530
#define sipName_QStyleOptionTabV4__StyleOptionVersion &sipStrings_QtWidgets[2530]
#define sipNameNr_QStyleOptionFrame__StyleOptionVersion 2568
#define sipName_QStyleOptionFrame__StyleOptionVersion &sipStrings_QtWidgets[2568]
#define sipNameNr_SH_Menu_SubMenuDontStartSloppyOnLeave 2606
#define sipName_SH_Menu_SubMenuDontStartSloppyOnLeave &sipStrings_QtWidgets[2606]
#define sipNameNr_SH_ItemView_ActivateItemOnSingleClick 2644
#define sipName_SH_ItemView_ActivateItemOnSingleClick &sipStrings_QtWidgets[2644]
#define sipNameNr_SH_ScrollView_FrameOnlyAroundContents 2682
#define sipName_SH_ScrollView_FrameOnlyAroundContents &sipStrings_QtWidgets[2682]
#define sipNameNr_PM_HeaderDefaultSectionSizeHorizontal 2720
#define sipName_PM_HeaderDefaultSectionSizeHorizontal &sipStrings_QtWidgets[2720]
#define sipNameNr_AdjustToMinimumContentsLengthWithIcon 2758
#define sipName_AdjustToMinimumContentsLengthWithIcon &sipStrings_QtWidgets[2758]
#define sipNameNr_QCalendarWidget__VerticalHeaderFormat 2796
#define sipName_QCalendarWidget__VerticalHeaderFormat &sipStrings_QtWidgets[2796]
#define sipNameNr_QAbstractScrollArea__SizeAdjustPolicy 2834
#define sipName_QAbstractScrollArea__SizeAdjustPolicy &sipStrings_QtWidgets[2834]
#define sipNameNr_QStyleOptionToolBar__ToolBarFeatures 2872
#define sipName_QStyleOptionToolBar__ToolBarFeatures &sipStrings_QtWidgets[2872]
#define sipNameNr_QStyleOptionToolBar__ToolBarPosition 2909
#define sipName_QStyleOptionToolBar__ToolBarPosition &sipStrings_QtWidgets[2909]
#define sipNameNr_QStyleOptionToolBar__StyleOptionType 2946
#define sipName_QStyleOptionToolBar__StyleOptionType &sipStrings_QtWidgets[2946]
#define sipNameNr_QStyleHintReturn__StyleOptionVersion 2983
#define sipName_QStyleHintReturn__StyleOptionVersion &sipStrings_QtWidgets[2983]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionType 3020
#define sipName_QStyleOptionSpinBox__StyleOptionType &sipStrings_QtWidgets[3020]
#define sipNameNr_QStyleOptionComplex__StyleOptionType 3057
#define sipName_QStyleOptionComplex__StyleOptionType &sipStrings_QtWidgets[3057]
#define sipNameNr_QStyleOptionToolBox__StyleOptionType 3094
#define sipName_QStyleOptionToolBox__StyleOptionType &sipStrings_QtWidgets[3094]
#define sipNameNr_QStyleOptionHeader__SelectedPosition 3131
#define sipName_QStyleOptionHeader__SelectedPosition &sipStrings_QtWidgets[3131]
#define sipNameNr_SH_Menu_SubMenuUniDirectionFailCount 3168
#define sipName_SH_Menu_SubMenuUniDirectionFailCount &sipStrings_QtWidgets[3168]
#define sipNameNr_SH_ProgressDialog_TextLabelAlignment 3205
#define sipName_SH_ProgressDialog_TextLabelAlignment &sipStrings_QtWidgets[3205]
#define sipNameNr_SH_ProgressDialog_CenterCancelButton 3242
#define sipName_SH_ProgressDialog_CenterCancelButton &sipStrings_QtWidgets[3242]
#define sipNameNr_QScrollerProperties__OvershootPolicy 3279
#define sipName_QScrollerProperties__OvershootPolicy &sipStrings_QtWidgets[3279]
#define sipNameNr_ItemDoesntPropagateOpacityToChildren 3316
#define sipName_ItemDoesntPropagateOpacityToChildren &sipStrings_QtWidgets[3316]
#define sipNameNr_QAbstractItemView__SelectionBehavior 3353
#define sipName_QAbstractItemView__SelectionBehavior &sipStrings_QtWidgets[3353]
#define sipNameNr_QStyleOptionToolBar__ToolBarFeature 3390
#define sipName_QStyleOptionToolBar__ToolBarFeature &sipStrings_QtWidgets[3390]
#define sipNameNr_QStyleOptionSlider__StyleOptionType 3426
#define sipName_QStyleOptionSlider__StyleOptionType &sipStrings_QtWidgets[3426]
#define sipNameNr_QStyleOptionTab__StyleOptionVersion 3462
#define sipName_QStyleOptionTab__StyleOptionVersion &sipStrings_QtWidgets[3462]
#define sipNameNr_QStyleOptionButton__StyleOptionType 3498
#define sipName_QStyleOptionButton__StyleOptionType &sipStrings_QtWidgets[3498]
#define sipNameNr_QStyleOptionHeader__SectionPosition 3534
#define sipName_QStyleOptionHeader__SectionPosition &sipStrings_QtWidgets[3534]
#define sipNameNr_QStyleOptionHeader__StyleOptionType 3570
#define sipName_QStyleOptionHeader__StyleOptionType &sipStrings_QtWidgets[3570]
#define sipNameNr_SP_ToolBarHorizontalExtensionButton 3606
#define sipName_SP_ToolBarHorizontalExtensionButton &sipStrings_QtWidgets[3606]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatThreshold 3642
#define sipName_SH_SpinBox_ClickAutoRepeatThreshold &sipStrings_QtWidgets[3642]
#define sipNameNr_SH_DialogButtonBox_ButtonsHaveIcons 3678
#define sipName_SH_DialogButtonBox_ButtonsHaveIcons &sipStrings_QtWidgets[3678]
#define sipNameNr_PM_HeaderDefaultSectionSizeVertical 3714
#define sipName_PM_HeaderDefaultSectionSizeVertical &sipStrings_QtWidgets[3714]
#define sipNameNr_QStyleOptionMenuItem__MenuItemType 3750
#define sipName_QStyleOptionMenuItem__MenuItemType &sipStrings_QtWidgets[3750]
#define sipNameNr_QStyleOptionButton__ButtonFeatures 3785
#define sipName_QStyleOptionButton__ButtonFeatures &sipStrings_QtWidgets[3785]
#define sipNameNr_QStyleOptionFrame__StyleOptionType 3820
#define sipName_QStyleOptionFrame__StyleOptionType &sipStrings_QtWidgets[3820]
#define sipNameNr_RSIP_OnMouseClickAndAlreadyFocused 3855
#define sipName_RSIP_OnMouseClickAndAlreadyFocused &sipStrings_QtWidgets[3855]
#define sipNameNr_SH_MessageBox_TextInteractionFlags 3890
#define sipName_SH_MessageBox_TextInteractionFlags &sipStrings_QtWidgets[3890]
#define sipNameNr_SH_ItemView_ShowDecorationSelected 3925
#define sipName_SH_ItemView_ShowDecorationSelected &sipStrings_QtWidgets[3925]
#define sipNameNr_SH_ItemView_ChangeHighlightOnFocus 3960
#define sipName_SH_ItemView_ChangeHighlightOnFocus &sipStrings_QtWidgets[3960]
#define sipNameNr_SH_FontDialog_SelectAssociatedText 3995
#define sipName_SH_FontDialog_SelectAssociatedText &sipStrings_QtWidgets[3995]
#define sipNameNr_PE_IndicatorDockWidgetResizeHandle 4030
#define sipName_PE_IndicatorDockWidgetResizeHandle &sipStrings_QtWidgets[4030]
#define sipNameNr_ItemTransformOriginPointHasChanged 4065
#define sipName_ItemTransformOriginPointHasChanged &sipStrings_QtWidgets[4065]
#define sipNameNr_QAbstractItemDelegate__EndEditHint 4100
#define sipName_QAbstractItemDelegate__EndEditHint &sipStrings_QtWidgets[4100]
#define sipNameNr_4135 4135
#define sipName_4135 &sipStrings_QtWidgets[4135]
#define sipNameNr_QSystemTrayIcon__ActivationReason 4169
#define sipName_QSystemTrayIcon__ActivationReason &sipStrings_QtWidgets[4169]
#define sipNameNr_QStyleHintReturn__StyleOptionType 4203
#define sipName_QStyleHintReturn__StyleOptionType &sipStrings_QtWidgets[4203]
#define sipNameNr_QStyleOptionTab__SelectedPosition 4237
#define sipName_QStyleOptionTab__SelectedPosition &sipStrings_QtWidgets[4237]
#define sipNameNr_QStyleOptionButton__ButtonFeature 4271
#define sipName_QStyleOptionButton__ButtonFeature &sipStrings_QtWidgets[4271]
#define sipNameNr_QStyleOptionHeader__SortIndicator 4305
#define sipName_QStyleOptionHeader__SortIndicator &sipStrings_QtWidgets[4305]
#define sipNameNr_QStyle__RequestSoftwareInputPanel 4339
#define sipName_QStyle__RequestSoftwareInputPanel &sipStrings_QtWidgets[4339]
#define sipNameNr_SP_ToolBarVerticalExtensionButton 4373
#define sipName_SP_ToolBarVerticalExtensionButton &sipStrings_QtWidgets[4373]
#define sipNameNr_SH_TitleBar_ShowToolTipsOnButtons 4407
#define sipName_SH_TitleBar_ShowToolTipsOnButtons &sipStrings_QtWidgets[4407]
#define sipNameNr_SH_Menu_SubMenuSloppyCloseTimeout 4441
#define sipName_SH_Menu_SubMenuSloppyCloseTimeout &sipStrings_QtWidgets[4441]
#define sipNameNr_SH_ListViewExpand_SelectMouseType 4475
#define sipName_SH_ListViewExpand_SelectMouseType &sipStrings_QtWidgets[4475]
#define sipNameNr_SH_SpinBox_KeyPressAutoRepeatRate 4509
#define sipName_SH_SpinBox_KeyPressAutoRepeatRate &sipStrings_QtWidgets[4509]
#define sipNameNr_PM_DockWidgetTitleBarButtonMargin 4543
#define sipName_PM_DockWidgetTitleBarButtonMargin &sipStrings_QtWidgets[4543]
#define sipNameNr_QScrollerProperties__ScrollMetric 4577
#define sipName_QScrollerProperties__ScrollMetric &sipStrings_QtWidgets[4577]
#define sipNameNr_DontMaximizeSubWindowOnActivation 4611
#define sipName_DontMaximizeSubWindowOnActivation &sipStrings_QtWidgets[4611]
#define sipNameNr_QGraphicsView__ViewportUpdateMode 4645
#define sipName_QGraphicsView__ViewportUpdateMode &sipStrings_QtWidgets[4645]
#define sipNameNr_QGraphicsItem__GraphicsItemChange 4679
#define sipName_QGraphicsItem__GraphicsItemChange &sipStrings_QtWidgets[4679]
#define sipNameNr_QDialogButtonBox__StandardButtons 4713
#define sipName_QDialogButtonBox__StandardButtons &sipStrings_QtWidgets[4713]
#define sipNameNr_QAbstractSpinBox__StepEnabledFlag 4747
#define sipName_QAbstractSpinBox__StepEnabledFlag &sipStrings_QtWidgets[4747]
#define sipNameNr_4781 4781
#define sipName_4781 &sipStrings_QtWidgets[4781]
#define sipNameNr_QToolButton__ToolButtonPopupMode 4814
#define sipName_QToolButton__ToolButtonPopupMode &sipStrings_QtWidgets[4814]
#define sipNameNr_QStyleHintReturn__HintReturnType 4847
#define sipName_QStyleHintReturn__HintReturnType &sipStrings_QtWidgets[4847]
#define sipNameNr_QStyleOptionToolBox__TabPosition 4880
#define sipName_QStyleOptionToolBox__TabPosition &sipStrings_QtWidgets[4880]
#define sipNameNr_QStyleOptionTab__StyleOptionType 4913
#define sipName_QStyleOptionTab__StyleOptionType &sipStrings_QtWidgets[4913]
#define sipNameNr_QStyleOptionFrame__FrameFeatures 4946
#define sipName_QStyleOptionFrame__FrameFeatures &sipStrings_QtWidgets[4946]
#define sipNameNr_QStyleOption__StyleOptionVersion 4979
#define sipName_QStyleOption__StyleOptionVersion &sipStrings_QtWidgets[4979]
#define sipNameNr_SH_ToolBox_SelectedPageTitleBold 5012
#define sipName_SH_ToolBox_SelectedPageTitleBold &sipStrings_QtWidgets[5012]
#define sipNameNr_SH_ScrollBar_StopMouseOverSlider 5045
#define sipName_SH_ScrollBar_StopMouseOverSlider &sipStrings_QtWidgets[5045]
#define sipNameNr_SH_Workspace_FillSpaceOnMaximize 5078
#define sipName_SH_Workspace_FillSpaceOnMaximize &sipStrings_QtWidgets[5078]
#define sipNameNr_SH_PrintDialog_RightAlignButtons 5111
#define sipName_SH_PrintDialog_RightAlignButtons &sipStrings_QtWidgets[5111]
#define sipNameNr_QInputDialog__InputDialogOptions 5144
#define sipName_QInputDialog__InputDialogOptions &sipStrings_QtWidgets[5144]
#define sipNameNr_QGraphicsView__OptimizationFlags 5177
#define sipName_QGraphicsView__OptimizationFlags &sipStrings_QtWidgets[5177]
#define sipNameNr_QGraphicsItem__GraphicsItemFlags 5210
#define sipName_QGraphicsItem__GraphicsItemFlags &sipStrings_QtWidgets[5210]
#define sipNameNr_QDialogButtonBox__StandardButton 5243
#define sipName_QDialogButtonBox__StandardButton &sipStrings_QtWidgets[5243]
#define sipNameNr_QColorDialog__ColorDialogOptions 5276
#define sipName_QColorDialog__ColorDialogOptions &sipStrings_QtWidgets[5276]
#define sipNameNr_QAbstractSpinBox__CorrectionMode 5309
#define sipName_QAbstractSpinBox__CorrectionMode &sipStrings_QtWidgets[5309]
#define sipNameNr_QAbstractItemView__SelectionMode 5342
#define sipName_QAbstractItemView__SelectionMode &sipStrings_QtWidgets[5342]
#define sipNameNr_QStyleOptionMenuItem__CheckType 5375
#define sipName_QStyleOptionMenuItem__CheckType &sipStrings_QtWidgets[5375]
#define sipNameNr_QStyleOptionFrame__FrameFeature 5407
#define sipName_QStyleOptionFrame__FrameFeature &sipStrings_QtWidgets[5407]
#define sipNameNr_SH_ComboBox_AllowWheelScrolling 5439
#define sipName_SH_ComboBox_AllowWheelScrolling &sipStrings_QtWidgets[5439]
#define sipNameNr_SH_TabWidget_DefaultTabPosition 5471
#define sipName_SH_TabWidget_DefaultTabPosition &sipStrings_QtWidgets[5471]
#define sipNameNr_SH_ScrollBar_RollBetweenButtons 5503
#define sipName_SH_ScrollBar_RollBetweenButtons &sipStrings_QtWidgets[5503]
#define sipNameNr_SH_SpinControls_DisableOnBounds 5535
#define sipName_SH_SpinControls_DisableOnBounds &sipStrings_QtWidgets[5535]
#define sipNameNr_SH_MainWindow_SpaceBelowMenuBar 5567
#define sipName_SH_MainWindow_SpaceBelowMenuBar &sipStrings_QtWidgets[5567]
#define sipNameNr_QScrollerProperties__FrameRates 5599
#define sipName_QScrollerProperties__FrameRates &sipStrings_QtWidgets[5599]
#define sipNameNr_QMdiSubWindow__SubWindowOptions 5631
#define sipName_QMdiSubWindow__SubWindowOptions &sipStrings_QtWidgets[5631]
#define sipNameNr_QInputDialog__InputDialogOption 5663
#define sipName_QInputDialog__InputDialogOption &sipStrings_QtWidgets[5663]
#define sipNameNr_QGraphicsView__OptimizationFlag 5695
#define sipName_QGraphicsView__OptimizationFlag &sipStrings_QtWidgets[5695]
#define sipNameNr_QGraphicsScene__ItemIndexMethod 5727
#define sipName_QGraphicsScene__ItemIndexMethod &sipStrings_QtWidgets[5727]
#define sipNameNr_ItemNegativeZStacksBehindParent 5759
#define sipName_ItemNegativeZStacksBehindParent &sipStrings_QtWidgets[5759]
#define sipNameNr_QGraphicsItem__GraphicsItemFlag 5791
#define sipName_QGraphicsItem__GraphicsItemFlag &sipStrings_QtWidgets[5791]
#define sipNameNr_QDockWidget__DockWidgetFeatures 5823
#define sipName_QDockWidget__DockWidgetFeatures &sipStrings_QtWidgets[5823]
#define sipNameNr_QDataWidgetMapper__SubmitPolicy 5855
#define sipName_QDataWidgetMapper__SubmitPolicy &sipStrings_QtWidgets[5855]
#define sipNameNr_QColorDialog__ColorDialogOption 5887
#define sipName_QColorDialog__ColorDialogOption &sipStrings_QtWidgets[5887]
#define sipNameNr_setShortcutVisibleInContextMenu 5919
#define sipName_setShortcutVisibleInContextMenu &sipStrings_QtWidgets[5919]
#define sipNameNr_QAbstractSpinBox__ButtonSymbols 5951
#define sipName_QAbstractSpinBox__ButtonSymbols &sipStrings_QtWidgets[5951]
#define sipNameNr_QAbstractItemView__CursorAction 5983
#define sipName_QAbstractItemView__CursorAction &sipStrings_QtWidgets[5983]
#define sipNameNr_horizontalScrollbarValueChanged 6015
#define sipName_horizontalScrollbarValueChanged &sipStrings_QtWidgets[6015]
#define sipNameNr_QAbstractItemView__EditTriggers 6047
#define sipName_QAbstractItemView__EditTriggers &sipStrings_QtWidgets[6047]
#define sipNameNr_QAbstractItemView__DragDropMode 6079
#define sipName_QAbstractItemView__DragDropMode &sipStrings_QtWidgets[6079]
#define sipNameNr_DontShowIndicatorWhenChildless 6111
#define sipName_DontShowIndicatorWhenChildless &sipStrings_QtWidgets[6111]
#define sipNameNr_QStyleOptionViewItem__Position 6142
#define sipName_QStyleOptionViewItem__Position &sipStrings_QtWidgets[6142]
#define sipNameNr_QStyleOptionTab__CornerWidgets 6173
#define sipName_QStyleOptionTab__CornerWidgets &sipStrings_QtWidgets[6173]
#define sipNameNr_SH_DockWidget_ButtonsHaveFrame 6204
#define sipName_SH_DockWidget_ButtonsHaveFrame &sipStrings_QtWidgets[6204]
#define sipNameNr_SH_FormLayoutFieldGrowthPolicy 6235
#define sipName_SH_FormLayoutFieldGrowthPolicy &sipStrings_QtWidgets[6235]
#define sipNameNr_SH_TitleBar_ModifyNotification 6266
#define sipName_SH_TitleBar_ModifyNotification &sipStrings_QtWidgets[6266]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatRate 6297
#define sipName_SH_SpinBox_ClickAutoRepeatRate &sipStrings_QtWidgets[6297]
#define sipNameNr_SH_DialogButtons_DefaultButton 6328
#define sipName_SH_DialogButtons_DefaultButton &sipStrings_QtWidgets[6328]
#define sipNameNr_SH_RichText_FullWidthSelection 6359
#define sipName_SH_RichText_FullWidthSelection &sipStrings_QtWidgets[6359]
#define sipNameNr_SH_BlinkCursorWhenTextSelected 6390
#define sipName_SH_BlinkCursorWhenTextSelected &sipStrings_QtWidgets[6390]
#define sipNameNr_SH_Menu_AllowActiveAndDisabled 6421
#define sipName_SH_Menu_AllowActiveAndDisabled &sipStrings_QtWidgets[6421]
#define sipNameNr_PM_ScrollView_ScrollBarOverlap 6452
#define sipName_PM_ScrollView_ScrollBarOverlap &sipStrings_QtWidgets[6452]
#define sipNameNr_PM_ScrollView_ScrollBarSpacing 6483
#define sipName_PM_ScrollView_ScrollBarSpacing &sipStrings_QtWidgets[6483]
#define sipNameNr_AcceleratingFlickSpeedupFactor 6514
#define sipName_AcceleratingFlickSpeedupFactor &sipStrings_QtWidgets[6514]
#define sipNameNr_unsetDefaultScrollerProperties 6545
#define sipName_unsetDefaultScrollerProperties &sipStrings_QtWidgets[6545]
#define sipNameNr_QScroller__ScrollerGestureType 6576
#define sipName_QScroller__ScrollerGestureType &sipStrings_QtWidgets[6576]
#define sipNameNr_QMdiSubWindow__SubWindowOption 6607
#define sipName_QMdiSubWindow__SubWindowOption &sipStrings_QtWidgets[6607]
#define sipNameNr_setUnifiedTitleAndToolBarOnMac 6638
#define sipName_setUnifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[6638]
#define sipNameNr_QGraphicsSceneContextMenuEvent 6669
#define sipName_QGraphicsSceneContextMenuEvent &sipStrings_QtWidgets[6669]
#define sipNameNr_QGraphicsPixmapItem__ShapeMode 6700
#define sipName_QGraphicsPixmapItem__ShapeMode &sipStrings_QtWidgets[6700]
#define sipNameNr_ItemTransformOriginPointChange 6731
#define sipName_ItemTransformOriginPointChange &sipStrings_QtWidgets[6731]
#define sipNameNr_QGraphicsBlurEffect__BlurHints 6762
#define sipName_QGraphicsBlurEffect__BlurHints &sipStrings_QtWidgets[6762]
#define sipNameNr_QGraphicsEffect__PixmapPadMode 6793
#define sipName_QGraphicsEffect__PixmapPadMode &sipStrings_QtWidgets[6793]
#define sipNameNr_QGestureRecognizer__ResultFlag 6824
#define sipName_QGestureRecognizer__ResultFlag &sipStrings_QtWidgets[6824]
#define sipNameNr_QFormLayout__FieldGrowthPolicy 6855
#define sipName_QFormLayout__FieldGrowthPolicy &sipStrings_QtWidgets[6855]
#define sipNameNr_QFontDialog__FontDialogOptions 6886
#define sipName_QFontDialog__FontDialogOptions &sipStrings_QtWidgets[6886]
#define sipNameNr_QDockWidget__DockWidgetFeature 6917
#define sipName_QDockWidget__DockWidgetFeature &sipStrings_QtWidgets[6917]
#define sipNameNr_QDialogButtonBox__ButtonLayout 6948
#define sipName_QDialogButtonBox__ButtonLayout &sipStrings_QtWidgets[6948]
#define sipNameNr_QCalendarWidget__SelectionMode 6979
#define sipName_QCalendarWidget__SelectionMode &sipStrings_QtWidgets[6979]
#define sipNameNr_isShortcutVisibleInContextMenu 7010
#define sipName_isShortcutVisibleInContextMenu &sipStrings_QtWidgets[7010]
#define sipNameNr_QAbstractItemView__EditTrigger 7041
#define sipName_QAbstractItemView__EditTrigger &sipStrings_QtWidgets[7041]
#define sipNameNr_QTextEdit__AutoFormattingFlag 7072
#define sipName_QTextEdit__AutoFormattingFlag &sipStrings_QtWidgets[7072]
#define sipNameNr_QStyleOptionTab__CornerWidget 7102
#define sipName_QStyleOptionTab__CornerWidget &sipStrings_QtWidgets[7102]
#define sipNameNr_QStyleOption__StyleOptionType 7132
#define sipName_QStyleOption__StyleOptionType &sipStrings_QtWidgets[7132]
#define sipNameNr_SH_SpinBox_ButtonsInsideFrame 7162
#define sipName_SH_SpinBox_ButtonsInsideFrame &sipStrings_QtWidgets[7162]
#define sipNameNr_SH_LineEdit_PasswordMaskDelay 7192
#define sipName_SH_LineEdit_PasswordMaskDelay &sipStrings_QtWidgets[7192]
#define sipNameNr_SH_TabBar_CloseButtonPosition 7222
#define sipName_SH_TabBar_CloseButtonPosition &sipStrings_QtWidgets[7222]
#define sipNameNr_SH_ItemView_DrawDelegateFrame 7252
#define sipName_SH_ItemView_DrawDelegateFrame &sipStrings_QtWidgets[7252]
#define sipNameNr_SH_Slider_StopMouseOverSlider 7282
#define sipName_SH_Slider_StopMouseOverSlider &sipStrings_QtWidgets[7282]
#define sipNameNr_SH_LineEdit_PasswordCharacter 7312
#define sipName_SH_LineEdit_PasswordCharacter &sipStrings_QtWidgets[7312]
#define sipNameNr_SH_ComboBox_ListMouseTracking 7342
#define sipName_SH_ComboBox_ListMouseTracking &sipStrings_QtWidgets[7342]
#define sipNameNr_PM_TabBar_ScrollButtonOverlap 7372
#define sipName_PM_TabBar_ScrollButtonOverlap &sipStrings_QtWidgets[7372]
#define sipNameNr_PM_MdiSubWindowMinimizedWidth 7402
#define sipName_PM_MdiSubWindowMinimizedWidth &sipStrings_QtWidgets[7402]
#define sipNameNr_SE_ItemViewItemCheckIndicator 7432
#define sipName_SE_ItemViewItemCheckIndicator &sipStrings_QtWidgets[7432]
#define sipNameNr_PE_IndicatorItemViewItemCheck 7462
#define sipName_PE_IndicatorItemViewItemCheck &sipStrings_QtWidgets[7462]
#define sipNameNr_OvershootScrollDistanceFactor 7492
#define sipName_OvershootScrollDistanceFactor &sipStrings_QtWidgets[7492]
#define sipNameNr_OvershootDragResistanceFactor 7522
#define sipName_OvershootDragResistanceFactor &sipStrings_QtWidgets[7522]
#define sipNameNr_QOpenGLWidget__UpdateBehavior 7552
#define sipName_QOpenGLWidget__UpdateBehavior &sipStrings_QtWidgets[7552]
#define sipNameNr_QGraphicsView__ViewportAnchor 7582
#define sipName_QGraphicsView__ViewportAnchor &sipStrings_QtWidgets[7582]
#define sipNameNr_ItemSendsScenePositionChanges 7612
#define sipName_ItemSendsScenePositionChanges &sipStrings_QtWidgets[7612]
#define sipNameNr_QGraphicsBlurEffect__BlurHint 7642
#define sipName_QGraphicsBlurEffect__BlurHint &sipStrings_QtWidgets[7642]
#define sipNameNr_QSwipeGesture__SwipeDirection 7672
#define sipName_QSwipeGesture__SwipeDirection &sipStrings_QtWidgets[7672]
#define sipNameNr_QGesture__GestureCancelPolicy 7702
#define sipName_QGesture__GestureCancelPolicy &sipStrings_QtWidgets[7702]
#define sipNameNr_QFontDialog__FontDialogOption 7732
#define sipName_QFontDialog__FontDialogOption &sipStrings_QtWidgets[7732]
#define sipNameNr_AdjustToMinimumContentsLength 7762
#define sipName_AdjustToMinimumContentsLength &sipStrings_QtWidgets[7762]
#define sipNameNr_QActionGroup__ExclusionPolicy 7792
#define sipName_QActionGroup__ExclusionPolicy &sipStrings_QtWidgets[7792]
#define sipNameNr_QAbstractSpinBox__StepEnabled 7822
#define sipName_QAbstractSpinBox__StepEnabled &sipStrings_QtWidgets[7822]
#define sipNameNr_QAbstractSlider__SliderChange 7852
#define sipName_QAbstractSlider__SliderChange &sipStrings_QtWidgets[7852]
#define sipNameNr_QAbstractSlider__SliderAction 7882
#define sipName_QAbstractSlider__SliderAction &sipStrings_QtWidgets[7882]
#define sipNameNr_verticalScrollbarValueChanged 7912
#define sipName_verticalScrollbarValueChanged &sipStrings_QtWidgets[7912]
#define sipNameNr_QAbstractItemView__ScrollMode 7942
#define sipName_QAbstractItemView__ScrollMode &sipStrings_QtWidgets[7942]
#define sipNameNr_QAbstractItemView__ScrollHint 7972
#define sipName_QAbstractItemView__ScrollHint &sipStrings_QtWidgets[7972]
#define sipNameNr_8002 8002
#define sipName_8002 &sipStrings_QtWidgets[8002]
#define sipNameNr_HaveFinishButtonOnEarlyPages 8031
#define sipName_HaveFinishButtonOnEarlyPages &sipStrings_QtWidgets[8031]
#define sipNameNr_DisabledBackButtonOnLastPage 8060
#define sipName_DisabledBackButtonOnLastPage &sipStrings_QtWidgets[8060]
#define sipNameNr_setSelectionBehaviorOnRemove 8089
#define sipName_setSelectionBehaviorOnRemove &sipStrings_QtWidgets[8089]
#define sipNameNr_QSystemTrayIcon__MessageIcon 8118
#define sipName_QSystemTrayIcon__MessageIcon &sipStrings_QtWidgets[8118]
#define sipNameNr_QStyleOptionTab__TabFeatures 8147
#define sipName_QStyleOptionTab__TabFeatures &sipStrings_QtWidgets[8147]
#define sipNameNr_QStyleOptionTab__TabPosition 8176
#define sipName_QStyleOptionTab__TabPosition &sipStrings_QtWidgets[8176]
#define sipNameNr_SP_TitleBarContextHelpButton 8205
#define sipName_SP_TitleBarContextHelpButton &sipStrings_QtWidgets[8205]
#define sipNameNr_SH_Widget_Animation_Duration 8234
#define sipName_SH_Widget_Animation_Duration &sipStrings_QtWidgets[8234]
#define sipNameNr_SH_TabBar_ChangeCurrentDelay 8263
#define sipName_SH_TabBar_ChangeCurrentDelay &sipStrings_QtWidgets[8263]
#define sipNameNr_SH_RequestSoftwareInputPanel 8292
#define sipName_SH_RequestSoftwareInputPanel &sipStrings_QtWidgets[8292]
#define sipNameNr_SH_Slider_AbsoluteSetButtons 8321
#define sipName_SH_Slider_AbsoluteSetButtons &sipStrings_QtWidgets[8321]
#define sipNameNr_SH_ItemView_EllipsisLocation 8350
#define sipName_SH_ItemView_EllipsisLocation &sipStrings_QtWidgets[8350]
#define sipNameNr_SH_Menu_FillScreenWithScroll 8379
#define sipName_SH_Menu_FillScreenWithScroll &sipStrings_QtWidgets[8379]
#define sipNameNr_PM_DialogButtonsButtonHeight 8408
#define sipName_PM_DialogButtonsButtonHeight &sipStrings_QtWidgets[8408]
#define sipNameNr_PM_DockWidgetSeparatorExtent 8437
#define sipName_PM_DockWidgetSeparatorExtent &sipStrings_QtWidgets[8437]
#define sipNameNr_SC_TitleBarContextHelpButton 8466
#define sipName_SC_TitleBarContextHelpButton &sipStrings_QtWidgets[8466]
#define sipNameNr_SE_DialogButtonBoxLayoutItem 8495
#define sipName_SE_DialogButtonBoxLayoutItem &sipStrings_QtWidgets[8495]
#define sipNameNr_PE_IndicatorItemViewItemDrop 8524
#define sipName_PE_IndicatorItemViewItemDrop &sipStrings_QtWidgets[8524]
#define sipNameNr_PE_IndicatorToolBarSeparator 8553
#define sipName_PE_IndicatorToolBarSeparator &sipStrings_QtWidgets[8553]
#define sipNameNr_QStackedLayout__StackingMode 8582
#define sipName_QStackedLayout__StackingMode &sipStrings_QtWidgets[8582]
#define sipNameNr_AcceleratingFlickMaximumTime 8611
#define sipName_AcceleratingFlickMaximumTime &sipStrings_QtWidgets[8611]
#define sipNameNr_setDefaultScrollerProperties 6547
#define sipName_setDefaultScrollerProperties &sipStrings_QtWidgets[6547]
#define sipNameNr_QPlainTextEdit__LineWrapMode 8640
#define sipName_QPlainTextEdit__LineWrapMode &sipStrings_QtWidgets[8640]
#define sipNameNr_QMessageBox__StandardButtons 8669
#define sipName_QMessageBox__StandardButtons &sipStrings_QtWidgets[8669]
#define sipNameNr_UsePlainTextEditForTextInput 8698
#define sipName_UsePlainTextEditForTextInput &sipStrings_QtWidgets[8698]
#define sipNameNr_QGraphicsView__CacheModeFlag 8727
#define sipName_QGraphicsView__CacheModeFlag &sipStrings_QtWidgets[8727]
#define sipNameNr_QGraphicsItem__PanelModality 8756
#define sipName_QGraphicsItem__PanelModality &sipStrings_QtWidgets[8756]
#define sipNameNr_setBoundingRegionGranularity 8785
#define sipName_setBoundingRegionGranularity &sipStrings_QtWidgets[8785]
#define sipNameNr_QGraphicsEffect__ChangeFlags 8814
#define sipName_QGraphicsEffect__ChangeFlags &sipStrings_QtWidgets[8814]
#define sipNameNr_QDialogButtonBox__ButtonRole 8843
#define sipName_QDialogButtonBox__ButtonRole &sipStrings_QtWidgets[8843]
#define sipNameNr_CaseInsensitivelySortedModel 8872
#define sipName_CaseInsensitivelySortedModel &sipStrings_QtWidgets[8872]
#define sipNameNr_setHorizontalScrollBarPolicy 8901
#define sipName_setHorizontalScrollBarPolicy &sipStrings_QtWidgets[8901]
#define sipNameNr_8930 8930
#define sipName_8930 &sipStrings_QtWidgets[8930]
#define sipNameNr_QStyleOptionTab__TabFeature 8958
#define sipName_QStyleOptionTab__TabFeature &sipStrings_QtWidgets[8958]
#define sipNameNr_SH_Menu_SubMenuUniDirection 8986
#define sipName_SH_Menu_SubMenuUniDirection &sipStrings_QtWidgets[8986]
#define sipNameNr_SH_FormLayoutLabelAlignment 9014
#define sipName_SH_FormLayoutLabelAlignment &sipStrings_QtWidgets[9014]
#define sipNameNr_SH_MessageBox_CenterButtons 9042
#define sipName_SH_MessageBox_CenterButtons &sipStrings_QtWidgets[9042]
#define sipNameNr_SH_SpellCheckUnderlineStyle 9070
#define sipName_SH_SpellCheckUnderlineStyle &sipStrings_QtWidgets[9070]
#define sipNameNr_SH_ComboBox_PopupFrameStyle 9098
#define sipName_SH_ComboBox_PopupFrameStyle &sipStrings_QtWidgets[9098]
#define sipNameNr_SH_ComboBox_LayoutDirection 9126
#define sipName_SH_ComboBox_LayoutDirection &sipStrings_QtWidgets[9126]
#define sipNameNr_SH_MenuBar_AltKeyNavigation 9154
#define sipName_SH_MenuBar_AltKeyNavigation &sipStrings_QtWidgets[9154]
#define sipNameNr_PM_TabBarTabShiftHorizontal 9182
#define sipName_PM_TabBarTabShiftHorizontal &sipStrings_QtWidgets[9182]
#define sipNameNr_PM_DialogButtonsButtonWidth 9210
#define sipName_PM_DialogButtonsButtonWidth &sipStrings_QtWidgets[9210]
#define sipNameNr_PM_ExclusiveIndicatorHeight 9238
#define sipName_PM_ExclusiveIndicatorHeight &sipStrings_QtWidgets[9238]
#define sipNameNr_SE_TabBarTearIndicatorRight 9266
#define sipName_SE_TabBarTearIndicatorRight &sipStrings_QtWidgets[9266]
#define sipNameNr_PE_IndicatorColumnViewArrow 9294
#define sipName_PE_IndicatorColumnViewArrow &sipStrings_QtWidgets[9294]
#define sipNameNr_OvershootDragDistanceFactor 9322
#define sipName_OvershootDragDistanceFactor &sipStrings_QtWidgets[9322]
#define sipNameNr_MaximumClickThroughVelocity 9350
#define sipName_MaximumClickThroughVelocity &sipStrings_QtWidgets[9350]
#define sipNameNr_DragVelocitySmoothingFactor 9378
#define sipName_DragVelocitySmoothingFactor &sipStrings_QtWidgets[9378]
#define sipNameNr_createMimeDataFromSelection 9406
#define sipName_createMimeDataFromSelection &sipStrings_QtWidgets[9406]
#define sipNameNr_QMessageBox__StandardButton 9434
#define sipName_QMessageBox__StandardButton &sipStrings_QtWidgets[9434]
#define sipNameNr_unifiedTitleAndToolBarOnMac 9462
#define sipName_unifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[9462]
#define sipNameNr_tabifiedDockWidgetActivated 9490
#define sipName_tabifiedDockWidgetActivated &sipStrings_QtWidgets[9490]
#define sipNameNr_UseListViewForComboBoxItems 9518
#define sipName_UseListViewForComboBoxItems &sipStrings_QtWidgets[9518]
#define sipNameNr_QGraphicsSceneDragDropEvent 9546
#define sipName_QGraphicsSceneDragDropEvent &sipStrings_QtWidgets[9546]
#define sipNameNr_QGraphicsScene__SceneLayers 9574
#define sipName_QGraphicsScene__SceneLayers &sipStrings_QtWidgets[9574]
#define sipNameNr_ItemContainsChildrenInShape 9602
#define sipName_ItemContainsChildrenInShape &sipStrings_QtWidgets[9602]
#define sipNameNr_ItemUsesExtendedStyleOption 9630
#define sipName_ItemUsesExtendedStyleOption &sipStrings_QtWidgets[9630]
#define sipNameNr_ItemScenePositionHasChanged 9658
#define sipName_ItemScenePositionHasChanged &sipStrings_QtWidgets[9658]
#define sipNameNr_QGraphicsEffect__ChangeFlag 9686
#define sipName_QGraphicsEffect__ChangeFlag &sipStrings_QtWidgets[9686]
#define sipNameNr_QFileIconProvider__IconType 9714
#define sipName_QFileIconProvider__IconType &sipStrings_QtWidgets[9714]
#define sipNameNr_DontUseCustomDirectoryIcons 9742
#define sipName_DontUseCustomDirectoryIcons &sipStrings_QtWidgets[9742]
#define sipNameNr_QComboBox__SizeAdjustPolicy 9770
#define sipName_QComboBox__SizeAdjustPolicy &sipStrings_QtWidgets[9770]
#define sipNameNr_AdjustToContentsOnFirstShow 9798
#define sipName_AdjustToContentsOnFirstShow &sipStrings_QtWidgets[9798]
#define sipNameNr_9826 9826
#define sipName_9826 &sipStrings_QtWidgets[9826]
#define sipNameNr_customContextMenuRequested 9853
#define sipName_customContextMenuRequested &sipStrings_QtWidgets[9853]
#define sipNameNr_QTableWidgetItem__ItemType 9880
#define sipName_QTableWidgetItem__ItemType &sipStrings_QtWidgets[9880]
#define sipNameNr_QTableWidgetSelectionRange 9907
#define sipName_QTableWidgetSelectionRange &sipStrings_QtWidgets[9907]
#define sipNameNr_QTabBar__SelectionBehavior 9934
#define sipName_QTabBar__SelectionBehavior &sipStrings_QtWidgets[9934]
#define sipNameNr_levelOfDetailFromTransform 9961
#define sipName_levelOfDetailFromTransform &sipStrings_QtWidgets[9961]
#define sipNameNr_NextAndPreviousAreSelected 9988
#define sipName_NextAndPreviousAreSelected &sipStrings_QtWidgets[9988]
#define sipNameNr_QStyleOptionTabWidgetFrame 10015
#define sipName_QStyleOptionTabWidgetFrame &sipStrings_QtWidgets[10015]
#define sipNameNr_SH_ToolTip_FallAsleepDelay 10042
#define sipName_SH_ToolTip_FallAsleepDelay &sipStrings_QtWidgets[10042]
#define sipNameNr_SH_FormLayoutFormAlignment 10069
#define sipName_SH_FormLayoutFormAlignment &sipStrings_QtWidgets[10069]
#define sipNameNr_SH_Menu_FlashTriggeredItem 10096
#define sipName_SH_Menu_FlashTriggeredItem &sipStrings_QtWidgets[10096]
#define sipNameNr_SH_GroupBox_TextLabelColor 10123
#define sipName_SH_GroupBox_TextLabelColor &sipStrings_QtWidgets[10123]
#define sipNameNr_SH_Menu_SpaceActivatesItem 10150
#define sipName_SH_Menu_SpaceActivatesItem &sipStrings_QtWidgets[10150]
#define sipNameNr_PM_TabCloseIndicatorHeight 10177
#define sipName_PM_TabCloseIndicatorHeight &sipStrings_QtWidgets[10177]
#define sipNameNr_PM_LayoutHorizontalSpacing 10204
#define sipName_PM_LayoutHorizontalSpacing &sipStrings_QtWidgets[10204]
#define sipNameNr_PM_RadioButtonLabelSpacing 10231
#define sipName_PM_RadioButtonLabelSpacing &sipStrings_QtWidgets[10231]
#define sipNameNr_PM_TabBarScrollButtonWidth 10258
#define sipName_PM_TabBarScrollButtonWidth &sipStrings_QtWidgets[10258]
#define sipNameNr_PM_ExclusiveIndicatorWidth 10285
#define sipName_PM_ExclusiveIndicatorWidth &sipStrings_QtWidgets[10285]
#define sipNameNr_SE_TabBarScrollRightButton 10312
#define sipName_SE_TabBarScrollRightButton &sipStrings_QtWidgets[10312]
#define sipNameNr_SE_TabBarTearIndicatorLeft 10339
#define sipName_SE_TabBarTearIndicatorLeft &sipStrings_QtWidgets[10339]
#define sipNameNr_PE_IndicatorButtonDropDown 10366
#define sipName_PE_IndicatorButtonDropDown &sipStrings_QtWidgets[10366]
#define sipNameNr_setResizeContentsPrecision 10393
#define sipName_setResizeContentsPrecision &sipStrings_QtWidgets[10393]
#define sipNameNr_setCascadingSectionResizes 10420
#define sipName_setCascadingSectionResizes &sipStrings_QtWidgets[10420]
#define sipNameNr_sectionHandleDoubleClicked 10447
#define sipName_sectionHandleDoubleClicked &sipStrings_QtWidgets[10447]
#define sipNameNr_setOffsetToSectionPosition 10474
#define sipName_setOffsetToSectionPosition &sipStrings_QtWidgets[10474]
#define sipNameNr_setRubberBandSelectionMode 10501
#define sipName_setRubberBandSelectionMode &sipStrings_QtWidgets[10501]
#define sipNameNr_BoundingRectViewportUpdate 10528
#define sipName_BoundingRectViewportUpdate &sipStrings_QtWidgets[10528]
#define sipNameNr_QGraphicsScene__SceneLayer 10555
#define sipName_QGraphicsScene__SceneLayer &sipStrings_QtWidgets[10555]
#define sipNameNr_QAbstractGraphicsShapeItem 10582
#define sipName_QAbstractGraphicsShapeItem &sipStrings_QtWidgets[10582]
#define sipNameNr_ItemIgnoresTransformations 10609
#define sipName_ItemIgnoresTransformations &sipStrings_QtWidgets[10609]
#define sipNameNr_PadToEffectiveBoundingRect 10636
#define sipName_PadToEffectiveBoundingRect &sipStrings_QtWidgets[10636]
#define sipNameNr_QGestureRecognizer__Result 10663
#define sipName_QGestureRecognizer__Result &sipStrings_QtWidgets[10663]
#define sipNameNr_QPinchGesture__ChangeFlags 10690
#define sipName_QPinchGesture__ChangeFlags &sipStrings_QtWidgets[10690]
#define sipNameNr_QFormLayout__TakeRowResult 10717
#define sipName_QFormLayout__TakeRowResult &sipStrings_QtWidgets[10717]
#define sipNameNr_QFormLayout__RowWrapPolicy 10744
#define sipName_QFormLayout__RowWrapPolicy &sipStrings_QtWidgets[10744]
#define sipNameNr_QFontComboBox__FontFilters 10771
#define sipName_QFontComboBox__FontFilters &sipStrings_QtWidgets[10771]
#define sipNameNr_QFileIconProvider__Options 10798
#define sipName_QFileIconProvider__Options &sipStrings_QtWidgets[10798]
#define sipNameNr_DockWidgetVerticalTitleBar 10825
#define sipName_DockWidgetVerticalTitleBar &sipStrings_QtWidgets[10825]
#define sipNameNr_CaseSensitivelySortedModel 10852
#define sipName_CaseSensitivelySortedModel &sipStrings_QtWidgets[10852]
#define sipNameNr_QCompleter__CompletionMode 10879
#define sipName_QCompleter__CompletionMode &sipStrings_QtWidgets[10879]
#define sipNameNr_QAbstractSpinBox__StepType 10906
#define sipName_QAbstractSpinBox__StepType &sipStrings_QtWidgets[10906]
#define sipNameNr_setVerticalScrollBarPolicy 10933
#define sipName_setVerticalScrollBarPolicy &sipStrings_QtWidgets[10933]
#define sipNameNr_scheduleDelayedItemsLayout 10960
#define sipName_scheduleDelayedItemsLayout &sipStrings_QtWidgets[10960]
#define sipNameNr_setFirstItemColumnSpanned 10987
#define sipName_setFirstItemColumnSpanned &sipStrings_QtWidgets[10987]
#define sipNameNr_QTreeWidgetItem__ItemType 11013
#define sipName_QTreeWidgetItem__ItemType &sipStrings_QtWidgets[11013]
#define sipNameNr_QTextEdit__AutoFormatting 11039
#define sipName_QTextEdit__AutoFormatting &sipStrings_QtWidgets[11039]
#define sipNameNr_QTextEdit__ExtraSelection 11065
#define sipName_QTextEdit__ExtraSelection &sipStrings_QtWidgets[11065]
#define sipNameNr_selectionBehaviorOnRemove 11091
#define sipName_selectionBehaviorOnRemove &sipStrings_QtWidgets[11091]
#define sipNameNr_SP_FileDialogContentsView 11117
#define sipName_SP_FileDialogContentsView &sipStrings_QtWidgets[11117]
#define sipNameNr_SP_FileDialogDetailedView 11143
#define sipName_SP_FileDialogDetailedView &sipStrings_QtWidgets[11143]
#define sipNameNr_SH_FocusFrame_AboveWidget 11169
#define sipName_SH_FocusFrame_AboveWidget &sipStrings_QtWidgets[11169]
#define sipNameNr_SH_Widget_ShareActivation 11195
#define sipName_SH_Widget_ShareActivation &sipStrings_QtWidgets[11195]
#define sipNameNr_SH_Menu_SubMenuPopupDelay 11221
#define sipName_SH_Menu_SubMenuPopupDelay &sipStrings_QtWidgets[11221]
#define sipNameNr_SH_Slider_SloppyKeyEvents 11247
#define sipName_SH_Slider_SloppyKeyEvents &sipStrings_QtWidgets[11247]
#define sipNameNr_SH_TabBar_SelectMouseType 11273
#define sipName_SH_TabBar_SelectMouseType &sipStrings_QtWidgets[11273]
#define sipNameNr_PM_TitleBarButtonIconSize 11299
#define sipName_PM_TitleBarButtonIconSize &sipStrings_QtWidgets[11299]
#define sipNameNr_PM_TabCloseIndicatorWidth 11325
#define sipName_PM_TabCloseIndicatorWidth &sipStrings_QtWidgets[11325]
#define sipNameNr_PM_ToolTipLabelFrameWidth 11351
#define sipName_PM_ToolTipLabelFrameWidth &sipStrings_QtWidgets[11351]
#define sipNameNr_PM_ToolBarExtensionExtent 11377
#define sipName_PM_ToolBarExtensionExtent &sipStrings_QtWidgets[11377]
#define sipNameNr_PM_ToolBarSeparatorExtent 11403
#define sipName_PM_ToolBarSeparatorExtent &sipStrings_QtWidgets[11403]
#define sipNameNr_PM_TabBarTabShiftVertical 11429
#define sipName_PM_TabBarTabShiftVertical &sipStrings_QtWidgets[11429]
#define sipNameNr_PM_MdiSubWindowFrameWidth 11455
#define sipName_PM_MdiSubWindowFrameWidth &sipStrings_QtWidgets[11455]
#define sipNameNr_PM_DialogButtonsSeparator 11481
#define sipName_PM_DialogButtonsSeparator &sipStrings_QtWidgets[11481]
#define sipNameNr_PM_DockWidgetHandleExtent 11507
#define sipName_PM_DockWidgetHandleExtent &sipStrings_QtWidgets[11507]
#define sipNameNr_PM_SliderControlThickness 11533
#define sipName_PM_SliderControlThickness &sipStrings_QtWidgets[11533]
#define sipNameNr_PM_ButtonDefaultIndicator 11559
#define sipName_PM_ButtonDefaultIndicator &sipStrings_QtWidgets[11559]
#define sipNameNr_SE_TabBarScrollLeftButton 11585
#define sipName_SE_TabBarScrollLeftButton &sipStrings_QtWidgets[11585]
#define sipNameNr_SE_ItemViewItemDecoration 11611
#define sipName_SE_ItemViewItemDecoration &sipStrings_QtWidgets[11611]
#define sipNameNr_SE_DateTimeEditLayoutItem 11637
#define sipName_SE_DateTimeEditLayoutItem &sipStrings_QtWidgets[11637]
#define sipNameNr_SE_DockWidgetTitleBarText 11663
#define sipName_SE_DockWidgetTitleBarText &sipStrings_QtWidgets[11663]
#define sipNameNr_SE_TreeViewDisclosureItem 11689
#define sipName_SE_TreeViewDisclosureItem &sipStrings_QtWidgets[11689]
#define sipNameNr_SE_ViewItemCheckIndicator 11715
#define sipName_SE_ViewItemCheckIndicator &sipStrings_QtWidgets[11715]
#define sipNameNr_PE_IndicatorToolBarHandle 11741
#define sipName_PE_IndicatorToolBarHandle &sipStrings_QtWidgets[11741]
#define sipNameNr_PE_IndicatorProgressChunk 11767
#define sipName_PE_IndicatorProgressChunk &sipStrings_QtWidgets[11767]
#define sipNameNr_PE_IndicatorMenuCheckMark 11793
#define sipName_PE_IndicatorMenuCheckMark &sipStrings_QtWidgets[11793]
#define sipNameNr_PE_IndicatorViewItemCheck 11819
#define sipName_PE_IndicatorViewItemCheck &sipStrings_QtWidgets[11819]
#define sipNameNr_State_KeyboardFocusChange 11845
#define sipName_State_KeyboardFocusChange &sipStrings_QtWidgets[11845]
#define sipNameNr_QSizePolicy__ControlTypes 11871
#define sipName_QSizePolicy__ControlTypes &sipStrings_QtWidgets[11871]
#define sipNameNr_HorizontalOvershootPolicy 11897
#define sipName_HorizontalOvershootPolicy &sipStrings_QtWidgets[11897]
#define sipNameNr_scrollerPropertiesChanged 11923
#define sipName_scrollerPropertiesChanged &sipStrings_QtWidgets[11923]
#define sipNameNr_activatePreviousSubWindow 11949
#define sipName_activatePreviousSubWindow &sipStrings_QtWidgets[11949]
#define sipNameNr_QListWidgetItem__ItemType 11975
#define sipName_QListWidgetItem__ItemType &sipStrings_QtWidgets[11975]
#define sipNameNr_QLineEdit__ActionPosition 12001
#define sipName_QLineEdit__ActionPosition &sipStrings_QtWidgets[12001]
#define sipNameNr_createStandardContextMenu 12027
#define sipName_createStandardContextMenu &sipStrings_QtWidgets[12027]
#define sipNameNr_DontAdjustForAntialiasing 12053
#define sipName_DontAdjustForAntialiasing &sipStrings_QtWidgets[12053]
#define sipNameNr_QGraphicsSceneResizeEvent 12079
#define sipName_QGraphicsSceneResizeEvent &sipStrings_QtWidgets[12079]
#define sipNameNr_createProxyForChildWidget 12105
#define sipName_createProxyForChildWidget &sipStrings_QtWidgets[12105]
#define sipNameNr_boundingRegionGranularity 12131
#define sipName_boundingRegionGranularity &sipStrings_QtWidgets[12131]
#define sipNameNr_QGraphicsDropShadowEffect 12157
#define sipName_QGraphicsDropShadowEffect &sipStrings_QtWidgets[12157]
#define sipNameNr_SourceBoundingRectChanged 12183
#define sipName_SourceBoundingRectChanged &sipStrings_QtWidgets[12183]
#define sipNameNr_QPinchGesture__ChangeFlag 12209
#define sipName_QPinchGesture__ChangeFlag &sipStrings_QtWidgets[12209]
#define sipNameNr_QFontComboBox__FontFilter 12235
#define sipName_QFontComboBox__FontFilter &sipStrings_QtWidgets[12235]
#define sipNameNr_QFileSystemModel__Options 12261
#define sipName_QFileSystemModel__Options &sipStrings_QtWidgets[12261]
#define sipNameNr_QFileIconProvider__Option 12287
#define sipName_QFileIconProvider__Option &sipStrings_QtWidgets[12287]
#define sipNameNr_UnfilteredPopupCompletion 12313
#define sipName_UnfilteredPopupCompletion &sipStrings_QtWidgets[12313]
#define sipNameNr_setHorizontalHeaderFormat 12339
#define sipName_setHorizontalHeaderFormat &sipStrings_QtWidgets[12339]
#define sipNameNr_associatedGraphicsWidgets 12365
#define sipName_associatedGraphicsWidgets &sipStrings_QtWidgets[12365]
#define sipNameNr_horizontalScrollBarPolicy 12391
#define sipName_horizontalScrollBarPolicy &sipStrings_QtWidgets[12391]
#define sipNameNr_resetHorizontalScrollMode 12417
#define sipName_resetHorizontalScrollMode &sipStrings_QtWidgets[12417]
#define sipNameNr_executeDelayedItemsLayout 12443
#define sipName_executeDelayedItemsLayout &sipStrings_QtWidgets[12443]
#define sipNameNr_horizontalScrollbarAction 12469
#define sipName_horizontalScrollbarAction &sipStrings_QtWidgets[12469]
#define sipNameNr_setHorizontalHeaderLabels 12495
#define sipName_setHorizontalHeaderLabels &sipStrings_QtWidgets[12495]
#define sipNameNr_RequestSoftwareInputPanel 4347
#define sipName_RequestSoftwareInputPanel &sipStrings_QtWidgets[4347]
#define sipNameNr_12521 12521
#define sipName_12521 &sipStrings_QtWidgets[12521]
#define sipNameNr_NoCancelButtonOnLastPage 12546
#define sipName_NoCancelButtonOnLastPage &sipStrings_QtWidgets[12546]
#define sipNameNr_HaveNextButtonOnLastPage 12571
#define sipName_HaveNextButtonOnLastPage &sipStrings_QtWidgets[12571]
#define sipNameNr_isFirstItemColumnSpanned 12596
#define sipName_isFirstItemColumnSpanned &sipStrings_QtWidgets[12596]
#define sipNameNr_currentCharFormatChanged 12621
#define sipName_currentCharFormatChanged &sipStrings_QtWidgets[12621]
#define sipNameNr_setLineWrapColumnOrWidth 12646
#define sipName_setLineWrapColumnOrWidth &sipStrings_QtWidgets[12646]
#define sipNameNr_QStyleOptionGraphicsItem 12671
#define sipName_QStyleOptionGraphicsItem &sipStrings_QtWidgets[12671]
#define sipNameNr_QStyleOption__OptionType 12696
#define sipName_QStyleOption__OptionType &sipStrings_QtWidgets[12696]
#define sipNameNr_SP_RestoreDefaultsButton 12721
#define sipName_SP_RestoreDefaultsButton &sipStrings_QtWidgets[12721]
#define sipNameNr_SP_MessageBoxInformation 12746
#define sipName_SP_MessageBoxInformation &sipStrings_QtWidgets[12746]
#define sipNameNr_SP_DockWidgetCloseButton 12771
#define sipName_SP_DockWidgetCloseButton &sipStrings_QtWidgets[12771]
#define sipNameNr_SP_TitleBarUnshadeButton 12796
#define sipName_SP_TitleBarUnshadeButton &sipStrings_QtWidgets[12796]
#define sipNameNr_SH_Splitter_OpaqueResize 12821
#define sipName_SH_Splitter_OpaqueResize &sipStrings_QtWidgets[12821]
#define sipNameNr_SH_Menu_SupportsSections 12846
#define sipName_SH_Menu_SupportsSections &sipStrings_QtWidgets[12846]
#define sipNameNr_SH_Slider_PageSetButtons 12871
#define sipName_SH_Slider_PageSetButtons &sipStrings_QtWidgets[12871]
#define sipNameNr_SH_ScrollBar_ContextMenu 12896
#define sipName_SH_ScrollBar_ContextMenu &sipStrings_QtWidgets[12896]
#define sipNameNr_SH_ToolButton_PopupDelay 12921
#define sipName_SH_ToolButton_PopupDelay &sipStrings_QtWidgets[12921]
#define sipNameNr_SH_SpinBox_AnimateButton 12946
#define sipName_SH_SpinBox_AnimateButton &sipStrings_QtWidgets[12946]
#define sipNameNr_SH_TabBar_PreferNoArrows 12971
#define sipName_SH_TabBar_PreferNoArrows &sipStrings_QtWidgets[12971]
#define sipNameNr_SH_MenuBar_MouseTracking 12996
#define sipName_SH_MenuBar_MouseTracking &sipStrings_QtWidgets[12996]
#define sipNameNr_SH_Header_ArrowAlignment 13021
#define sipName_SH_Header_ArrowAlignment &sipStrings_QtWidgets[13021]
#define sipNameNr_PM_LayoutVerticalSpacing 13046
#define sipName_PM_LayoutVerticalSpacing &sipStrings_QtWidgets[13046]
#define sipNameNr_PM_DockWidgetTitleMargin 13071
#define sipName_PM_DockWidgetTitleMargin &sipStrings_QtWidgets[13071]
#define sipNameNr_PM_DefaultTopLevelMargin 13096
#define sipName_PM_DefaultTopLevelMargin &sipStrings_QtWidgets[13096]
#define sipNameNr_PM_MenuDesktopFrameWidth 13121
#define sipName_PM_MenuDesktopFrameWidth &sipStrings_QtWidgets[13121]
#define sipNameNr_PM_ProgressBarChunkWidth 13146
#define sipName_PM_ProgressBarChunkWidth &sipStrings_QtWidgets[13146]
#define sipNameNr_PM_ButtonShiftHorizontal 13171
#define sipName_PM_ButtonShiftHorizontal &sipStrings_QtWidgets[13171]
#define sipNameNr_SC_TitleBarUnshadeButton 13196
#define sipName_SC_TitleBarUnshadeButton &sipStrings_QtWidgets[13196]
#define sipNameNr_SE_ItemViewItemFocusRect 13221
#define sipName_SE_ItemViewItemFocusRect &sipStrings_QtWidgets[13221]
#define sipNameNr_SE_RadioButtonLayoutItem 13246
#define sipName_SE_RadioButtonLayoutItem &sipStrings_QtWidgets[13246]
#define sipNameNr_SE_ProgressBarLayoutItem 13271
#define sipName_SE_ProgressBarLayoutItem &sipStrings_QtWidgets[13271]
#define sipNameNr_SE_DockWidgetFloatButton 13296
#define sipName_SE_DockWidgetFloatButton &sipStrings_QtWidgets[13296]
#define sipNameNr_SE_DockWidgetCloseButton 13321
#define sipName_SE_DockWidgetCloseButton &sipStrings_QtWidgets[13321]
#define sipNameNr_PE_IndicatorTabTearRight 13346
#define sipName_PE_IndicatorTabTearRight &sipStrings_QtWidgets[13346]
#define sipNameNr_PE_PanelScrollAreaCorner 13371
#define sipName_PE_PanelScrollAreaCorner &sipStrings_QtWidgets[13371]
#define sipNameNr_QStyle__PrimitiveElement 13396
#define sipName_QStyle__PrimitiveElement &sipStrings_QtWidgets[13396]
#define sipNameNr_QSizePolicy__ControlType 13421
#define sipName_QSizePolicy__ControlType &sipStrings_QtWidgets[13421]
#define sipNameNr_MiddleMouseButtonGesture 13446
#define sipName_MiddleMouseButtonGesture &sipStrings_QtWidgets[13446]
#define sipNameNr_QPlainTextDocumentLayout 13471
#define sipName_QPlainTextDocumentLayout &sipStrings_QtWidgets[13471]
#define sipNameNr_setSeparatorsCollapsible 13496
#define sipName_setSeparatorsCollapsible &sipStrings_QtWidgets[13496]
#define sipNameNr_QMainWindow__DockOptions 13521
#define sipName_QMainWindow__DockOptions &sipStrings_QtWidgets[13521]
#define sipNameNr_QLCDNumber__SegmentStyle 13546
#define sipName_QLCDNumber__SegmentStyle &sipStrings_QtWidgets[13546]
#define sipNameNr_sectionsAboutToBeRemoved 13571
#define sipName_sectionsAboutToBeRemoved &sipStrings_QtWidgets[13571]
#define sipNameNr_QGraphicsView__CacheMode 13596
#define sipName_QGraphicsView__CacheMode &sipStrings_QtWidgets[13596]
#define sipNameNr_QGraphicsSceneHoverEvent 13621
#define sipName_QGraphicsSceneHoverEvent &sipStrings_QtWidgets[13621]
#define sipNameNr_QGraphicsSceneWheelEvent 13646
#define sipName_QGraphicsSceneWheelEvent &sipStrings_QtWidgets[13646]
#define sipNameNr_QGraphicsSceneMouseEvent 13671
#define sipName_QGraphicsSceneMouseEvent &sipStrings_QtWidgets[13671]
#define sipNameNr_ItemSendsGeometryChanges 13696
#define sipName_ItemSendsGeometryChanges &sipStrings_QtWidgets[13696]
#define sipNameNr_ItemIgnoresParentOpacity 13721
#define sipName_ItemIgnoresParentOpacity &sipStrings_QtWidgets[13721]
#define sipNameNr_ItemClipsChildrenToShape 13746
#define sipName_ItemClipsChildrenToShape &sipStrings_QtWidgets[13746]
#define sipNameNr_QGraphicsItem__CacheMode 13771
#define sipName_QGraphicsItem__CacheMode &sipStrings_QtWidgets[13771]
#define sipNameNr_QFileSystemModel__Option 13796
#define sipName_QFileSystemModel__Option &sipStrings_QtWidgets[13796]
#define sipNameNr_QFileDialog__DialogLabel 13821
#define sipName_QFileDialog__DialogLabel &sipStrings_QtWidgets[13821]
#define sipNameNr_QCompleter__ModelSorting 13846
#define sipName_QCompleter__ModelSorting &sipStrings_QtWidgets[13846]
#define sipNameNr_setMinimumContentsLength 13871
#define sipName_setMinimumContentsLength &sipStrings_QtWidgets[13871]
#define sipNameNr_setKeyboardInputInterval 13896
#define sipName_setKeyboardInputInterval &sipStrings_QtWidgets[13896]
#define sipNameNr_setItemDelegateForColumn 13921
#define sipName_setItemDelegateForColumn &sipStrings_QtWidgets[13921]
#define sipNameNr_setDragDropOverwriteMode 13946
#define sipName_setDragDropOverwriteMode &sipStrings_QtWidgets[13946]
#define sipNameNr_QAbstractItemView__State 13971
#define sipName_QAbstractItemView__State &sipStrings_QtWidgets[13971]
#define sipNameNr_visualRegionForSelection 13996
#define sipName_visualRegionForSelection &sipStrings_QtWidgets[13996]
#define sipNameNr_takeHorizontalHeaderItem 14021
#define sipName_takeHorizontalHeaderItem &sipStrings_QtWidgets[14021]
#define sipNameNr_defaultFramebufferObject 14046
#define sipName_defaultFramebufferObject &sipStrings_QtWidgets[14046]
#define sipNameNr_14071 14071
#define sipName_14071 &sipStrings_QtWidgets[14071]
#define sipNameNr_14095 14095
#define sipName_14095 &sipStrings_QtWidgets[14095]
#define sipNameNr_14119 14119
#define sipName_14119 &sipStrings_QtWidgets[14119]
#define sipNameNr_14143 14143
#define sipName_14143 &sipStrings_QtWidgets[14143]
#define sipNameNr_NoBackButtonOnStartPage 14167
#define sipName_NoBackButtonOnStartPage &sipStrings_QtWidgets[14167]
#define sipNameNr_ExtendedWatermarkPixmap 14191
#define sipName_ExtendedWatermarkPixmap &sipStrings_QtWidgets[14191]
#define sipNameNr_QTreeWidgetItemIterator 14215
#define sipName_QTreeWidgetItemIterator &sipStrings_QtWidgets[14215]
#define sipNameNr_setChildIndicatorPolicy 14239
#define sipName_setChildIndicatorPolicy &sipStrings_QtWidgets[14239]
#define sipNameNr_setExpandsOnDoubleClick 14263
#define sipName_setExpandsOnDoubleClick &sipStrings_QtWidgets[14263]
#define sipNameNr_QTextEdit__LineWrapMode 14287
#define sipName_QTextEdit__LineWrapMode &sipStrings_QtWidgets[14287]
#define sipNameNr_QTabWidget__TabPosition 14311
#define sipName_QTabWidget__TabPosition &sipStrings_QtWidgets[14311]
#define sipNameNr_resizeColumnsToContents 14335
#define sipName_resizeColumnsToContents &sipStrings_QtWidgets[14335]
#define sipNameNr_QTabBar__ButtonPosition 14359
#define sipName_QTabBar__ButtonPosition &sipStrings_QtWidgets[14359]
#define sipNameNr_QStyleHintReturnVariant 14383
#define sipName_QStyleHintReturnVariant &sipStrings_QtWidgets[14383]
#define sipNameNr_QStyleOptionProgressBar 14407
#define sipName_QStyleOptionProgressBar &sipStrings_QtWidgets[14407]
#define sipNameNr_sliderValueFromPosition 14431
#define sipName_sliderValueFromPosition &sipStrings_QtWidgets[14431]
#define sipNameNr_sliderPositionFromValue 14455
#define sipName_sliderPositionFromValue &sipStrings_QtWidgets[14455]
#define sipNameNr_SP_DialogYesToAllButton 14479
#define sipName_SP_DialogYesToAllButton &sipStrings_QtWidgets[14479]
#define sipNameNr_SP_TitleBarNormalButton 14503
#define sipName_SP_TitleBarNormalButton &sipStrings_QtWidgets[14503]
#define sipNameNr_SH_SpinBox_StepModifier 14527
#define sipName_SH_SpinBox_StepModifier &sipStrings_QtWidgets[14527]
#define sipNameNr_SH_FormLayoutWrapPolicy 14551
#define sipName_SH_FormLayoutWrapPolicy &sipStrings_QtWidgets[14551]
#define sipNameNr_SH_DrawMenuBarSeparator 14575
#define sipName_SH_DrawMenuBarSeparator &sipStrings_QtWidgets[14575]
#define sipNameNr_SH_ToolTipLabel_Opacity 14599
#define sipName_SH_ToolTipLabel_Opacity &sipStrings_QtWidgets[14599]
#define sipNameNr_PM_CheckBoxLabelSpacing 14623
#define sipName_PM_CheckBoxLabelSpacing &sipStrings_QtWidgets[14623]
#define sipNameNr_PM_DefaultLayoutSpacing 14647
#define sipName_PM_DefaultLayoutSpacing &sipStrings_QtWidgets[14647]
#define sipNameNr_PM_DockWidgetFrameWidth 14671
#define sipName_PM_DockWidgetFrameWidth &sipStrings_QtWidgets[14671]
#define sipNameNr_PM_SliderSpaceAvailable 14695
#define sipName_PM_SliderSpaceAvailable &sipStrings_QtWidgets[14695]
#define sipNameNr_PM_SliderTickmarkOffset 14719
#define sipName_PM_SliderTickmarkOffset &sipStrings_QtWidgets[14719]
#define sipNameNr_SC_TitleBarNormalButton 14743
#define sipName_SC_TitleBarNormalButton &sipStrings_QtWidgets[14743]
#define sipNameNr_SC_ComboBoxListBoxPopup 14767
#define sipName_SC_ComboBoxListBoxPopup &sipStrings_QtWidgets[14767]
#define sipNameNr_SE_TabBarTabRightButton 14791
#define sipName_SE_TabBarTabRightButton &sipStrings_QtWidgets[14791]
#define sipNameNr_SE_ToolButtonLayoutItem 14815
#define sipName_SE_ToolButtonLayoutItem &sipStrings_QtWidgets[14815]
#define sipNameNr_SE_PushButtonLayoutItem 14839
#define sipName_SE_PushButtonLayoutItem &sipStrings_QtWidgets[14839]
#define sipNameNr_SE_TabWidgetRightCorner 14863
#define sipName_SE_TabWidgetRightCorner &sipStrings_QtWidgets[14863]
#define sipNameNr_SE_TabWidgetTabContents 14887
#define sipName_SE_TabWidgetTabContents &sipStrings_QtWidgets[14887]
#define sipNameNr_SE_RadioButtonClickRect 14911
#define sipName_SE_RadioButtonClickRect &sipStrings_QtWidgets[14911]
#define sipNameNr_SE_RadioButtonFocusRect 14935
#define sipName_SE_RadioButtonFocusRect &sipStrings_QtWidgets[14935]
#define sipNameNr_SE_RadioButtonIndicator 14959
#define sipName_SE_RadioButtonIndicator &sipStrings_QtWidgets[14959]
#define sipNameNr_PE_IndicatorTabTearLeft 14983
#define sipName_PE_IndicatorTabTearLeft &sipStrings_QtWidgets[14983]
#define sipNameNr_PE_IndicatorRadioButton 15007
#define sipName_PE_IndicatorRadioButton &sipStrings_QtWidgets[15007]
#define sipNameNr_PE_IndicatorHeaderArrow 15031
#define sipName_PE_IndicatorHeaderArrow &sipStrings_QtWidgets[15031]
#define sipNameNr_setRetainSizeWhenHidden 15055
#define sipName_setRetainSizeWhenHidden &sipStrings_QtWidgets[15055]
#define sipNameNr_QSizePolicy__PolicyFlag 15079
#define sipName_QSizePolicy__PolicyFlag &sipStrings_QtWidgets[15079]
#define sipNameNr_VerticalOvershootPolicy 15103
#define sipName_VerticalOvershootPolicy &sipStrings_QtWidgets[15103]
#define sipNameNr_OvershootWhenScrollable 15127
#define sipName_OvershootWhenScrollable &sipStrings_QtWidgets[15127]
#define sipNameNr_RightMouseButtonGesture 15151
#define sipName_RightMouseButtonGesture &sipStrings_QtWidgets[15151]
#define sipNameNr_QProgressBar__Direction 15175
#define sipName_QProgressBar__Direction &sipStrings_QtWidgets[15175]
#define sipNameNr_QMessageBox__ButtonRole 15199
#define sipName_QMessageBox__ButtonRole &sipStrings_QtWidgets[15199]
#define sipNameNr_QMainWindow__DockOption 15223
#define sipName_QMainWindow__DockOption &sipStrings_QtWidgets[15223]
#define sipNameNr_setSelectionRectVisible 15247
#define sipName_setSelectionRectVisible &sipStrings_QtWidgets[15247]
#define sipNameNr_QLayout__SizeConstraint 15271
#define sipName_QLayout__SizeConstraint &sipStrings_QtWidgets[15271]
#define sipNameNr_QInputDialog__InputMode 15295
#define sipName_QInputDialog__InputMode &sipStrings_QtWidgets[15295]
#define sipNameNr_resetDefaultSectionSize 15319
#define sipName_resetDefaultSectionSize &sipStrings_QtWidgets[15319]
#define sipNameNr_resizeContentsPrecision 15343
#define sipName_resizeContentsPrecision &sipStrings_QtWidgets[15343]
#define sipNameNr_cascadingSectionResizes 15367
#define sipName_cascadingSectionResizes &sipStrings_QtWidgets[15367]
#define sipNameNr_sectionSizeFromContents 15391
#define sipName_sectionSizeFromContents &sipStrings_QtWidgets[15391]
#define sipNameNr_sectionViewportPosition 15415
#define sipName_sectionViewportPosition &sipStrings_QtWidgets[15415]
#define sipNameNr_QHeaderView__ResizeMode 15439
#define sipName_QHeaderView__ResizeMode &sipStrings_QtWidgets[15439]
#define sipNameNr_unsetWindowFrameMargins 15463
#define sipName_unsetWindowFrameMargins &sipStrings_QtWidgets[15463]
#define sipNameNr_rubberBandSelectionMode 15487
#define sipName_rubberBandSelectionMode &sipStrings_QtWidgets[15487]
#define sipNameNr_setTransformationAnchor 15511
#define sipName_setTransformationAnchor &sipStrings_QtWidgets[15511]
#define sipNameNr_QGraphicsView__DragMode 15535
#define sipName_QGraphicsView__DragMode &sipStrings_QtWidgets[15535]
#define sipNameNr_QGraphicsSceneMoveEvent 15559
#define sipName_QGraphicsSceneMoveEvent &sipStrings_QtWidgets[15559]
#define sipNameNr_QGraphicsSceneHelpEvent 15583
#define sipName_QGraphicsSceneHelpEvent &sipStrings_QtWidgets[15583]
#define sipNameNr_setTextInteractionFlags 15607
#define sipName_setTextInteractionFlags &sipStrings_QtWidgets[15607]
#define sipNameNr_QGraphicsSimpleTextItem 15631
#define sipName_QGraphicsSimpleTextItem &sipStrings_QtWidgets[15631]
#define sipNameNr_setTransformOriginPoint 15655
#define sipName_setTransformOriginPoint &sipStrings_QtWidgets[15655]
#define sipNameNr_installSceneEventFilter 15679
#define sipName_installSceneEventFilter &sipStrings_QtWidgets[15679]
#define sipNameNr_setAcceptedMouseButtons 15703
#define sipName_setAcceptedMouseButtons &sipStrings_QtWidgets[15703]
#define sipNameNr_ItemTransformHasChanged 15727
#define sipName_ItemTransformHasChanged &sipStrings_QtWidgets[15727]
#define sipNameNr_setColumnPreferredWidth 15751
#define sipName_setColumnPreferredWidth &sipStrings_QtWidgets[15751]
#define sipNameNr_QGraphicsColorizeEffect 15775
#define sipName_QGraphicsColorizeEffect &sipStrings_QtWidgets[15775]
#define sipNameNr_QFileSystemModel__Roles 15799
#define sipName_QFileSystemModel__Roles &sipStrings_QtWidgets[15799]
#define sipNameNr_getExistingDirectoryUrl 15823
#define sipName_getExistingDirectoryUrl &sipStrings_QtWidgets[15823]
#define sipNameNr_QFileDialog__AcceptMode 15847
#define sipName_QFileDialog__AcceptMode &sipStrings_QtWidgets[15847]
#define sipNameNr_QDateTimeEdit__Sections 15871
#define sipName_QDateTimeEdit__Sections &sipStrings_QtWidgets[15871]
#define sipNameNr_QComboBox__InsertPolicy 15895
#define sipName_QComboBox__InsertPolicy &sipStrings_QtWidgets[15895]
#define sipNameNr_setNavigationBarVisible 15919
#define sipName_setNavigationBarVisible &sipStrings_QtWidgets[15919]
#define sipNameNr_setVerticalHeaderFormat 15943
#define sipName_setVerticalHeaderFormat &sipStrings_QtWidgets[15943]
#define sipNameNr_QApplication__ColorSpec 15967
#define sipName_QApplication__ColorSpec &sipStrings_QtWidgets[15967]
#define sipNameNr_ApplicationSpecificRole 15991
#define sipName_ApplicationSpecificRole &sipStrings_QtWidgets[15991]
#define sipNameNr_AdaptiveDecimalStepType 16015
#define sipName_AdaptiveDecimalStepType &sipStrings_QtWidgets[16015]
#define sipNameNr_SliderOrientationChange 16039
#define sipName_SliderOrientationChange &sipStrings_QtWidgets[16039]
#define sipNameNr_verticalScrollBarPolicy 16063
#define sipName_verticalScrollBarPolicy &sipStrings_QtWidgets[16063]
#define sipNameNr_resetVerticalScrollMode 16087
#define sipName_resetVerticalScrollMode &sipStrings_QtWidgets[16087]
#define sipNameNr_setHorizontalScrollMode 12419
#define sipName_setHorizontalScrollMode &sipStrings_QtWidgets[12419]
#define sipNameNr_verticalScrollbarAction 16111
#define sipName_verticalScrollbarAction &sipStrings_QtWidgets[16111]
#define sipNameNr_setAlternatingRowColors 16135
#define sipName_setAlternatingRowColors &sipStrings_QtWidgets[16135]
#define sipNameNr_setVerticalHeaderLabels 16159
#define sipName_setVerticalHeaderLabels &sipStrings_QtWidgets[16159]
#define sipNameNr_setHorizontalHeaderItem 16183
#define sipName_setHorizontalHeaderItem &sipStrings_QtWidgets[16183]
#define sipNameNr_QWizard__WizardOptions 16207
#define sipName_QWizard__WizardOptions &sipStrings_QtWidgets[16207]
#define sipNameNr_NoBackButtonOnLastPage 16230
#define sipName_NoBackButtonOnLastPage &sipStrings_QtWidgets[16230]
#define sipNameNr_setAllColumnsShowFocus 16253
#define sipName_setAllColumnsShowFocus &sipStrings_QtWidgets[16253]
#define sipNameNr_setTextBackgroundColor 16276
#define sipName_setTextBackgroundColor &sipStrings_QtWidgets[16276]
#define sipNameNr_setCornerButtonEnabled 16299
#define sipName_setCornerButtonEnabled &sipStrings_QtWidgets[16299]
#define sipNameNr_resizeColumnToContents 16322
#define sipName_resizeColumnToContents &sipStrings_QtWidgets[16322]
#define sipNameNr_columnViewportPosition 16345
#define sipName_columnViewportPosition &sipStrings_QtWidgets[16345]
#define sipNameNr_setChangeCurrentOnDrag 16368
#define sipName_setChangeCurrentOnDrag &sipStrings_QtWidgets[16368]
#define sipNameNr_QStyleOptionToolButton 16391
#define sipName_QStyleOptionToolButton &sipStrings_QtWidgets[16391]
#define sipNameNr_QStyleOptionRubberBand 16414
#define sipName_QStyleOptionRubberBand &sipStrings_QtWidgets[16414]
#define sipNameNr_showDecorationSelected 16437
#define sipName_showDecorationSelected &sipStrings_QtWidgets[16437]
#define sipNameNr_QStyleOptionDockWidget 16460
#define sipName_QStyleOptionDockWidget &sipStrings_QtWidgets[16460]
#define sipNameNr_QStyleOptionTabBarBase 16483
#define sipName_QStyleOptionTabBarBase &sipStrings_QtWidgets[16483]
#define sipNameNr_SP_DialogSaveAllButton 16506
#define sipName_SP_DialogSaveAllButton &sipStrings_QtWidgets[16506]
#define sipNameNr_SP_DialogNoToAllButton 16529
#define sipName_SP_DialogNoToAllButton &sipStrings_QtWidgets[16529]
#define sipNameNr_SP_LineEditClearButton 16552
#define sipName_SP_LineEditClearButton &sipStrings_QtWidgets[16552]
#define sipNameNr_SP_DialogDiscardButton 16575
#define sipName_SP_DialogDiscardButton &sipStrings_QtWidgets[16575]
#define sipNameNr_SP_FileDialogNewFolder 16598
#define sipName_SP_FileDialogNewFolder &sipStrings_QtWidgets[16598]
#define sipNameNr_SP_TitleBarShadeButton 16621
#define sipName_SP_TitleBarShadeButton &sipStrings_QtWidgets[16621]
#define sipNameNr_SP_TitleBarCloseButton 16644
#define sipName_SP_TitleBarCloseButton &sipStrings_QtWidgets[16644]
#define sipNameNr_QStyle__StandardPixmap 16667
#define sipName_QStyle__StandardPixmap &sipStrings_QtWidgets[16667]
#define sipNameNr_SH_ItemView_ScrollMode 16690
#define sipName_SH_ItemView_ScrollMode &sipStrings_QtWidgets[16690]
#define sipNameNr_SH_ToolTip_WakeUpDelay 16713
#define sipName_SH_ToolTip_WakeUpDelay &sipStrings_QtWidgets[16713]
#define sipNameNr_SH_ScrollBar_Transient 16736
#define sipName_SH_ScrollBar_Transient &sipStrings_QtWidgets[16736]
#define sipNameNr_SH_Menu_KeyboardSearch 16759
#define sipName_SH_Menu_KeyboardSearch &sipStrings_QtWidgets[16759]
#define sipNameNr_SH_Dial_BackgroundRole 16782
#define sipName_SH_Dial_BackgroundRole &sipStrings_QtWidgets[16782]
#define sipNameNr_SH_Table_GridLineColor 16805
#define sipName_SH_Table_GridLineColor &sipStrings_QtWidgets[16805]
#define sipNameNr_SH_Menu_SloppySubMenus 16828
#define sipName_SH_Menu_SloppySubMenus &sipStrings_QtWidgets[16828]
#define sipNameNr_PM_TreeViewIndentation 16851
#define sipName_PM_TreeViewIndentation &sipStrings_QtWidgets[16851]
#define sipNameNr_PM_SpinBoxSliderHeight 16874
#define sipName_PM_SpinBoxSliderHeight &sipStrings_QtWidgets[16874]
#define sipNameNr_PM_ToolBarHandleExtent 16897
#define sipName_PM_ToolBarHandleExtent &sipStrings_QtWidgets[16897]
#define sipNameNr_PM_MaximumDragDistance 16920
#define sipName_PM_MaximumDragDistance &sipStrings_QtWidgets[16920]
#define sipNameNr_PM_ButtonShiftVertical 16943
#define sipName_PM_ButtonShiftVertical &sipStrings_QtWidgets[16943]
#define sipNameNr_PM_MenuButtonIndicator 16966
#define sipName_PM_MenuButtonIndicator &sipStrings_QtWidgets[16966]
#define sipNameNr_SC_TitleBarShadeButton 16989
#define sipName_SC_TitleBarShadeButton &sipStrings_QtWidgets[16989]
#define sipNameNr_SC_TitleBarCloseButton 17012
#define sipName_SC_TitleBarCloseButton &sipStrings_QtWidgets[17012]
#define sipNameNr_QStyle__ComplexControl 17035
#define sipName_QStyle__ComplexControl &sipStrings_QtWidgets[17035]
#define sipNameNr_SE_ShapedFrameContents 17058
#define sipName_SE_ShapedFrameContents &sipStrings_QtWidgets[17058]
#define sipNameNr_SE_TabBarTabLeftButton 17081
#define sipName_SE_TabBarTabLeftButton &sipStrings_QtWidgets[17081]
#define sipNameNr_SE_TabWidgetLayoutItem 17104
#define sipName_SE_TabWidgetLayoutItem &sipStrings_QtWidgets[17104]
#define sipNameNr_SE_TabBarTearIndicator 17127
#define sipName_SE_TabBarTearIndicator &sipStrings_QtWidgets[17127]
#define sipNameNr_SE_TabWidgetLeftCorner 17150
#define sipName_SE_TabWidgetLeftCorner &sipStrings_QtWidgets[17150]
#define sipNameNr_SE_ProgressBarContents 17173
#define sipName_SE_ProgressBarContents &sipStrings_QtWidgets[17173]
#define sipNameNr_SE_RadioButtonContents 17196
#define sipName_SE_RadioButtonContents &sipStrings_QtWidgets[17196]
#define sipNameNr_SE_PushButtonFocusRect 17219
#define sipName_SE_PushButtonFocusRect &sipStrings_QtWidgets[17219]
#define sipNameNr_CE_ProgressBarContents 17242
#define sipName_CE_ProgressBarContents &sipStrings_QtWidgets[17242]
#define sipNameNr_QStyle__ControlElement 17265
#define sipName_QStyle__ControlElement &sipStrings_QtWidgets[17265]
#define sipNameNr_PE_IndicatorArrowRight 17288
#define sipName_PE_IndicatorArrowRight &sipStrings_QtWidgets[17288]
#define sipNameNr_setChildrenCollapsible 17311
#define sipName_setChildrenCollapsible &sipStrings_QtWidgets[17311]
#define sipNameNr_LeftMouseButtonGesture 17334
#define sipName_LeftMouseButtonGesture &sipStrings_QtWidgets[17334]
#define sipNameNr_mergeCurrentCharFormat 17357
#define sipName_mergeCurrentCharFormat &sipStrings_QtWidgets[17357]
#define sipNameNr_ActivationHistoryOrder 17380
#define sipName_ActivationHistoryOrder &sipStrings_QtWidgets[17380]
#define sipNameNr_toolButtonStyleChanged 17403
#define sipName_toolButtonStyleChanged &sipStrings_QtWidgets[17403]
#define sipNameNr_isSelectionRectVisible 17426
#define sipName_isSelectionRectVisible &sipStrings_QtWidgets[17426]
#define sipNameNr_QItemEditorCreatorBase 17449
#define sipName_QItemEditorCreatorBase &sipStrings_QtWidgets[17449]
#define sipNameNr_setFirstSectionMovable 17472
#define sipName_setFirstSectionMovable &sipStrings_QtWidgets[17472]
#define sipNameNr_setOffsetToLastSection 17495
#define sipName_setOffsetToLastSection &sipStrings_QtWidgets[17495]
#define sipNameNr_removeSceneEventFilter 17518
#define sipName_removeSceneEventFilter &sipStrings_QtWidgets[17518]
#define sipNameNr_ItemAcceptsInputMethod 17541
#define sipName_ItemAcceptsInputMethod &sipStrings_QtWidgets[17541]
#define sipNameNr_ItemStacksBehindParent 17564
#define sipName_ItemStacksBehindParent &sipStrings_QtWidgets[17564]
#define sipNameNr_ItemRotationHasChanged 17587
#define sipName_ItemRotationHasChanged &sipStrings_QtWidgets[17587]
#define sipNameNr_ItemSelectedHasChanged 17610
#define sipName_ItemSelectedHasChanged &sipStrings_QtWidgets[17610]
#define sipNameNr_ItemPositionHasChanged 17633
#define sipName_ItemPositionHasChanged &sipStrings_QtWidgets[17633]
#define sipNameNr_ItemChildRemovedChange 17656
#define sipName_ItemChildRemovedChange &sipStrings_QtWidgets[17656]
#define sipNameNr_setColumnStretchFactor 17679
#define sipName_setColumnStretchFactor &sipStrings_QtWidgets[17679]
#define sipNameNr_QGraphicsOpacityEffect 17702
#define sipName_QGraphicsOpacityEffect &sipStrings_QtWidgets[17702]
#define sipNameNr_PadToTransparentBorder 17725
#define sipName_PadToTransparentBorder &sipStrings_QtWidgets[17725]
#define sipNameNr_setGestureCancelPolicy 17748
#define sipName_setGestureCancelPolicy &sipStrings_QtWidgets[17748]
#define sipNameNr_selectedMimeTypeFilter 17771
#define sipName_selectedMimeTypeFilter &sipStrings_QtWidgets[17771]
#define sipNameNr_setCurrentSectionIndex 17794
#define sipName_setCurrentSectionIndex &sipStrings_QtWidgets[17794]
#define sipNameNr_QDateTimeEdit__Section 17817
#define sipName_QDateTimeEdit__Section &sipStrings_QtWidgets[17817]
#define sipNameNr_setDateEditAcceptDelay 17840
#define sipName_setDateEditAcceptDelay &sipStrings_QtWidgets[17840]
#define sipNameNr_isNavigationBarVisible 17863
#define sipName_isNavigationBarVisible &sipStrings_QtWidgets[17863]
#define sipNameNr_horizontalHeaderFormat 17886
#define sipName_horizontalHeaderFormat &sipStrings_QtWidgets[17886]
#define sipNameNr_HorizontalHeaderFormat 1699
#define sipName_HorizontalHeaderFormat &sipStrings_QtWidgets[1699]
#define sipNameNr_setDoubleClickInterval 17909
#define sipName_setDoubleClickInterval &sipStrings_QtWidgets[17909]
#define sipNameNr_setGroupSeparatorShown 17932
#define sipName_setGroupSeparatorShown &sipStrings_QtWidgets[17932]
#define sipNameNr_CorrectToPreviousValue 17955
#define sipName_CorrectToPreviousValue &sipStrings_QtWidgets[17955]
#define sipNameNr_setHorizontalScrollBar 17978
#define sipName_setHorizontalScrollBar &sipStrings_QtWidgets[17978]
#define sipNameNr_isPersistentEditorOpen 18001
#define sipName_isPersistentEditorOpen &sipStrings_QtWidgets[18001]
#define sipNameNr_updateEditorGeometries 18024
#define sipName_updateEditorGeometries &sipStrings_QtWidgets[18024]
#define sipNameNr_takeVerticalHeaderItem 18047
#define sipName_takeVerticalHeaderItem &sipStrings_QtWidgets[18047]
#define sipNameNr_18070 18070
#define sipName_18070 &sipStrings_QtWidgets[18070]
#define sipNameNr_18092 18092
#define sipName_18092 &sipStrings_QtWidgets[18092]
#define sipNameNr_18114 18114
#define sipName_18114 &sipStrings_QtWidgets[18114]
#define sipNameNr_QWizard__WizardOption 18136
#define sipName_QWizard__WizardOption &sipStrings_QtWidgets[18136]
#define sipNameNr_QWizard__WizardPixmap 18158
#define sipName_QWizard__WizardPixmap &sipStrings_QtWidgets[18158]
#define sipNameNr_QWizard__WizardButton 18180
#define sipName_QWizard__WizardButton &sipStrings_QtWidgets[18180]
#define sipNameNr_windowIconTextChanged 18202
#define sipName_windowIconTextChanged &sipStrings_QtWidgets[18202]
#define sipNameNr_createWindowContainer 18224
#define sipName_createWindowContainer &sipStrings_QtWidgets[18224]
#define sipNameNr_setFirstColumnSpanned 18246
#define sipName_setFirstColumnSpanned &sipStrings_QtWidgets[18246]
#define sipNameNr_lineWrapColumnOrWidth 18268
#define sipName_lineWrapColumnOrWidth &sipStrings_QtWidgets[18268]
#define sipNameNr_isCornerButtonEnabled 18290
#define sipName_isCornerButtonEnabled &sipStrings_QtWidgets[18290]
#define sipNameNr_isSystemTrayAvailable 18312
#define sipName_isSystemTrayAvailable &sipStrings_QtWidgets[18312]
#define sipNameNr_menuHasCheckableItems 18334
#define sipName_menuHasCheckableItems &sipStrings_QtWidgets[18334]
#define sipNameNr_rightCornerWidgetSize 18356
#define sipName_rightCornerWidgetSize &sipStrings_QtWidgets[18356]
#define sipNameNr_QStyleOptionFocusRect 18378
#define sipName_QStyleOptionFocusRect &sipStrings_QtWidgets[18378]
#define sipNameNr_combinedLayoutSpacing 18400
#define sipName_combinedLayoutSpacing &sipStrings_QtWidgets[18400]
#define sipNameNr_SP_DialogIgnoreButton 18422
#define sipName_SP_DialogIgnoreButton &sipStrings_QtWidgets[18422]
#define sipNameNr_SP_DialogCancelButton 18444
#define sipName_SP_DialogCancelButton &sipStrings_QtWidgets[18444]
#define sipNameNr_SP_FileDialogListView 18466
#define sipName_SP_FileDialogListView &sipStrings_QtWidgets[18466]
#define sipNameNr_SP_FileDialogInfoView 18488
#define sipName_SP_FileDialogInfoView &sipStrings_QtWidgets[18488]
#define sipNameNr_SP_FileDialogToParent 18510
#define sipName_SP_FileDialogToParent &sipStrings_QtWidgets[18510]
#define sipNameNr_SP_MessageBoxQuestion 18532
#define sipName_SP_MessageBoxQuestion &sipStrings_QtWidgets[18532]
#define sipNameNr_SP_MessageBoxCritical 18554
#define sipName_SP_MessageBoxCritical &sipStrings_QtWidgets[18554]
#define sipNameNr_SP_TitleBarMenuButton 18576
#define sipName_SP_TitleBarMenuButton &sipStrings_QtWidgets[18576]
#define sipNameNr_SH_Menu_FadeOutOnHide 18598
#define sipName_SH_Menu_FadeOutOnHide &sipStrings_QtWidgets[18598]
#define sipNameNr_SH_Menu_SelectionWrap 18620
#define sipName_SH_Menu_SelectionWrap &sipStrings_QtWidgets[18620]
#define sipNameNr_SH_DialogButtonLayout 18642
#define sipName_SH_DialogButtonLayout &sipStrings_QtWidgets[18642]
#define sipNameNr_SH_TitleBar_AutoRaise 18664
#define sipName_SH_TitleBar_AutoRaise &sipStrings_QtWidgets[18664]
#define sipNameNr_SH_Button_FocusPolicy 18686
#define sipName_SH_Button_FocusPolicy &sipStrings_QtWidgets[18686]
#define sipNameNr_SH_Menu_MouseTracking 18708
#define sipName_SH_Menu_MouseTracking &sipStrings_QtWidgets[18708]
#define sipNameNr_SH_Slider_SnapToValue 18730
#define sipName_SH_Slider_SnapToValue &sipStrings_QtWidgets[18730]
#define sipNameNr_SH_DitherDisabledText 18752
#define sipName_SH_DitherDisabledText &sipStrings_QtWidgets[18752]
#define sipNameNr_PM_TitleBarButtonSize 18774
#define sipName_PM_TitleBarButtonSize &sipStrings_QtWidgets[18774]
#define sipNameNr_PM_LayoutBottomMargin 18796
#define sipName_PM_LayoutBottomMargin &sipStrings_QtWidgets[18796]
#define sipNameNr_PM_MessageBoxIconSize 18818
#define sipName_PM_MessageBoxIconSize &sipStrings_QtWidgets[18818]
#define sipNameNr_PM_DefaultChildMargin 18840
#define sipName_PM_DefaultChildMargin &sipStrings_QtWidgets[18840]
#define sipNameNr_PM_ToolBarItemSpacing 18862
#define sipName_PM_ToolBarItemSpacing &sipStrings_QtWidgets[18862]
#define sipNameNr_PM_MenuBarItemSpacing 18884
#define sipName_PM_MenuBarItemSpacing &sipStrings_QtWidgets[18884]
#define sipNameNr_PM_MenuScrollerHeight 18906
#define sipName_PM_MenuScrollerHeight &sipStrings_QtWidgets[18906]
#define sipNameNr_PM_ScrollBarSliderMin 18928
#define sipName_PM_ScrollBarSliderMin &sipStrings_QtWidgets[18928]
#define sipNameNr_PM_ComboBoxFrameWidth 18950
#define sipName_PM_ComboBoxFrameWidth &sipStrings_QtWidgets[18950]
#define sipNameNr_SE_GroupBoxLayoutItem 18972
#define sipName_SE_GroupBoxLayoutItem &sipStrings_QtWidgets[18972]
#define sipNameNr_SE_ComboBoxLayoutItem 18994
#define sipName_SE_ComboBoxLayoutItem &sipStrings_QtWidgets[18994]
#define sipNameNr_SE_CheckBoxLayoutItem 19016
#define sipName_SE_CheckBoxLayoutItem &sipStrings_QtWidgets[19016]
#define sipNameNr_SE_ToolBoxTabContents 19038
#define sipName_SE_ToolBoxTabContents &sipStrings_QtWidgets[19038]
#define sipNameNr_SE_PushButtonContents 19060
#define sipName_SE_PushButtonContents &sipStrings_QtWidgets[19060]
#define sipNameNr_PE_FrameStatusBarItem 19082
#define sipName_PE_FrameStatusBarItem &sipStrings_QtWidgets[19082]
#define sipNameNr_PE_IndicatorSpinMinus 19104
#define sipName_PE_IndicatorSpinMinus &sipStrings_QtWidgets[19104]
#define sipNameNr_PE_IndicatorArrowLeft 19126
#define sipName_PE_IndicatorArrowLeft &sipStrings_QtWidgets[19126]
#define sipNameNr_PE_IndicatorArrowDown 19148
#define sipName_PE_IndicatorArrowDown &sipStrings_QtWidgets[19148]
#define sipNameNr_PE_PanelButtonCommand 19170
#define sipName_PE_PanelButtonCommand &sipStrings_QtWidgets[19170]
#define sipNameNr_PE_FrameDefaultButton 19192
#define sipName_PE_FrameDefaultButton &sipStrings_QtWidgets[19192]
#define sipNameNr_insertPermanentWidget 19214
#define sipName_insertPermanentWidget &sipStrings_QtWidgets[19214]
#define sipNameNr_setDisplayIntegerBase 19236
#define sipName_setDisplayIntegerBase &sipStrings_QtWidgets[19236]
#define sipNameNr_QSlider__TickPosition 19258
#define sipName_QSlider__TickPosition &sipStrings_QtWidgets[19258]
#define sipNameNr_setScrollerProperties 19280
#define sipName_setScrollerProperties &sipStrings_QtWidgets[19280]
#define sipNameNr_blockBoundingGeometry 19302
#define sipName_blockBoundingGeometry &sipStrings_QtWidgets[19302]
#define sipNameNr_canInsertFromMimeData 19324
#define sipName_canInsertFromMimeData &sipStrings_QtWidgets[19324]
#define sipNameNr_QMouseEventTransition 19346
#define sipName_QMouseEventTransition &sipStrings_QtWidgets[19346]
#define sipNameNr_separatorsCollapsible 19368
#define sipName_separatorsCollapsible &sipStrings_QtWidgets[19368]
#define sipNameNr_setKeyboardSingleStep 19390
#define sipName_setKeyboardSingleStep &sipStrings_QtWidgets[19390]
#define sipNameNr_activateNextSubWindow 19412
#define sipName_activateNextSubWindow &sipStrings_QtWidgets[19412]
#define sipNameNr_QMdiArea__WindowOrder 19434
#define sipName_QMdiArea__WindowOrder &sipStrings_QtWidgets[19434]
#define sipNameNr_QMdiArea__AreaOptions 19456
#define sipName_QMdiArea__AreaOptions &sipStrings_QtWidgets[19456]
#define sipNameNr_setDockNestingEnabled 19478
#define sipName_setDockNestingEnabled &sipStrings_QtWidgets[19478]
#define sipNameNr_QListView__LayoutMode 19500
#define sipName_QListView__LayoutMode &sipStrings_QtWidgets[19500]
#define sipNameNr_QListView__ResizeMode 19522
#define sipName_QListView__ResizeMode &sipStrings_QtWidgets[19522]
#define sipNameNr_setClearButtonEnabled 19544
#define sipName_setClearButtonEnabled &sipStrings_QtWidgets[19544]
#define sipNameNr_closestAcceptableSize 19566
#define sipName_closestAcceptableSize &sipStrings_QtWidgets[19566]
#define sipNameNr_isFirstSectionMovable 19588
#define sipName_isFirstSectionMovable &sipStrings_QtWidgets[19588]
#define sipNameNr_setMaximumSectionSize 19610
#define sipName_setMaximumSectionSize &sipStrings_QtWidgets[19610]
#define sipNameNr_setMinimumSectionSize 19632
#define sipName_setMinimumSectionSize &sipStrings_QtWidgets[19632]
#define sipNameNr_setDefaultSectionSize 15321
#define sipName_setDefaultSectionSize &sipStrings_QtWidgets[15321]
#define sipNameNr_setStretchLastSection 19654
#define sipName_setStretchLastSection &sipStrings_QtWidgets[19654]
#define sipNameNr_setSortIndicatorShown 19676
#define sipName_setSortIndicatorShown &sipStrings_QtWidgets[19676]
#define sipNameNr_setDefaultPositioning 19698
#define sipName_setDefaultPositioning &sipStrings_QtWidgets[19698]
#define sipNameNr_setAutoFillBackground 19720
#define sipName_setAutoFillBackground &sipStrings_QtWidgets[19720]
#define sipNameNr_setShortcutAutoRepeat 19742
#define sipName_setShortcutAutoRepeat &sipStrings_QtWidgets[19742]
#define sipNameNr_getWindowFrameMargins 19764
#define sipName_getWindowFrameMargins &sipStrings_QtWidgets[19764]
#define sipNameNr_setWindowFrameMargins 15465
#define sipName_setWindowFrameMargins &sipStrings_QtWidgets[15465]
#define sipNameNr_setViewportUpdateMode 19786
#define sipName_setViewportUpdateMode &sipStrings_QtWidgets[19786]
#define sipNameNr_MinimalViewportUpdate 19808
#define sipName_MinimalViewportUpdate &sipStrings_QtWidgets[19808]
#define sipNameNr_QGraphicsLinearLayout 19830
#define sipName_QGraphicsLinearLayout &sipStrings_QtWidgets[19830]
#define sipNameNr_setTransformationMode 19852
#define sipName_setTransformationMode &sipStrings_QtWidgets[19852]
#define sipNameNr_setFiltersChildEvents 19874
#define sipName_setFiltersChildEvents &sipStrings_QtWidgets[19874]
#define sipNameNr_isBlockedByModalPanel 19896
#define sipName_isBlockedByModalPanel &sipStrings_QtWidgets[19896]
#define sipNameNr_prepareGeometryChange 19918
#define sipName_prepareGeometryChange &sipStrings_QtWidgets[19918]
#define sipNameNr_ItemOpacityHasChanged 19940
#define sipName_ItemOpacityHasChanged &sipStrings_QtWidgets[19940]
#define sipNameNr_ItemToolTipHasChanged 19962
#define sipName_ItemToolTipHasChanged &sipStrings_QtWidgets[19962]
#define sipNameNr_ItemEnabledHasChanged 19984
#define sipName_ItemEnabledHasChanged &sipStrings_QtWidgets[19984]
#define sipNameNr_ItemVisibleHasChanged 20006
#define sipName_ItemVisibleHasChanged &sipStrings_QtWidgets[20006]
#define sipNameNr_DeviceCoordinateCache 20028
#define sipName_DeviceCoordinateCache &sipStrings_QtWidgets[20028]
#define sipNameNr_setColumnMaximumWidth 20050
#define sipName_setColumnMaximumWidth &sipStrings_QtWidgets[20050]
#define sipNameNr_setColumnMinimumWidth 20072
#define sipName_setColumnMinimumWidth &sipStrings_QtWidgets[20072]
#define sipNameNr_setRowPreferredHeight 20094
#define sipName_setRowPreferredHeight &sipStrings_QtWidgets[20094]
#define sipNameNr_QGraphicsAnchorLayout 20116
#define sipName_QGraphicsAnchorLayout &sipStrings_QtWidgets[20116]
#define sipNameNr_setTotalRotationAngle 20138
#define sipName_setTotalRotationAngle &sipStrings_QtWidgets[20138]
#define sipNameNr_QFormLayout__ItemRole 20160
#define sipName_QFormLayout__ItemRole &sipStrings_QtWidgets[20160]
#define sipNameNr_AllNonFixedFieldsGrow 20182
#define sipName_AllNonFixedFieldsGrow &sipStrings_QtWidgets[20182]
#define sipNameNr_setNameFilterDisables 20204
#define sipName_setNameFilterDisables &sipStrings_QtWidgets[20204]
#define sipNameNr_HideNameFilterDetails 20226
#define sipName_HideNameFilterDetails &sipStrings_QtWidgets[20226]
#define sipNameNr_QFileDialog__FileMode 20248
#define sipName_QFileDialog__FileMode &sipStrings_QtWidgets[20248]
#define sipNameNr_QFileDialog__ViewMode 20270
#define sipName_QFileDialog__ViewMode &sipStrings_QtWidgets[20270]
#define sipNameNr_AllDockWidgetFeatures 20292
#define sipName_AllDockWidgetFeatures &sipStrings_QtWidgets[20292]
#define sipNameNr_hitTestComplexControl 20314
#define sipName_hitTestComplexControl &sipStrings_QtWidgets[20314]
#define sipNameNr_minimumContentsLength 20336
#define sipName_minimumContentsLength &sipStrings_QtWidgets[20336]
#define sipNameNr_setResizeGripsVisible 20358
#define sipName_setResizeGripsVisible &sipStrings_QtWidgets[20358]
#define sipNameNr_minimumHeightForWidth 20380
#define sipName_minimumHeightForWidth &sipStrings_QtWidgets[20380]
#define sipNameNr_QBoxLayout__Direction 20402
#define sipName_QBoxLayout__Direction &sipStrings_QtWidgets[20402]
#define sipNameNr_isGroupSeparatorShown 20424
#define sipName_isGroupSeparatorShown &sipStrings_QtWidgets[20424]
#define sipNameNr_CorrectToNearestValue 20446
#define sipName_CorrectToNearestValue &sipStrings_QtWidgets[20446]
#define sipNameNr_setInvertedAppearance 20468
#define sipName_setInvertedAppearance &sipStrings_QtWidgets[20468]
#define sipNameNr_itemDelegateForColumn 20490
#define sipName_itemDelegateForColumn &sipStrings_QtWidgets[20490]
#define sipNameNr_setItemDelegateForRow 20512
#define sipName_setItemDelegateForRow &sipStrings_QtWidgets[20512]
#define sipNameNr_dragDropOverwriteMode 20534
#define sipName_dragDropOverwriteMode &sipStrings_QtWidgets[20534]
#define sipNameNr_setVerticalScrollMode 16089
#define sipName_setVerticalScrollMode &sipStrings_QtWidgets[16089]
#define sipNameNr_dropIndicatorPosition 20556
#define sipName_dropIndicatorPosition &sipStrings_QtWidgets[20556]
#define sipNameNr_DropIndicatorPosition 1260
#define sipName_DropIndicatorPosition &sipStrings_QtWidgets[1260]
#define sipNameNr_closePersistentEditor 20578
#define sipName_closePersistentEditor &sipStrings_QtWidgets[20578]
#define sipNameNr_setDropIndicatorShown 20600
#define sipName_setDropIndicatorShown &sipStrings_QtWidgets[20600]
#define sipNameNr_QAbstractItemDelegate 20622
#define sipName_QAbstractItemDelegate &sipStrings_QtWidgets[20622]
#define sipNameNr_setAutoRepeatInterval 20644
#define sipName_setAutoRepeatInterval &sipStrings_QtWidgets[20644]
#define sipNameNr_mouseDoubleClickEvent 20666
#define sipName_mouseDoubleClickEvent &sipStrings_QtWidgets[20666]
#define sipNameNr_cursorPositionChanged 20688
#define sipName_cursorPositionChanged &sipStrings_QtWidgets[20688]
#define sipNameNr_keyboardInputInterval 20710
#define sipName_keyboardInputInterval &sipStrings_QtWidgets[20710]
#define sipNameNr_setVerticalHeaderItem 20732
#define sipName_setVerticalHeaderItem &sipStrings_QtWidgets[20732]
#define sipNameNr_QWizard__WizardStyle 20754
#define sipName_QWizard__WizardStyle &sipStrings_QtWidgets[20754]
#define sipNameNr_previousInFocusChain 20775
#define sipName_previousInFocusChain &sipStrings_QtWidgets[20775]
#define sipNameNr_QWidget__RenderFlags 20796
#define sipName_QWidget__RenderFlags &sipStrings_QtWidgets[20796]
#define sipNameNr_DrawWindowBackground 20817
#define sipName_DrawWindowBackground &sipStrings_QtWidgets[20817]
#define sipNameNr_setContextMenuPolicy 20838
#define sipName_setContextMenuPolicy &sipStrings_QtWidgets[20838]
#define sipNameNr_childIndicatorPolicy 20859
#define sipName_childIndicatorPolicy &sipStrings_QtWidgets[20859]
#define sipNameNr_ChildIndicatorPolicy 2167
#define sipName_ChildIndicatorPolicy &sipStrings_QtWidgets[2167]
#define sipNameNr_expandsOnDoubleClick 20880
#define sipName_expandsOnDoubleClick &sipStrings_QtWidgets[20880]
#define sipNameNr_isFirstColumnSpanned 20901
#define sipName_isFirstColumnSpanned &sipStrings_QtWidgets[20901]
#define sipNameNr_setUniformRowHeights 20922
#define sipName_setUniformRowHeights &sipStrings_QtWidgets[20922]
#define sipNameNr_backwardHistoryCount 20943
#define sipName_backwardHistoryCount &sipStrings_QtWidgets[20943]
#define sipNameNr_QTabWidget__TabShape 20964
#define sipName_QTabWidget__TabShape &sipStrings_QtWidgets[20964]
#define sipNameNr_resizeRowsToContents 20985
#define sipName_resizeRowsToContents &sipStrings_QtWidgets[20985]
#define sipNameNr_setUsesScrollButtons 21006
#define sipName_setUsesScrollButtons &sipStrings_QtWidgets[21006]
#define sipNameNr_QStyleOptionSizeGrip 21027
#define sipName_QStyleOptionSizeGrip &sipStrings_QtWidgets[21027]
#define sipNameNr_QStyleOptionGroupBox 21048
#define sipName_QStyleOptionGroupBox &sipStrings_QtWidgets[21048]
#define sipNameNr_QStyleHintReturnMask 21069
#define sipName_QStyleHintReturnMask &sipStrings_QtWidgets[21069]
#define sipNameNr_QStyleOptionTitleBar 21090
#define sipName_QStyleOptionTitleBar &sipStrings_QtWidgets[21090]
#define sipNameNr_QStyleOptionComboBox 21111
#define sipName_QStyleOptionComboBox &sipStrings_QtWidgets[21111]
#define sipNameNr_QStyleOptionViewItem 21132
#define sipName_QStyleOptionViewItem &sipStrings_QtWidgets[21132]
#define sipNameNr_QStyleOptionMenuItem 21153
#define sipName_QStyleOptionMenuItem &sipStrings_QtWidgets[21153]
#define sipNameNr_leftCornerWidgetSize 21174
#define sipName_leftCornerWidgetSize &sipStrings_QtWidgets[21174]
#define sipNameNr_SO_ComplexCustomBase 21195
#define sipName_SO_ComplexCustomBase &sipStrings_QtWidgets[21195]
#define sipNameNr_SP_DialogRetryButton 21216
#define sipName_SP_DialogRetryButton &sipStrings_QtWidgets[21216]
#define sipNameNr_SP_DialogAbortButton 21237
#define sipName_SP_DialogAbortButton &sipStrings_QtWidgets[21237]
#define sipNameNr_SP_MediaSeekBackward 21258
#define sipName_SP_MediaSeekBackward &sipStrings_QtWidgets[21258]
#define sipNameNr_SP_MediaSkipBackward 21279
#define sipName_SP_MediaSkipBackward &sipStrings_QtWidgets[21279]
#define sipNameNr_SP_DialogResetButton 21300
#define sipName_SP_DialogResetButton &sipStrings_QtWidgets[21300]
#define sipNameNr_SP_DialogApplyButton 21321
#define sipName_SP_DialogApplyButton &sipStrings_QtWidgets[21321]
#define sipNameNr_SP_DialogCloseButton 21342
#define sipName_SP_DialogCloseButton &sipStrings_QtWidgets[21342]
#define sipNameNr_SP_MessageBoxWarning 21363
#define sipName_SP_MessageBoxWarning &sipStrings_QtWidgets[21363]
#define sipNameNr_SP_TitleBarMaxButton 21384
#define sipName_SP_TitleBarMaxButton &sipStrings_QtWidgets[21384]
#define sipNameNr_SP_TitleBarMinButton 21405
#define sipName_SP_TitleBarMinButton &sipStrings_QtWidgets[21405]
#define sipNameNr_SH_UnderlineShortcut 21426
#define sipName_SH_UnderlineShortcut &sipStrings_QtWidgets[21426]
#define sipNameNr_SH_TitleBar_NoBorder 21447
#define sipName_SH_TitleBar_NoBorder &sipStrings_QtWidgets[21447]
#define sipNameNr_QStyle__ContentsType 21468
#define sipName_QStyle__ContentsType &sipStrings_QtWidgets[21468]
#define sipNameNr_PM_LayoutRightMargin 21489
#define sipName_PM_LayoutRightMargin &sipStrings_QtWidgets[21489]
#define sipNameNr_PM_FocusFrameHMargin 21510
#define sipName_PM_FocusFrameHMargin &sipStrings_QtWidgets[21510]
#define sipNameNr_PM_FocusFrameVMargin 21531
#define sipName_PM_FocusFrameVMargin &sipStrings_QtWidgets[21531]
#define sipNameNr_PM_ToolBarItemMargin 21552
#define sipName_PM_ToolBarItemMargin &sipStrings_QtWidgets[21552]
#define sipNameNr_PM_ToolBarFrameWidth 21573
#define sipName_PM_ToolBarFrameWidth &sipStrings_QtWidgets[21573]
#define sipNameNr_PM_MDIMinimizedWidth 21594
#define sipName_PM_MDIMinimizedWidth &sipStrings_QtWidgets[21594]
#define sipNameNr_PM_MenuBarPanelWidth 21615
#define sipName_PM_MenuBarPanelWidth &sipStrings_QtWidgets[21615]
#define sipNameNr_PM_MenuTearoffHeight 21636
#define sipName_PM_MenuTearoffHeight &sipStrings_QtWidgets[21636]
#define sipNameNr_PM_TabBarBaseOverlap 21657
#define sipName_PM_TabBarBaseOverlap &sipStrings_QtWidgets[21657]
#define sipNameNr_PM_SpinBoxFrameWidth 21678
#define sipName_PM_SpinBoxFrameWidth &sipStrings_QtWidgets[21678]
#define sipNameNr_PM_DefaultFrameWidth 21699
#define sipName_PM_DefaultFrameWidth &sipStrings_QtWidgets[21699]
#define sipNameNr_SC_TitleBarMaxButton 21720
#define sipName_SC_TitleBarMaxButton &sipStrings_QtWidgets[21720]
#define sipNameNr_SC_TitleBarMinButton 21741
#define sipName_SC_TitleBarMinButton &sipStrings_QtWidgets[21741]
#define sipNameNr_SC_ComboBoxEditField 21762
#define sipName_SC_ComboBoxEditField &sipStrings_QtWidgets[21762]
#define sipNameNr_SE_SpinBoxLayoutItem 21783
#define sipName_SE_SpinBoxLayoutItem &sipStrings_QtWidgets[21783]
#define sipNameNr_SE_ProgressBarGroove 21804
#define sipName_SE_ProgressBarGroove &sipStrings_QtWidgets[21804]
#define sipNameNr_SE_ComboBoxFocusRect 21825
#define sipName_SE_ComboBoxFocusRect &sipStrings_QtWidgets[21825]
#define sipNameNr_SE_CheckBoxClickRect 21846
#define sipName_SE_CheckBoxClickRect &sipStrings_QtWidgets[21846]
#define sipNameNr_SE_CheckBoxFocusRect 21867
#define sipName_SE_CheckBoxFocusRect &sipStrings_QtWidgets[21867]
#define sipNameNr_SE_CheckBoxIndicator 21888
#define sipName_SE_CheckBoxIndicator &sipStrings_QtWidgets[21888]
#define sipNameNr_CE_ProgressBarGroove 21909
#define sipName_CE_ProgressBarGroove &sipStrings_QtWidgets[21909]
#define sipNameNr_PE_IndicatorTabClose 21930
#define sipName_PE_IndicatorTabClose &sipStrings_QtWidgets[21930]
#define sipNameNr_PE_PanelItemViewItem 21951
#define sipName_PE_PanelItemViewItem &sipStrings_QtWidgets[21951]
#define sipNameNr_PE_IndicatorSpinPlus 21972
#define sipName_PE_IndicatorSpinPlus &sipStrings_QtWidgets[21972]
#define sipNameNr_PE_IndicatorSpinDown 21993
#define sipName_PE_IndicatorSpinDown &sipStrings_QtWidgets[21993]
#define sipNameNr_PE_IndicatorCheckBox 22014
#define sipName_PE_IndicatorCheckBox &sipStrings_QtWidgets[22014]
#define sipNameNr_closestLegalPosition 22035
#define sipName_closestLegalPosition &sipStrings_QtWidgets[22035]
#define sipNameNr_retainSizeWhenHidden 22056
#define sipName_retainSizeWhenHidden &sipStrings_QtWidgets[22056]
#define sipNameNr_setHorizontalStretch 22077
#define sipName_setHorizontalStretch &sipStrings_QtWidgets[22077]
#define sipNameNr_activatedAmbiguously 22098
#define sipName_activatedAmbiguously &sipStrings_QtWidgets[22098]
#define sipNameNr_MousePressEventDelay 22119
#define sipName_MousePressEventDelay &sipStrings_QtWidgets[22119]
#define sipNameNr_setBackgroundVisible 22140
#define sipName_setBackgroundVisible &sipStrings_QtWidgets[22140]
#define sipNameNr_setCurrentCharFormat 22161
#define sipName_setCurrentCharFormat &sipStrings_QtWidgets[22161]
#define sipNameNr_isTearOffMenuVisible 22182
#define sipName_isTearOffMenuVisible &sipStrings_QtWidgets[22182]
#define sipNameNr_closeActiveSubWindow 22203
#define sipName_closeActiveSubWindow &sipStrings_QtWidgets[22203]
#define sipNameNr_QMdiArea__AreaOption 22224
#define sipName_QMdiArea__AreaOption &sipStrings_QtWidgets[22224]
#define sipNameNr_isDockNestingEnabled 22245
#define sipName_isDockNestingEnabled &sipStrings_QtWidgets[22245]
#define sipNameNr_itemSelectionChanged 22266
#define sipName_itemSelectionChanged &sipStrings_QtWidgets[22266]
#define sipNameNr_isClearButtonEnabled 22287
#define sipName_isClearButtonEnabled &sipStrings_QtWidgets[22287]
#define sipNameNr_setSmallDecimalPoint 22308
#define sipName_setSmallDecimalPoint &sipStrings_QtWidgets[22308]
#define sipNameNr_SetDefaultConstraint 22329
#define sipName_SetDefaultConstraint &sipStrings_QtWidgets[22329]
#define sipNameNr_setItemEditorFactory 22350
#define sipName_setItemEditorFactory &sipStrings_QtWidgets[22350]
#define sipNameNr_setSectionResizeMode 22371
#define sipName_setSectionResizeMode &sipStrings_QtWidgets[22371]
#define sipNameNr_setSectionsClickable 22392
#define sipName_setSectionsClickable &sipStrings_QtWidgets[22392]
#define sipNameNr_sortIndicatorChanged 22413
#define sipName_sortIndicatorChanged &sipStrings_QtWidgets[22413]
#define sipNameNr_sectionDoubleClicked 22434
#define sipName_sectionDoubleClicked &sipStrings_QtWidgets[22434]
#define sipNameNr_sortIndicatorSection 22455
#define sipName_sortIndicatorSection &sipStrings_QtWidgets[22455]
#define sipNameNr_isSortIndicatorShown 22476
#define sipName_isSortIndicatorShown &sipStrings_QtWidgets[22476]
#define sipNameNr_setHighlightSections 22497
#define sipName_setHighlightSections &sipStrings_QtWidgets[22497]
#define sipNameNr_windowFrameSectionAt 22518
#define sipName_windowFrameSectionAt &sipStrings_QtWidgets[22518]
#define sipNameNr_unsetLayoutDirection 22539
#define sipName_unsetLayoutDirection &sipStrings_QtWidgets[22539]
#define sipNameNr_setOptimizationFlags 22560
#define sipName_setOptimizationFlags &sipStrings_QtWidgets[22560]
#define sipNameNr_DontSavePainterState 22581
#define sipName_DontSavePainterState &sipStrings_QtWidgets[22581]
#define sipNameNr_transformationAnchor 22602
#define sipName_transformationAnchor &sipStrings_QtWidgets[22602]
#define sipNameNr_setMinimumRenderSize 22623
#define sipName_setMinimumRenderSize &sipStrings_QtWidgets[22623]
#define sipNameNr_QGraphicsProxyWidget 22644
#define sipName_QGraphicsProxyWidget &sipStrings_QtWidgets[22644]
#define sipNameNr_setOpenExternalLinks 22665
#define sipName_setOpenExternalLinks &sipStrings_QtWidgets[22665]
#define sipNameNr_textInteractionFlags 22686
#define sipName_textInteractionFlags &sipStrings_QtWidgets[22686]
#define sipNameNr_QGraphicsPolygonItem 22707
#define sipName_QGraphicsPolygonItem &sipStrings_QtWidgets[22707]
#define sipNameNr_QGraphicsEllipseItem 22728
#define sipName_QGraphicsEllipseItem &sipStrings_QtWidgets[22728]
#define sipNameNr_transformOriginPoint 22749
#define sipName_transformOriginPoint &sipStrings_QtWidgets[22749]
#define sipNameNr_setAcceptTouchEvents 22770
#define sipName_setAcceptTouchEvents &sipStrings_QtWidgets[22770]
#define sipNameNr_setAcceptHoverEvents 22791
#define sipName_setAcceptHoverEvents &sipStrings_QtWidgets[22791]
#define sipNameNr_childrenBoundingRect 22812
#define sipName_childrenBoundingRect &sipStrings_QtWidgets[22812]
#define sipNameNr_acceptedMouseButtons 22833
#define sipName_acceptedMouseButtons &sipStrings_QtWidgets[22833]
#define sipNameNr_ItemZValueHasChanged 22854
#define sipName_ItemZValueHasChanged &sipStrings_QtWidgets[22854]
#define sipNameNr_ItemFlagsHaveChanged 22875
#define sipName_ItemFlagsHaveChanged &sipStrings_QtWidgets[22875]
#define sipNameNr_ItemCursorHasChanged 22896
#define sipName_ItemCursorHasChanged &sipStrings_QtWidgets[22896]
#define sipNameNr_ItemParentHasChanged 22917
#define sipName_ItemParentHasChanged &sipStrings_QtWidgets[22917]
#define sipNameNr_ItemChildAddedChange 22938
#define sipName_ItemChildAddedChange &sipStrings_QtWidgets[22938]
#define sipNameNr_columnPreferredWidth 22959
#define sipName_columnPreferredWidth &sipStrings_QtWidgets[22959]
#define sipNameNr_unregisterRecognizer 22980
#define sipName_unregisterRecognizer &sipStrings_QtWidgets[22980]
#define sipNameNr_setLastRotationAngle 23001
#define sipName_setLastRotationAngle &sipStrings_QtWidgets[23001]
#define sipNameNr_RotationAngleChanged 23022
#define sipName_RotationAngleChanged &sipStrings_QtWidgets[23022]
#define sipNameNr_setHorizontalSpacing 23043
#define sipName_setHorizontalSpacing &sipStrings_QtWidgets[23043]
#define sipNameNr_setFieldGrowthPolicy 23064
#define sipName_setFieldGrowthPolicy &sipStrings_QtWidgets[23064]
#define sipNameNr_FieldsStayAtSizeHint 23085
#define sipName_FieldsStayAtSizeHint &sipStrings_QtWidgets[23085]
#define sipNameNr_selectMimeTypeFilter 23106
#define sipName_selectMimeTypeFilter &sipStrings_QtWidgets[23106]
#define sipNameNr_getExistingDirectory 23127
#define sipName_getExistingDirectory &sipStrings_QtWidgets[23127]
#define sipNameNr_QFileDialog__Options 23148
#define sipName_QFileDialog__Options &sipStrings_QtWidgets[23148]
#define sipNameNr_DontConfirmOverwrite 23169
#define sipName_DontConfirmOverwrite &sipStrings_QtWidgets[23169]
#define sipNameNr_NoDockWidgetFeatures 23190
#define sipName_NoDockWidgetFeatures &sipStrings_QtWidgets[23190]
#define sipNameNr_clearMaximumDateTime 23211
#define sipName_clearMaximumDateTime &sipStrings_QtWidgets[23211]
#define sipNameNr_clearMinimumDateTime 23232
#define sipName_clearMinimumDateTime &sipStrings_QtWidgets[23232]
#define sipNameNr_setCurrentModelIndex 23253
#define sipName_setCurrentModelIndex &sipStrings_QtWidgets[23253]
#define sipNameNr_InsertAlphabetically 23274
#define sipName_InsertAlphabetically &sipStrings_QtWidgets[23274]
#define sipNameNr_setDuplicatesEnabled 23295
#define sipName_setDuplicatesEnabled &sipStrings_QtWidgets[23295]
#define sipNameNr_setWeekdayTextFormat 23316
#define sipName_setWeekdayTextFormat &sipStrings_QtWidgets[23316]
#define sipNameNr_verticalHeaderFormat 23337
#define sipName_verticalHeaderFormat &sipStrings_QtWidgets[23337]
#define sipNameNr_VerticalHeaderFormat 2813
#define sipName_VerticalHeaderFormat &sipStrings_QtWidgets[2813]
#define sipNameNr_SingleLetterDayNames 23358
#define sipName_SingleLetterDayNames &sipStrings_QtWidgets[23358]
#define sipNameNr_setStartDragDistance 23379
#define sipName_setStartDragDistance &sipStrings_QtWidgets[23379]
#define sipNameNr_setIconVisibleInMenu 23400
#define sipName_setIconVisibleInMenu &sipStrings_QtWidgets[23400]
#define sipNameNr_QAction__ActionEvent 23421
#define sipName_QAction__ActionEvent &sipStrings_QtWidgets[23421]
#define sipNameNr_setVerticalScrollBar 23442
#define sipName_setVerticalScrollBar &sipStrings_QtWidgets[23442]
#define sipNameNr_setDefaultDropAction 23463
#define sipName_setDefaultDropAction &sipStrings_QtWidgets[23463]
#define sipNameNr_horizontalScrollMode 23484
#define sipName_horizontalScrollMode &sipStrings_QtWidgets[23484]
#define sipNameNr_openPersistentEditor 23505
#define sipName_openPersistentEditor &sipStrings_QtWidgets[23505]
#define sipNameNr_alternatingRowColors 23526
#define sipName_alternatingRowColors &sipStrings_QtWidgets[23526]
#define sipNameNr_setSelectionBehavior 23547
#define sipName_setSelectionBehavior &sipStrings_QtWidgets[23547]
#define sipNameNr_updateEditorGeometry 23568
#define sipName_updateEditorGeometry &sipStrings_QtWidgets[23568]
#define sipNameNr_setMaximumBlockCount 23589
#define sipName_setMaximumBlockCount &sipStrings_QtWidgets[23589]
#define sipNameNr_horizontalHeaderItem 23610
#define sipName_horizontalHeaderItem &sipStrings_QtWidgets[23610]
#define sipNameNr_primaryScreenChanged 23631
#define sipName_primaryScreenChanged &sipStrings_QtWidgets[23631]
#define sipNameNr_acceptProposedAction 23652
#define sipName_acceptProposedAction &sipStrings_QtWidgets[23652]
#define sipNameNr_positionInlineObject 23673
#define sipName_positionInlineObject &sipStrings_QtWidgets[23673]
#define sipNameNr_supportedDragActions 23694
#define sipName_supportedDragActions &sipStrings_QtWidgets[23694]
#define sipNameNr_rowsAboutToBeRemoved 23715
#define sipName_rowsAboutToBeRemoved &sipStrings_QtWidgets[23715]
#define sipNameNr_supportedDropActions 23736
#define sipName_supportedDropActions &sipStrings_QtWidgets[23736]
#define sipNameNr_23757 23757
#define sipName_23757 &sipStrings_QtWidgets[23757]
#define sipNameNr_customButtonClicked 23777
#define sipName_customButtonClicked &sipStrings_QtWidgets[23777]
#define sipNameNr_validateCurrentPage 23797
#define sipName_validateCurrentPage &sipStrings_QtWidgets[23797]
#define sipNameNr_graphicsProxyWidget 23817
#define sipName_graphicsProxyWidget &sipStrings_QtWidgets[23817]
#define sipNameNr_QWidget__RenderFlag 23837
#define sipName_QWidget__RenderFlag &sipStrings_QtWidgets[23837]
#define sipNameNr_overrideWindowFlags 23857
#define sipName_overrideWindowFlags &sipStrings_QtWidgets[23857]
#define sipNameNr_overrideWindowState 23877
#define sipName_overrideWindowState &sipStrings_QtWidgets[23877]
#define sipNameNr_insertTopLevelItems 23897
#define sipName_insertTopLevelItems &sipStrings_QtWidgets[23897]
#define sipNameNr_indexOfTopLevelItem 23917
#define sipName_indexOfTopLevelItem &sipStrings_QtWidgets[23917]
#define sipNameNr_allColumnsShowFocus 23937
#define sipName_allColumnsShowFocus &sipStrings_QtWidgets[23937]
#define sipNameNr_ToolButtonPopupMode 4827
#define sipName_ToolButtonPopupMode &sipStrings_QtWidgets[4827]
#define sipNameNr_textBackgroundColor 23957
#define sipName_textBackgroundColor &sipStrings_QtWidgets[23957]
#define sipNameNr_forwardHistoryCount 23977
#define sipName_forwardHistoryCount &sipStrings_QtWidgets[23977]
#define sipNameNr_isBackwardAvailable 23997
#define sipName_isBackwardAvailable &sipStrings_QtWidgets[23997]
#define sipNameNr_resizeRowToContents 24017
#define sipName_resizeRowToContents &sipStrings_QtWidgets[24017]
#define sipNameNr_rowViewportPosition 24037
#define sipName_rowViewportPosition &sipStrings_QtWidgets[24037]
#define sipNameNr_setHorizontalHeader 24057
#define sipName_setHorizontalHeader &sipStrings_QtWidgets[24057]
#define sipNameNr_changeCurrentOnDrag 24077
#define sipName_changeCurrentOnDrag &sipStrings_QtWidgets[24077]
#define sipNameNr_tabBarDoubleClicked 24097
#define sipName_tabBarDoubleClicked &sipStrings_QtWidgets[24097]
#define sipNameNr_QStyleOptionToolBar 24117
#define sipName_QStyleOptionToolBar &sipStrings_QtWidgets[24117]
#define sipNameNr_QStyleOptionSpinBox 24137
#define sipName_QStyleOptionSpinBox &sipStrings_QtWidgets[24137]
#define sipNameNr_QStyleOptionComplex 24157
#define sipName_QStyleOptionComplex &sipStrings_QtWidgets[24157]
#define sipNameNr_QStyleOptionToolBox 24177
#define sipName_QStyleOptionToolBox &sipStrings_QtWidgets[24177]
#define sipNameNr_decorationAlignment 24197
#define sipName_decorationAlignment &sipStrings_QtWidgets[24197]
#define sipNameNr_QStyledItemDelegate 24217
#define sipName_QStyledItemDelegate &sipStrings_QtWidgets[24217]
#define sipNameNr_SP_MediaVolumeMuted 24237
#define sipName_SP_MediaVolumeMuted &sipStrings_QtWidgets[24237]
#define sipNameNr_SP_MediaSeekForward 24257
#define sipName_SP_MediaSeekForward &sipStrings_QtWidgets[24257]
#define sipNameNr_SP_MediaSkipForward 24277
#define sipName_SP_MediaSkipForward &sipStrings_QtWidgets[24277]
#define sipNameNr_SP_DialogSaveButton 24297
#define sipName_SP_DialogSaveButton &sipStrings_QtWidgets[24297]
#define sipNameNr_SP_DialogOpenButton 24317
#define sipName_SP_DialogOpenButton &sipStrings_QtWidgets[24317]
#define sipNameNr_SP_DialogHelpButton 24337
#define sipName_SP_DialogHelpButton &sipStrings_QtWidgets[24337]
#define sipNameNr_SH_TabBar_ElideMode 24357
#define sipName_SH_TabBar_ElideMode &sipStrings_QtWidgets[24357]
#define sipNameNr_SH_WindowFrame_Mask 24377
#define sipName_SH_WindowFrame_Mask &sipStrings_QtWidgets[24377]
#define sipNameNr_SH_TabBar_Alignment 24397
#define sipName_SH_TabBar_Alignment &sipStrings_QtWidgets[24397]
#define sipNameNr_SH_EtchDisabledText 24417
#define sipName_SH_EtchDisabledText &sipStrings_QtWidgets[24417]
#define sipNameNr_PM_LayoutLeftMargin 24437
#define sipName_PM_LayoutLeftMargin &sipStrings_QtWidgets[24437]
#define sipNameNr_PM_IconViewIconSize 24457
#define sipName_PM_IconViewIconSize &sipStrings_QtWidgets[24457]
#define sipNameNr_PM_ListViewIconSize 24477
#define sipName_PM_ListViewIconSize &sipStrings_QtWidgets[24477]
#define sipNameNr_PM_HeaderGripMargin 24497
#define sipName_PM_HeaderGripMargin &sipStrings_QtWidgets[24497]
#define sipNameNr_PM_TabBarBaseHeight 24517
#define sipName_PM_TabBarBaseHeight &sipStrings_QtWidgets[24517]
#define sipNameNr_PM_TabBarTabOverlap 24537
#define sipName_PM_TabBarTabOverlap &sipStrings_QtWidgets[24537]
#define sipNameNr_QStyle__PixelMetric 24557
#define sipName_QStyle__PixelMetric &sipStrings_QtWidgets[24557]
#define sipNameNr_QStyle__SubControls 24577
#define sipName_QStyle__SubControls &sipStrings_QtWidgets[24577]
#define sipNameNr_SC_GroupBoxContents 24597
#define sipName_SC_GroupBoxContents &sipStrings_QtWidgets[24597]
#define sipNameNr_SC_GroupBoxCheckBox 24617
#define sipName_SC_GroupBoxCheckBox &sipStrings_QtWidgets[24617]
#define sipNameNr_SC_SpinBoxEditField 24637
#define sipName_SC_SpinBoxEditField &sipStrings_QtWidgets[24637]
#define sipNameNr_SC_ScrollBarSubPage 24657
#define sipName_SC_ScrollBarSubPage &sipStrings_QtWidgets[24657]
#define sipNameNr_SC_ScrollBarAddPage 24677
#define sipName_SC_ScrollBarAddPage &sipStrings_QtWidgets[24677]
#define sipNameNr_SC_ScrollBarSubLine 24697
#define sipName_SC_ScrollBarSubLine &sipStrings_QtWidgets[24697]
#define sipNameNr_SC_ScrollBarAddLine 24717
#define sipName_SC_ScrollBarAddLine &sipStrings_QtWidgets[24717]
#define sipNameNr_SE_ItemViewItemText 24737
#define sipName_SE_ItemViewItemText &sipStrings_QtWidgets[24737]
#define sipNameNr_SE_SliderLayoutItem 24757
#define sipName_SE_SliderLayoutItem &sipStrings_QtWidgets[24757]
#define sipNameNr_SE_LineEditContents 24777
#define sipName_SE_LineEditContents &sipStrings_QtWidgets[24777]
#define sipNameNr_SE_TabWidgetTabPane 24797
#define sipName_SE_TabWidgetTabPane &sipStrings_QtWidgets[24797]
#define sipNameNr_SE_ProgressBarLabel 24817
#define sipName_SE_ProgressBarLabel &sipStrings_QtWidgets[24817]
#define sipNameNr_SE_CheckBoxContents 24837
#define sipName_SE_CheckBoxContents &sipStrings_QtWidgets[24837]
#define sipNameNr_CE_ScrollBarSubPage 24857
#define sipName_CE_ScrollBarSubPage &sipStrings_QtWidgets[24857]
#define sipNameNr_CE_ScrollBarAddPage 24877
#define sipName_CE_ScrollBarAddPage &sipStrings_QtWidgets[24877]
#define sipNameNr_CE_ScrollBarSubLine 24897
#define sipName_CE_ScrollBarSubLine &sipStrings_QtWidgets[24897]
#define sipNameNr_CE_ScrollBarAddLine 24917
#define sipName_CE_ScrollBarAddLine &sipStrings_QtWidgets[24917]
#define sipNameNr_CE_MenuBarEmptyArea 24937
#define sipName_CE_MenuBarEmptyArea &sipStrings_QtWidgets[24937]
#define sipNameNr_CE_ProgressBarLabel 24957
#define sipName_CE_ProgressBarLabel &sipStrings_QtWidgets[24957]
#define sipNameNr_CE_RadioButtonLabel 24977
#define sipName_CE_RadioButtonLabel &sipStrings_QtWidgets[24977]
#define sipNameNr_PE_PanelItemViewRow 24997
#define sipName_PE_PanelItemViewRow &sipStrings_QtWidgets[24997]
#define sipNameNr_PE_IndicatorTabTear 25017
#define sipName_PE_IndicatorTabTear &sipStrings_QtWidgets[25017]
#define sipNameNr_PE_IndicatorArrowUp 25037
#define sipName_PE_IndicatorArrowUp &sipStrings_QtWidgets[25037]
#define sipNameNr_PE_PanelButtonBevel 25057
#define sipName_PE_PanelButtonBevel &sipStrings_QtWidgets[25057]
#define sipNameNr_PE_FrameButtonBevel 25077
#define sipName_PE_FrameButtonBevel &sipStrings_QtWidgets[25077]
#define sipNameNr_State_FocusAtBorder 25097
#define sipName_State_FocusAtBorder &sipStrings_QtWidgets[25097]
#define sipNameNr_childrenCollapsible 25117
#define sipName_childrenCollapsible &sipStrings_QtWidgets[25117]
#define sipNameNr_setHorizontalPolicy 25137
#define sipName_setHorizontalPolicy &sipStrings_QtWidgets[25137]
#define sipNameNr_QSizePolicy__Policy 25157
#define sipName_QSizePolicy__Policy &sipStrings_QtWidgets[25157]
#define sipNameNr_OvershootScrollTime 25177
#define sipName_OvershootScrollTime &sipStrings_QtWidgets[25177]
#define sipNameNr_QScrollerProperties 25197
#define sipName_QScrollerProperties &sipStrings_QtWidgets[25197]
#define sipNameNr_ScrollerGestureType 6587
#define sipName_ScrollerGestureType &sipStrings_QtWidgets[6587]
#define sipNameNr_ensureWidgetVisible 25217
#define sipName_ensureWidgetVisible &sipStrings_QtWidgets[25217]
#define sipNameNr_ensureCursorVisible 25237
#define sipName_ensureCursorVisible &sipStrings_QtWidgets[25237]
#define sipNameNr_setKeyboardPageStep 25257
#define sipName_setKeyboardPageStep &sipStrings_QtWidgets[25257]
#define sipNameNr_tabifiedDockWidgets 25277
#define sipName_tabifiedDockWidgets &sipStrings_QtWidgets[25277]
#define sipNameNr_setPositionForIndex 25297
#define sipName_setPositionForIndex &sipStrings_QtWidgets[25297]
#define sipNameNr_setUniformItemSizes 25317
#define sipName_setUniformItemSizes &sipStrings_QtWidgets[25317]
#define sipNameNr_QListView__ViewMode 25337
#define sipName_QListView__ViewMode &sipStrings_QtWidgets[25337]
#define sipNameNr_QListView__Movement 25357
#define sipName_QListView__Movement &sipStrings_QtWidgets[25357]
#define sipNameNr_QLineEdit__EchoMode 25377
#define sipName_QLineEdit__EchoMode &sipStrings_QtWidgets[25377]
#define sipNameNr_totalHeightForWidth 25397
#define sipName_totalHeightForWidth &sipStrings_QtWidgets[25397]
#define sipNameNr_QKeyEventTransition 25417
#define sipName_QKeyEventTransition &sipStrings_QtWidgets[25417]
#define sipNameNr_doubleValueSelected 25437
#define sipName_doubleValueSelected &sipStrings_QtWidgets[25437]
#define sipNameNr_setCancelButtonText 25457
#define sipName_setCancelButtonText &sipStrings_QtWidgets[25457]
#define sipNameNr_setComboBoxEditable 25477
#define sipName_setComboBoxEditable &sipStrings_QtWidgets[25477]
#define sipNameNr_setDefaultAlignment 25497
#define sipName_setDefaultAlignment &sipStrings_QtWidgets[25497]
#define sipNameNr_sectionCountChanged 25517
#define sipName_sectionCountChanged &sipStrings_QtWidgets[25517]
#define sipNameNr_stretchSectionCount 25537
#define sipName_stretchSectionCount &sipStrings_QtWidgets[25537]
#define sipNameNr_ungrabKeyboardEvent 25557
#define sipName_ungrabKeyboardEvent &sipStrings_QtWidgets[25557]
#define sipNameNr_windowFrameGeometry 25577
#define sipName_windowFrameGeometry &sipStrings_QtWidgets[25577]
#define sipNameNr_setOptimizationFlag 25597
#define sipName_setOptimizationFlag &sipStrings_QtWidgets[25597]
#define sipNameNr_SmartViewportUpdate 25617
#define sipName_SmartViewportUpdate &sipStrings_QtWidgets[25617]
#define sipNameNr_buttonDownScreenPos 25637
#define sipName_buttonDownScreenPos &sipStrings_QtWidgets[25637]
#define sipNameNr_QGraphicsSceneEvent 25657
#define sipName_QGraphicsSceneEvent &sipStrings_QtWidgets[25657]
#define sipNameNr_setParentLayoutItem 25677
#define sipName_setParentLayoutItem &sipStrings_QtWidgets[25677]
#define sipNameNr_QGraphicsLayoutItem 25697
#define sipName_QGraphicsLayoutItem &sipStrings_QtWidgets[25697]
#define sipNameNr_setDefaultTextColor 25717
#define sipName_setDefaultTextColor &sipStrings_QtWidgets[25717]
#define sipNameNr_QGraphicsPixmapItem 25737
#define sipName_QGraphicsPixmapItem &sipStrings_QtWidgets[25737]
#define sipNameNr_setInputMethodHints 25757
#define sipName_setInputMethodHints &sipStrings_QtWidgets[25757]
#define sipNameNr_ItemScaleHasChanged 25777
#define sipName_ItemScaleHasChanged &sipStrings_QtWidgets[25777]
#define sipNameNr_ItemSceneHasChanged 25797
#define sipName_ItemSceneHasChanged &sipStrings_QtWidgets[25797]
#define sipNameNr_ItemTransformChange 25817
#define sipName_ItemTransformChange &sipStrings_QtWidgets[25817]
#define sipNameNr_ItemCoordinateCache 25837
#define sipName_ItemCoordinateCache &sipStrings_QtWidgets[25837]
#define sipNameNr_setColumnFixedWidth 25857
#define sipName_setColumnFixedWidth &sipStrings_QtWidgets[25857]
#define sipNameNr_setRowMaximumHeight 25877
#define sipName_setRowMaximumHeight &sipStrings_QtWidgets[25877]
#define sipNameNr_setRowMinimumHeight 25897
#define sipName_setRowMinimumHeight &sipStrings_QtWidgets[25897]
#define sipNameNr_columnStretchFactor 25917
#define sipName_columnStretchFactor &sipStrings_QtWidgets[25917]
#define sipNameNr_setRowStretchFactor 25937
#define sipName_setRowStretchFactor &sipStrings_QtWidgets[25937]
#define sipNameNr_QGraphicsGridLayout 25957
#define sipName_QGraphicsGridLayout &sipStrings_QtWidgets[25957]
#define sipNameNr_QGraphicsBlurEffect 25977
#define sipName_QGraphicsBlurEffect &sipStrings_QtWidgets[25977]
#define sipNameNr_horizontalDirection 25997
#define sipName_horizontalDirection &sipStrings_QtWidgets[25997]
#define sipNameNr_setTotalScaleFactor 26017
#define sipName_setTotalScaleFactor &sipStrings_QtWidgets[26017]
#define sipNameNr_setStartCenterPoint 26037
#define sipName_setStartCenterPoint &sipStrings_QtWidgets[26037]
#define sipNameNr_setTotalChangeFlags 26057
#define sipName_setTotalChangeFlags &sipStrings_QtWidgets[26057]
#define sipNameNr_gestureCancelPolicy 26077
#define sipName_gestureCancelPolicy &sipStrings_QtWidgets[26077]
#define sipNameNr_GestureCancelPolicy 7712
#define sipName_GestureCancelPolicy &sipStrings_QtWidgets[7712]
#define sipNameNr_ExpandingFieldsGrow 26097
#define sipName_ExpandingFieldsGrow &sipStrings_QtWidgets[26097]
#define sipNameNr_DontWatchForChanges 26117
#define sipName_DontWatchForChanges &sipStrings_QtWidgets[26117]
#define sipNameNr_setSupportedSchemes 26137
#define sipName_setSupportedSchemes &sipStrings_QtWidgets[26137]
#define sipNameNr_directoryUrlEntered 26157
#define sipName_directoryUrlEntered &sipStrings_QtWidgets[26157]
#define sipNameNr_DontResolveSymlinks 26177
#define sipName_DontResolveSymlinks &sipStrings_QtWidgets[26177]
#define sipNameNr_QFileDialog__Option 26197
#define sipName_QFileDialog__Option &sipStrings_QtWidgets[26197]
#define sipNameNr_dockLocationChanged 26217
#define sipName_dockLocationChanged &sipStrings_QtWidgets[26217]
#define sipNameNr_allowedAreasChanged 26237
#define sipName_allowedAreasChanged &sipStrings_QtWidgets[26237]
#define sipNameNr_DockWidgetFloatable 26257
#define sipName_DockWidgetFloatable &sipStrings_QtWidgets[26257]
#define sipNameNr_QDialog__DialogCode 26277
#define sipName_QDialog__DialogCode &sipStrings_QtWidgets[26277]
#define sipNameNr_currentSectionIndex 26297
#define sipName_currentSectionIndex &sipStrings_QtWidgets[26297]
#define sipNameNr_setCompletionPrefix 26317
#define sipName_setCompletionPrefix &sipStrings_QtWidgets[26317]
#define sipNameNr_setCompletionColumn 26337
#define sipName_setCompletionColumn &sipStrings_QtWidgets[26337]
#define sipNameNr_generatedIconPixmap 26357
#define sipName_generatedIconPixmap &sipStrings_QtWidgets[26357]
#define sipNameNr_currentIndexChanged 26377
#define sipName_currentIndexChanged &sipStrings_QtWidgets[26377]
#define sipNameNr_InsertBeforeCurrent 26397
#define sipName_InsertBeforeCurrent &sipStrings_QtWidgets[26397]
#define sipNameNr_updatePreviewWidget 26417
#define sipName_updatePreviewWidget &sipStrings_QtWidgets[26417]
#define sipNameNr_currentColorChanged 26437
#define sipName_currentColorChanged &sipStrings_QtWidgets[26437]
#define sipNameNr_DontUseNativeDialog 26457
#define sipName_DontUseNativeDialog &sipStrings_QtWidgets[26457]
#define sipNameNr_dateEditAcceptDelay 26477
#define sipName_dateEditAcceptDelay &sipStrings_QtWidgets[26477]
#define sipNameNr_setHeaderTextFormat 26497
#define sipName_setHeaderTextFormat &sipStrings_QtWidgets[26497]
#define sipNameNr_expandingDirections 26517
#define sipName_expandingDirections &sipStrings_QtWidgets[26517]
#define sipNameNr_setWheelScrollLines 26537
#define sipName_setWheelScrollLines &sipStrings_QtWidgets[26537]
#define sipNameNr_doubleClickInterval 26557
#define sipName_doubleClickInterval &sipStrings_QtWidgets[26557]
#define sipNameNr_isIconVisibleInMenu 26577
#define sipName_isIconVisibleInMenu &sipStrings_QtWidgets[26577]
#define sipNameNr_setKeyboardTracking 26597
#define sipName_setKeyboardTracking &sipStrings_QtWidgets[26597]
#define sipNameNr_setSpecialValueText 26617
#define sipName_setSpecialValueText &sipStrings_QtWidgets[26617]
#define sipNameNr_SliderSingleStepSub 26637
#define sipName_SliderSingleStepSub &sipStrings_QtWidgets[26637]
#define sipNameNr_SliderSingleStepAdd 26657
#define sipName_SliderSingleStepAdd &sipStrings_QtWidgets[26657]
#define sipNameNr_setInvertedControls 26677
#define sipName_setInvertedControls &sipStrings_QtWidgets[26677]
#define sipNameNr_setSizeAdjustPolicy 26697
#define sipName_setSizeAdjustPolicy &sipStrings_QtWidgets[26697]
#define sipNameNr_maximumViewportSize 26717
#define sipName_maximumViewportSize &sipStrings_QtWidgets[26717]
#define sipNameNr_horizontalScrollBar 26737
#define sipName_horizontalScrollBar &sipStrings_QtWidgets[26737]
#define sipNameNr_setAutoScrollMargin 26757
#define sipName_setAutoScrollMargin &sipStrings_QtWidgets[26757]
#define sipNameNr_setTabKeyNavigation 26777
#define sipName_setTabKeyNavigation &sipStrings_QtWidgets[26777]
#define sipNameNr_ContiguousSelection 26797
#define sipName_ContiguousSelection &sipStrings_QtWidgets[26797]
#define sipNameNr_QAbstractScrollArea 26817
#define sipName_QAbstractScrollArea &sipStrings_QtWidgets[26817]
#define sipNameNr_modificationChanged 26837
#define sipName_modificationChanged &sipStrings_QtWidgets[26837]
#define sipNameNr_26857 26857
#define sipName_26857 &sipStrings_QtWidgets[26857]
#define sipNameNr_setDefaultProperty 26876
#define sipName_setDefaultProperty &sipStrings_QtWidgets[26876]
#define sipNameNr_CancelButtonOnLeft 26895
#define sipName_CancelButtonOnLeft &sipStrings_QtWidgets[26895]
#define sipNameNr_setToolTipDuration 26914
#define sipName_setToolTipDuration &sipStrings_QtWidgets[26914]
#define sipNameNr_nativeParentWidget 26933
#define sipName_nativeParentWidget &sipStrings_QtWidgets[26933]
#define sipNameNr_focusPreviousChild 26952
#define sipName_focusPreviousChild &sipStrings_QtWidgets[26952]
#define sipNameNr_leaveWhatsThisMode 26971
#define sipName_leaveWhatsThisMode &sipStrings_QtWidgets[26971]
#define sipNameNr_enterWhatsThisMode 26990
#define sipName_enterWhatsThisMode &sipStrings_QtWidgets[26990]
#define sipNameNr_activeStackChanged 27009
#define sipName_activeStackChanged &sipStrings_QtWidgets[27009]
#define sipNameNr_insertTopLevelItem 27028
#define sipName_insertTopLevelItem &sipStrings_QtWidgets[27028]
#define sipNameNr_setAutoExpandDelay 27047
#define sipName_setAutoExpandDelay &sipStrings_QtWidgets[27047]
#define sipNameNr_setItemsExpandable 27066
#define sipName_setItemsExpandable &sipStrings_QtWidgets[27066]
#define sipNameNr_setRootIsDecorated 27085
#define sipName_setRootIsDecorated &sipStrings_QtWidgets[27085]
#define sipNameNr_AutoFormattingFlag 7083
#define sipName_AutoFormattingFlag &sipStrings_QtWidgets[7083]
#define sipNameNr_isForwardAvailable 27104
#define sipName_isForwardAvailable &sipStrings_QtWidgets[27104]
#define sipNameNr_currentCellChanged 27123
#define sipName_currentCellChanged &sipStrings_QtWidgets[27123]
#define sipNameNr_columnCountChanged 27142
#define sipName_columnCountChanged &sipStrings_QtWidgets[27142]
#define sipNameNr_minimumTabSizeHint 27161
#define sipName_minimumTabSizeHint &sipStrings_QtWidgets[27161]
#define sipNameNr_positionWithinLine 27180
#define sipName_positionWithinLine &sipStrings_QtWidgets[27180]
#define sipNameNr_ToolButtonFeatures 431
#define sipName_ToolButtonFeatures &sipStrings_QtWidgets[431]
#define sipNameNr_QStyleOptionSlider 27199
#define sipName_QStyleOptionSlider &sipStrings_QtWidgets[27199]
#define sipNameNr_decorationPosition 27218
#define sipName_decorationPosition &sipStrings_QtWidgets[27218]
#define sipNameNr_QStyleOptionButton 27237
#define sipName_QStyleOptionButton &sipStrings_QtWidgets[27237]
#define sipNameNr_PreviousIsSelected 27256
#define sipName_PreviousIsSelected &sipStrings_QtWidgets[27256]
#define sipNameNr_QStyleOptionHeader 27275
#define sipName_QStyleOptionHeader &sipStrings_QtWidgets[27275]
#define sipNameNr_StyleOptionVersion 78
#define sipName_StyleOptionVersion &sipStrings_QtWidgets[78]
#define sipNameNr_SP_DirLinkOpenIcon 27294
#define sipName_SP_DirLinkOpenIcon &sipStrings_QtWidgets[27294]
#define sipNameNr_SP_DialogYesButton 27313
#define sipName_SP_DialogYesButton &sipStrings_QtWidgets[27313]
#define sipNameNr_SP_FileDialogStart 27332
#define sipName_SP_FileDialogStart &sipStrings_QtWidgets[27332]
#define sipNameNr_SH_ToolButtonStyle 27351
#define sipName_SH_ToolButtonStyle &sipStrings_QtWidgets[27351]
#define sipNameNr_SH_ToolBar_Movable 27370
#define sipName_SH_ToolBar_Movable &sipStrings_QtWidgets[27370]
#define sipNameNr_SH_RubberBand_Mask 27389
#define sipName_SH_RubberBand_Mask &sipStrings_QtWidgets[27389]
#define sipNameNr_SH_FocusFrame_Mask 27408
#define sipName_SH_FocusFrame_Mask &sipStrings_QtWidgets[27408]
#define sipNameNr_SH_Menu_Scrollable 27427
#define sipName_SH_Menu_Scrollable &sipStrings_QtWidgets[27427]
#define sipNameNr_PM_TextCursorWidth 27446
#define sipName_PM_TextCursorWidth &sipStrings_QtWidgets[27446]
#define sipNameNr_PM_LayoutTopMargin 27465
#define sipName_PM_LayoutTopMargin &sipStrings_QtWidgets[27465]
#define sipNameNr_PM_ToolBarIconSize 27484
#define sipName_PM_ToolBarIconSize &sipStrings_QtWidgets[27484]
#define sipNameNr_PM_IndicatorHeight 27503
#define sipName_PM_IndicatorHeight &sipStrings_QtWidgets[27503]
#define sipNameNr_PM_TabBarTabVSpace 27522
#define sipName_PM_TabBarTabVSpace &sipStrings_QtWidgets[27522]
#define sipNameNr_PM_TabBarTabHSpace 27541
#define sipName_PM_TabBarTabHSpace &sipStrings_QtWidgets[27541]
#define sipNameNr_PM_SliderThickness 27560
#define sipName_PM_SliderThickness &sipStrings_QtWidgets[27560]
#define sipNameNr_PM_ScrollBarExtent 27579
#define sipName_PM_ScrollBarExtent &sipStrings_QtWidgets[27579]
#define sipNameNr_SC_MdiNormalButton 27598
#define sipName_SC_MdiNormalButton &sipStrings_QtWidgets[27598]
#define sipNameNr_SC_TitleBarSysMenu 27617
#define sipName_SC_TitleBarSysMenu &sipStrings_QtWidgets[27617]
#define sipNameNr_SC_SliderTickmarks 27636
#define sipName_SC_SliderTickmarks &sipStrings_QtWidgets[27636]
#define sipNameNr_SC_ScrollBarGroove 27655
#define sipName_SC_ScrollBarGroove &sipStrings_QtWidgets[27655]
#define sipNameNr_SC_ScrollBarSlider 27674
#define sipName_SC_ScrollBarSlider &sipStrings_QtWidgets[27674]
#define sipNameNr_QStyle__SubControl 27693
#define sipName_QStyle__SubControl &sipStrings_QtWidgets[27693]
#define sipNameNr_SE_PushButtonBevel 27712
#define sipName_SE_PushButtonBevel &sipStrings_QtWidgets[27712]
#define sipNameNr_SE_FrameLayoutItem 27731
#define sipName_SE_FrameLayoutItem &sipStrings_QtWidgets[27731]
#define sipNameNr_SE_LabelLayoutItem 27750
#define sipName_SE_LabelLayoutItem &sipStrings_QtWidgets[27750]
#define sipNameNr_SE_TabWidgetTabBar 27769
#define sipName_SE_TabWidgetTabBar &sipStrings_QtWidgets[27769]
#define sipNameNr_SE_SliderFocusRect 27788
#define sipName_SE_SliderFocusRect &sipStrings_QtWidgets[27788]
#define sipNameNr_QStyle__SubElement 27807
#define sipName_QStyle__SubElement &sipStrings_QtWidgets[27807]
#define sipNameNr_CE_HeaderEmptyArea 27826
#define sipName_CE_HeaderEmptyArea &sipStrings_QtWidgets[27826]
#define sipNameNr_CE_ToolBoxTabLabel 27845
#define sipName_CE_ToolBoxTabLabel &sipStrings_QtWidgets[27845]
#define sipNameNr_CE_ToolBoxTabShape 27864
#define sipName_CE_ToolBoxTabShape &sipStrings_QtWidgets[27864]
#define sipNameNr_CE_ScrollBarSlider 27883
#define sipName_CE_ScrollBarSlider &sipStrings_QtWidgets[27883]
#define sipNameNr_CE_DockWidgetTitle 27902
#define sipName_CE_DockWidgetTitle &sipStrings_QtWidgets[27902]
#define sipNameNr_CE_ToolButtonLabel 27921
#define sipName_CE_ToolButtonLabel &sipStrings_QtWidgets[27921]
#define sipNameNr_CE_PushButtonLabel 27940
#define sipName_CE_PushButtonLabel &sipStrings_QtWidgets[27940]
#define sipNameNr_CE_PushButtonBevel 27959
#define sipName_CE_PushButtonBevel &sipStrings_QtWidgets[27959]
#define sipNameNr_PE_IndicatorSpinUp 27978
#define sipName_PE_IndicatorSpinUp &sipStrings_QtWidgets[27978]
#define sipNameNr_PE_IndicatorBranch 27997
#define sipName_PE_IndicatorBranch &sipStrings_QtWidgets[27997]
#define sipNameNr_PE_PanelButtonTool 28016
#define sipName_PE_PanelButtonTool &sipStrings_QtWidgets[28016]
#define sipNameNr_PE_FrameTabBarBase 28035
#define sipName_PE_FrameTabBarBase &sipStrings_QtWidgets[28035]
#define sipNameNr_PE_FrameButtonTool 28054
#define sipName_PE_FrameButtonTool &sipStrings_QtWidgets[28054]
#define sipNameNr_PE_FrameDockWidget 28073
#define sipName_PE_FrameDockWidget &sipStrings_QtWidgets[28073]
#define sipNameNr_addPermanentWidget 28092
#define sipName_addPermanentWidget &sipStrings_QtWidgets[28092]
#define sipNameNr_displayIntegerBase 28111
#define sipName_displayIntegerBase &sipStrings_QtWidgets[28111]
#define sipNameNr_setVerticalStretch 28130
#define sipName_setVerticalStretch &sipStrings_QtWidgets[28130]
#define sipNameNr_DecelerationFactor 28149
#define sipName_DecelerationFactor &sipStrings_QtWidgets[28149]
#define sipNameNr_OvershootAlwaysOff 28168
#define sipName_OvershootAlwaysOff &sipStrings_QtWidgets[28168]
#define sipNameNr_resendPrepareEvent 28187
#define sipName_resendPrepareEvent &sipStrings_QtWidgets[28187]
#define sipNameNr_scrollerProperties 28206
#define sipName_scrollerProperties &sipStrings_QtWidgets[28206]
#define sipNameNr_setWidgetResizable 28225
#define sipName_setWidgetResizable &sipStrings_QtWidgets[28225]
#define sipNameNr_QRubberBand__Shape 28244
#define sipName_QRubberBand__Shape &sipStrings_QtWidgets[28244]
#define sipNameNr_setMinimumDuration 28263
#define sipName_setMinimumDuration &sipStrings_QtWidgets[28263]
#define sipNameNr_insertFromMimeData 28282
#define sipName_insertFromMimeData &sipStrings_QtWidgets[28282]
#define sipNameNr_setExtraSelections 28301
#define sipName_setExtraSelections &sipStrings_QtWidgets[28301]
#define sipNameNr_setInformativeText 28320
#define sipName_setInformativeText &sipStrings_QtWidgets[28320]
#define sipNameNr_setToolTipsVisible 28339
#define sipName_setToolTipsVisible &sipStrings_QtWidgets[28339]
#define sipNameNr_keyboardSingleStep 28358
#define sipName_keyboardSingleStep &sipStrings_QtWidgets[28358]
#define sipNameNr_setActivationOrder 28377
#define sipName_setActivationOrder &sipStrings_QtWidgets[28377]
#define sipNameNr_closeAllSubWindows 28396
#define sipName_closeAllSubWindows &sipStrings_QtWidgets[28396]
#define sipNameNr_setActiveSubWindow 28415
#define sipName_setActiveSubWindow &sipStrings_QtWidgets[28415]
#define sipNameNr_subWindowActivated 28434
#define sipName_subWindowActivated &sipStrings_QtWidgets[28434]
#define sipNameNr_QMdiArea__ViewMode 28453
#define sipName_QMdiArea__ViewMode &sipStrings_QtWidgets[28453]
#define sipNameNr_removeToolBarBreak 28472
#define sipName_removeToolBarBreak &sipStrings_QtWidgets[28472]
#define sipNameNr_insertToolBarBreak 28491
#define sipName_insertToolBarBreak &sipStrings_QtWidgets[28491]
#define sipNameNr_setToolButtonStyle 28510
#define sipName_setToolButtonStyle &sipStrings_QtWidgets[28510]
#define sipNameNr_currentItemChanged 28529
#define sipName_currentItemChanged &sipStrings_QtWidgets[28529]
#define sipNameNr_clearPropertyFlags 28548
#define sipName_clearPropertyFlags &sipStrings_QtWidgets[28548]
#define sipNameNr_cursorWordBackward 28567
#define sipName_cursorWordBackward &sipStrings_QtWidgets[28567]
#define sipNameNr_PasswordEchoOnEdit 28586
#define sipName_PasswordEchoOnEdit &sipStrings_QtWidgets[28586]
#define sipNameNr_keySequenceChanged 28605
#define sipName_keySequenceChanged &sipStrings_QtWidgets[28605]
#define sipNameNr_QItemEditorFactory 28624
#define sipName_QItemEditorFactory &sipStrings_QtWidgets[28624]
#define sipNameNr_doubleValueChanged 28643
#define sipName_doubleValueChanged &sipStrings_QtWidgets[28643]
#define sipNameNr_isComboBoxEditable 28662
#define sipName_isComboBoxEditable &sipStrings_QtWidgets[28662]
#define sipNameNr_InputDialogOptions 5158
#define sipName_InputDialogOptions &sipStrings_QtWidgets[5158]
#define sipNameNr_maximumSectionSize 28681
#define sipName_maximumSectionSize &sipStrings_QtWidgets[28681]
#define sipNameNr_setSectionsMovable 28700
#define sipName_setSectionsMovable &sipStrings_QtWidgets[28700]
#define sipNameNr_minimumSectionSize 28719
#define sipName_minimumSectionSize &sipStrings_QtWidgets[28719]
#define sipNameNr_defaultSectionSize 28738
#define sipName_defaultSectionSize &sipStrings_QtWidgets[28738]
#define sipNameNr_hiddenSectionCount 28757
#define sipName_hiddenSectionCount &sipStrings_QtWidgets[28757]
#define sipNameNr_initializeSections 28776
#define sipName_initializeSections &sipStrings_QtWidgets[28776]
#define sipNameNr_stretchLastSection 28795
#define sipName_stretchLastSection &sipStrings_QtWidgets[28795]
#define sipNameNr_sortIndicatorOrder 28814
#define sipName_sortIndicatorOrder &sipStrings_QtWidgets[28814]
#define sipNameNr_autoFillBackground 28833
#define sipName_autoFillBackground &sipStrings_QtWidgets[28833]
#define sipNameNr_setShortcutEnabled 28852
#define sipName_setShortcutEnabled &sipStrings_QtWidgets[28852]
#define sipNameNr_viewportUpdateMode 28871
#define sipName_viewportUpdateMode &sipStrings_QtWidgets[28871]
#define sipNameNr_FullViewportUpdate 28890
#define sipName_FullViewportUpdate &sipStrings_QtWidgets[28890]
#define sipNameNr_ViewportUpdateMode 4660
#define sipName_ViewportUpdateMode &sipStrings_QtWidgets[4660]
#define sipNameNr_resetCachedContent 28909
#define sipName_resetCachedContent &sipStrings_QtWidgets[28909]
#define sipNameNr_QGraphicsTransform 28928
#define sipName_QGraphicsTransform &sipStrings_QtWidgets[28928]
#define sipNameNr_buttonDownScenePos 28947
#define sipName_buttonDownScenePos &sipStrings_QtWidgets[28947]
#define sipNameNr_setForegroundBrush 28966
#define sipName_setForegroundBrush &sipStrings_QtWidgets[28966]
#define sipNameNr_setBackgroundBrush 28985
#define sipName_setBackgroundBrush &sipStrings_QtWidgets[28985]
#define sipNameNr_setItemIndexMethod 29004
#define sipName_setItemIndexMethod &sipStrings_QtWidgets[29004]
#define sipNameNr_setPreferredHeight 29023
#define sipName_setPreferredHeight &sipStrings_QtWidgets[29023]
#define sipNameNr_addChildLayoutItem 29042
#define sipName_addChildLayoutItem &sipStrings_QtWidgets[29042]
#define sipNameNr_getContentsMargins 29061
#define sipName_getContentsMargins &sipStrings_QtWidgets[29061]
#define sipNameNr_setContentsMargins 29080
#define sipName_setContentsMargins &sipStrings_QtWidgets[29080]
#define sipNameNr_setTabChangesFocus 29099
#define sipName_setTabChangesFocus &sipStrings_QtWidgets[29099]
#define sipNameNr_QGraphicsItemGroup 29118
#define sipName_QGraphicsItemGroup &sipStrings_QtWidgets[29118]
#define sipNameNr_transformationMode 29137
#define sipName_transformationMode &sipStrings_QtWidgets[29137]
#define sipNameNr_HeuristicMaskShape 29156
#define sipName_HeuristicMaskShape &sipStrings_QtWidgets[29156]
#define sipNameNr_setTransformations 29175
#define sipName_setTransformations &sipStrings_QtWidgets[29175]
#define sipNameNr_filtersChildEvents 29194
#define sipName_filtersChildEvents &sipStrings_QtWidgets[29194]
#define sipNameNr_commonAncestorItem 29213
#define sipName_commonAncestorItem &sipStrings_QtWidgets[29213]
#define sipNameNr_ItemRotationChange 29232
#define sipName_ItemRotationChange &sipStrings_QtWidgets[29232]
#define sipNameNr_ItemSelectedChange 29251
#define sipName_ItemSelectedChange &sipStrings_QtWidgets[29251]
#define sipNameNr_ItemPositionChange 29270
#define sipName_ItemPositionChange &sipStrings_QtWidgets[29270]
#define sipNameNr_GraphicsItemChange 4694
#define sipName_GraphicsItemChange &sipStrings_QtWidgets[4694]
#define sipNameNr_setColumnAlignment 29289
#define sipName_setColumnAlignment &sipStrings_QtWidgets[29289]
#define sipNameNr_columnMaximumWidth 29308
#define sipName_columnMaximumWidth &sipStrings_QtWidgets[29308]
#define sipNameNr_columnMinimumWidth 29327
#define sipName_columnMinimumWidth &sipStrings_QtWidgets[29327]
#define sipNameNr_rowPreferredHeight 29346
#define sipName_rowPreferredHeight &sipStrings_QtWidgets[29346]
#define sipNameNr_opacityMaskChanged 29365
#define sipName_opacityMaskChanged &sipStrings_QtWidgets[29365]
#define sipNameNr_sourceBoundingRect 29384
#define sipName_sourceBoundingRect &sipStrings_QtWidgets[29384]
#define sipNameNr_updateBoundingRect 29403
#define sipName_updateBoundingRect &sipStrings_QtWidgets[29403]
#define sipNameNr_registerRecognizer 22982
#define sipName_registerRecognizer &sipStrings_QtWidgets[22982]
#define sipNameNr_QGestureRecognizer 29422
#define sipName_QGestureRecognizer &sipStrings_QtWidgets[29422]
#define sipNameNr_mapToGraphicsScene 29441
#define sipName_mapToGraphicsScene &sipStrings_QtWidgets[29441]
#define sipNameNr_QTapAndHoldGesture 29460
#define sipName_QTapAndHoldGesture &sipStrings_QtWidgets[29460]
#define sipNameNr_totalRotationAngle 29479
#define sipName_totalRotationAngle &sipStrings_QtWidgets[29479]
#define sipNameNr_setLastScaleFactor 29498
#define sipName_setLastScaleFactor &sipStrings_QtWidgets[29498]
#define sipNameNr_setLastCenterPoint 29517
#define sipName_setLastCenterPoint &sipStrings_QtWidgets[29517]
#define sipNameNr_CenterPointChanged 29536
#define sipName_CenterPointChanged &sipStrings_QtWidgets[29536]
#define sipNameNr_ScaleFactorChanged 29555
#define sipName_ScaleFactorChanged &sipStrings_QtWidgets[29555]
#define sipNameNr_CancelAllInContext 29574
#define sipName_CancelAllInContext &sipStrings_QtWidgets[29574]
#define sipNameNr_setVerticalSpacing 29593
#define sipName_setVerticalSpacing &sipStrings_QtWidgets[29593]
#define sipNameNr_currentFontChanged 29612
#define sipName_currentFontChanged &sipStrings_QtWidgets[29612]
#define sipNameNr_nameFilterDisables 29631
#define sipName_nameFilterDisables &sipStrings_QtWidgets[29631]
#define sipNameNr_setMimeTypeFilters 29650
#define sipName_setMimeTypeFilters &sipStrings_QtWidgets[29650]
#define sipNameNr_selectedNameFilter 29669
#define sipName_selectedNameFilter &sipStrings_QtWidgets[29669]
#define sipNameNr_DockWidgetFeatures 5836
#define sipName_DockWidgetFeatures &sipStrings_QtWidgets[5836]
#define sipNameNr_DockWidgetClosable 29688
#define sipName_DockWidgetClosable &sipStrings_QtWidgets[29688]
#define sipNameNr_setResolveSymlinks 29707
#define sipName_setResolveSymlinks &sipStrings_QtWidgets[29707]
#define sipNameNr_setStandardButtons 29726
#define sipName_setStandardButtons &sipStrings_QtWidgets[29726]
#define sipNameNr_setSizeGripEnabled 29745
#define sipName_setSizeGripEnabled &sipStrings_QtWidgets[29745]
#define sipNameNr_screenCountChanged 29764
#define sipName_screenCountChanged &sipStrings_QtWidgets[29764]
#define sipNameNr_setMaximumDateTime 29783
#define sipName_setMaximumDateTime &sipStrings_QtWidgets[29783]
#define sipNameNr_setMinimumDateTime 29802
#define sipName_setMinimumDateTime &sipStrings_QtWidgets[29802]
#define sipNameNr_setSelectedSection 29821
#define sipName_setSelectedSection &sipStrings_QtWidgets[29821]
#define sipNameNr_mappedPropertyName 29840
#define sipName_mappedPropertyName &sipStrings_QtWidgets[29840]
#define sipNameNr_drawComplexControl 29859
#define sipName_drawComplexControl &sipStrings_QtWidgets[29859]
#define sipNameNr_QCommandLinkButton 29878
#define sipName_QCommandLinkButton &sipStrings_QtWidgets[29878]
#define sipNameNr_setPlaceholderText 29897
#define sipName_setPlaceholderText &sipStrings_QtWidgets[29897]
#define sipNameNr_currentTextChanged 29916
#define sipName_currentTextChanged &sipStrings_QtWidgets[29916]
#define sipNameNr_InsertAfterCurrent 29935
#define sipName_InsertAfterCurrent &sipStrings_QtWidgets[29935]
#define sipNameNr_setMaxVisibleItems 29954
#define sipName_setMaxVisibleItems &sipStrings_QtWidgets[29954]
#define sipNameNr_resizeGripsVisible 29973
#define sipName_resizeGripsVisible &sipStrings_QtWidgets[29973]
#define sipNameNr_ColorDialogOptions 5290
#define sipName_ColorDialogOptions &sipStrings_QtWidgets[5290]
#define sipNameNr_setDateEditEnabled 29992
#define sipName_setDateEditEnabled &sipStrings_QtWidgets[29992]
#define sipNameNr_currentPageChanged 30011
#define sipName_currentPageChanged &sipStrings_QtWidgets[30011]
#define sipNameNr_NoHorizontalHeader 30030
#define sipName_NoHorizontalHeader &sipStrings_QtWidgets[30030]
#define sipNameNr_setCursorFlashTime 30049
#define sipName_setCursorFlashTime &sipStrings_QtWidgets[30049]
#define sipNameNr_setExclusionPolicy 30068
#define sipName_setExclusionPolicy &sipStrings_QtWidgets[30068]
#define sipNameNr_setShortcutContext 30087
#define sipName_setShortcutContext &sipStrings_QtWidgets[30087]
#define sipNameNr_hasAcceptableInput 30106
#define sipName_hasAcceptableInput &sipStrings_QtWidgets[30106]
#define sipNameNr_invertedAppearance 30125
#define sipName_invertedAppearance &sipStrings_QtWidgets[30125]
#define sipNameNr_addScrollBarWidget 30144
#define sipName_addScrollBarWidget &sipStrings_QtWidgets[30144]
#define sipNameNr_setViewportMargins 30163
#define sipName_setViewportMargins &sipStrings_QtWidgets[30163]
#define sipNameNr_focusNextPrevChild 30182
#define sipName_focusNextPrevChild &sipStrings_QtWidgets[30182]
#define sipNameNr_itemDelegateForRow 30201
#define sipName_itemDelegateForRow &sipStrings_QtWidgets[30201]
#define sipNameNr_verticalScrollMode 30220
#define sipName_verticalScrollMode &sipStrings_QtWidgets[30220]
#define sipNameNr_DragSelectingState 30239
#define sipName_DragSelectingState &sipStrings_QtWidgets[30239]
#define sipNameNr_autoRepeatInterval 30258
#define sipName_autoRepeatInterval &sipStrings_QtWidgets[30258]
#define sipNameNr_setAutoRepeatDelay 30277
#define sipName_setAutoRepeatDelay &sipStrings_QtWidgets[30277]
#define sipNameNr_windowTitleChanged 30296
#define sipName_windowTitleChanged &sipStrings_QtWidgets[30296]
#define sipNameNr_windowStateChanged 30315
#define sipName_windowStateChanged &sipStrings_QtWidgets[30315]
#define sipNameNr_setTabStopDistance 30334
#define sipName_setTabStopDistance &sipStrings_QtWidgets[30334]
#define sipNameNr_setCursorMoveStyle 30353
#define sipName_setCursorMoveStyle &sipStrings_QtWidgets[30353]
#define sipNameNr_setUndoRedoEnabled 30372
#define sipName_setUndoRedoEnabled &sipStrings_QtWidgets[30372]
#define sipNameNr_verticalHeaderItem 30391
#define sipName_verticalHeaderItem &sipStrings_QtWidgets[30391]
#define sipNameNr_orientationChanged 30410
#define sipName_orientationChanged &sipStrings_QtWidgets[30410]
#define sipNameNr_setLayoutDirection 22541
#define sipName_setLayoutDirection &sipStrings_QtWidgets[22541]
#define sipNameNr_resizeInlineObject 30429
#define sipName_resizeInlineObject &sipStrings_QtWidgets[30429]
#define sipNameNr_setCaseSensitivity 30448
#define sipName_setCaseSensitivity &sipStrings_QtWidgets[30448]
#define sipNameNr_30467 30467
#define sipName_30467 &sipStrings_QtWidgets[30467]
#define sipNameNr_setSubTitleFormat 30485
#define sipName_setSubTitleFormat &sipStrings_QtWidgets[30485]
#define sipNameNr_HaveCustomButton3 30503
#define sipName_HaveCustomButton3 &sipStrings_QtWidgets[30503]
#define sipNameNr_HaveCustomButton2 30521
#define sipName_HaveCustomButton2 &sipStrings_QtWidgets[30521]
#define sipNameNr_HaveCustomButton1 30539
#define sipName_HaveCustomButton1 &sipStrings_QtWidgets[30539]
#define sipNameNr_HelpButtonOnRight 30557
#define sipName_HelpButtonOnRight &sipStrings_QtWidgets[30557]
#define sipNameNr_hasTabletTracking 30575
#define sipName_hasTabletTracking &sipStrings_QtWidgets[30575]
#define sipNameNr_setTabletTracking 30593
#define sipName_setTabletTracking &sipStrings_QtWidgets[30593]
#define sipNameNr_windowIconChanged 30611
#define sipName_windowIconChanged &sipStrings_QtWidgets[30611]
#define sipNameNr_setWindowFilePath 30629
#define sipName_setWindowFilePath &sipStrings_QtWidgets[30629]
#define sipNameNr_destroySubWindows 30647
#define sipName_destroySubWindows &sipStrings_QtWidgets[30647]
#define sipNameNr_setUpdatesEnabled 30665
#define sipName_setUpdatesEnabled &sipStrings_QtWidgets[30665]
#define sipNameNr_contextMenuPolicy 30683
#define sipName_contextMenuPolicy &sipStrings_QtWidgets[30683]
#define sipNameNr_setWindowIconText 30701
#define sipName_setWindowIconText &sipStrings_QtWidgets[30701]
#define sipNameNr_setForegroundRole 30719
#define sipName_setForegroundRole &sipStrings_QtWidgets[30719]
#define sipNameNr_setBackgroundRole 30737
#define sipName_setBackgroundRole &sipStrings_QtWidgets[30737]
#define sipNameNr_setWindowModified 30755
#define sipName_setWindowModified &sipStrings_QtWidgets[30755]
#define sipNameNr_topLevelItemCount 30773
#define sipName_topLevelItemCount &sipStrings_QtWidgets[30773]
#define sipNameNr_DontShowIndicator 30791
#define sipName_DontShowIndicator &sipStrings_QtWidgets[30791]
#define sipNameNr_expandRecursively 30809
#define sipName_expandRecursively &sipStrings_QtWidgets[30809]
#define sipNameNr_uniformRowHeights 30827
#define sipName_uniformRowHeights &sipStrings_QtWidgets[30827]
#define sipNameNr_setAcceptRichText 30845
#define sipName_setAcceptRichText &sipStrings_QtWidgets[30845]
#define sipNameNr_backwardAvailable 30863
#define sipName_backwardAvailable &sipStrings_QtWidgets[30863]
#define sipNameNr_setTabBarAutoHide 30881
#define sipName_setTabBarAutoHide &sipStrings_QtWidgets[30881]
#define sipNameNr_cellDoubleClicked 30899
#define sipName_cellDoubleClicked &sipStrings_QtWidgets[30899]
#define sipNameNr_setVerticalHeader 30917
#define sipName_setVerticalHeader &sipStrings_QtWidgets[30917]
#define sipNameNr_tabCloseRequested 30935
#define sipName_tabCloseRequested &sipStrings_QtWidgets[30935]
#define sipNameNr_SelectPreviousTab 30953
#define sipName_SelectPreviousTab &sipStrings_QtWidgets[30953]
#define sipNameNr_usesScrollButtons 30971
#define sipName_usesScrollButtons &sipStrings_QtWidgets[30971]
#define sipNameNr_ToolButtonFeature 688
#define sipName_ToolButtonFeature &sipStrings_QtWidgets[688]
#define sipNameNr_activeSubControls 30989
#define sipName_activeSubControls &sipStrings_QtWidgets[30989]
#define sipNameNr_HasCheckIndicator 31007
#define sipName_HasCheckIndicator &sipStrings_QtWidgets[31007]
#define sipNameNr_QStyleOptionTabV4 31025
#define sipName_QStyleOptionTabV4 &sipStrings_QtWidgets[31025]
#define sipNameNr_RightCornerWidget 31043
#define sipName_RightCornerWidget &sipStrings_QtWidgets[31043]
#define sipNameNr_CommandLinkButton 29879
#define sipName_CommandLinkButton &sipStrings_QtWidgets[29879]
#define sipNameNr_AutoDefaultButton 31061
#define sipName_AutoDefaultButton &sipStrings_QtWidgets[31061]
#define sipNameNr_QStyleOptionFrame 31079
#define sipName_QStyleOptionFrame &sipStrings_QtWidgets[31079]
#define sipNameNr_SO_TabWidgetFrame 31097
#define sipName_SO_TabWidgetFrame &sipStrings_QtWidgets[31097]
#define sipNameNr_RSIP_OnMouseClick 31115
#define sipName_RSIP_OnMouseClick &sipStrings_QtWidgets[31115]
#define sipNameNr_SP_DialogNoButton 31133
#define sipName_SP_DialogNoButton &sipStrings_QtWidgets[31133]
#define sipNameNr_SP_DialogOkButton 31151
#define sipName_SP_DialogOkButton &sipStrings_QtWidgets[31151]
#define sipNameNr_SP_FileDialogBack 31169
#define sipName_SP_FileDialogBack &sipStrings_QtWidgets[31169]
#define sipNameNr_SH_Widget_Animate 31187
#define sipName_SH_Widget_Animate &sipStrings_QtWidgets[31187]
#define sipNameNr_SH_ComboBox_Popup 31205
#define sipName_SH_ComboBox_Popup &sipStrings_QtWidgets[31205]
#define sipNameNr_QStyle__StyleHint 31223
#define sipName_QStyle__StyleHint &sipStrings_QtWidgets[31223]
#define sipNameNr_PM_SubMenuOverlap 31241
#define sipName_PM_SubMenuOverlap &sipStrings_QtWidgets[31241]
#define sipNameNr_PM_ButtonIconSize 31259
#define sipName_PM_ButtonIconSize &sipStrings_QtWidgets[31259]
#define sipNameNr_PM_TabBarIconSize 31277
#define sipName_PM_TabBarIconSize &sipStrings_QtWidgets[31277]
#define sipNameNr_PM_HeaderMarkSize 31295
#define sipName_PM_HeaderMarkSize &sipStrings_QtWidgets[31295]
#define sipNameNr_PM_IndicatorWidth 31313
#define sipName_PM_IndicatorWidth &sipStrings_QtWidgets[31313]
#define sipNameNr_PM_MenuBarHMargin 31331
#define sipName_PM_MenuBarHMargin &sipStrings_QtWidgets[31331]
#define sipNameNr_PM_MenuBarVMargin 31349
#define sipName_PM_MenuBarVMargin &sipStrings_QtWidgets[31349]
#define sipNameNr_PM_MenuPanelWidth 31367
#define sipName_PM_MenuPanelWidth &sipStrings_QtWidgets[31367]
#define sipNameNr_PM_TitleBarHeight 31385
#define sipName_PM_TitleBarHeight &sipStrings_QtWidgets[31385]
#define sipNameNr_SC_MdiCloseButton 31403
#define sipName_SC_MdiCloseButton &sipStrings_QtWidgets[31403]
#define sipNameNr_SC_ToolButtonMenu 31421
#define sipName_SC_ToolButtonMenu &sipStrings_QtWidgets[31421]
#define sipNameNr_SC_ScrollBarFirst 31439
#define sipName_SC_ScrollBarFirst &sipStrings_QtWidgets[31439]
#define sipNameNr_SE_DockWidgetIcon 31457
#define sipName_SE_DockWidgetIcon &sipStrings_QtWidgets[31457]
#define sipNameNr_CE_ColumnViewGrip 31475
#define sipName_CE_ColumnViewGrip &sipStrings_QtWidgets[31475]
#define sipNameNr_CE_ScrollBarFirst 31493
#define sipName_CE_ScrollBarFirst &sipStrings_QtWidgets[31493]
#define sipNameNr_CE_TabBarTabLabel 31511
#define sipName_CE_TabBarTabLabel &sipStrings_QtWidgets[31511]
#define sipNameNr_CE_TabBarTabShape 31529
#define sipName_CE_TabBarTabShape &sipStrings_QtWidgets[31529]
#define sipNameNr_PE_PanelStatusBar 31547
#define sipName_PE_PanelStatusBar &sipStrings_QtWidgets[31547]
#define sipNameNr_PE_FrameTabWidget 31565
#define sipName_PE_FrameTabWidget &sipStrings_QtWidgets[31565]
#define sipNameNr_PE_FrameStatusBar 31583
#define sipName_PE_FrameStatusBar &sipStrings_QtWidgets[31583]
#define sipNameNr_PE_FrameFocusRect 31601
#define sipName_PE_FrameFocusRect &sipStrings_QtWidgets[31601]
#define sipNameNr_QStyle__StateFlag 31619
#define sipName_QStyle__StateFlag &sipStrings_QtWidgets[31619]
#define sipNameNr_hasWidthForHeight 31637
#define sipName_hasWidthForHeight &sipStrings_QtWidgets[31637]
#define sipNameNr_setWidthForHeight 31655
#define sipName_setWidthForHeight &sipStrings_QtWidgets[31655]
#define sipNameNr_horizontalStretch 31673
#define sipName_horizontalStretch &sipStrings_QtWidgets[31673]
#define sipNameNr_setHeightForWidth 31691
#define sipName_setHeightForWidth &sipStrings_QtWidgets[31691]
#define sipNameNr_setVerticalPolicy 31709
#define sipName_setVerticalPolicy &sipStrings_QtWidgets[31709]
#define sipNameNr_ScrollMetricCount 31727
#define sipName_ScrollMetricCount &sipStrings_QtWidgets[31727]
#define sipNameNr_SnapPositionRatio 31745
#define sipName_SnapPositionRatio &sipStrings_QtWidgets[31745]
#define sipNameNr_AxisLockThreshold 31763
#define sipName_AxisLockThreshold &sipStrings_QtWidgets[31763]
#define sipNameNr_DragStartDistance 31781
#define sipName_DragStartDistance &sipStrings_QtWidgets[31781]
#define sipNameNr_OvershootAlwaysOn 31799
#define sipName_OvershootAlwaysOn &sipStrings_QtWidgets[31799]
#define sipNameNr_setSnapPositionsY 31817
#define sipName_setSnapPositionsY &sipStrings_QtWidgets[31817]
#define sipNameNr_setSnapPositionsX 31835
#define sipName_setSnapPositionsX &sipStrings_QtWidgets[31835]
#define sipNameNr_scrollGestureType 31853
#define sipName_scrollGestureType &sipStrings_QtWidgets[31853]
#define sipNameNr_ensureBlockLayout 31871
#define sipName_ensureBlockLayout &sipStrings_QtWidgets[31871]
#define sipNameNr_firstVisibleBlock 31889
#define sipName_firstVisibleBlock &sipStrings_QtWidgets[31889]
#define sipNameNr_cursorForPosition 31907
#define sipName_cursorForPosition &sipStrings_QtWidgets[31907]
#define sipNameNr_setCenterOnScroll 31925
#define sipName_setCenterOnScroll &sipStrings_QtWidgets[31925]
#define sipNameNr_backgroundVisible 31943
#define sipName_backgroundVisible &sipStrings_QtWidgets[31943]
#define sipNameNr_currentCharFormat 31961
#define sipName_currentCharFormat &sipStrings_QtWidgets[31961]
#define sipNameNr_setUpdateBehavior 31979
#define sipName_setUpdateBehavior &sipStrings_QtWidgets[31979]
#define sipNameNr_setWindowModality 31997
#define sipName_setWindowModality &sipStrings_QtWidgets[31997]
#define sipNameNr_QMessageBox__Icon 32015
#define sipName_QMessageBox__Icon &sipStrings_QtWidgets[32015]
#define sipNameNr_setTearOffEnabled 32033
#define sipName_setTearOffEnabled &sipStrings_QtWidgets[32033]
#define sipNameNr_cascadeSubWindows 32051
#define sipName_cascadeSubWindows &sipStrings_QtWidgets[32051]
#define sipNameNr_takeCentralWidget 32069
#define sipName_takeCentralWidget &sipStrings_QtWidgets[32069]
#define sipNameNr_restoreDockWidget 32087
#define sipName_restoreDockWidget &sipStrings_QtWidgets[32087]
#define sipNameNr_setSortingEnabled 32105
#define sipName_setSortingEnabled &sipStrings_QtWidgets[32105]
#define sipNameNr_itemDoubleClicked 32123
#define sipName_itemDoubleClicked &sipStrings_QtWidgets[32123]
#define sipNameNr_cursorWordForward 32141
#define sipName_cursorWordForward &sipStrings_QtWidgets[32141]
#define sipNameNr_setCursorPosition 32159
#define sipName_setCursorPosition &sipStrings_QtWidgets[32159]
#define sipNameNr_smallDecimalPoint 32177
#define sipName_smallDecimalPoint &sipStrings_QtWidgets[32177]
#define sipNameNr_setSizeConstraint 32195
#define sipName_setSizeConstraint &sipStrings_QtWidgets[32195]
#define sipNameNr_setScaledContents 32213
#define sipName_setScaledContents &sipStrings_QtWidgets[32213]
#define sipNameNr_hasScaledContents 32231
#define sipName_hasScaledContents &sipStrings_QtWidgets[32231]
#define sipNameNr_setDefaultFactory 32249
#define sipName_setDefaultFactory &sipStrings_QtWidgets[32249]
#define sipNameNr_valuePropertyName 32267
#define sipName_valuePropertyName &sipStrings_QtWidgets[32267]
#define sipNameNr_itemEditorFactory 32285
#define sipName_itemEditorFactory &sipStrings_QtWidgets[32285]
#define sipNameNr_textValueSelected 32303
#define sipName_textValueSelected &sipStrings_QtWidgets[32303]
#define sipNameNr_setDoubleDecimals 32321
#define sipName_setDoubleDecimals &sipStrings_QtWidgets[32321]
#define sipNameNr_InputDialogOption 5677
#define sipName_InputDialogOption &sipStrings_QtWidgets[5677]
#define sipNameNr_sectionResizeMode 32339
#define sipName_sectionResizeMode &sipStrings_QtWidgets[32339]
#define sipNameNr_sectionsClickable 32357
#define sipName_sectionsClickable &sipStrings_QtWidgets[32357]
#define sipNameNr_geometriesChanged 32375
#define sipName_geometriesChanged &sipStrings_QtWidgets[32375]
#define sipNameNr_highlightSections 32393
#define sipName_highlightSections &sipStrings_QtWidgets[32393]
#define sipNameNr_grabKeyboardEvent 25559
#define sipName_grabKeyboardEvent &sipStrings_QtWidgets[25559]
#define sipNameNr_rubberBandChanged 32411
#define sipName_rubberBandChanged &sipStrings_QtWidgets[32411]
#define sipNameNr_optimizationFlags 32429
#define sipName_optimizationFlags &sipStrings_QtWidgets[32429]
#define sipNameNr_OptimizationFlags 5192
#define sipName_OptimizationFlags &sipStrings_QtWidgets[5192]
#define sipNameNr_QGraphicsRotation 32447
#define sipName_QGraphicsRotation &sipStrings_QtWidgets[32447]
#define sipNameNr_minimumRenderSize 32465
#define sipName_minimumRenderSize &sipStrings_QtWidgets[32465]
#define sipNameNr_itemsBoundingRect 32483
#define sipName_itemsBoundingRect &sipStrings_QtWidgets[32483]
#define sipNameNr_effectiveSizeHint 32501
#define sipName_effectiveSizeHint &sipStrings_QtWidgets[32501]
#define sipNameNr_setPreferredWidth 32519
#define sipName_setPreferredWidth &sipStrings_QtWidgets[32519]
#define sipNameNr_openExternalLinks 32537
#define sipName_openExternalLinks &sipStrings_QtWidgets[32537]
#define sipNameNr_QGraphicsTextItem 32555
#define sipName_QGraphicsTextItem &sipStrings_QtWidgets[32555]
#define sipNameNr_BoundingRectShape 32573
#define sipName_BoundingRectShape &sipStrings_QtWidgets[32573]
#define sipNameNr_QGraphicsLineItem 32591
#define sipName_QGraphicsLineItem &sipStrings_QtWidgets[32591]
#define sipNameNr_QGraphicsRectItem 32609
#define sipName_QGraphicsRectItem &sipStrings_QtWidgets[32609]
#define sipNameNr_QGraphicsPathItem 32627
#define sipName_QGraphicsPathItem &sipStrings_QtWidgets[32627]
#define sipNameNr_acceptTouchEvents 32645
#define sipName_acceptTouchEvents &sipStrings_QtWidgets[32645]
#define sipNameNr_setGraphicsEffect 32663
#define sipName_setGraphicsEffect &sipStrings_QtWidgets[32663]
#define sipNameNr_mapRectFromParent 32681
#define sipName_mapRectFromParent &sipStrings_QtWidgets[32681]
#define sipNameNr_acceptHoverEvents 32699
#define sipName_acceptHoverEvents &sipStrings_QtWidgets[32699]
#define sipNameNr_viewportTransform 32717
#define sipName_viewportTransform &sipStrings_QtWidgets[32717]
#define sipNameNr_sceneBoundingRect 32735
#define sipName_sceneBoundingRect &sipStrings_QtWidgets[32735]
#define sipNameNr_GraphicsItemFlags 5225
#define sipName_GraphicsItemFlags &sipStrings_QtWidgets[5225]
#define sipNameNr_ItemHasNoContents 32753
#define sipName_ItemHasNoContents &sipStrings_QtWidgets[32753]
#define sipNameNr_ItemOpacityChange 32771
#define sipName_ItemOpacityChange &sipStrings_QtWidgets[32771]
#define sipNameNr_ItemToolTipChange 32789
#define sipName_ItemToolTipChange &sipStrings_QtWidgets[32789]
#define sipNameNr_ItemEnabledChange 32807
#define sipName_ItemEnabledChange &sipStrings_QtWidgets[32807]
#define sipNameNr_ItemVisibleChange 32825
#define sipName_ItemVisibleChange &sipStrings_QtWidgets[32825]
#define sipNameNr_setRowFixedHeight 32843
#define sipName_setRowFixedHeight &sipStrings_QtWidgets[32843]
#define sipNameNr_blurRadiusChanged 32861
#define sipName_blurRadiusChanged &sipStrings_QtWidgets[32861]
#define sipNameNr_SourceInvalidated 32879
#define sipName_SourceInvalidated &sipStrings_QtWidgets[32879]
#define sipNameNr_verticalDirection 32897
#define sipName_verticalDirection &sipStrings_QtWidgets[32897]
#define sipNameNr_lastRotationAngle 32915
#define sipName_lastRotationAngle &sipStrings_QtWidgets[32915]
#define sipNameNr_QFrame__StyleMask 32933
#define sipName_QFrame__StyleMask &sipStrings_QtWidgets[32933]
#define sipNameNr_getLayoutPosition 32951
#define sipName_getLayoutPosition &sipStrings_QtWidgets[32951]
#define sipNameNr_getWidgetPosition 32969
#define sipName_getWidgetPosition &sipStrings_QtWidgets[32969]
#define sipNameNr_horizontalSpacing 32987
#define sipName_horizontalSpacing &sipStrings_QtWidgets[32987]
#define sipNameNr_setLabelAlignment 33005
#define sipName_setLabelAlignment &sipStrings_QtWidgets[33005]
#define sipNameNr_fieldGrowthPolicy 33023
#define sipName_fieldGrowthPolicy &sipStrings_QtWidgets[33023]
#define sipNameNr_FieldGrowthPolicy 6248
#define sipName_FieldGrowthPolicy &sipStrings_QtWidgets[6248]
#define sipNameNr_FontDialogOptions 6899
#define sipName_FontDialogOptions &sipStrings_QtWidgets[6899]
#define sipNameNr_ProportionalFonts 33041
#define sipName_ProportionalFonts &sipStrings_QtWidgets[33041]
#define sipNameNr_QFileIconProvider 33059
#define sipName_QFileIconProvider &sipStrings_QtWidgets[33059]
#define sipNameNr_currentUrlChanged 33077
#define sipName_currentUrlChanged &sipStrings_QtWidgets[33077]
#define sipNameNr_qDrawBorderPixmap 33095
#define sipName_qDrawBorderPixmap &sipStrings_QtWidgets[33095]
#define sipNameNr_setTitleBarWidget 33113
#define sipName_setTitleBarWidget &sipStrings_QtWidgets[33113]
#define sipNameNr_DockWidgetMovable 33131
#define sipName_DockWidgetMovable &sipStrings_QtWidgets[33131]
#define sipNameNr_DockWidgetFeature 6930
#define sipName_DockWidgetFeature &sipStrings_QtWidgets[6930]
#define sipNameNr_setLazyChildCount 33149
#define sipName_setLazyChildCount &sipStrings_QtWidgets[33149]
#define sipNameNr_isSizeGripEnabled 33167
#define sipName_isSizeGripEnabled &sipStrings_QtWidgets[33167]
#define sipNameNr_setNotchesVisible 33185
#define sipName_setNotchesVisible &sipStrings_QtWidgets[33185]
#define sipNameNr_setCalendarWidget 33203
#define sipName_setCalendarWidget &sipStrings_QtWidgets[33203]
#define sipNameNr_setCurrentSection 33221
#define sipName_setCurrentSection &sipStrings_QtWidgets[33221]
#define sipNameNr_displayedSections 33239
#define sipName_displayedSections &sipStrings_QtWidgets[33239]
#define sipNameNr_DateSections_Mask 33257
#define sipName_DateSections_Mask &sipStrings_QtWidgets[33257]
#define sipNameNr_TimeSections_Mask 33275
#define sipName_TimeSections_Mask &sipStrings_QtWidgets[33275]
#define sipNameNr_QDataWidgetMapper 33293
#define sipName_QDataWidgetMapper &sipStrings_QtWidgets[33293]
#define sipNameNr_currentCompletion 33311
#define sipName_currentCompletion &sipStrings_QtWidgets[33311]
#define sipNameNr_setCompletionRole 33329
#define sipName_setCompletionRole &sipStrings_QtWidgets[33329]
#define sipNameNr_setCompletionMode 33347
#define sipName_setCompletionMode &sipStrings_QtWidgets[33347]
#define sipNameNr_setRootModelIndex 33365
#define sipName_setRootModelIndex &sipStrings_QtWidgets[33365]
#define sipNameNr_duplicatesEnabled 33383
#define sipName_duplicatesEnabled &sipStrings_QtWidgets[33383]
#define sipNameNr_ColorDialogOption 5901
#define sipName_ColorDialogOption &sipStrings_QtWidgets[5901]
#define sipNameNr_isDateEditEnabled 33401
#define sipName_isDateEditEnabled &sipStrings_QtWidgets[33401]
#define sipNameNr_showPreviousMonth 33419
#define sipName_showPreviousMonth &sipStrings_QtWidgets[33419]
#define sipNameNr_setDateTextFormat 33437
#define sipName_setDateTextFormat &sipStrings_QtWidgets[33437]
#define sipNameNr_weekdayTextFormat 33455
#define sipName_weekdayTextFormat &sipStrings_QtWidgets[33455]
#define sipNameNr_setFirstDayOfWeek 33473
#define sipName_setFirstDayOfWeek &sipStrings_QtWidgets[33473]
#define sipNameNr_hasHeightForWidth 33491
#define sipName_hasHeightForWidth &sipStrings_QtWidgets[33491]
#define sipNameNr_setAutoSipEnabled 33509
#define sipName_setAutoSipEnabled &sipStrings_QtWidgets[33509]
#define sipNameNr_activeModalWidget 33527
#define sipName_activeModalWidget &sipStrings_QtWidgets[33527]
#define sipNameNr_activePopupWidget 33545
#define sipName_activePopupWidget &sipStrings_QtWidgets[33545]
#define sipNameNr_ExclusiveOptional 33563
#define sipName_ExclusiveOptional &sipStrings_QtWidgets[33563]
#define sipNameNr_QAction__Priority 33581
#define sipName_QAction__Priority &sipStrings_QtWidgets[33581]
#define sipNameNr_associatedWidgets 33599
#define sipName_associatedWidgets &sipStrings_QtWidgets[33599]
#define sipNameNr_TextHeuristicRole 33617
#define sipName_TextHeuristicRole &sipStrings_QtWidgets[33617]
#define sipNameNr_QAction__MenuRole 33635
#define sipName_QAction__MenuRole &sipStrings_QtWidgets[33635]
#define sipNameNr_setCorrectionMode 33653
#define sipName_setCorrectionMode &sipStrings_QtWidgets[33653]
#define sipNameNr_SliderValueChange 33671
#define sipName_SliderValueChange &sipStrings_QtWidgets[33671]
#define sipNameNr_SliderStepsChange 33689
#define sipName_SliderStepsChange &sipStrings_QtWidgets[33689]
#define sipNameNr_SliderRangeChange 33707
#define sipName_SliderRangeChange &sipStrings_QtWidgets[33707]
#define sipNameNr_SliderPageStepSub 33725
#define sipName_SliderPageStepSub &sipStrings_QtWidgets[33725]
#define sipNameNr_SliderPageStepAdd 33743
#define sipName_SliderPageStepAdd &sipStrings_QtWidgets[33743]
#define sipNameNr_setSliderPosition 33761
#define sipName_setSliderPosition &sipStrings_QtWidgets[33761]
#define sipNameNr_verticalScrollBar 33779
#define sipName_verticalScrollBar &sipStrings_QtWidgets[33779]
#define sipNameNr_dirtyRegionOffset 33797
#define sipName_dirtyRegionOffset &sipStrings_QtWidgets[33797]
#define sipNameNr_scrollDirtyRegion 33815
#define sipName_scrollDirtyRegion &sipStrings_QtWidgets[33815]
#define sipNameNr_sizeHintForColumn 33833
#define sipName_sizeHintForColumn &sipStrings_QtWidgets[33833]
#define sipNameNr_showDropIndicator 33851
#define sipName_showDropIndicator &sipStrings_QtWidgets[33851]
#define sipNameNr_selectionBehavior 33869
#define sipName_selectionBehavior &sipStrings_QtWidgets[33869]
#define sipNameNr_setSelectionModel 33887
#define sipName_setSelectionModel &sipStrings_QtWidgets[33887]
#define sipNameNr_ExtendedSelection 33905
#define sipName_ExtendedSelection &sipStrings_QtWidgets[33905]
#define sipNameNr_SelectionBehavior 3372
#define sipName_SelectionBehavior &sipStrings_QtWidgets[3372]
#define sipNameNr_QAbstractItemView 33923
#define sipName_QAbstractItemView &sipStrings_QtWidgets[33923]
#define sipNameNr_visibilityChanged 33941
#define sipName_visibilityChanged &sipStrings_QtWidgets[33941]
#define sipNameNr_mouseReleaseEvent 33959
#define sipName_mouseReleaseEvent &sipStrings_QtWidgets[33959]
#define sipNameNr_maximumBlockCount 33977
#define sipName_maximumBlockCount &sipStrings_QtWidgets[33977]
#define sipNameNr_blockCountChanged 33995
#define sipName_blockCountChanged &sipStrings_QtWidgets[33995]
#define sipNameNr_isUndoRedoEnabled 34013
#define sipName_isUndoRedoEnabled &sipStrings_QtWidgets[34013]
#define sipNameNr_startDragDistance 34031
#define sipName_startDragDistance &sipStrings_QtWidgets[34031]
#define sipNameNr_invisibleRootItem 34049
#define sipName_invisibleRootItem &sipStrings_QtWidgets[34049]
#define sipNameNr_availableGeometry 34067
#define sipName_availableGeometry &sipStrings_QtWidgets[34067]
#define sipNameNr_defaultDropAction 34085
#define sipName_defaultDropAction &sipStrings_QtWidgets[34085]
#define sipNameNr_blockBoundingRect 34103
#define sipName_blockBoundingRect &sipStrings_QtWidgets[34103]
#define sipNameNr_frameBoundingRect 34121
#define sipName_frameBoundingRect &sipStrings_QtWidgets[34121]
#define sipNameNr_setAutoFormatting 34139
#define sipName_setAutoFormatting &sipStrings_QtWidgets[34139]
#define sipNameNr_currentRowChanged 34157
#define sipName_currentRowChanged &sipStrings_QtWidgets[34157]
#define sipNameNr_headerDataChanged 34175
#define sipName_headerDataChanged &sipStrings_QtWidgets[34175]
#define sipNameNr_sip_simplewrapper 34193
#define sipName_sip_simplewrapper &sipStrings_QtWidgets[34193]
#define sipNameNr_34211 34211
#define sipName_34211 &sipStrings_QtWidgets[34211]
#define sipNameNr_currentIdChanged 34228
#define sipName_currentIdChanged &sipStrings_QtWidgets[34228]
#define sipNameNr_IndependentPages 34245
#define sipName_IndependentPages &sipStrings_QtWidgets[34245]
#define sipNameNr_BackgroundPixmap 34262
#define sipName_BackgroundPixmap &sipStrings_QtWidgets[34262]
#define sipNameNr_setDefaultWidget 34279
#define sipName_setDefaultWidget &sipStrings_QtWidgets[34279]
#define sipNameNr_hasMouseTracking 34296
#define sipName_hasMouseTracking &sipStrings_QtWidgets[34296]
#define sipNameNr_setMouseTracking 34313
#define sipName_setMouseTracking &sipStrings_QtWidgets[34313]
#define sipNameNr_destroyOldWindow 34330
#define sipName_destroyOldWindow &sipStrings_QtWidgets[34330]
#define sipNameNr_initializeWindow 34347
#define sipName_initializeWindow &sipStrings_QtWidgets[34347]
#define sipNameNr_nextInFocusChain 34364
#define sipName_nextInFocusChain &sipStrings_QtWidgets[34364]
#define sipNameNr_isWindowModified 34381
#define sipName_isWindowModified &sipStrings_QtWidgets[34381]
#define sipNameNr_setWindowOpacity 34398
#define sipName_setWindowOpacity &sipStrings_QtWidgets[34398]
#define sipNameNr_createUndoAction 34415
#define sipName_createUndoAction &sipStrings_QtWidgets[34415]
#define sipNameNr_createRedoAction 34432
#define sipName_createRedoAction &sipStrings_QtWidgets[34432]
#define sipNameNr_addTopLevelItems 34449
#define sipName_addTopLevelItems &sipStrings_QtWidgets[34449]
#define sipNameNr_takeTopLevelItem 34466
#define sipName_takeTopLevelItem &sipStrings_QtWidgets[34466]
#define sipNameNr_resetIndentation 34483
#define sipName_resetIndentation &sipStrings_QtWidgets[34483]
#define sipNameNr_indexRowSizeHint 34500
#define sipName_indexRowSizeHint &sipStrings_QtWidgets[34500]
#define sipNameNr_FixedColumnWidth 34517
#define sipName_FixedColumnWidth &sipStrings_QtWidgets[34517]
#define sipNameNr_forwardAvailable 34534
#define sipName_forwardAvailable &sipStrings_QtWidgets[34534]
#define sipNameNr_setRangeSelected 34551
#define sipName_setRangeSelected &sipStrings_QtWidgets[34551]
#define sipNameNr_removeCellWidget 34568
#define sipName_removeCellWidget &sipStrings_QtWidgets[34568]
#define sipNameNr_QTableWidgetItem 34585
#define sipName_QTableWidgetItem &sipStrings_QtWidgets[34585]
#define sipNameNr_horizontalHeader 34602
#define sipName_horizontalHeader &sipStrings_QtWidgets[34602]
#define sipNameNr_supportsMessages 34619
#define sipName_supportsMessages &sipStrings_QtWidgets[34619]
#define sipNameNr_ActivationReason 4186
#define sipName_ActivationReason &sipStrings_QtWidgets[4186]
#define sipNameNr_QStyleHintReturn 34636
#define sipName_QStyleHintReturn &sipStrings_QtWidgets[34636]
#define sipNameNr_viewItemPosition 34653
#define sipName_viewItemPosition &sipStrings_QtWidgets[34653]
#define sipNameNr_ViewItemPosition 1822
#define sipName_ViewItemPosition &sipStrings_QtWidgets[1822]
#define sipNameNr_ViewItemFeatures 1861
#define sipName_ViewItemFeatures &sipStrings_QtWidgets[1861]
#define sipNameNr_displayAlignment 34670
#define sipName_displayAlignment &sipStrings_QtWidgets[34670]
#define sipNameNr_verticalTitleBar 34687
#define sipName_verticalTitleBar &sipStrings_QtWidgets[34687]
#define sipNameNr_LeftCornerWidget 34704
#define sipName_LeftCornerWidget &sipStrings_QtWidgets[34704]
#define sipNameNr_selectedPosition 34721
#define sipName_selectedPosition &sipStrings_QtWidgets[34721]
#define sipNameNr_SelectedPosition 2399
#define sipName_SelectedPosition &sipStrings_QtWidgets[2399]
#define sipNameNr_SP_BrowserReload 34738
#define sipName_SP_BrowserReload &sipStrings_QtWidgets[34738]
#define sipNameNr_SP_FileDialogEnd 34755
#define sipName_SP_FileDialogEnd &sipStrings_QtWidgets[34755]
#define sipNameNr_SP_DirClosedIcon 34772
#define sipName_SP_DirClosedIcon &sipStrings_QtWidgets[34772]
#define sipNameNr_CT_HeaderSection 34789
#define sipName_CT_HeaderSection &sipStrings_QtWidgets[34789]
#define sipNameNr_CT_DialogButtons 34806
#define sipName_CT_DialogButtons &sipStrings_QtWidgets[34806]
#define sipNameNr_PM_LargeIconSize 34823
#define sipName_PM_LargeIconSize &sipStrings_QtWidgets[34823]
#define sipNameNr_PM_SmallIconSize 34840
#define sipName_PM_SmallIconSize &sipStrings_QtWidgets[34840]
#define sipNameNr_PM_MDIFrameWidth 34857
#define sipName_PM_MDIFrameWidth &sipStrings_QtWidgets[34857]
#define sipNameNr_PM_SplitterWidth 34874
#define sipName_PM_SplitterWidth &sipStrings_QtWidgets[34874]
#define sipNameNr_SC_GroupBoxFrame 34891
#define sipName_SC_GroupBoxFrame &sipStrings_QtWidgets[34891]
#define sipNameNr_SC_GroupBoxLabel 34908
#define sipName_SC_GroupBoxLabel &sipStrings_QtWidgets[34908]
#define sipNameNr_SC_DialTickmarks 34925
#define sipName_SC_DialTickmarks &sipStrings_QtWidgets[34925]
#define sipNameNr_SC_TitleBarLabel 34942
#define sipName_SC_TitleBarLabel &sipStrings_QtWidgets[34942]
#define sipNameNr_SC_ComboBoxArrow 34959
#define sipName_SC_ComboBoxArrow &sipStrings_QtWidgets[34959]
#define sipNameNr_SC_ComboBoxFrame 34976
#define sipName_SC_ComboBoxFrame &sipStrings_QtWidgets[34976]
#define sipNameNr_SC_ScrollBarLast 34993
#define sipName_SC_ScrollBarLast &sipStrings_QtWidgets[34993]
#define sipNameNr_SE_ToolBarHandle 35010
#define sipName_SE_ToolBarHandle &sipStrings_QtWidgets[35010]
#define sipNameNr_SE_TabBarTabText 35027
#define sipName_SE_TabBarTabText &sipStrings_QtWidgets[35027]
#define sipNameNr_SE_FrameContents 35044
#define sipName_SE_FrameContents &sipStrings_QtWidgets[35044]
#define sipNameNr_CE_ComboBoxLabel 35061
#define sipName_CE_ComboBoxLabel &sipStrings_QtWidgets[35061]
#define sipNameNr_CE_ScrollBarLast 35078
#define sipName_CE_ScrollBarLast &sipStrings_QtWidgets[35078]
#define sipNameNr_CE_HeaderSection 35095
#define sipName_CE_HeaderSection &sipStrings_QtWidgets[35095]
#define sipNameNr_CE_MenuEmptyArea 35112
#define sipName_CE_MenuEmptyArea &sipStrings_QtWidgets[35112]
#define sipNameNr_CE_CheckBoxLabel 35129
#define sipName_CE_CheckBoxLabel &sipStrings_QtWidgets[35129]
#define sipNameNr_PE_PanelTipLabel 35146
#define sipName_PE_PanelTipLabel &sipStrings_QtWidgets[35146]
#define sipNameNr_PE_PanelLineEdit 35163
#define sipName_PE_PanelLineEdit &sipStrings_QtWidgets[35163]
#define sipNameNr_PE_FrameLineEdit 35180
#define sipName_PE_FrameLineEdit &sipStrings_QtWidgets[35180]
#define sipNameNr_PE_FrameGroupBox 35197
#define sipName_PE_FrameGroupBox &sipStrings_QtWidgets[35197]
#define sipNameNr_PrimitiveElement 13404
#define sipName_PrimitiveElement &sipStrings_QtWidgets[13404]
#define sipNameNr_State_Horizontal 35214
#define sipName_State_Horizontal &sipStrings_QtWidgets[35214]
#define sipNameNr_setCurrentWidget 35231
#define sipName_setCurrentWidget &sipStrings_QtWidgets[35231]
#define sipNameNr_horizontalPolicy 35248
#define sipName_horizontalPolicy &sipStrings_QtWidgets[35248]
#define sipNameNr_MinimumExpanding 35265
#define sipName_MinimumExpanding &sipStrings_QtWidgets[35265]
#define sipNameNr_QScroller__Input 35282
#define sipName_QScroller__Input &sipStrings_QtWidgets[35282]
#define sipNameNr_QScroller__State 35299
#define sipName_QScroller__State &sipStrings_QtWidgets[35299]
#define sipNameNr_setOverwriteMode 35316
#define sipName_setOverwriteMode &sipStrings_QtWidgets[35316]
#define sipNameNr_setDocumentTitle 35333
#define sipName_setDocumentTitle &sipStrings_QtWidgets[35333]
#define sipNameNr_setTextureFormat 35350
#define sipName_setTextureFormat &sipStrings_QtWidgets[35350]
#define sipNameNr_setDefaultButton 35367
#define sipName_setDefaultButton &sipStrings_QtWidgets[35367]
#define sipNameNr_setNativeMenuBar 35384
#define sipName_setNativeMenuBar &sipStrings_QtWidgets[35384]
#define sipNameNr_setDefaultAction 35401
#define sipName_setDefaultAction &sipStrings_QtWidgets[35401]
#define sipNameNr_isTearOffEnabled 35418
#define sipName_isTearOffEnabled &sipStrings_QtWidgets[35418]
#define sipNameNr_keyboardPageStep 35435
#define sipName_keyboardPageStep &sipStrings_QtWidgets[35435]
#define sipNameNr_SubWindowOptions 5646
#define sipName_SubWindowOptions &sipStrings_QtWidgets[5646]
#define sipNameNr_RubberBandResize 35452
#define sipName_RubberBandResize &sipStrings_QtWidgets[35452]
#define sipNameNr_currentSubWindow 35469
#define sipName_currentSubWindow &sipStrings_QtWidgets[35469]
#define sipNameNr_ForceTabbedDocks 35486
#define sipName_ForceTabbedDocks &sipStrings_QtWidgets[35486]
#define sipNameNr_AllowTabbedDocks 35503
#define sipName_AllowTabbedDocks &sipStrings_QtWidgets[35503]
#define sipNameNr_AllowNestedDocks 35520
#define sipName_AllowNestedDocks &sipStrings_QtWidgets[35520]
#define sipNameNr_tabifyDockWidget 35537
#define sipName_tabifyDockWidget &sipStrings_QtWidgets[35537]
#define sipNameNr_removeDockWidget 35554
#define sipName_removeDockWidget &sipStrings_QtWidgets[35554]
#define sipNameNr_setCentralWidget 35571
#define sipName_setCentralWidget &sipStrings_QtWidgets[35571]
#define sipNameNr_removeItemWidget 35588
#define sipName_removeItemWidget &sipStrings_QtWidgets[35588]
#define sipNameNr_isSortingEnabled 35605
#define sipName_isSortingEnabled &sipStrings_QtWidgets[35605]
#define sipNameNr_setItemAlignment 35622
#define sipName_setItemAlignment &sipStrings_QtWidgets[35622]
#define sipNameNr_uniformItemSizes 35639
#define sipName_uniformItemSizes &sipStrings_QtWidgets[35639]
#define sipNameNr_TrailingPosition 35656
#define sipName_TrailingPosition &sipStrings_QtWidgets[35656]
#define sipNameNr_cursorPositionAt 35673
#define sipName_cursorPositionAt &sipStrings_QtWidgets[35673]
#define sipNameNr_QLCDNumber__Mode 35690
#define sipName_QLCDNumber__Mode &sipStrings_QtWidgets[35690]
#define sipNameNr_totalMaximumSize 35707
#define sipName_totalMaximumSize &sipStrings_QtWidgets[35707]
#define sipNameNr_totalMinimumSize 35724
#define sipName_totalMinimumSize &sipStrings_QtWidgets[35724]
#define sipNameNr_SetMinAndMaxSize 35741
#define sipName_SetMinAndMaxSize &sipStrings_QtWidgets[35741]
#define sipNameNr_QKeySequenceEdit 35758
#define sipName_QKeySequenceEdit &sipStrings_QtWidgets[35758]
#define sipNameNr_intValueSelected 35775
#define sipName_intValueSelected &sipStrings_QtWidgets[35775]
#define sipNameNr_textValueChanged 35792
#define sipName_textValueChanged &sipStrings_QtWidgets[35792]
#define sipNameNr_cancelButtonText 35809
#define sipName_cancelButtonText &sipStrings_QtWidgets[35809]
#define sipNameNr_setDoubleMaximum 35826
#define sipName_setDoubleMaximum &sipStrings_QtWidgets[35826]
#define sipNameNr_setDoubleMinimum 35843
#define sipName_setDoubleMinimum &sipStrings_QtWidgets[35843]
#define sipNameNr_setComboBoxItems 35860
#define sipName_setComboBoxItems &sipStrings_QtWidgets[35860]
#define sipNameNr_getMultiLineText 35877
#define sipName_getMultiLineText &sipStrings_QtWidgets[35877]
#define sipNameNr_defaultAlignment 35894
#define sipName_defaultAlignment &sipStrings_QtWidgets[35894]
#define sipNameNr_sectionsInserted 35911
#define sipName_sectionsInserted &sipStrings_QtWidgets[35911]
#define sipNameNr_setSortIndicator 35928
#define sipName_setSortIndicator &sipStrings_QtWidgets[35928]
#define sipNameNr_setSectionHidden 35945
#define sipName_setSectionHidden &sipStrings_QtWidgets[35945]
#define sipNameNr_ResizeToContents 35962
#define sipName_ResizeToContents &sipStrings_QtWidgets[35962]
#define sipNameNr_setColumnStretch 35979
#define sipName_setColumnStretch &sipStrings_QtWidgets[35979]
#define sipNameNr_windowFrameEvent 35996
#define sipName_windowFrameEvent &sipStrings_QtWidgets[35996]
#define sipNameNr_paintWindowFrame 36013
#define sipName_paintWindowFrame &sipStrings_QtWidgets[36013]
#define sipNameNr_OptimizationFlag 5710
#define sipName_OptimizationFlag &sipStrings_QtWidgets[5710]
#define sipNameNr_NoViewportUpdate 36030
#define sipName_NoViewportUpdate &sipStrings_QtWidgets[36030]
#define sipNameNr_AnchorUnderMouse 36047
#define sipName_AnchorUnderMouse &sipStrings_QtWidgets[36047]
#define sipNameNr_AnchorViewCenter 36064
#define sipName_AnchorViewCenter &sipStrings_QtWidgets[36064]
#define sipNameNr_focusItemChanged 36081
#define sipName_focusItemChanged &sipStrings_QtWidgets[36081]
#define sipNameNr_sceneRectChanged 36098
#define sipName_sceneRectChanged &sipStrings_QtWidgets[36098]
#define sipNameNr_mouseGrabberItem 36115
#define sipName_mouseGrabberItem &sipStrings_QtWidgets[36115]
#define sipNameNr_destroyItemGroup 36132
#define sipName_destroyItemGroup &sipStrings_QtWidgets[36132]
#define sipNameNr_setSelectionArea 36149
#define sipName_setSelectionArea &sipStrings_QtWidgets[36149]
#define sipNameNr_ungrabMouseEvent 36166
#define sipName_ungrabMouseEvent &sipStrings_QtWidgets[36166]
#define sipNameNr_setOwnedByLayout 36183
#define sipName_setOwnedByLayout &sipStrings_QtWidgets[36183]
#define sipNameNr_parentLayoutItem 36200
#define sipName_parentLayoutItem &sipStrings_QtWidgets[36200]
#define sipNameNr_setPreferredSize 36217
#define sipName_setPreferredSize &sipStrings_QtWidgets[36217]
#define sipNameNr_defaultTextColor 36234
#define sipName_defaultTextColor &sipStrings_QtWidgets[36234]
#define sipNameNr_updateMicroFocus 36251
#define sipName_updateMicroFocus &sipStrings_QtWidgets[36251]
#define sipNameNr_inputMethodHints 36268
#define sipName_inputMethodHints &sipStrings_QtWidgets[36268]
#define sipNameNr_setPanelModality 36285
#define sipName_setPanelModality &sipStrings_QtWidgets[36285]
#define sipNameNr_toGraphicsObject 36302
#define sipName_toGraphicsObject &sipStrings_QtWidgets[36302]
#define sipNameNr_mapRectFromScene 36319
#define sipName_mapRectFromScene &sipStrings_QtWidgets[36319]
#define sipNameNr_effectiveOpacity 36336
#define sipName_effectiveOpacity &sipStrings_QtWidgets[36336]
#define sipNameNr_logicalCacheSize 36353
#define sipName_logicalCacheSize &sipStrings_QtWidgets[36353]
#define sipNameNr_sceneEventFilter 36370
#define sipName_sceneEventFilter &sipStrings_QtWidgets[36370]
#define sipNameNr_collidesWithPath 36387
#define sipName_collidesWithPath &sipStrings_QtWidgets[36387]
#define sipNameNr_collidesWithItem 36404
#define sipName_collidesWithItem &sipStrings_QtWidgets[36404]
#define sipNameNr_ItemClipsToShape 36421
#define sipName_ItemClipsToShape &sipStrings_QtWidgets[36421]
#define sipNameNr_GraphicsItemFlag 5806
#define sipName_GraphicsItemFlag &sipStrings_QtWidgets[5806]
#define sipNameNr_ItemZValueChange 36438
#define sipName_ItemZValueChange &sipStrings_QtWidgets[36438]
#define sipNameNr_ItemCursorChange 36455
#define sipName_ItemCursorChange &sipStrings_QtWidgets[36455]
#define sipNameNr_ItemParentChange 36472
#define sipName_ItemParentChange &sipStrings_QtWidgets[36472]
#define sipNameNr_ItemMatrixChange 36489
#define sipName_ItemMatrixChange &sipStrings_QtWidgets[36489]
#define sipNameNr_rowMaximumHeight 36506
#define sipName_rowMaximumHeight &sipStrings_QtWidgets[36506]
#define sipNameNr_rowMinimumHeight 36523
#define sipName_rowMinimumHeight &sipStrings_QtWidgets[36523]
#define sipNameNr_rowStretchFactor 36540
#define sipName_rowStretchFactor &sipStrings_QtWidgets[36540]
#define sipNameNr_setColumnSpacing 36557
#define sipName_setColumnSpacing &sipStrings_QtWidgets[36557]
#define sipNameNr_blurHintsChanged 36574
#define sipName_blurHintsChanged &sipStrings_QtWidgets[36574]
#define sipNameNr_addCornerAnchors 36591
#define sipName_addCornerAnchors &sipStrings_QtWidgets[36591]
#define sipNameNr_ConsumeEventHint 36608
#define sipName_ConsumeEventHint &sipStrings_QtWidgets[36608]
#define sipNameNr_canceledGestures 36625
#define sipName_canceledGestures &sipStrings_QtWidgets[36625]
#define sipNameNr_setRotationAngle 36642
#define sipName_setRotationAngle &sipStrings_QtWidgets[36642]
#define sipNameNr_totalScaleFactor 36659
#define sipName_totalScaleFactor &sipStrings_QtWidgets[36659]
#define sipNameNr_startCenterPoint 36676
#define sipName_startCenterPoint &sipStrings_QtWidgets[36676]
#define sipNameNr_totalChangeFlags 36693
#define sipName_totalChangeFlags &sipStrings_QtWidgets[36693]
#define sipNameNr_setFormAlignment 36710
#define sipName_setFormAlignment &sipStrings_QtWidgets[36710]
#define sipNameNr_setRowWrapPolicy 36727
#define sipName_setRowWrapPolicy &sipStrings_QtWidgets[36727]
#define sipNameNr_FontDialogOption 7745
#define sipName_FontDialogOption &sipStrings_QtWidgets[7745]
#define sipNameNr_setWritingSystem 36744
#define sipName_setWritingSystem &sipStrings_QtWidgets[36744]
#define sipNameNr_NonScalableFonts 36761
#define sipName_NonScalableFonts &sipStrings_QtWidgets[36761]
#define sipNameNr_QFileSystemModel 36778
#define sipName_QFileSystemModel &sipStrings_QtWidgets[36778]
#define sipNameNr_selectNameFilter 36795
#define sipName_selectNameFilter &sipStrings_QtWidgets[36795]
#define sipNameNr_getOpenFileNames 36812
#define sipName_getOpenFileNames &sipStrings_QtWidgets[36812]
#define sipNameNr_supportedSchemes 36829
#define sipName_supportedSchemes &sipStrings_QtWidgets[36829]
#define sipNameNr_directoryEntered 36846
#define sipName_directoryEntered &sipStrings_QtWidgets[36846]
#define sipNameNr_setDefaultSuffix 36863
#define sipName_setDefaultSuffix &sipStrings_QtWidgets[36863]
#define sipNameNr_toggleViewAction 36880
#define sipName_toggleViewAction &sipStrings_QtWidgets[36880]
#define sipNameNr_QDirModel__Roles 36897
#define sipName_QDirModel__Roles &sipStrings_QtWidgets[36897]
#define sipNameNr_setCenterButtons 36914
#define sipName_setCenterButtons &sipStrings_QtWidgets[36914]
#define sipNameNr_QDialogButtonBox 36931
#define sipName_QDialogButtonBox &sipStrings_QtWidgets[36931]
#define sipNameNr_isVirtualDesktop 36948
#define sipName_isVirtualDesktop &sipStrings_QtWidgets[36948]
#define sipNameNr_setDateTimeRange 36965
#define sipName_setDateTimeRange &sipStrings_QtWidgets[36965]
#define sipNameNr_textFromDateTime 36982
#define sipName_textFromDateTime &sipStrings_QtWidgets[36982]
#define sipNameNr_dateTimeFromText 36999
#define sipName_dateTimeFromText &sipStrings_QtWidgets[36999]
#define sipNameNr_setCalendarPopup 37016
#define sipName_setCalendarPopup &sipStrings_QtWidgets[37016]
#define sipNameNr_setDisplayFormat 37033
#define sipName_setDisplayFormat &sipStrings_QtWidgets[37033]
#define sipNameNr_clearMaximumTime 37050
#define sipName_clearMaximumTime &sipStrings_QtWidgets[37050]
#define sipNameNr_clearMinimumTime 37067
#define sipName_clearMinimumTime &sipStrings_QtWidgets[37067]
#define sipNameNr_clearMaximumDate 37084
#define sipName_clearMaximumDate &sipStrings_QtWidgets[37084]
#define sipNameNr_clearMinimumDate 37101
#define sipName_clearMinimumDate &sipStrings_QtWidgets[37101]
#define sipNameNr_completionPrefix 37118
#define sipName_completionPrefix &sipStrings_QtWidgets[37118]
#define sipNameNr_completionColumn 37135
#define sipName_completionColumn &sipStrings_QtWidgets[37135]
#define sipNameNr_InlineCompletion 37152
#define sipName_InlineCompletion &sipStrings_QtWidgets[37152]
#define sipNameNr_sizeFromContents 37169
#define sipName_sizeFromContents &sipStrings_QtWidgets[37169]
#define sipNameNr_initializeColumn 37186
#define sipName_initializeColumn &sipStrings_QtWidgets[37186]
#define sipNameNr_setPreviewWidget 37203
#define sipName_setPreviewWidget &sipStrings_QtWidgets[37203]
#define sipNameNr_setStandardColor 37220
#define sipName_setStandardColor &sipStrings_QtWidgets[37220]
#define sipNameNr_ShowAlphaChannel 37237
#define sipName_ShowAlphaChannel &sipStrings_QtWidgets[37237]
#define sipNameNr_showSelectedDate 37254
#define sipName_showSelectedDate &sipStrings_QtWidgets[37254]
#define sipNameNr_showPreviousYear 37271
#define sipName_showPreviousYear &sipStrings_QtWidgets[37271]
#define sipNameNr_headerTextFormat 37288
#define sipName_headerTextFormat &sipStrings_QtWidgets[37288]
#define sipNameNr_NoVerticalHeader 37305
#define sipName_NoVerticalHeader &sipStrings_QtWidgets[37305]
#define sipNameNr_insertSpacerItem 37322
#define sipName_insertSpacerItem &sipStrings_QtWidgets[37322]
#define sipNameNr_setStretchFactor 37339
#define sipName_setStretchFactor &sipStrings_QtWidgets[37339]
#define sipNameNr_setEffectEnabled 37356
#define sipName_setEffectEnabled &sipStrings_QtWidgets[37356]
#define sipNameNr_setStartDragTime 37373
#define sipName_setStartDragTime &sipStrings_QtWidgets[37373]
#define sipNameNr_keyboardTracking 37390
#define sipName_keyboardTracking &sipStrings_QtWidgets[37390]
#define sipNameNr_specialValueText 37407
#define sipName_specialValueText &sipStrings_QtWidgets[37407]
#define sipNameNr_setButtonSymbols 37424
#define sipName_setButtonSymbols &sipStrings_QtWidgets[37424]
#define sipNameNr_QAbstractSpinBox 37441
#define sipName_QAbstractSpinBox &sipStrings_QtWidgets[37441]
#define sipNameNr_invertedControls 37458
#define sipName_invertedControls &sipStrings_QtWidgets[37458]
#define sipNameNr_sizeAdjustPolicy 37475
#define sipName_sizeAdjustPolicy &sipStrings_QtWidgets[37475]
#define sipNameNr_AdjustToContents 37492
#define sipName_AdjustToContents &sipStrings_QtWidgets[37492]
#define sipNameNr_SizeAdjustPolicy 2855
#define sipName_SizeAdjustPolicy &sipStrings_QtWidgets[2855]
#define sipNameNr_scrollBarWidgets 37509
#define sipName_scrollBarWidgets &sipStrings_QtWidgets[37509]
#define sipNameNr_scrollContentsBy 37526
#define sipName_scrollContentsBy &sipStrings_QtWidgets[37526]
#define sipNameNr_contextMenuEvent 37543
#define sipName_contextMenuEvent &sipStrings_QtWidgets[37543]
#define sipNameNr_viewportSizeHint 37560
#define sipName_viewportSizeHint &sipStrings_QtWidgets[37560]
#define sipNameNr_inputMethodEvent 37577
#define sipName_inputMethodEvent &sipStrings_QtWidgets[37577]
#define sipNameNr_autoScrollMargin 37594
#define sipName_autoScrollMargin &sipStrings_QtWidgets[37594]
#define sipNameNr_inputMethodQuery 37611
#define sipName_inputMethodQuery &sipStrings_QtWidgets[37611]
#define sipNameNr_selectionCommand 37628
#define sipName_selectionCommand &sipStrings_QtWidgets[37628]
#define sipNameNr_horizontalOffset 37645
#define sipName_horizontalOffset &sipStrings_QtWidgets[37645]
#define sipNameNr_updateGeometries 37662
#define sipName_updateGeometries &sipStrings_QtWidgets[37662]
#define sipNameNr_updateEditorData 37679
#define sipName_updateEditorData &sipStrings_QtWidgets[37679]
#define sipNameNr_sizeHintForIndex 37696
#define sipName_sizeHintForIndex &sipStrings_QtWidgets[37696]
#define sipNameNr_setTextElideMode 37713
#define sipName_setTextElideMode &sipStrings_QtWidgets[37713]
#define sipNameNr_tabKeyNavigation 37730
#define sipName_tabKeyNavigation &sipStrings_QtWidgets[37730]
#define sipNameNr_setSelectionMode 37747
#define sipName_setSelectionMode &sipStrings_QtWidgets[37747]
#define sipNameNr_PositionAtCenter 37764
#define sipName_PositionAtCenter &sipStrings_QtWidgets[37764]
#define sipNameNr_PositionAtBottom 37781
#define sipName_PositionAtBottom &sipStrings_QtWidgets[37781]
#define sipNameNr_RevertModelCache 37798
#define sipName_RevertModelCache &sipStrings_QtWidgets[37798]
#define sipNameNr_SubmitModelCache 37815
#define sipName_SubmitModelCache &sipStrings_QtWidgets[37815]
#define sipNameNr_EditPreviousItem 37832
#define sipName_EditPreviousItem &sipStrings_QtWidgets[37832]
#define sipNameNr_setAutoExclusive 37849
#define sipName_setAutoExclusive &sipStrings_QtWidgets[37849]
#define sipNameNr_setMaximumHeight 37866
#define sipName_setMaximumHeight &sipStrings_QtWidgets[37866]
#define sipNameNr_setMinimumHeight 37883
#define sipName_setMinimumHeight &sipStrings_QtWidgets[37883]
#define sipNameNr_setSizeIncrement 37900
#define sipName_setSizeIncrement &sipStrings_QtWidgets[37900]
#define sipNameNr_setTextDirection 37917
#define sipName_setTextDirection &sipStrings_QtWidgets[37917]
#define sipNameNr_setFontUnderline 37934
#define sipName_setFontUnderline &sipStrings_QtWidgets[37934]
#define sipNameNr_setFontPointSize 37951
#define sipName_setFontPointSize &sipStrings_QtWidgets[37951]
#define sipNameNr_wheelScrollLines 37968
#define sipName_wheelScrollLines &sipStrings_QtWidgets[37968]
#define sipNameNr_setTextAlignment 37985
#define sipName_setTextAlignment &sipStrings_QtWidgets[37985]
#define sipNameNr_setItemPrototype 38002
#define sipName_setItemPrototype &sipStrings_QtWidgets[38002]
#define sipNameNr_drawInlineObject 38019
#define sipName_drawInlineObject &sipStrings_QtWidgets[38019]
#define sipNameNr_selectionChanged 38036
#define sipName_selectionChanged &sipStrings_QtWidgets[38036]
#define sipNameNr_disconnectNotify 38053
#define sipName_disconnectNotify &sipStrings_QtWidgets[38053]
#define sipNameNr_ItemIsSelectable 38070
#define sipName_ItemIsSelectable &sipStrings_QtWidgets[38070]
#define sipNameNr_38087 38087
#define sipName_38087 &sipStrings_QtWidgets[38087]
#define sipNameNr_38103 38103
#define sipName_38103 &sipStrings_QtWidgets[38103]
#define sipNameNr_completeChanged 38119
#define sipName_completeChanged &sipStrings_QtWidgets[38119]
#define sipNameNr_setButtonLayout 38135
#define sipName_setButtonLayout &sipStrings_QtWidgets[38135]
#define sipNameNr_NoDefaultButton 38151
#define sipName_NoDefaultButton &sipStrings_QtWidgets[38151]
#define sipNameNr_IgnoreSubTitles 38167
#define sipName_IgnoreSubTitles &sipStrings_QtWidgets[38167]
#define sipNameNr_WatermarkPixmap 14199
#define sipName_WatermarkPixmap &sipStrings_QtWidgets[14199]
#define sipNameNr_toolTipDuration 38183
#define sipName_toolTipDuration &sipStrings_QtWidgets[38183]
#define sipNameNr_restoreGeometry 38199
#define sipName_restoreGeometry &sipStrings_QtWidgets[38199]
#define sipNameNr_keyboardGrabber 38215
#define sipName_keyboardGrabber &sipStrings_QtWidgets[38215]
#define sipNameNr_releaseKeyboard 38231
#define sipName_releaseKeyboard &sipStrings_QtWidgets[38231]
#define sipNameNr_QWIDGETSIZE_MAX 38247
#define sipName_QWIDGETSIZE_MAX &sipStrings_QtWidgets[38247]
#define sipNameNr_inWhatsThisMode 38263
#define sipName_inWhatsThisMode &sipStrings_QtWidgets[38263]
#define sipNameNr_undoTextChanged 38279
#define sipName_undoTextChanged &sipStrings_QtWidgets[38279]
#define sipNameNr_redoTextChanged 38295
#define sipName_redoTextChanged &sipStrings_QtWidgets[38295]
#define sipNameNr_setHeaderLabels 38311
#define sipName_setHeaderLabels &sipStrings_QtWidgets[38311]
#define sipNameNr_addTopLevelItem 38327
#define sipName_addTopLevelItem &sipStrings_QtWidgets[38327]
#define sipNameNr_QTreeWidgetItem 38343
#define sipName_QTreeWidgetItem &sipStrings_QtWidgets[38343]
#define sipNameNr_setTreePosition 38359
#define sipName_setTreePosition &sipStrings_QtWidgets[38359]
#define sipNameNr_setHeaderHidden 38375
#define sipName_setHeaderHidden &sipStrings_QtWidgets[38375]
#define sipNameNr_autoExpandDelay 38391
#define sipName_autoExpandDelay &sipStrings_QtWidgets[38391]
#define sipNameNr_itemsExpandable 38407
#define sipName_itemsExpandable &sipStrings_QtWidgets[38407]
#define sipNameNr_rootIsDecorated 38423
#define sipName_rootIsDecorated &sipStrings_QtWidgets[38423]
#define sipNameNr_widgetForAction 38439
#define sipName_widgetForAction &sipStrings_QtWidgets[38439]
#define sipNameNr_FixedPixelWidth 38455
#define sipName_FixedPixelWidth &sipStrings_QtWidgets[38455]
#define sipNameNr_rowCountChanged 38471
#define sipName_rowCountChanged &sipStrings_QtWidgets[38471]
#define sipNameNr_setColumnHidden 38487
#define sipName_setColumnHidden &sipStrings_QtWidgets[38487]
#define sipNameNr_tabLayoutChange 38503
#define sipName_tabLayoutChange &sipStrings_QtWidgets[38503]
#define sipNameNr_setTabWhatsThis 38519
#define sipName_setTabWhatsThis &sipStrings_QtWidgets[38519]
#define sipNameNr_setTabTextColor 38535
#define sipName_setTabTextColor &sipStrings_QtWidgets[38535]
#define sipNameNr_TriangularSouth 38551
#define sipName_TriangularSouth &sipStrings_QtWidgets[38551]
#define sipNameNr_TriangularNorth 38567
#define sipName_TriangularNorth &sipStrings_QtWidgets[38567]
#define sipNameNr_QSystemTrayIcon 38583
#define sipName_QSystemTrayIcon &sipStrings_QtWidgets[38583]
#define sipNameNr_ToolBarFeatures 2893
#define sipName_ToolBarFeatures &sipStrings_QtWidgets[2893]
#define sipNameNr_ToolBarPosition 2930
#define sipName_ToolBarPosition &sipStrings_QtWidgets[2930]
#define sipNameNr_MenuButtonPopup 38599
#define sipName_MenuButtonPopup &sipStrings_QtWidgets[38599]
#define sipNameNr_ViewItemFeature 2438
#define sipName_ViewItemFeature &sipStrings_QtWidgets[2438]
#define sipNameNr_rightButtonSize 38615
#define sipName_rightButtonSize &sipStrings_QtWidgets[38615]
#define sipNameNr_NoCornerWidgets 38631
#define sipName_NoCornerWidgets &sipStrings_QtWidgets[38631]
#define sipNameNr_QStyleOptionTab 38647
#define sipName_QStyleOptionTab &sipStrings_QtWidgets[38647]
#define sipNameNr_SectionPosition 3554
#define sipName_SectionPosition &sipStrings_QtWidgets[3554]
#define sipNameNr_selectedTabRect 38663
#define sipName_selectedTabRect &sipStrings_QtWidgets[38663]
#define sipNameNr_StyleOptionType 303
#define sipName_StyleOptionType &sipStrings_QtWidgets[303]
#define sipNameNr_SO_GraphicsItem 38679
#define sipName_SO_GraphicsItem &sipStrings_QtWidgets[38679]
#define sipNameNr_visualAlignment 38695
#define sipName_visualAlignment &sipStrings_QtWidgets[38695]
#define sipNameNr_SP_ArrowForward 38711
#define sipName_SP_ArrowForward &sipStrings_QtWidgets[38711]
#define sipNameNr_SP_FileLinkIcon 38727
#define sipName_SP_FileLinkIcon &sipStrings_QtWidgets[38727]
#define sipNameNr_SP_DriveNetIcon 38743
#define sipName_SP_DriveNetIcon &sipStrings_QtWidgets[38743]
#define sipNameNr_SP_DriveDVDIcon 38759
#define sipName_SP_DriveDVDIcon &sipStrings_QtWidgets[38759]
#define sipNameNr_SP_ComputerIcon 38775
#define sipName_SP_ComputerIcon &sipStrings_QtWidgets[38775]
#define sipNameNr_SH_ToolTip_Mask 38791
#define sipName_SH_ToolTip_Mask &sipStrings_QtWidgets[38791]
#define sipNameNr_CT_ItemViewItem 38807
#define sipName_CT_ItemViewItem &sipStrings_QtWidgets[38807]
#define sipNameNr_PM_SizeGripSize 38823
#define sipName_PM_SizeGripSize &sipStrings_QtWidgets[38823]
#define sipNameNr_PM_HeaderMargin 38839
#define sipName_PM_HeaderMargin &sipStrings_QtWidgets[38839]
#define sipNameNr_PM_SliderLength 38855
#define sipName_PM_SliderLength &sipStrings_QtWidgets[38855]
#define sipNameNr_PM_ButtonMargin 38871
#define sipName_PM_ButtonMargin &sipStrings_QtWidgets[38871]
#define sipNameNr_SC_MdiMinButton 38887
#define sipName_SC_MdiMinButton &sipStrings_QtWidgets[38887]
#define sipNameNr_SC_SliderHandle 38903
#define sipName_SC_SliderHandle &sipStrings_QtWidgets[38903]
#define sipNameNr_SC_SliderGroove 38919
#define sipName_SC_SliderGroove &sipStrings_QtWidgets[38919]
#define sipNameNr_SC_SpinBoxFrame 38935
#define sipName_SC_SpinBoxFrame &sipStrings_QtWidgets[38935]
#define sipNameNr_CE_ItemViewItem 38951
#define sipName_CE_ItemViewItem &sipStrings_QtWidgets[38951]
#define sipNameNr_CE_MenuScroller 38967
#define sipName_CE_MenuScroller &sipStrings_QtWidgets[38967]
#define sipNameNr_PE_PanelToolBar 38983
#define sipName_PE_PanelToolBar &sipStrings_QtWidgets[38983]
#define sipNameNr_PE_PanelMenuBar 38999
#define sipName_PE_PanelMenuBar &sipStrings_QtWidgets[38999]
#define sipNameNr_State_MouseOver 39015
#define sipName_State_MouseOver &sipStrings_QtWidgets[39015]
#define sipNameNr_State_AutoRaise 39031
#define sipName_State_AutoRaise &sipStrings_QtWidgets[39031]
#define sipNameNr_State_DownArrow 39047
#define sipName_State_DownArrow &sipStrings_QtWidgets[39047]
#define sipNameNr_setStackingMode 39063
#define sipName_setStackingMode &sipStrings_QtWidgets[39063]
#define sipNameNr_QSplitterHandle 39079
#define sipName_QSplitterHandle &sipStrings_QtWidgets[39079]
#define sipNameNr_setOpaqueResize 39095
#define sipName_setOpaqueResize &sipStrings_QtWidgets[39095]
#define sipNameNr_setTickInterval 39111
#define sipName_setTickInterval &sipStrings_QtWidgets[39111]
#define sipNameNr_setTickPosition 39127
#define sipName_setTickPosition &sipStrings_QtWidgets[39127]
#define sipNameNr_verticalStretch 39143
#define sipName_verticalStretch &sipStrings_QtWidgets[39143]
#define sipNameNr_ambiguousMember 39159
#define sipName_ambiguousMember &sipStrings_QtWidgets[39159]
#define sipNameNr_setScrollMetric 39175
#define sipName_setScrollMetric &sipStrings_QtWidgets[39175]
#define sipNameNr_MaximumVelocity 39191
#define sipName_MaximumVelocity &sipStrings_QtWidgets[39191]
#define sipNameNr_MinimumVelocity 39207
#define sipName_MinimumVelocity &sipStrings_QtWidgets[39207]
#define sipNameNr_OvershootPolicy 3300
#define sipName_OvershootPolicy &sipStrings_QtWidgets[3300]
#define sipNameNr_activeScrollers 39223
#define sipName_activeScrollers &sipStrings_QtWidgets[39223]
#define sipNameNr_widgetResizable 39239
#define sipName_widgetResizable &sipStrings_QtWidgets[39239]
#define sipNameNr_standardPalette 39255
#define sipName_standardPalette &sipStrings_QtWidgets[39255]
#define sipNameNr_minimumDuration 39271
#define sipName_minimumDuration &sipStrings_QtWidgets[39271]
#define sipNameNr_setCancelButton 39287
#define sipName_setCancelButton &sipStrings_QtWidgets[39287]
#define sipNameNr_QProgressDialog 39303
#define sipName_QProgressDialog &sipStrings_QtWidgets[39303]
#define sipNameNr_getPaintContext 39319
#define sipName_getPaintContext &sipStrings_QtWidgets[39319]
#define sipNameNr_appendPlainText 39335
#define sipName_appendPlainText &sipStrings_QtWidgets[39335]
#define sipNameNr_insertPlainText 39351
#define sipName_insertPlainText &sipStrings_QtWidgets[39351]
#define sipNameNr_extraSelections 39367
#define sipName_extraSelections &sipStrings_QtWidgets[39367]
#define sipNameNr_setTabStopWidth 39383
#define sipName_setTabStopWidth &sipStrings_QtWidgets[39383]
#define sipNameNr_setWordWrapMode 39399
#define sipName_setWordWrapMode &sipStrings_QtWidgets[39399]
#define sipNameNr_setLineWrapMode 39415
#define sipName_setLineWrapMode &sipStrings_QtWidgets[39415]
#define sipNameNr_setDetailedText 39431
#define sipName_setDetailedText &sipStrings_QtWidgets[39431]
#define sipNameNr_informativeText 39447
#define sipName_informativeText &sipStrings_QtWidgets[39447]
#define sipNameNr_setEscapeButton 39463
#define sipName_setEscapeButton &sipStrings_QtWidgets[39463]
#define sipNameNr_isNativeMenuBar 39479
#define sipName_isNativeMenuBar &sipStrings_QtWidgets[39479]
#define sipNameNr_showTearOffMenu 39495
#define sipName_showTearOffMenu &sipStrings_QtWidgets[39495]
#define sipNameNr_toolTipsVisible 39511
#define sipName_toolTipsVisible &sipStrings_QtWidgets[39511]
#define sipNameNr_setActiveAction 39527
#define sipName_setActiveAction &sipStrings_QtWidgets[39527]
#define sipNameNr_hideTearOffMenu 39543
#define sipName_hideTearOffMenu &sipStrings_QtWidgets[39543]
#define sipNameNr_aboutToActivate 39559
#define sipName_aboutToActivate &sipStrings_QtWidgets[39559]
#define sipNameNr_SubWindowOption 6622
#define sipName_SubWindowOption &sipStrings_QtWidgets[6622]
#define sipNameNr_setTabsClosable 39575
#define sipName_setTabsClosable &sipStrings_QtWidgets[39575]
#define sipNameNr_activationOrder 39591
#define sipName_activationOrder &sipStrings_QtWidgets[39591]
#define sipNameNr_removeSubWindow 39607
#define sipName_removeSubWindow &sipStrings_QtWidgets[39607]
#define sipNameNr_activeSubWindow 39623
#define sipName_activeSubWindow &sipStrings_QtWidgets[39623]
#define sipNameNr_setDocumentMode 39639
#define sipName_setDocumentMode &sipStrings_QtWidgets[39639]
#define sipNameNr_GroupedDragging 39655
#define sipName_GroupedDragging &sipStrings_QtWidgets[39655]
#define sipNameNr_createPopupMenu 39671
#define sipName_createPopupMenu &sipStrings_QtWidgets[39671]
#define sipNameNr_splitDockWidget 39687
#define sipName_splitDockWidget &sipStrings_QtWidgets[39687]
#define sipNameNr_addToolBarBreak 39703
#define sipName_addToolBarBreak &sipStrings_QtWidgets[39703]
#define sipNameNr_toolButtonStyle 39719
#define sipName_toolButtonStyle &sipStrings_QtWidgets[39719]
#define sipNameNr_QListWidgetItem 39735
#define sipName_QListWidgetItem &sipStrings_QtWidgets[39735]
#define sipNameNr_QListView__Flow 39751
#define sipName_QListView__Flow &sipStrings_QtWidgets[39751]
#define sipNameNr_selectionLength 39767
#define sipName_selectionLength &sipStrings_QtWidgets[39767]
#define sipNameNr_LeadingPosition 39783
#define sipName_LeadingPosition &sipStrings_QtWidgets[39783]
#define sipNameNr_setSegmentStyle 39799
#define sipName_setSegmentStyle &sipStrings_QtWidgets[39799]
#define sipNameNr_contentsMargins 39815
#define sipName_contentsMargins &sipStrings_QtWidgets[39815]
#define sipNameNr_SetNoConstraint 39831
#define sipName_SetNoConstraint &sipStrings_QtWidgets[39831]
#define sipNameNr_hasSelectedText 39847
#define sipName_hasSelectedText &sipStrings_QtWidgets[39847]
#define sipNameNr_setModifierMask 39863
#define sipName_setModifierMask &sipStrings_QtWidgets[39863]
#define sipNameNr_intValueChanged 39879
#define sipName_intValueChanged &sipStrings_QtWidgets[39879]
#define sipNameNr_setOkButtonText 39895
#define sipName_setOkButtonText &sipStrings_QtWidgets[39895]
#define sipNameNr_setTextEchoMode 39911
#define sipName_setTextEchoMode &sipStrings_QtWidgets[39911]
#define sipNameNr_sectionsMovable 39927
#define sipName_sectionsMovable &sipStrings_QtWidgets[39927]
#define sipNameNr_isSectionHidden 39943
#define sipName_isSectionHidden &sipStrings_QtWidgets[39943]
#define sipNameNr_sectionPosition 39959
#define sipName_sectionPosition &sipStrings_QtWidgets[39959]
#define sipNameNr_sectionSizeHint 39975
#define sipName_sectionSizeHint &sipStrings_QtWidgets[39975]
#define sipNameNr_setOriginCorner 39991
#define sipName_setOriginCorner &sipStrings_QtWidgets[39991]
#define sipNameNr_releaseShortcut 40007
#define sipName_releaseShortcut &sipStrings_QtWidgets[40007]
#define sipNameNr_windowFrameRect 40023
#define sipName_windowFrameRect &sipStrings_QtWidgets[40023]
#define sipNameNr_DontClipPainter 40039
#define sipName_DontClipPainter &sipStrings_QtWidgets[40039]
#define sipNameNr_updateSceneRect 40055
#define sipName_updateSceneRect &sipStrings_QtWidgets[40055]
#define sipNameNr_invalidateScene 40071
#define sipName_invalidateScene &sipStrings_QtWidgets[40071]
#define sipNameNr_setResizeAnchor 40087
#define sipName_setResizeAnchor &sipStrings_QtWidgets[40087]
#define sipNameNr_CacheBackground 40103
#define sipName_CacheBackground &sipStrings_QtWidgets[40103]
#define sipNameNr_setFocusOnTouch 40119
#define sipName_setFocusOnTouch &sipStrings_QtWidgets[40119]
#define sipNameNr_setBspTreeDepth 40135
#define sipName_setBspTreeDepth &sipStrings_QtWidgets[40135]
#define sipNameNr_ForegroundLayer 40151
#define sipName_ForegroundLayer &sipStrings_QtWidgets[40151]
#define sipNameNr_BackgroundLayer 40167
#define sipName_BackgroundLayer &sipStrings_QtWidgets[40167]
#define sipNameNr_foregroundBrush 40183
#define sipName_foregroundBrush &sipStrings_QtWidgets[40183]
#define sipNameNr_createItemGroup 40199
#define sipName_createItemGroup &sipStrings_QtWidgets[40199]
#define sipNameNr_itemIndexMethod 40215
#define sipName_itemIndexMethod &sipStrings_QtWidgets[40215]
#define sipNameNr_ItemIndexMethod 5743
#define sipName_ItemIndexMethod &sipStrings_QtWidgets[5743]
#define sipNameNr_QGraphicsWidget 40231
#define sipName_QGraphicsWidget &sipStrings_QtWidgets[40231]
#define sipNameNr_setGraphicsItem 40247
#define sipName_setGraphicsItem &sipStrings_QtWidgets[40247]
#define sipNameNr_preferredHeight 40263
#define sipName_preferredHeight &sipStrings_QtWidgets[40263]
#define sipNameNr_tabChangesFocus 40279
#define sipName_tabChangesFocus &sipStrings_QtWidgets[40279]
#define sipNameNr_rotationChanged 40295
#define sipName_rotationChanged &sipStrings_QtWidgets[40295]
#define sipNameNr_QGraphicsObject 40311
#define sipName_QGraphicsObject &sipStrings_QtWidgets[40311]
#define sipNameNr_removeFromGroup 40327
#define sipName_removeFromGroup &sipStrings_QtWidgets[40327]
#define sipNameNr_transformations 40343
#define sipName_transformations &sipStrings_QtWidgets[40343]
#define sipNameNr_mapRectFromItem 40359
#define sipName_mapRectFromItem &sipStrings_QtWidgets[40359]
#define sipNameNr_mapRectToParent 40375
#define sipName_mapRectToParent &sipStrings_QtWidgets[40375]
#define sipNameNr_hoverLeaveEvent 40391
#define sipName_hoverLeaveEvent &sipStrings_QtWidgets[40391]
#define sipNameNr_hoverEnterEvent 40407
#define sipName_hoverEnterEvent &sipStrings_QtWidgets[40407]
#define sipNameNr_ItemIsFocusable 40423
#define sipName_ItemIsFocusable &sipStrings_QtWidgets[40423]
#define sipNameNr_ItemScaleChange 40439
#define sipName_ItemScaleChange &sipStrings_QtWidgets[40439]
#define sipNameNr_ItemFlagsChange 40455
#define sipName_ItemFlagsChange &sipStrings_QtWidgets[40455]
#define sipNameNr_ItemSceneChange 40471
#define sipName_ItemSceneChange &sipStrings_QtWidgets[40471]
#define sipNameNr_columnAlignment 40487
#define sipName_columnAlignment &sipStrings_QtWidgets[40487]
#define sipNameNr_setRowAlignment 40503
#define sipName_setRowAlignment &sipStrings_QtWidgets[40503]
#define sipNameNr_strengthChanged 40519
#define sipName_strengthChanged &sipStrings_QtWidgets[40519]
#define sipNameNr_boundingRectFor 40535
#define sipName_boundingRectFor &sipStrings_QtWidgets[40535]
#define sipNameNr_QGraphicsEffect 40551
#define sipName_QGraphicsEffect &sipStrings_QtWidgets[40551]
#define sipNameNr_QGraphicsLayout 40567
#define sipName_QGraphicsLayout &sipStrings_QtWidgets[40567]
#define sipNameNr_QGraphicsAnchor 40583
#define sipName_QGraphicsAnchor &sipStrings_QtWidgets[40583]
#define sipNameNr_lastScaleFactor 40599
#define sipName_lastScaleFactor &sipStrings_QtWidgets[40599]
#define sipNameNr_lastCenterPoint 40615
#define sipName_lastCenterPoint &sipStrings_QtWidgets[40615]
#define sipNameNr_setAcceleration 40631
#define sipName_setAcceleration &sipStrings_QtWidgets[40631]
#define sipNameNr_setMidLineWidth 40647
#define sipName_setMidLineWidth &sipStrings_QtWidgets[40647]
#define sipNameNr_getItemPosition 40663
#define sipName_getItemPosition &sipStrings_QtWidgets[40663]
#define sipNameNr_verticalSpacing 40679
#define sipName_verticalSpacing &sipStrings_QtWidgets[40679]
#define sipNameNr_MonospacedFonts 40695
#define sipName_MonospacedFonts &sipStrings_QtWidgets[40695]
#define sipNameNr_directoryLoaded 40711
#define sipName_directoryLoaded &sipStrings_QtWidgets[40711]
#define sipNameNr_rootPathChanged 40727
#define sipName_rootPathChanged &sipStrings_QtWidgets[40727]
#define sipNameNr_FilePermissions 40743
#define sipName_FilePermissions &sipStrings_QtWidgets[40743]
#define sipNameNr_saveFileContent 40759
#define sipName_saveFileContent &sipStrings_QtWidgets[40759]
#define sipNameNr_getOpenFileUrls 40775
#define sipName_getOpenFileUrls &sipStrings_QtWidgets[40775]
#define sipNameNr_mimeTypeFilters 40791
#define sipName_mimeTypeFilters &sipStrings_QtWidgets[40791]
#define sipNameNr_setDirectoryUrl 40807
#define sipName_setDirectoryUrl &sipStrings_QtWidgets[40807]
#define sipNameNr_getSaveFileName 40823
#define sipName_getSaveFileName &sipStrings_QtWidgets[40823]
#define sipNameNr_getOpenFileName 40839
#define sipName_getOpenFileName &sipStrings_QtWidgets[40839]
#define sipNameNr_qDrawShadePanel 40855
#define sipName_qDrawShadePanel &sipStrings_QtWidgets[40855]
#define sipNameNr_topLevelChanged 40871
#define sipName_topLevelChanged &sipStrings_QtWidgets[40871]
#define sipNameNr_featuresChanged 40887
#define sipName_featuresChanged &sipStrings_QtWidgets[40887]
#define sipNameNr_setAllowedAreas 40903
#define sipName_setAllowedAreas &sipStrings_QtWidgets[40903]
#define sipNameNr_resolveSymlinks 40919
#define sipName_resolveSymlinks &sipStrings_QtWidgets[40919]
#define sipNameNr_setIconProvider 40935
#define sipName_setIconProvider &sipStrings_QtWidgets[40935]
#define sipNameNr_standardButtons 40951
#define sipName_standardButtons &sipStrings_QtWidgets[40951]
#define sipNameNr_StandardButtons 4731
#define sipName_StandardButtons &sipStrings_QtWidgets[4731]
#define sipNameNr_RestoreDefaults 40967
#define sipName_RestoreDefaults &sipStrings_QtWidgets[40967]
#define sipNameNr_DestructiveRole 40983
#define sipName_DestructiveRole &sipStrings_QtWidgets[40983]
#define sipNameNr_workAreaResized 40999
#define sipName_workAreaResized &sipStrings_QtWidgets[40999]
#define sipNameNr_maximumDateTime 41015
#define sipName_maximumDateTime &sipStrings_QtWidgets[41015]
#define sipNameNr_minimumDateTime 41031
#define sipName_minimumDateTime &sipStrings_QtWidgets[41031]
#define sipNameNr_dateTimeChanged 41047
#define sipName_dateTimeChanged &sipStrings_QtWidgets[41047]
#define sipNameNr_setSubmitPolicy 41063
#define sipName_setSubmitPolicy &sipStrings_QtWidgets[41063]
#define sipNameNr_completionModel 41079
#define sipName_completionModel &sipStrings_QtWidgets[41079]
#define sipNameNr_completionCount 41095
#define sipName_completionCount &sipStrings_QtWidgets[41095]
#define sipNameNr_setModelSorting 41111
#define sipName_setModelSorting &sipStrings_QtWidgets[41111]
#define sipNameNr_PopupCompletion 12323
#define sipName_PopupCompletion &sipStrings_QtWidgets[12323]
#define sipNameNr_textHighlighted 41127
#define sipName_textHighlighted &sipStrings_QtWidgets[41127]
#define sipNameNr_editTextChanged 41143
#define sipName_editTextChanged &sipStrings_QtWidgets[41143]
#define sipNameNr_insertSeparator 41159
#define sipName_insertSeparator &sipStrings_QtWidgets[41159]
#define sipNameNr_setInsertPolicy 41175
#define sipName_setInsertPolicy &sipStrings_QtWidgets[41175]
#define sipNameNr_InsertAtCurrent 41191
#define sipName_InsertAtCurrent &sipStrings_QtWidgets[41191]
#define sipNameNr_maxVisibleItems 41207
#define sipName_maxVisibleItems &sipStrings_QtWidgets[41207]
#define sipNameNr_setColumnWidths 41223
#define sipName_setColumnWidths &sipStrings_QtWidgets[41223]
#define sipNameNr_setCurrentColor 41239
#define sipName_setCurrentColor &sipStrings_QtWidgets[41239]
#define sipNameNr_setSelectedDate 41255
#define sipName_setSelectedDate &sipStrings_QtWidgets[41255]
#define sipNameNr_QCalendarWidget 41271
#define sipName_QCalendarWidget &sipStrings_QtWidgets[41271]
#define sipNameNr_closeAllWindows 41287
#define sipName_closeAllWindows &sipStrings_QtWidgets[41287]
#define sipNameNr_isEffectEnabled 41303
#define sipName_isEffectEnabled &sipStrings_QtWidgets[41303]
#define sipNameNr_setActiveWindow 41319
#define sipName_setActiveWindow &sipStrings_QtWidgets[41319]
#define sipNameNr_topLevelWidgets 41335
#define sipName_topLevelWidgets &sipStrings_QtWidgets[41335]
#define sipNameNr_exclusionPolicy 41351
#define sipName_exclusionPolicy &sipStrings_QtWidgets[41351]
#define sipNameNr_ExclusionPolicy 7806
#define sipName_ExclusionPolicy &sipStrings_QtWidgets[7806]
#define sipNameNr_PreferencesRole 41367
#define sipName_PreferencesRole &sipStrings_QtWidgets[41367]
#define sipNameNr_shortcutContext 41383
#define sipName_shortcutContext &sipStrings_QtWidgets[41383]
#define sipNameNr_DefaultStepType 41399
#define sipName_DefaultStepType &sipStrings_QtWidgets[41399]
#define sipNameNr_initStyleOption 41415
#define sipName_initStyleOption &sipStrings_QtWidgets[41415]
#define sipNameNr_editingFinished 41431
#define sipName_editingFinished &sipStrings_QtWidgets[41431]
#define sipNameNr_StepDownEnabled 41447
#define sipName_StepDownEnabled &sipStrings_QtWidgets[41447]
#define sipNameNr_StepEnabledFlag 4765
#define sipName_StepEnabledFlag &sipStrings_QtWidgets[4765]
#define sipNameNr_setRepeatAction 41463
#define sipName_setRepeatAction &sipStrings_QtWidgets[41463]
#define sipNameNr_actionTriggered 41479
#define sipName_actionTriggered &sipStrings_QtWidgets[41479]
#define sipNameNr_SliderToMaximum 41495
#define sipName_SliderToMaximum &sipStrings_QtWidgets[41495]
#define sipNameNr_SliderToMinimum 41511
#define sipName_SliderToMinimum &sipStrings_QtWidgets[41511]
#define sipNameNr_QAbstractSlider 41527
#define sipName_QAbstractSlider &sipStrings_QtWidgets[41527]
#define sipNameNr_setCornerWidget 41543
#define sipName_setCornerWidget &sipStrings_QtWidgets[41543]
#define sipNameNr_viewportMargins 41559
#define sipName_viewportMargins &sipStrings_QtWidgets[41559]
#define sipNameNr_minimumSizeHint 41575
#define sipName_minimumSizeHint &sipStrings_QtWidgets[41575]
#define sipNameNr_setDragDropMode 41591
#define sipName_setDragDropMode &sipStrings_QtWidgets[41591]
#define sipNameNr_CollapsingState 41607
#define sipName_CollapsingState &sipStrings_QtWidgets[41607]
#define sipNameNr_iconSizeChanged 41623
#define sipName_iconSizeChanged &sipStrings_QtWidgets[41623]
#define sipNameNr_viewportEntered 41639
#define sipName_viewportEntered &sipStrings_QtWidgets[41639]
#define sipNameNr_editorDestroyed 41655
#define sipName_editorDestroyed &sipStrings_QtWidgets[41655]
#define sipNameNr_setEditTriggers 41671
#define sipName_setEditTriggers &sipStrings_QtWidgets[41671]
#define sipNameNr_setItemDelegate 41687
#define sipName_setItemDelegate &sipStrings_QtWidgets[41687]
#define sipNameNr_SingleSelection 41703
#define sipName_SingleSelection &sipStrings_QtWidgets[41703]
#define sipNameNr_AllEditTriggers 41719
#define sipName_AllEditTriggers &sipStrings_QtWidgets[41719]
#define sipNameNr_SelectedClicked 41735
#define sipName_SelectedClicked &sipStrings_QtWidgets[41735]
#define sipNameNr_sizeHintChanged 41751
#define sipName_sizeHintChanged &sipStrings_QtWidgets[41751]
#define sipNameNr_autoRepeatDelay 41767
#define sipName_autoRepeatDelay &sipStrings_QtWidgets[41767]
#define sipNameNr_QAbstractButton 41783
#define sipName_QAbstractButton &sipStrings_QtWidgets[41783]
#define sipNameNr_mousePressEvent 41799
#define sipName_mousePressEvent &sipStrings_QtWidgets[41799]
#define sipNameNr_keyReleaseEvent 41815
#define sipName_keyReleaseEvent &sipStrings_QtWidgets[41815]
#define sipNameNr_setMaximumWidth 41831
#define sipName_setMaximumWidth &sipStrings_QtWidgets[41831]
#define sipNameNr_setMinimumWidth 41847
#define sipName_setMinimumWidth &sipStrings_QtWidgets[41847]
#define sipNameNr_tabStopDistance 41863
#define sipName_tabStopDistance &sipStrings_QtWidgets[41863]
#define sipNameNr_cursorMoveStyle 41879
#define sipName_cursorMoveStyle &sipStrings_QtWidgets[41879]
#define sipNameNr_isRedoAvailable 41895
#define sipName_isRedoAvailable &sipStrings_QtWidgets[41895]
#define sipNameNr_isUndoAvailable 41911
#define sipName_isUndoAvailable &sipStrings_QtWidgets[41911]
#define sipNameNr_cursorFlashTime 41927
#define sipName_cursorFlashTime &sipStrings_QtWidgets[41927]
#define sipNameNr_PerformanceHint 41943
#define sipName_PerformanceHint &sipStrings_QtWidgets[41943]
#define sipNameNr_emitDataChanged 41959
#define sipName_emitDataChanged &sipStrings_QtWidgets[41959]
#define sipNameNr_geometryChanged 41975
#define sipName_geometryChanged &sipStrings_QtWidgets[41975]
#define sipNameNr_placeholderText 41991
#define sipName_placeholderText &sipStrings_QtWidgets[41991]
#define sipNameNr_backgroundBrush 42007
#define sipName_backgroundBrush &sipStrings_QtWidgets[42007]
#define sipNameNr_deviceTransform 42023
#define sipName_deviceTransform &sipStrings_QtWidgets[42023]
#define sipNameNr_grabFramebuffer 42039
#define sipName_grabFramebuffer &sipStrings_QtWidgets[42039]
#define sipNameNr_NoPartialUpdate 42055
#define sipName_NoPartialUpdate &sipStrings_QtWidgets[42055]
#define sipNameNr_backgroundColor 42071
#define sipName_backgroundColor &sipStrings_QtWidgets[42071]
#define sipNameNr_layoutDirection 42087
#define sipName_layoutDirection &sipStrings_QtWidgets[42087]
#define sipNameNr_possibleActions 42103
#define sipName_possibleActions &sipStrings_QtWidgets[42103]
#define sipNameNr_documentChanged 42119
#define sipName_documentChanged &sipStrings_QtWidgets[42119]
#define sipNameNr_setCurrentIndex 42135
#define sipName_setCurrentIndex &sipStrings_QtWidgets[42135]
#define sipNameNr_selectedIndexes 42151
#define sipName_selectedIndexes &sipStrings_QtWidgets[42151]
#define sipNameNr_caseSensitivity 42167
#define sipName_caseSensitivity &sipStrings_QtWidgets[42167]
#define sipNameNr_canDropMimeData 42183
#define sipName_canDropMimeData &sipStrings_QtWidgets[42183]
#define sipNameNr_PyQt5_QtWidgets 42199
#define sipName_PyQt5_QtWidgets &sipStrings_QtWidgets[42199]
#define sipNameNr_initializePage 42215
#define sipName_initializePage &sipStrings_QtWidgets[42215]
#define sipNameNr_subTitleFormat 42230
#define sipName_subTitleFormat &sipStrings_QtWidgets[42230]
#define sipNameNr_setTitleFormat 42245
#define sipName_setTitleFormat &sipStrings_QtWidgets[42245]
#define sipNameNr_setWizardStyle 42260
#define sipName_setWizardStyle &sipStrings_QtWidgets[42260]
#define sipNameNr_hasVisitedPage 42275
#define sipName_hasVisitedPage &sipStrings_QtWidgets[42275]
#define sipNameNr_HaveHelpButton 42290
#define sipName_HaveHelpButton &sipStrings_QtWidgets[42290]
#define sipNameNr_NoCancelButton 42305
#define sipName_NoCancelButton &sipStrings_QtWidgets[42305]
#define sipNameNr_createdWidgets 42320
#define sipName_createdWidgets &sipStrings_QtWidgets[42320]
#define sipNameNr_windowFilePath 42335
#define sipName_windowFilePath &sipStrings_QtWidgets[42335]
#define sipNameNr_effectiveWinId 42350
#define sipName_effectiveWinId &sipStrings_QtWidgets[42350]
#define sipNameNr_updatesEnabled 42365
#define sipName_updatesEnabled &sipStrings_QtWidgets[42365]
#define sipNameNr_focusNextChild 42380
#define sipName_focusNextChild &sipStrings_QtWidgets[42380]
#define sipNameNr_ensurePolished 42395
#define sipName_ensurePolished &sipStrings_QtWidgets[42395]
#define sipNameNr_activateWindow 42410
#define sipName_activateWindow &sipStrings_QtWidgets[42410]
#define sipNameNr_windowIconText 42425
#define sipName_windowIconText &sipStrings_QtWidgets[42425]
#define sipNameNr_foregroundRole 42440
#define sipName_foregroundRole &sipStrings_QtWidgets[42440]
#define sipNameNr_backgroundRole 42455
#define sipName_backgroundRole &sipStrings_QtWidgets[42455]
#define sipNameNr_setFixedHeight 42470
#define sipName_setFixedHeight &sipStrings_QtWidgets[42470]
#define sipNameNr_childrenRegion 42485
#define sipName_childrenRegion &sipStrings_QtWidgets[42485]
#define sipNameNr_normalGeometry 42500
#define sipName_normalGeometry &sipStrings_QtWidgets[42500]
#define sipNameNr_canUndoChanged 42515
#define sipName_canUndoChanged &sipStrings_QtWidgets[42515]
#define sipNameNr_canRedoChanged 42530
#define sipName_canRedoChanged &sipStrings_QtWidgets[42530]
#define sipNameNr_setActiveStack 42545
#define sipName_setActiveStack &sipStrings_QtWidgets[42545]
#define sipNameNr_setHeaderLabel 42560
#define sipName_setHeaderLabel &sipStrings_QtWidgets[42560]
#define sipNameNr_insertChildren 42575
#define sipName_insertChildren &sipStrings_QtWidgets[42575]
#define sipNameNr_isHeaderHidden 42590
#define sipName_isHeaderHidden &sipStrings_QtWidgets[42590]
#define sipNameNr_setIndentation 34485
#define sipName_setIndentation &sipStrings_QtWidgets[34485]
#define sipNameNr_setItemToolTip 42605
#define sipName_setItemToolTip &sipStrings_QtWidgets[42605]
#define sipNameNr_setItemEnabled 42620
#define sipName_setItemEnabled &sipStrings_QtWidgets[42620]
#define sipNameNr_movableChanged 42635
#define sipName_movableChanged &sipStrings_QtWidgets[42635]
#define sipNameNr_scrollToAnchor 42650
#define sipName_scrollToAnchor &sipStrings_QtWidgets[42650]
#define sipNameNr_acceptRichText 42665
#define sipName_acceptRichText &sipStrings_QtWidgets[42665]
#define sipNameNr_AutoFormatting 11050
#define sipName_AutoFormatting &sipStrings_QtWidgets[11050]
#define sipNameNr_AutoBulletList 42680
#define sipName_AutoBulletList &sipStrings_QtWidgets[42680]
#define sipNameNr_ExtraSelection 11076
#define sipName_ExtraSelection &sipStrings_QtWidgets[11076]
#define sipNameNr_historyChanged 42695
#define sipName_historyChanged &sipStrings_QtWidgets[42695]
#define sipNameNr_tabBarAutoHide 42710
#define sipName_tabBarAutoHide &sipStrings_QtWidgets[42710]
#define sipNameNr_selectedRanges 42725
#define sipName_selectedRanges &sipStrings_QtWidgets[42725]
#define sipNameNr_setCurrentCell 42740
#define sipName_setCurrentCell &sipStrings_QtWidgets[42740]
#define sipNameNr_isColumnHidden 42755
#define sipName_isColumnHidden &sipStrings_QtWidgets[42755]
#define sipNameNr_setColumnWidth 42770
#define sipName_setColumnWidth &sipStrings_QtWidgets[42770]
#define sipNameNr_verticalHeader 42785
#define sipName_verticalHeader &sipStrings_QtWidgets[42785]
#define sipNameNr_SelectRightTab 42800
#define sipName_SelectRightTab &sipStrings_QtWidgets[42800]
#define sipNameNr_ButtonPosition 7237
#define sipName_ButtonPosition &sipStrings_QtWidgets[7237]
#define sipNameNr_TriangularEast 42815
#define sipName_TriangularEast &sipStrings_QtWidgets[42815]
#define sipNameNr_TriangularWest 42830
#define sipName_TriangularWest &sipStrings_QtWidgets[42830]
#define sipNameNr_QTabBar__Shape 42845
#define sipName_QTabBar__Shape &sipStrings_QtWidgets[42845]
#define sipNameNr_messageClicked 42860
#define sipName_messageClicked &sipStrings_QtWidgets[42860]
#define sipNameNr_setContextMenu 42875
#define sipName_setContextMenu &sipStrings_QtWidgets[42875]
#define sipNameNr_positionOfLine 42890
#define sipName_positionOfLine &sipStrings_QtWidgets[42890]
#define sipNameNr_ToolBarFeature 3411
#define sipName_ToolBarFeature &sipStrings_QtWidgets[3411]
#define sipNameNr_HintReturnType 4865
#define sipName_HintReturnType &sipStrings_QtWidgets[4865]
#define sipNameNr_decorationSize 42905
#define sipName_decorationSize &sipStrings_QtWidgets[42905]
#define sipNameNr_leftButtonSize 42920
#define sipName_leftButtonSize &sipStrings_QtWidgets[42920]
#define sipNameNr_ButtonFeatures 435
#define sipName_ButtonFeatures &sipStrings_QtWidgets[435]
#define sipNameNr_NextIsSelected 42935
#define sipName_NextIsSelected &sipStrings_QtWidgets[42935]
#define sipNameNr_OnlyOneSection 42950
#define sipName_OnlyOneSection &sipStrings_QtWidgets[42950]
#define sipNameNr_SO_ProgressBar 42965
#define sipName_SO_ProgressBar &sipStrings_QtWidgets[42965]
#define sipNameNr_SP_MediaVolume 42980
#define sipName_SP_MediaVolume &sipStrings_QtWidgets[42980]
#define sipNameNr_SP_BrowserStop 42995
#define sipName_SP_BrowserStop &sipStrings_QtWidgets[42995]
#define sipNameNr_SP_VistaShield 43010
#define sipName_SP_VistaShield &sipStrings_QtWidgets[43010]
#define sipNameNr_SP_CommandLink 43025
#define sipName_SP_CommandLink &sipStrings_QtWidgets[43025]
#define sipNameNr_SP_DirHomeIcon 43040
#define sipName_SP_DirHomeIcon &sipStrings_QtWidgets[43040]
#define sipNameNr_SP_DirLinkIcon 43055
#define sipName_SP_DirLinkIcon &sipStrings_QtWidgets[43055]
#define sipNameNr_SP_DirOpenIcon 43070
#define sipName_SP_DirOpenIcon &sipStrings_QtWidgets[43070]
#define sipNameNr_SP_DriveCDIcon 43085
#define sipName_SP_DriveCDIcon &sipStrings_QtWidgets[43085]
#define sipNameNr_SP_DriveHDIcon 43100
#define sipName_SP_DriveHDIcon &sipStrings_QtWidgets[43100]
#define sipNameNr_SP_DriveFDIcon 43115
#define sipName_SP_DriveFDIcon &sipStrings_QtWidgets[43115]
#define sipNameNr_SP_DesktopIcon 43130
#define sipName_SP_DesktopIcon &sipStrings_QtWidgets[43130]
#define sipNameNr_StandardPixmap 16675
#define sipName_StandardPixmap &sipStrings_QtWidgets[16675]
#define sipNameNr_SH_WizardStyle 43145
#define sipName_SH_WizardStyle &sipStrings_QtWidgets[43145]
#define sipNameNr_CT_MdiControls 43160
#define sipName_CT_MdiControls &sipStrings_QtWidgets[43160]
#define sipNameNr_CT_MenuBarItem 43175
#define sipName_CT_MenuBarItem &sipStrings_QtWidgets[43175]
#define sipNameNr_CT_ProgressBar 43190
#define sipName_CT_ProgressBar &sipStrings_QtWidgets[43190]
#define sipNameNr_CT_RadioButton 43205
#define sipName_CT_RadioButton &sipStrings_QtWidgets[43205]
#define sipNameNr_PM_MenuVMargin 43220
#define sipName_PM_MenuVMargin &sipStrings_QtWidgets[43220]
#define sipNameNr_PM_MenuHMargin 43235
#define sipName_PM_MenuHMargin &sipStrings_QtWidgets[43235]
#define sipNameNr_SC_SpinBoxDown 43250
#define sipName_SC_SpinBoxDown &sipStrings_QtWidgets[43250]
#define sipNameNr_CC_MdiControls 43265
#define sipName_CC_MdiControls &sipStrings_QtWidgets[43265]
#define sipNameNr_ComplexControl 17043
#define sipName_ComplexControl &sipStrings_QtWidgets[17043]
#define sipNameNr_SE_HeaderArrow 43280
#define sipName_SE_HeaderArrow &sipStrings_QtWidgets[43280]
#define sipNameNr_SE_HeaderLabel 43295
#define sipName_SE_HeaderLabel &sipStrings_QtWidgets[43295]
#define sipNameNr_CE_ShapedFrame 43310
#define sipName_CE_ShapedFrame &sipStrings_QtWidgets[43310]
#define sipNameNr_CE_HeaderLabel 43325
#define sipName_CE_HeaderLabel &sipStrings_QtWidgets[43325]
#define sipNameNr_CE_MenuBarItem 43340
#define sipName_CE_MenuBarItem &sipStrings_QtWidgets[43340]
#define sipNameNr_CE_MenuTearoff 43355
#define sipName_CE_MenuTearoff &sipStrings_QtWidgets[43355]
#define sipNameNr_CE_MenuHMargin 43370
#define sipName_CE_MenuHMargin &sipStrings_QtWidgets[43370]
#define sipNameNr_CE_MenuVMargin 43385
#define sipName_CE_MenuVMargin &sipStrings_QtWidgets[43385]
#define sipNameNr_CE_ProgressBar 43400
#define sipName_CE_ProgressBar &sipStrings_QtWidgets[43400]
#define sipNameNr_CE_RadioButton 43415
#define sipName_CE_RadioButton &sipStrings_QtWidgets[43415]
#define sipNameNr_ControlElement 17273
#define sipName_ControlElement &sipStrings_QtWidgets[17273]
#define sipNameNr_PE_FrameWindow 43430
#define sipName_PE_FrameWindow &sipStrings_QtWidgets[43430]
#define sipNameNr_State_ReadOnly 43445
#define sipName_State_ReadOnly &sipStrings_QtWidgets[43445]
#define sipNameNr_State_Children 43460
#define sipName_State_Children &sipStrings_QtWidgets[43460]
#define sipNameNr_State_Selected 43475
#define sipName_State_Selected &sipStrings_QtWidgets[43475]
#define sipNameNr_State_HasFocus 43490
#define sipName_State_HasFocus &sipStrings_QtWidgets[43490]
#define sipNameNr_State_NoChange 43505
#define sipName_State_NoChange &sipStrings_QtWidgets[43505]
#define sipNameNr_currentMessage 43520
#define sipName_currentMessage &sipStrings_QtWidgets[43520]
#define sipNameNr_QStackedWidget 43535
#define sipName_QStackedWidget &sipStrings_QtWidgets[43535]
#define sipNameNr_QStackedLayout 43550
#define sipName_QStackedLayout &sipStrings_QtWidgets[43550]
#define sipNameNr_setHandleWidth 43565
#define sipName_setHandleWidth &sipStrings_QtWidgets[43565]
#define sipNameNr_setCollapsible 43580
#define sipName_setCollapsible &sipStrings_QtWidgets[43580]
#define sipNameNr_messageChanged 43595
#define sipName_messageChanged &sipStrings_QtWidgets[43595]
#define sipNameNr_QDoubleSpinBox 43610
#define sipName_QDoubleSpinBox &sipStrings_QtWidgets[43610]
#define sipNameNr_TicksBothSides 43625
#define sipName_TicksBothSides &sipStrings_QtWidgets[43625]
#define sipNameNr_setControlType 43640
#define sipName_setControlType &sipStrings_QtWidgets[43640]
#define sipNameNr_verticalPolicy 43655
#define sipName_verticalPolicy &sipStrings_QtWidgets[43655]
#define sipNameNr_ScrollingCurve 43670
#define sipName_ScrollingCurve &sipStrings_QtWidgets[43670]
#define sipNameNr_grabbedGesture 43685
#define sipName_grabbedGesture &sipStrings_QtWidgets[43685]
#define sipNameNr_setAutoDefault 43700
#define sipName_setAutoDefault &sipStrings_QtWidgets[43700]
#define sipNameNr_itemPixmapRect 43715
#define sipName_itemPixmapRect &sipStrings_QtWidgets[43715]
#define sipNameNr_drawItemPixmap 43730
#define sipName_drawItemPixmap &sipStrings_QtWidgets[43730]
#define sipNameNr_setTextVisible 43745
#define sipName_setTextVisible &sipStrings_QtWidgets[43745]
#define sipNameNr_setCursorWidth 43760
#define sipName_setCursorWidth &sipStrings_QtWidgets[43760]
#define sipNameNr_centerOnScroll 43775
#define sipName_centerOnScroll &sipStrings_QtWidgets[43775]
#define sipNameNr_QPlainTextEdit 43790
#define sipName_QPlainTextEdit &sipStrings_QtWidgets[43790]
#define sipNameNr_aboutToCompose 43805
#define sipName_aboutToCompose &sipStrings_QtWidgets[43805]
#define sipNameNr_setHitTestPath 43820
#define sipName_setHitTestPath &sipStrings_QtWidgets[43820]
#define sipNameNr_windowModality 43835
#define sipName_windowModality &sipStrings_QtWidgets[43835]
#define sipNameNr_setNoReplayFor 43850
#define sipName_setNoReplayFor &sipStrings_QtWidgets[43850]
#define sipNameNr_actionGeometry 43865
#define sipName_actionGeometry &sipStrings_QtWidgets[43865]
#define sipNameNr_showSystemMenu 43880
#define sipName_showSystemMenu &sipStrings_QtWidgets[43880]
#define sipNameNr_RubberBandMove 43895
#define sipName_RubberBandMove &sipStrings_QtWidgets[43895]
#define sipNameNr_setTabsMovable 43910
#define sipName_setTabsMovable &sipStrings_QtWidgets[43910]
#define sipNameNr_tileSubWindows 43925
#define sipName_tileSubWindows &sipStrings_QtWidgets[43925]
#define sipNameNr_setTabPosition 43940
#define sipName_setTabPosition &sipStrings_QtWidgets[43940]
#define sipNameNr_setDockOptions 43955
#define sipName_setDockOptions &sipStrings_QtWidgets[43955]
#define sipNameNr_dockWidgetArea 43970
#define sipName_dockWidgetArea &sipStrings_QtWidgets[43970]
#define sipNameNr_visualItemRect 43985
#define sipName_visualItemRect &sipStrings_QtWidgets[43985]
#define sipNameNr_setCurrentItem 44000
#define sipName_setCurrentItem &sipStrings_QtWidgets[44000]
#define sipNameNr_ActionPosition 12012
#define sipName_ActionPosition &sipStrings_QtWidgets[12012]
#define sipNameNr_getTextMargins 44015
#define sipName_getTextMargins &sipStrings_QtWidgets[44015]
#define sipNameNr_setTextMargins 44030
#define sipName_setTextMargins &sipStrings_QtWidgets[44030]
#define sipNameNr_cursorBackward 44045
#define sipName_cursorBackward &sipStrings_QtWidgets[44045]
#define sipNameNr_addChildWidget 44060
#define sipName_addChildWidget &sipStrings_QtWidgets[44060]
#define sipNameNr_addChildLayout 44075
#define sipName_addChildLayout &sipStrings_QtWidgets[44075]
#define sipNameNr_sizeConstraint 44090
#define sipName_sizeConstraint &sipStrings_QtWidgets[44090]
#define sipNameNr_SetMaximumSize 44105
#define sipName_SetMaximumSize &sipStrings_QtWidgets[44105]
#define sipNameNr_SetMinimumSize 44120
#define sipName_SetMinimumSize &sipStrings_QtWidgets[44120]
#define sipNameNr_SizeConstraint 15280
#define sipName_SizeConstraint &sipStrings_QtWidgets[15280]
#define sipNameNr_setKeySequence 44135
#define sipName_setKeySequence &sipStrings_QtWidgets[44135]
#define sipNameNr_defaultFactory 44150
#define sipName_defaultFactory &sipStrings_QtWidgets[44150]
#define sipNameNr_registerEditor 44165
#define sipName_registerEditor &sipStrings_QtWidgets[44165]
#define sipNameNr_drawDecoration 44180
#define sipName_drawDecoration &sipStrings_QtWidgets[44180]
#define sipNameNr_doubleDecimals 44195
#define sipName_doubleDecimals &sipStrings_QtWidgets[44195]
#define sipNameNr_setDoubleRange 44210
#define sipName_setDoubleRange &sipStrings_QtWidgets[44210]
#define sipNameNr_setDoubleValue 44225
#define sipName_setDoubleValue &sipStrings_QtWidgets[44225]
#define sipNameNr_sectionEntered 44240
#define sipName_sectionEntered &sipStrings_QtWidgets[44240]
#define sipNameNr_sectionsHidden 44255
#define sipName_sectionsHidden &sipStrings_QtWidgets[44255]
#define sipNameNr_resizeSections 44270
#define sipName_resizeSections &sipStrings_QtWidgets[44270]
#define sipNameNr_sectionClicked 44285
#define sipName_sectionClicked &sipStrings_QtWidgets[44285]
#define sipNameNr_sectionPressed 44300
#define sipName_sectionPressed &sipStrings_QtWidgets[44300]
#define sipNameNr_sectionResized 44315
#define sipName_sectionResized &sipStrings_QtWidgets[44315]
#define sipNameNr_logicalIndexAt 44330
#define sipName_logicalIndexAt &sipStrings_QtWidgets[44330]
#define sipNameNr_itemAtPosition 44345
#define sipName_itemAtPosition &sipStrings_QtWidgets[44345]
#define sipNameNr_setFocusPolicy 44360
#define sipName_setFocusPolicy &sipStrings_QtWidgets[44360]
#define sipNameNr_setWindowTitle 44375
#define sipName_setWindowTitle &sipStrings_QtWidgets[44375]
#define sipNameNr_isActiveWindow 44390
#define sipName_isActiveWindow &sipStrings_QtWidgets[44390]
#define sipNameNr_setWindowFlags 44405
#define sipName_setWindowFlags &sipStrings_QtWidgets[44405]
#define sipNameNr_rubberBandRect 44420
#define sipName_rubberBandRect &sipStrings_QtWidgets[44420]
#define sipNameNr_setInteractive 44435
#define sipName_setInteractive &sipStrings_QtWidgets[44435]
#define sipNameNr_ViewportAnchor 7597
#define sipName_ViewportAnchor &sipStrings_QtWidgets[7597]
#define sipNameNr_RubberBandDrag 44450
#define sipName_RubberBandDrag &sipStrings_QtWidgets[44450]
#define sipNameNr_ScrollHandDrag 44465
#define sipName_ScrollHandDrag &sipStrings_QtWidgets[44465]
#define sipNameNr_QGraphicsScale 44480
#define sipName_QGraphicsScale &sipStrings_QtWidgets[44480]
#define sipNameNr_setActivePanel 44495
#define sipName_setActivePanel &sipStrings_QtWidgets[44495]
#define sipNameNr_setStickyFocus 44510
#define sipName_setStickyFocus &sipStrings_QtWidgets[44510]
#define sipNameNr_drawForeground 44525
#define sipName_drawForeground &sipStrings_QtWidgets[44525]
#define sipNameNr_drawBackground 44540
#define sipName_drawBackground &sipStrings_QtWidgets[44540]
#define sipNameNr_QGraphicsScene 44555
#define sipName_QGraphicsScene &sipStrings_QtWidgets[44555]
#define sipNameNr_newProxyWidget 44570
#define sipName_newProxyWidget &sipStrings_QtWidgets[44570]
#define sipNameNr_grabMouseEvent 36168
#define sipName_grabMouseEvent &sipStrings_QtWidgets[36168]
#define sipNameNr_setItemSpacing 44585
#define sipName_setItemSpacing &sipStrings_QtWidgets[44585]
#define sipNameNr_preferredWidth 44600
#define sipName_preferredWidth &sipStrings_QtWidgets[44600]
#define sipNameNr_updateGeometry 44615
#define sipName_updateGeometry &sipStrings_QtWidgets[44615]
#define sipNameNr_graphicsEffect 44630
#define sipName_graphicsEffect &sipStrings_QtWidgets[44630]
#define sipNameNr_mapRectToScene 44645
#define sipName_mapRectToScene &sipStrings_QtWidgets[44645]
#define sipNameNr_boundingRegion 44660
#define sipName_boundingRegion &sipStrings_QtWidgets[44660]
#define sipNameNr_ungrabKeyboard 44675
#define sipName_ungrabKeyboard &sipStrings_QtWidgets[44675]
#define sipNameNr_topLevelWidget 44690
#define sipName_topLevelWidget &sipStrings_QtWidgets[44690]
#define sipNameNr_sceneTransform 44705
#define sipName_sceneTransform &sipStrings_QtWidgets[44705]
#define sipNameNr_hoverMoveEvent 44720
#define sipName_hoverMoveEvent &sipStrings_QtWidgets[44720]
#define sipNameNr_collidingItems 44735
#define sipName_collidingItems &sipStrings_QtWidgets[44735]
#define sipNameNr_setAcceptDrops 44750
#define sipName_setAcceptDrops &sipStrings_QtWidgets[44750]
#define sipNameNr_setOpacityMask 44765
#define sipName_setOpacityMask &sipStrings_QtWidgets[44765]
#define sipNameNr_sourceIsPixmap 44780
#define sipName_sourceIsPixmap &sipStrings_QtWidgets[44780]
#define sipNameNr_enabledChanged 44795
#define sipName_enabledChanged &sipStrings_QtWidgets[44795]
#define sipNameNr_SourceDetached 44810
#define sipName_SourceDetached &sipStrings_QtWidgets[44810]
#define sipNameNr_SourceAttached 44825
#define sipName_SourceAttached &sipStrings_QtWidgets[44825]
#define sipNameNr_TriggerGesture 44840
#define sipName_TriggerGesture &sipStrings_QtWidgets[44840]
#define sipNameNr_activeGestures 44855
#define sipName_activeGestures &sipStrings_QtWidgets[44855]
#define sipNameNr_SwipeDirection 7687
#define sipName_SwipeDirection &sipStrings_QtWidgets[7687]
#define sipNameNr_setScaleFactor 44870
#define sipName_setScaleFactor &sipStrings_QtWidgets[44870]
#define sipNameNr_setCenterPoint 44885
#define sipName_setCenterPoint &sipStrings_QtWidgets[44885]
#define sipNameNr_setChangeFlags 44900
#define sipName_setChangeFlags &sipStrings_QtWidgets[44900]
#define sipNameNr_setFrameShadow 44915
#define sipName_setFrameShadow &sipStrings_QtWidgets[44915]
#define sipNameNr_QFrame__Shadow 44930
#define sipName_QFrame__Shadow &sipStrings_QtWidgets[44930]
#define sipNameNr_labelAlignment 44945
#define sipName_labelAlignment &sipStrings_QtWidgets[44945]
#define sipNameNr_setCurrentFont 44960
#define sipName_setCurrentFont &sipStrings_QtWidgets[44960]
#define sipNameNr_setFontFilters 44975
#define sipName_setFontFilters &sipStrings_QtWidgets[44975]
#define sipNameNr_getSaveFileUrl 44990
#define sipName_getSaveFileUrl &sipStrings_QtWidgets[44990]
#define sipNameNr_getOpenFileUrl 45005
#define sipName_getOpenFileUrl &sipStrings_QtWidgets[45005]
#define sipNameNr_setSidebarUrls 45020
#define sipName_setSidebarUrls &sipStrings_QtWidgets[45020]
#define sipNameNr_filterSelected 45035
#define sipName_filterSelected &sipStrings_QtWidgets[45035]
#define sipNameNr_qDrawPlainRect 45050
#define sipName_qDrawPlainRect &sipStrings_QtWidgets[45050]
#define sipNameNr_qDrawWinButton 45065
#define sipName_qDrawWinButton &sipStrings_QtWidgets[45065]
#define sipNameNr_qDrawShadeRect 45080
#define sipName_qDrawShadeRect &sipStrings_QtWidgets[45080]
#define sipNameNr_qDrawShadeLine 45095
#define sipName_qDrawShadeLine &sipStrings_QtWidgets[45095]
#define sipNameNr_titleBarWidget 45110
#define sipName_titleBarWidget &sipStrings_QtWidgets[45110]
#define sipNameNr_lazyChildCount 45125
#define sipName_lazyChildCount &sipStrings_QtWidgets[45125]
#define sipNameNr_standardButton 45140
#define sipName_standardButton &sipStrings_QtWidgets[45140]
#define sipNameNr_StandardButton 5261
#define sipName_StandardButton &sipStrings_QtWidgets[5261]
#define sipNameNr_notchesVisible 45155
#define sipName_notchesVisible &sipStrings_QtWidgets[45155]
#define sipNameNr_setNotchTarget 45170
#define sipName_setNotchTarget &sipStrings_QtWidgets[45170]
#define sipNameNr_screenGeometry 45185
#define sipName_screenGeometry &sipStrings_QtWidgets[45185]
#define sipNameNr_QDesktopWidget 45200
#define sipName_QDesktopWidget &sipStrings_QtWidgets[45200]
#define sipNameNr_calendarWidget 45215
#define sipName_calendarWidget &sipStrings_QtWidgets[45215]
#define sipNameNr_currentSection 45230
#define sipName_currentSection &sipStrings_QtWidgets[45230]
#define sipNameNr_setMaximumTime 45245
#define sipName_setMaximumTime &sipStrings_QtWidgets[45245]
#define sipNameNr_setMinimumTime 45260
#define sipName_setMinimumTime &sipStrings_QtWidgets[45260]
#define sipNameNr_mappedWidgetAt 45275
#define sipName_mappedWidgetAt &sipStrings_QtWidgets[45275]
#define sipNameNr_completionRole 45290
#define sipName_completionRole &sipStrings_QtWidgets[45290]
#define sipNameNr_completionMode 45305
#define sipName_completionMode &sipStrings_QtWidgets[45305]
#define sipNameNr_CompletionMode 10891
#define sipName_CompletionMode &sipStrings_QtWidgets[10891]
#define sipNameNr_standardPixmap 45320
#define sipName_standardPixmap &sipStrings_QtWidgets[45320]
#define sipNameNr_subControlRect 45335
#define sipName_subControlRect &sipStrings_QtWidgets[45335]
#define sipNameNr_subElementRect 45350
#define sipName_subElementRect &sipStrings_QtWidgets[45350]
#define sipNameNr_setCurrentText 45365
#define sipName_setCurrentText &sipStrings_QtWidgets[45365]
#define sipNameNr_setModelColumn 45380
#define sipName_setModelColumn &sipStrings_QtWidgets[45380]
#define sipNameNr_rootModelIndex 45395
#define sipName_rootModelIndex &sipStrings_QtWidgets[45395]
#define sipNameNr_InsertAtBottom 45410
#define sipName_InsertAtBottom &sipStrings_QtWidgets[45410]
#define sipNameNr_setCustomColor 45425
#define sipName_setCustomColor &sipStrings_QtWidgets[45425]
#define sipNameNr_setCurrentPage 45440
#define sipName_setCurrentPage &sipStrings_QtWidgets[45440]
#define sipNameNr_dateTextFormat 45455
#define sipName_dateTextFormat &sipStrings_QtWidgets[45455]
#define sipNameNr_setGridVisible 45470
#define sipName_setGridVisible &sipStrings_QtWidgets[45470]
#define sipNameNr_setMaximumDate 45485
#define sipName_setMaximumDate &sipStrings_QtWidgets[45485]
#define sipNameNr_setMinimumDate 45500
#define sipName_setMinimumDate &sipStrings_QtWidgets[45500]
#define sipNameNr_ISOWeekNumbers 45515
#define sipName_ISOWeekNumbers &sipStrings_QtWidgets[45515]
#define sipNameNr_buttonReleased 45530
#define sipName_buttonReleased &sipStrings_QtWidgets[45530]
#define sipNameNr_heightForWidth 45545
#define sipName_heightForWidth &sipStrings_QtWidgets[45545]
#define sipNameNr_autoSipEnabled 45560
#define sipName_autoSipEnabled &sipStrings_QtWidgets[45560]
#define sipNameNr_setGlobalStrut 45575
#define sipName_setGlobalStrut &sipStrings_QtWidgets[45575]
#define sipNameNr_showStatusText 45590
#define sipName_showStatusText &sipStrings_QtWidgets[45590]
#define sipNameNr_setActionGroup 45605
#define sipName_setActionGroup &sipStrings_QtWidgets[45605]
#define sipNameNr_setAccelerated 45620
#define sipName_setAccelerated &sipStrings_QtWidgets[45620]
#define sipNameNr_correctionMode 45635
#define sipName_correctionMode &sipStrings_QtWidgets[45635]
#define sipNameNr_CorrectionMode 5327
#define sipName_CorrectionMode &sipStrings_QtWidgets[5327]
#define sipNameNr_sliderReleased 45650
#define sipName_sliderReleased &sipStrings_QtWidgets[45650]
#define sipNameNr_SliderNoAction 45665
#define sipName_SliderNoAction &sipStrings_QtWidgets[45665]
#define sipNameNr_sliderPosition 45680
#define sipName_sliderPosition &sipStrings_QtWidgets[45680]
#define sipNameNr_dragLeaveEvent 45695
#define sipName_dragLeaveEvent &sipStrings_QtWidgets[45695]
#define sipNameNr_dragEnterEvent 45710
#define sipName_dragEnterEvent &sipStrings_QtWidgets[45710]
#define sipNameNr_setDirtyRegion 45725
#define sipName_setDirtyRegion &sipStrings_QtWidgets[45725]
#define sipNameNr_AnimatingState 45740
#define sipName_AnimatingState &sipStrings_QtWidgets[45740]
#define sipNameNr_ExpandingState 45755
#define sipName_ExpandingState &sipStrings_QtWidgets[45755]
#define sipNameNr_verticalOffset 45770
#define sipName_verticalOffset &sipStrings_QtWidgets[45770]
#define sipNameNr_scrollToBottom 45785
#define sipName_scrollToBottom &sipStrings_QtWidgets[45785]
#define sipNameNr_setIndexWidget 45800
#define sipName_setIndexWidget &sipStrings_QtWidgets[45800]
#define sipNameNr_sizeHintForRow 45815
#define sipName_sizeHintForRow &sipStrings_QtWidgets[45815]
#define sipNameNr_keyboardSearch 45830
#define sipName_keyboardSearch &sipStrings_QtWidgets[45830]
#define sipNameNr_selectionModel 45845
#define sipName_selectionModel &sipStrings_QtWidgets[45845]
#define sipNameNr_MultiSelection 45860
#define sipName_MultiSelection &sipStrings_QtWidgets[45860]
#define sipNameNr_ScrollPerPixel 45875
#define sipName_ScrollPerPixel &sipStrings_QtWidgets[45875]
#define sipNameNr_EditKeyPressed 45890
#define sipName_EditKeyPressed &sipStrings_QtWidgets[45890]
#define sipNameNr_CurrentChanged 45905
#define sipName_CurrentChanged &sipStrings_QtWidgets[45905]
#define sipNameNr_NoEditTriggers 45920
#define sipName_NoEditTriggers &sipStrings_QtWidgets[45920]
#define sipNameNr_nextCheckState 45935
#define sipName_nextCheckState &sipStrings_QtWidgets[45935]
#define sipNameNr_opacityChanged 45950
#define sipName_opacityChanged &sipStrings_QtWidgets[45950]
#define sipNameNr_mouseMoveEvent 45965
#define sipName_mouseMoveEvent &sipStrings_QtWidgets[45965]
#define sipNameNr_showFullScreen 45980
#define sipName_showFullScreen &sipStrings_QtWidgets[45980]
#define sipNameNr_setMaximumSize 45995
#define sipName_setMaximumSize &sipStrings_QtWidgets[45995]
#define sipNameNr_setMinimumSize 46010
#define sipName_setMinimumSize &sipStrings_QtWidgets[46010]
#define sipNameNr_setWindowState 46025
#define sipName_setWindowState &sipStrings_QtWidgets[46025]
#define sipNameNr_selectionStart 46040
#define sipName_selectionStart &sipStrings_QtWidgets[46040]
#define sipNameNr_setDragEnabled 46055
#define sipName_setDragEnabled &sipStrings_QtWidgets[46055]
#define sipNameNr_setColumnCount 46070
#define sipName_setColumnCount &sipStrings_QtWidgets[46070]
#define sipNameNr_resetTransform 46085
#define sipName_resetTransform &sipStrings_QtWidgets[46085]
#define sipNameNr_setRenderHints 46100
#define sipName_setRenderHints &sipStrings_QtWidgets[46100]
#define sipNameNr_setOrientation 46115
#define sipName_setOrientation &sipStrings_QtWidgets[46115]
#define sipNameNr_updateBehavior 46130
#define sipName_updateBehavior &sipStrings_QtWidgets[46130]
#define sipNameNr_UpdateBehavior 7567
#define sipName_UpdateBehavior &sipStrings_QtWidgets[7567]
#define sipNameNr_visibleChanged 46145
#define sipName_visibleChanged &sipStrings_QtWidgets[46145]
#define sipNameNr_proposedAction 46160
#define sipName_proposedAction &sipStrings_QtWidgets[46160]
#define sipNameNr_cursorPosition 46175
#define sipName_cursorPosition &sipStrings_QtWidgets[46175]
#define sipNameNr_autoFormatting 46190
#define sipName_autoFormatting &sipStrings_QtWidgets[46190]
#define sipNameNr_NormalPriority 46205
#define sipName_NormalPriority &sipStrings_QtWidgets[46205]
#define sipNameNr_firstDayOfWeek 46220
#define sipName_firstDayOfWeek &sipStrings_QtWidgets[46220]
#define sipNameNr_currentChanged 46235
#define sipName_currentChanged &sipStrings_QtWidgets[46235]
#define sipNameNr_clearSelection 46250
#define sipName_clearSelection &sipStrings_QtWidgets[46250]
#define sipNameNr_setSearchPaths 46265
#define sipName_setSearchPaths &sipStrings_QtWidgets[46265]
#define sipNameNr_setNameFilters 46280
#define sipName_setNameFilters &sipStrings_QtWidgets[46280]
#define sipNameNr_setDescription 46295
#define sipName_setDescription &sipStrings_QtWidgets[46295]
#define sipNameNr_46310 46310
#define sipName_46310 &sipStrings_QtWidgets[46310]
#define sipNameNr_registerField 46324
#define sipName_registerField &sipStrings_QtWidgets[46324]
#define sipNameNr_setCommitPage 46338
#define sipName_setCommitPage &sipStrings_QtWidgets[46338]
#define sipNameNr_setSideWidget 46352
#define sipName_setSideWidget &sipStrings_QtWidgets[46352]
#define sipNameNr_changedSignal 46366
#define sipName_changedSignal &sipStrings_QtWidgets[46366]
#define sipNameNr_setButtonText 46380
#define sipName_setButtonText &sipStrings_QtWidgets[46380]
#define sipNameNr_WizardOptions 16216
#define sipName_WizardOptions &sipStrings_QtWidgets[16216]
#define sipNameNr_CustomButton3 30507
#define sipName_CustomButton3 &sipStrings_QtWidgets[30507]
#define sipNameNr_CustomButton2 30525
#define sipName_CustomButton2 &sipStrings_QtWidgets[30525]
#define sipNameNr_CustomButton1 30543
#define sipName_CustomButton1 &sipStrings_QtWidgets[30543]
#define sipNameNr_releaseWidget 46394
#define sipName_releaseWidget &sipStrings_QtWidgets[46394]
#define sipNameNr_requestWidget 46408
#define sipName_requestWidget &sipStrings_QtWidgets[46408]
#define sipNameNr_defaultWidget 46422
#define sipName_defaultWidget &sipStrings_QtWidgets[46422]
#define sipNameNr_QWidgetAction 46436
#define sipName_QWidgetAction &sipStrings_QtWidgets[46436]
#define sipNameNr_setWindowFlag 46450
#define sipName_setWindowFlag &sipStrings_QtWidgets[46450]
#define sipNameNr_sharedPainter 46464
#define sipName_sharedPainter &sipStrings_QtWidgets[46464]
#define sipNameNr_destroyWindow 46478
#define sipName_destroyWindow &sipStrings_QtWidgets[46478]
#define sipNameNr_visibleRegion 46492
#define sipName_visibleRegion &sipStrings_QtWidgets[46492]
#define sipNameNr_windowOpacity 46506
#define sipName_windowOpacity &sipStrings_QtWidgets[46506]
#define sipNameNr_setWindowRole 46520
#define sipName_setWindowRole &sipStrings_QtWidgets[46520]
#define sipNameNr_setFixedWidth 46534
#define sipName_setFixedWidth &sipStrings_QtWidgets[46534]
#define sipNameNr_setEmptyLabel 46548
#define sipName_setEmptyLabel &sipStrings_QtWidgets[46548]
#define sipNameNr_NotSelectable 46562
#define sipName_NotSelectable &sipStrings_QtWidgets[46562]
#define sipNameNr_itemCollapsed 46576
#define sipName_itemCollapsed &sipStrings_QtWidgets[46576]
#define sipNameNr_setHeaderItem 46590
#define sipName_setHeaderItem &sipStrings_QtWidgets[46590]
#define sipNameNr_ShowIndicator 30795
#define sipName_ShowIndicator &sipStrings_QtWidgets[30795]
#define sipNameNr_expandToDepth 46604
#define sipName_expandToDepth &sipStrings_QtWidgets[46604]
#define sipNameNr_isItemEnabled 46618
#define sipName_isItemEnabled &sipStrings_QtWidgets[46618]
#define sipNameNr_anchorClicked 46632
#define sipName_anchorClicked &sipStrings_QtWidgets[46632]
#define sipNameNr_cellActivated 46646
#define sipName_cellActivated &sipStrings_QtWidgets[46646]
#define sipNameNr_clearContents 46660
#define sipName_clearContents &sipStrings_QtWidgets[46660]
#define sipNameNr_setCellWidget 46674
#define sipName_setCellWidget &sipStrings_QtWidgets[46674]
#define sipNameNr_currentColumn 46688
#define sipName_currentColumn &sipStrings_QtWidgets[46688]
#define sipNameNr_columnResized 46702
#define sipName_columnResized &sipStrings_QtWidgets[46702]
#define sipNameNr_setTabVisible 46716
#define sipName_setTabVisible &sipStrings_QtWidgets[46716]
#define sipNameNr_tabBarClicked 46730
#define sipName_tabBarClicked &sipStrings_QtWidgets[46730]
#define sipNameNr_SelectLeftTab 46744
#define sipName_SelectLeftTab &sipStrings_QtWidgets[46744]
#define sipNameNr_setTabToolTip 46758
#define sipName_setTabToolTip &sipStrings_QtWidgets[46758]
#define sipNameNr_setTabEnabled 46772
#define sipName_setTabEnabled &sipStrings_QtWidgets[46772]
#define sipNameNr_QStylePainter 46786
#define sipName_QStylePainter &sipStrings_QtWidgets[46786]
#define sipNameNr_titleBarFlags 46800
#define sipName_titleBarFlags &sipStrings_QtWidgets[46800]
#define sipNameNr_titleBarState 46814
#define sipName_titleBarState &sipStrings_QtWidgets[46814]
#define sipNameNr_HasDecoration 46828
#define sipName_HasDecoration &sipStrings_QtWidgets[46828]
#define sipNameNr_cornerWidgets 46842
#define sipName_cornerWidgets &sipStrings_QtWidgets[46842]
#define sipNameNr_CornerWidgets 6190
#define sipName_CornerWidgets &sipStrings_QtWidgets[6190]
#define sipNameNr_DefaultButton 6345
#define sipName_DefaultButton &sipStrings_QtWidgets[6345]
#define sipNameNr_ButtonFeature 692
#define sipName_ButtonFeature &sipStrings_QtWidgets[692]
#define sipNameNr_sortIndicator 46856
#define sipName_sortIndicator &sipStrings_QtWidgets[46856]
#define sipNameNr_iconAlignment 46870
#define sipName_iconAlignment &sipStrings_QtWidgets[46870]
#define sipNameNr_SortIndicator 4325
#define sipName_SortIndicator &sipStrings_QtWidgets[4325]
#define sipNameNr_FrameFeatures 4965
#define sipName_FrameFeatures &sipStrings_QtWidgets[4965]
#define sipNameNr_SO_CustomBase 46884
#define sipName_SO_CustomBase &sipStrings_QtWidgets[46884]
#define sipNameNr_SO_ToolButton 46898
#define sipName_SO_ToolButton &sipStrings_QtWidgets[46898]
#define sipNameNr_SO_RubberBand 46912
#define sipName_SO_RubberBand &sipStrings_QtWidgets[46912]
#define sipNameNr_SO_TabBarBase 46926
#define sipName_SO_TabBarBase &sipStrings_QtWidgets[46926]
#define sipNameNr_SO_DockWidget 46940
#define sipName_SO_DockWidget &sipStrings_QtWidgets[46940]
#define sipNameNr_QStyleFactory 46954
#define sipName_QStyleFactory &sipStrings_QtWidgets[46954]
#define sipNameNr_SP_CustomBase 46968
#define sipName_SP_CustomBase &sipStrings_QtWidgets[46968]
#define sipNameNr_SP_MediaPause 46982
#define sipName_SP_MediaPause &sipStrings_QtWidgets[46982]
#define sipNameNr_SP_ArrowRight 46996
#define sipName_SP_ArrowRight &sipStrings_QtWidgets[46996]
#define sipNameNr_SH_CustomBase 47010
#define sipName_SH_CustomBase &sipStrings_QtWidgets[47010]
#define sipNameNr_CT_CustomBase 47024
#define sipName_CT_CustomBase &sipStrings_QtWidgets[47024]
#define sipNameNr_CT_ToolButton 47038
#define sipName_CT_ToolButton &sipStrings_QtWidgets[47038]
#define sipNameNr_CT_PushButton 47052
#define sipName_CT_PushButton &sipStrings_QtWidgets[47052]
#define sipNameNr_PM_CustomBase 47066
#define sipName_PM_CustomBase &sipStrings_QtWidgets[47066]
#define sipNameNr_SC_CustomBase 47080
#define sipName_SC_CustomBase &sipStrings_QtWidgets[47080]
#define sipNameNr_SC_DialHandle 47094
#define sipName_SC_DialHandle &sipStrings_QtWidgets[47094]
#define sipNameNr_SC_DialGroove 47108
#define sipName_SC_DialGroove &sipStrings_QtWidgets[47108]
#define sipNameNr_SC_ToolButton 47122
#define sipName_SC_ToolButton &sipStrings_QtWidgets[47122]
#define sipNameNr_CC_CustomBase 47136
#define sipName_CC_CustomBase &sipStrings_QtWidgets[47136]
#define sipNameNr_CC_ToolButton 47150
#define sipName_CC_ToolButton &sipStrings_QtWidgets[47150]
#define sipNameNr_SE_CustomBase 47164
#define sipName_SE_CustomBase &sipStrings_QtWidgets[47164]
#define sipNameNr_CE_CustomBase 47178
#define sipName_CE_CustomBase &sipStrings_QtWidgets[47178]
#define sipNameNr_CE_FocusFrame 47192
#define sipName_CE_FocusFrame &sipStrings_QtWidgets[47192]
#define sipNameNr_CE_RubberBand 47206
#define sipName_CE_RubberBand &sipStrings_QtWidgets[47206]
#define sipNameNr_CE_ToolBoxTab 47220
#define sipName_CE_ToolBoxTab &sipStrings_QtWidgets[47220]
#define sipNameNr_CE_PushButton 47234
#define sipName_CE_PushButton &sipStrings_QtWidgets[47234]
#define sipNameNr_PE_CustomBase 47248
#define sipName_PE_CustomBase &sipStrings_QtWidgets[47248]
#define sipNameNr_QStyle__State 47262
#define sipName_QStyle__State &sipStrings_QtWidgets[47262]
#define sipNameNr_State_Editing 47276
#define sipName_State_Editing &sipStrings_QtWidgets[47276]
#define sipNameNr_State_Sibling 47290
#define sipName_State_Sibling &sipStrings_QtWidgets[47290]
#define sipNameNr_State_UpArrow 47304
#define sipName_State_UpArrow &sipStrings_QtWidgets[47304]
#define sipNameNr_State_Enabled 47318
#define sipName_State_Enabled &sipStrings_QtWidgets[47318]
#define sipNameNr_widgetRemoved 47332
#define sipName_widgetRemoved &sipStrings_QtWidgets[47332]
#define sipNameNr_currentWidget 47346
#define sipName_currentWidget &sipStrings_QtWidgets[47346]
#define sipNameNr_setRubberBand 47360
#define sipName_setRubberBand &sipStrings_QtWidgets[47360]
#define sipNameNr_splitterMoved 47374
#define sipName_splitterMoved &sipStrings_QtWidgets[47374]
#define sipNameNr_isCollapsible 47388
#define sipName_isCollapsible &sipStrings_QtWidgets[47388]
#define sipNameNr_QSplashScreen 47402
#define sipName_QSplashScreen &sipStrings_QtWidgets[47402]
#define sipNameNr_textFromValue 47416
#define sipName_textFromValue &sipStrings_QtWidgets[47416]
#define sipNameNr_valueFromText 47430
#define sipName_valueFromText &sipStrings_QtWidgets[47430]
#define sipNameNr_pixelPerMeter 47444
#define sipName_pixelPerMeter &sipStrings_QtWidgets[47444]
#define sipNameNr_finalPosition 47458
#define sipName_finalPosition &sipStrings_QtWidgets[47458]
#define sipNameNr_isTextVisible 47472
#define sipName_isTextVisible &sipStrings_QtWidgets[47472]
#define sipNameNr_contentOffset 47486
#define sipName_contentOffset &sipStrings_QtWidgets[47486]
#define sipNameNr_updateRequest 47500
#define sipName_updateRequest &sipStrings_QtWidgets[47500]
#define sipNameNr_copyAvailable 47514
#define sipName_copyAvailable &sipStrings_QtWidgets[47514]
#define sipNameNr_overwriteMode 47528
#define sipName_overwriteMode &sipStrings_QtWidgets[47528]
#define sipNameNr_documentTitle 47542
#define sipName_documentTitle &sipStrings_QtWidgets[47542]
#define sipNameNr_textureFormat 47556
#define sipName_textureFormat &sipStrings_QtWidgets[47556]
#define sipNameNr_PartialUpdate 42057
#define sipName_PartialUpdate &sipStrings_QtWidgets[42057]
#define sipNameNr_aboutToResize 47570
#define sipName_aboutToResize &sipStrings_QtWidgets[47570]
#define sipNameNr_QOpenGLWidget 47584
#define sipName_QOpenGLWidget &sipStrings_QtWidgets[47584]
#define sipNameNr_clickedButton 47598
#define sipName_clickedButton &sipStrings_QtWidgets[47598]
#define sipNameNr_defaultButton 47612
#define sipName_defaultButton &sipStrings_QtWidgets[47612]
#define sipNameNr_setIconPixmap 47626
#define sipName_setIconPixmap &sipStrings_QtWidgets[47626]
#define sipNameNr_insertSection 47640
#define sipName_insertSection &sipStrings_QtWidgets[47640]
#define sipNameNr_setSystemMenu 47654
#define sipName_setSystemMenu &sipStrings_QtWidgets[47654]
#define sipNameNr_QMdiSubWindow 47668
#define sipName_QMdiSubWindow &sipStrings_QtWidgets[47668]
#define sipNameNr_subWindowList 47682
#define sipName_subWindowList &sipStrings_QtWidgets[47682]
#define sipNameNr_StackingOrder 47696
#define sipName_StackingOrder &sipStrings_QtWidgets[47696]
#define sipNameNr_CreationOrder 47710
#define sipName_CreationOrder &sipStrings_QtWidgets[47710]
#define sipNameNr_SubWindowView 47724
#define sipName_SubWindowView &sipStrings_QtWidgets[47724]
#define sipNameNr_AnimatedDocks 47738
#define sipName_AnimatedDocks &sipStrings_QtWidgets[47738]
#define sipNameNr_setMenuWidget 47752
#define sipName_setMenuWidget &sipStrings_QtWidgets[47752]
#define sipNameNr_addDockWidget 47766
#define sipName_addDockWidget &sipStrings_QtWidgets[47766]
#define sipNameNr_removeToolBar 47780
#define sipName_removeToolBar &sipStrings_QtWidgets[47780]
#define sipNameNr_insertToolBar 47794
#define sipName_insertToolBar &sipStrings_QtWidgets[47794]
#define sipNameNr_centralWidget 47808
#define sipName_centralWidget &sipStrings_QtWidgets[47808]
#define sipNameNr_itemActivated 47822
#define sipName_itemActivated &sipStrings_QtWidgets[47822]
#define sipNameNr_setItemWidget 47836
#define sipName_setItemWidget &sipStrings_QtWidgets[47836]
#define sipNameNr_itemAlignment 47850
#define sipName_itemAlignment &sipStrings_QtWidgets[47850]
#define sipNameNr_setLayoutMode 47864
#define sipName_setLayoutMode &sipStrings_QtWidgets[47864]
#define sipNameNr_setResizeMode 47878
#define sipName_setResizeMode &sipStrings_QtWidgets[47878]
#define sipNameNr_inputRejected 47892
#define sipName_inputRejected &sipStrings_QtWidgets[47892]
#define sipNameNr_returnPressed 47906
#define sipName_returnPressed &sipStrings_QtWidgets[47906]
#define sipNameNr_cursorForward 47920
#define sipName_cursorForward &sipStrings_QtWidgets[47920]
#define sipNameNr_checkOverflow 47934
#define sipName_checkOverflow &sipStrings_QtWidgets[47934]
#define sipNameNr_setDigitCount 47948
#define sipName_setDigitCount &sipStrings_QtWidgets[47948]
#define sipNameNr_replaceWidget 47962
#define sipName_replaceWidget &sipStrings_QtWidgets[47962]
#define sipNameNr_alignmentRect 47976
#define sipName_alignmentRect &sipStrings_QtWidgets[47976]
#define sipNameNr_totalSizeHint 47990
#define sipName_totalSizeHint &sipStrings_QtWidgets[47990]
#define sipNameNr_QItemDelegate 48004
#define sipName_QItemDelegate &sipStrings_QtWidgets[48004]
#define sipNameNr_setDoubleStep 48018
#define sipName_setDoubleStep &sipStrings_QtWidgets[48018]
#define sipNameNr_doubleMaximum 48032
#define sipName_doubleMaximum &sipStrings_QtWidgets[48032]
#define sipNameNr_doubleMinimum 48046
#define sipName_doubleMinimum &sipStrings_QtWidgets[48046]
#define sipNameNr_setIntMaximum 48060
#define sipName_setIntMaximum &sipStrings_QtWidgets[48060]
#define sipNameNr_setIntMinimum 48074
#define sipName_setIntMinimum &sipStrings_QtWidgets[48074]
#define sipNameNr_comboBoxItems 48088
#define sipName_comboBoxItems &sipStrings_QtWidgets[48088]
#define sipNameNr_updateSection 48102
#define sipName_updateSection &sipStrings_QtWidgets[48102]
#define sipNameNr_sectionsMoved 48116
#define sipName_sectionsMoved &sipStrings_QtWidgets[48116]
#define sipNameNr_resizeSection 48130
#define sipName_resizeSection &sipStrings_QtWidgets[48130]
#define sipNameNr_visualIndexAt 48144
#define sipName_visualIndexAt &sipStrings_QtWidgets[48144]
#define sipNameNr_columnStretch 48158
#define sipName_columnStretch &sipStrings_QtWidgets[48158]
#define sipNameNr_setRowStretch 48172
#define sipName_setRowStretch &sipStrings_QtWidgets[48172]
#define sipNameNr_insertActions 48186
#define sipName_insertActions &sipStrings_QtWidgets[48186]
#define sipNameNr_isTransformed 48200
#define sipName_isTransformed &sipStrings_QtWidgets[48200]
#define sipNameNr_isInteractive 48214
#define sipName_isInteractive &sipStrings_QtWidgets[48214]
#define sipNameNr_CacheModeFlag 8742
#define sipName_CacheModeFlag &sipStrings_QtWidgets[8742]
#define sipNameNr_QGraphicsView 48228
#define sipName_QGraphicsView &sipStrings_QtWidgets[48228]
#define sipNameNr_zScaleChanged 48242
#define sipName_zScaleChanged &sipStrings_QtWidgets[48242]
#define sipNameNr_yScaleChanged 48256
#define sipName_yScaleChanged &sipStrings_QtWidgets[48256]
#define sipNameNr_xScaleChanged 48270
#define sipName_xScaleChanged &sipStrings_QtWidgets[48270]
#define sipNameNr_originChanged 48284
#define sipName_originChanged &sipStrings_QtWidgets[48284]
#define sipNameNr_buttonDownPos 48298
#define sipName_buttonDownPos &sipStrings_QtWidgets[48298]
#define sipNameNr_selectionArea 48312
#define sipName_selectionArea &sipStrings_QtWidgets[48312]
#define sipNameNr_addSimpleText 48326
#define sipName_addSimpleText &sipStrings_QtWidgets[48326]
#define sipNameNr_selectedItems 48340
#define sipName_selectedItems &sipStrings_QtWidgets[48340]
#define sipNameNr_subWidgetRect 48354
#define sipName_subWidgetRect &sipStrings_QtWidgets[48354]
#define sipNameNr_stretchFactor 48368
#define sipName_stretchFactor &sipStrings_QtWidgets[48368]
#define sipNameNr_ownedByLayout 48382
#define sipName_ownedByLayout &sipStrings_QtWidgets[48382]
#define sipNameNr_preferredSize 48396
#define sipName_preferredSize &sipStrings_QtWidgets[48396]
#define sipNameNr_linkActivated 48410
#define sipName_linkActivated &sipStrings_QtWidgets[48410]
#define sipNameNr_setTextCursor 48424
#define sipName_setTextCursor &sipStrings_QtWidgets[48424]
#define sipNameNr_parentChanged 48438
#define sipName_parentChanged &sipStrings_QtWidgets[48438]
#define sipNameNr_ungrabGesture 48452
#define sipName_ungrabGesture &sipStrings_QtWidgets[48452]
#define sipNameNr_setStartAngle 48466
#define sipName_setStartAngle &sipStrings_QtWidgets[48466]
#define sipNameNr_setFocusProxy 48480
#define sipName_setFocusProxy &sipStrings_QtWidgets[48480]
#define sipNameNr_blockingPanel 48494
#define sipName_blockingPanel &sipStrings_QtWidgets[48494]
#define sipNameNr_panelModality 48508
#define sipName_panelModality &sipStrings_QtWidgets[48508]
#define sipNameNr_PanelModality 8771
#define sipName_PanelModality &sipStrings_QtWidgets[8771]
#define sipNameNr_mapRectToItem 48522
#define sipName_mapRectToItem &sipStrings_QtWidgets[48522]
#define sipNameNr_itemTransform 48536
#define sipName_itemTransform &sipStrings_QtWidgets[48536]
#define sipNameNr_mapFromParent 48550
#define sipName_mapFromParent &sipStrings_QtWidgets[48550]
#define sipNameNr_ensureVisible 48564
#define sipName_ensureVisible &sipStrings_QtWidgets[48564]
#define sipNameNr_setParentItem 48578
#define sipName_setParentItem &sipStrings_QtWidgets[48578]
#define sipNameNr_ItemIsMovable 48592
#define sipName_ItemIsMovable &sipStrings_QtWidgets[48592]
#define sipNameNr_QGraphicsItem 48606
#define sipName_QGraphicsItem &sipStrings_QtWidgets[48606]
#define sipNameNr_columnSpacing 48620
#define sipName_columnSpacing &sipStrings_QtWidgets[48620]
#define sipNameNr_setRowSpacing 48634
#define sipName_setRowSpacing &sipStrings_QtWidgets[48634]
#define sipNameNr_offsetChanged 48648
#define sipName_offsetChanged &sipStrings_QtWidgets[48648]
#define sipNameNr_setBlurRadius 48662
#define sipName_setBlurRadius &sipStrings_QtWidgets[48662]
#define sipNameNr_AnimationHint 48676
#define sipName_AnimationHint &sipStrings_QtWidgets[48676]
#define sipNameNr_sourceChanged 48690
#define sipName_sourceChanged &sipStrings_QtWidgets[48690]
#define sipNameNr_PixmapPadMode 6810
#define sipName_PixmapPadMode &sipStrings_QtWidgets[6810]
#define sipNameNr_setSizePolicy 48704
#define sipName_setSizePolicy &sipStrings_QtWidgets[48704]
#define sipNameNr_CancelGesture 48718
#define sipName_CancelGesture &sipStrings_QtWidgets[48718]
#define sipNameNr_FinishGesture 48732
#define sipName_FinishGesture &sipStrings_QtWidgets[48732]
#define sipNameNr_QGestureEvent 48746
#define sipName_QGestureEvent &sipStrings_QtWidgets[48746]
#define sipNameNr_setSwipeAngle 48760
#define sipName_setSwipeAngle &sipStrings_QtWidgets[48760]
#define sipNameNr_QSwipeGesture 48774
#define sipName_QSwipeGesture &sipStrings_QtWidgets[48774]
#define sipNameNr_rotationAngle 48788
#define sipName_rotationAngle &sipStrings_QtWidgets[48788]
#define sipNameNr_QPinchGesture 48802
#define sipName_QPinchGesture &sipStrings_QtWidgets[48802]
#define sipNameNr_setLastOffset 48816
#define sipName_setLastOffset &sipStrings_QtWidgets[48816]
#define sipNameNr_setFrameShape 48830
#define sipName_setFrameShape &sipStrings_QtWidgets[48830]
#define sipNameNr_setFrameStyle 48844
#define sipName_setFrameStyle &sipStrings_QtWidgets[48844]
#define sipNameNr_QFrame__Shape 48858
#define sipName_QFrame__Shape &sipStrings_QtWidgets[48858]
#define sipNameNr_TakeRowResult 10730
#define sipName_TakeRowResult &sipStrings_QtWidgets[10730]
#define sipNameNr_labelForField 48872
#define sipName_labelForField &sipStrings_QtWidgets[48872]
#define sipNameNr_formAlignment 48886
#define sipName_formAlignment &sipStrings_QtWidgets[48886]
#define sipNameNr_rowWrapPolicy 48900
#define sipName_rowWrapPolicy &sipStrings_QtWidgets[48900]
#define sipNameNr_RowWrapPolicy 10757
#define sipName_RowWrapPolicy &sipStrings_QtWidgets[10757]
#define sipNameNr_ScalableFonts 36764
#define sipName_ScalableFonts &sipStrings_QtWidgets[36764]
#define sipNameNr_QFontComboBox 48914
#define sipName_QFontComboBox &sipStrings_QtWidgets[48914]
#define sipNameNr_rootDirectory 48928
#define sipName_rootDirectory &sipStrings_QtWidgets[48928]
#define sipNameNr_setNameFilter 48942
#define sipName_setNameFilter &sipStrings_QtWidgets[48942]
#define sipNameNr_setProxyModel 48956
#define sipName_setProxyModel &sipStrings_QtWidgets[48956]
#define sipNameNr_initialFilter 48970
#define sipName_initialFilter &sipStrings_QtWidgets[48970]
#define sipNameNr_filesSelected 48984
#define sipName_filesSelected &sipStrings_QtWidgets[48984]
#define sipNameNr_defaultSuffix 48998
#define sipName_defaultSuffix &sipStrings_QtWidgets[48998]
#define sipNameNr_setAcceptMode 49012
#define sipName_setAcceptMode &sipStrings_QtWidgets[49012]
#define sipNameNr_selectedFiles 49026
#define sipName_selectedFiles &sipStrings_QtWidgets[49026]
#define sipNameNr_DirectoryOnly 49040
#define sipName_DirectoryOnly &sipStrings_QtWidgets[49040]
#define sipNameNr_ExistingFiles 49054
#define sipName_ExistingFiles &sipStrings_QtWidgets[49054]
#define sipNameNr_QErrorMessage 49068
#define sipName_QErrorMessage &sipStrings_QtWidgets[49068]
#define sipNameNr_qDrawWinPanel 49082
#define sipName_qDrawWinPanel &sipStrings_QtWidgets[49082]
#define sipNameNr_isAreaAllowed 49096
#define sipName_isAreaAllowed &sipStrings_QtWidgets[49096]
#define sipNameNr_helpRequested 49110
#define sipName_helpRequested &sipStrings_QtWidgets[49110]
#define sipNameNr_centerButtons 49124
#define sipName_centerButtons &sipStrings_QtWidgets[49124]
#define sipNameNr_AndroidLayout 49138
#define sipName_AndroidLayout &sipStrings_QtWidgets[49138]
#define sipNameNr_calendarPopup 49152
#define sipName_calendarPopup &sipStrings_QtWidgets[49152]
#define sipNameNr_displayFormat 49166
#define sipName_displayFormat &sipStrings_QtWidgets[49166]
#define sipNameNr_MinuteSection 49180
#define sipName_MinuteSection &sipStrings_QtWidgets[49180]
#define sipNameNr_SecondSection 49194
#define sipName_SecondSection &sipStrings_QtWidgets[49194]
#define sipNameNr_QDateTimeEdit 49208
#define sipName_QDateTimeEdit &sipStrings_QtWidgets[49208]
#define sipNameNr_mappedSection 49222
#define sipName_mappedSection &sipStrings_QtWidgets[49222]
#define sipNameNr_removeMapping 49236
#define sipName_removeMapping &sipStrings_QtWidgets[49236]
#define sipNameNr_setFilterMode 49250
#define sipName_setFilterMode &sipStrings_QtWidgets[49250]
#define sipNameNr_setWrapAround 49264
#define sipName_setWrapAround &sipStrings_QtWidgets[49264]
#define sipNameNr_pathFromIndex 49278
#define sipName_pathFromIndex &sipStrings_QtWidgets[49278]
#define sipNameNr_setCurrentRow 49292
#define sipName_setCurrentRow &sipStrings_QtWidgets[49292]
#define sipNameNr_UnsortedModel 49306
#define sipName_UnsortedModel &sipStrings_QtWidgets[49306]
#define sipNameNr_layoutSpacing 49320
#define sipName_layoutSpacing &sipStrings_QtWidgets[49320]
#define sipNameNr_drawPrimitive 49334
#define sipName_drawPrimitive &sipStrings_QtWidgets[49334]
#define sipNameNr_textActivated 49348
#define sipName_textActivated &sipStrings_QtWidgets[49348]
#define sipNameNr_clearEditText 49362
#define sipName_clearEditText &sipStrings_QtWidgets[49362]
#define sipNameNr_previewWidget 49376
#define sipName_previewWidget &sipStrings_QtWidgets[49376]
#define sipNameNr_selectedColor 49390
#define sipName_selectedColor &sipStrings_QtWidgets[49390]
#define sipNameNr_colorSelected 49404
#define sipName_colorSelected &sipStrings_QtWidgets[49404]
#define sipNameNr_standardColor 49418
#define sipName_standardColor &sipStrings_QtWidgets[49418]
#define sipNameNr_showNextMonth 49432
#define sipName_showNextMonth &sipStrings_QtWidgets[49432]
#define sipNameNr_isGridVisible 49446
#define sipName_isGridVisible &sipStrings_QtWidgets[49446]
#define sipNameNr_ShortDayNames 49460
#define sipName_ShortDayNames &sipStrings_QtWidgets[49460]
#define sipNameNr_buttonToggled 49474
#define sipName_buttonToggled &sipStrings_QtWidgets[49474]
#define sipNameNr_buttonPressed 49488
#define sipName_buttonPressed &sipStrings_QtWidgets[49488]
#define sipNameNr_buttonClicked 49502
#define sipName_buttonClicked &sipStrings_QtWidgets[49502]
#define sipNameNr_checkedButton 49516
#define sipName_checkedButton &sipStrings_QtWidgets[49516]
#define sipNameNr_addSpacerItem 49530
#define sipName_addSpacerItem &sipStrings_QtWidgets[49530]
#define sipNameNr_insertStretch 49544
#define sipName_insertStretch &sipStrings_QtWidgets[49544]
#define sipNameNr_insertSpacing 49558
#define sipName_insertSpacing &sipStrings_QtWidgets[49558]
#define sipNameNr_setStyleSheet 49572
#define sipName_setStyleSheet &sipStrings_QtWidgets[49572]
#define sipNameNr_checkedAction 49586
#define sipName_checkedAction &sipStrings_QtWidgets[49586]
#define sipNameNr_isAccelerated 49600
#define sipName_isAccelerated &sipStrings_QtWidgets[49600]
#define sipNameNr_interpretText 49614
#define sipName_interpretText &sipStrings_QtWidgets[49614]
#define sipNameNr_buttonSymbols 49628
#define sipName_buttonSymbols &sipStrings_QtWidgets[49628]
#define sipNameNr_ButtonSymbols 5969
#define sipName_ButtonSymbols &sipStrings_QtWidgets[5969]
#define sipNameNr_StepUpEnabled 49642
#define sipName_StepUpEnabled &sipStrings_QtWidgets[49642]
#define sipNameNr_thresholdTime 49656
#define sipName_thresholdTime &sipStrings_QtWidgets[49656]
#define sipNameNr_sliderPressed 49670
#define sipName_sliderPressed &sipStrings_QtWidgets[49670]
#define sipNameNr_triggerAction 49684
#define sipName_triggerAction &sipStrings_QtWidgets[49684]
#define sipNameNr_setSliderDown 49698
#define sipName_setSliderDown &sipStrings_QtWidgets[49698]
#define sipNameNr_setSingleStep 49712
#define sipName_setSingleStep &sipStrings_QtWidgets[49712]
#define sipNameNr_AdjustIgnored 49726
#define sipName_AdjustIgnored &sipStrings_QtWidgets[49726]
#define sipNameNr_setupViewport 49740
#define sipName_setupViewport &sipStrings_QtWidgets[49740]
#define sipNameNr_dragMoveEvent 49754
#define sipName_dragMoveEvent &sipStrings_QtWidgets[49754]
#define sipNameNr_viewportEvent 49768
#define sipName_viewportEvent &sipStrings_QtWidgets[49768]
#define sipNameNr_DraggingState 49782
#define sipName_DraggingState &sipStrings_QtWidgets[49782]
#define sipNameNr_isIndexHidden 49796
#define sipName_isIndexHidden &sipStrings_QtWidgets[49796]
#define sipNameNr_doubleClicked 49810
#define sipName_doubleClicked &sipStrings_QtWidgets[49810]
#define sipNameNr_textElideMode 49824
#define sipName_textElideMode &sipStrings_QtWidgets[49824]
#define sipNameNr_hasAutoScroll 49838
#define sipName_hasAutoScroll &sipStrings_QtWidgets[49838]
#define sipNameNr_setAutoScroll 49852
#define sipName_setAutoScroll &sipStrings_QtWidgets[49852]
#define sipNameNr_selectionMode 49866
#define sipName_selectionMode &sipStrings_QtWidgets[49866]
#define sipNameNr_SelectionMode 5361
#define sipName_SelectionMode &sipStrings_QtWidgets[5361]
#define sipNameNr_SelectColumns 49880
#define sipName_SelectColumns &sipStrings_QtWidgets[49880]
#define sipNameNr_ScrollPerItem 49894
#define sipName_ScrollPerItem &sipStrings_QtWidgets[49894]
#define sipNameNr_PositionAtTop 49908
#define sipName_PositionAtTop &sipStrings_QtWidgets[49908]
#define sipNameNr_EnsureVisible 49922
#define sipName_EnsureVisible &sipStrings_QtWidgets[49922]
#define sipNameNr_AnyKeyPressed 49936
#define sipName_AnyKeyPressed &sipStrings_QtWidgets[49936]
#define sipNameNr_DoubleClicked 10460
#define sipName_DoubleClicked &sipStrings_QtWidgets[10460]
#define sipNameNr_destroyEditor 49950
#define sipName_destroyEditor &sipStrings_QtWidgets[49950]
#define sipNameNr_setEditorData 49964
#define sipName_setEditorData &sipStrings_QtWidgets[49964]
#define sipNameNr_checkStateSet 49978
#define sipName_checkStateSet &sipStrings_QtWidgets[49978]
#define sipNameNr_autoExclusive 49992
#define sipName_autoExclusive &sipStrings_QtWidgets[49992]
#define sipNameNr_setAutoRepeat 50006
#define sipName_setAutoRepeat &sipStrings_QtWidgets[50006]
#define sipNameNr_keyPressEvent 50020
#define sipName_keyPressEvent &sipStrings_QtWidgets[50020]
#define sipNameNr_focusOutEvent 50034
#define sipName_focusOutEvent &sipStrings_QtWidgets[50034]
#define sipNameNr_requestUpdate 50048
#define sipName_requestUpdate &sipStrings_QtWidgets[50048]
#define sipNameNr_showMaximized 50062
#define sipName_showMaximized &sipStrings_QtWidgets[50062]
#define sipNameNr_showMinimized 50076
#define sipName_showMinimized &sipStrings_QtWidgets[50076]
#define sipNameNr_mapFromGlobal 50090
#define sipName_mapFromGlobal &sipStrings_QtWidgets[50090]
#define sipNameNr_frameGeometry 50104
#define sipName_frameGeometry &sipStrings_QtWidgets[50104]
#define sipNameNr_sizeIncrement 50118
#define sipName_sizeIncrement &sipStrings_QtWidgets[50118]
#define sipNameNr_maximumHeight 50132
#define sipName_maximumHeight &sipStrings_QtWidgets[50132]
#define sipNameNr_minimumHeight 50146
#define sipName_minimumHeight &sipStrings_QtWidgets[50146]
#define sipNameNr_fontUnderline 50160
#define sipName_fontUnderline &sipStrings_QtWidgets[50160]
#define sipNameNr_setFontItalic 50174
#define sipName_setFontItalic &sipStrings_QtWidgets[50174]
#define sipNameNr_setFontWeight 50188
#define sipName_setFontWeight &sipStrings_QtWidgets[50188]
#define sipNameNr_fontPointSize 50202
#define sipName_fontPointSize &sipStrings_QtWidgets[50202]
#define sipNameNr_setFontFamily 50216
#define sipName_setFontFamily &sipStrings_QtWidgets[50216]
#define sipNameNr_undoAvailable 50230
#define sipName_undoAvailable &sipStrings_QtWidgets[50230]
#define sipNameNr_redoAvailable 50244
#define sipName_redoAvailable &sipStrings_QtWidgets[50244]
#define sipNameNr_startDragTime 50258
#define sipName_startDragTime &sipStrings_QtWidgets[50258]
#define sipNameNr_setTextFormat 50272
#define sipName_setTextFormat &sipStrings_QtWidgets[50272]
#define sipNameNr_setCheckState 50286
#define sipName_setCheckState &sipStrings_QtWidgets[50286]
#define sipNameNr_setForeground 50300
#define sipName_setForeground &sipStrings_QtWidgets[50300]
#define sipNameNr_textAlignment 50314
#define sipName_textAlignment &sipStrings_QtWidgets[50314]
#define sipNameNr_itemPrototype 50328
#define sipName_itemPrototype &sipStrings_QtWidgets[50328]
#define sipNameNr_indexFromItem 50342
#define sipName_indexFromItem &sipStrings_QtWidgets[50342]
#define sipNameNr_itemFromIndex 50356
#define sipName_itemFromIndex &sipStrings_QtWidgets[50356]
#define sipNameNr_setRenderHint 50370
#define sipName_setRenderHint &sipStrings_QtWidgets[50370]
#define sipNameNr_setBackground 50384
#define sipName_setBackground &sipStrings_QtWidgets[50384]
#define sipNameNr_setWindowIcon 50398
#define sipName_setWindowIcon &sipStrings_QtWidgets[50398]
#define sipNameNr_isLeftToRight 50412
#define sipName_isLeftToRight &sipStrings_QtWidgets[50412]
#define sipNameNr_primaryScreen 50426
#define sipName_primaryScreen &sipStrings_QtWidgets[50426]
#define sipNameNr_isRightToLeft 50440
#define sipName_isRightToLeft &sipStrings_QtWidgets[50440]
#define sipNameNr_writingSystem 50454
#define sipName_writingSystem &sipStrings_QtWidgets[50454]
#define sipNameNr_lastScreenPos 50468
#define sipName_lastScreenPos &sipStrings_QtWidgets[50468]
#define sipNameNr_setDropAction 50482
#define sipName_setDropAction &sipStrings_QtWidgets[50482]
#define sipNameNr_defaultAction 50496
#define sipName_defaultAction &sipStrings_QtWidgets[50496]
#define sipNameNr_IteratorFlags 1747
#define sipName_IteratorFlags &sipStrings_QtWidgets[1747]
#define sipNameNr_testAttribute 50510
#define sipName_testAttribute &sipStrings_QtWidgets[50510]
#define sipNameNr_connectNotify 38056
#define sipName_connectNotify &sipStrings_QtWidgets[38056]
#define sipNameNr_removeColumns 50524
#define sipName_removeColumns &sipStrings_QtWidgets[50524]
#define sipNameNr_insertColumns 50538
#define sipName_insertColumns &sipStrings_QtWidgets[50538]
#define sipNameNr_setHeaderData 50552
#define sipName_setHeaderData &sipStrings_QtWidgets[50552]
#define sipNameNr_validatePage 50566
#define sipName_validatePage &sipStrings_QtWidgets[50566]
#define sipNameNr_isCommitPage 50579
#define sipName_isCommitPage &sipStrings_QtWidgets[50579]
#define sipNameNr_setFinalPage 50592
#define sipName_setFinalPage &sipStrings_QtWidgets[50592]
#define sipNameNr_visitedPages 50605
#define sipName_visitedPages &sipStrings_QtWidgets[50605]
#define sipNameNr_WizardOption 18145
#define sipName_WizardOption &sipStrings_QtWidgets[18145]
#define sipNameNr_ClassicStyle 50618
#define sipName_ClassicStyle &sipStrings_QtWidgets[50618]
#define sipNameNr_BannerPixmap 50631
#define sipName_BannerPixmap &sipStrings_QtWidgets[50631]
#define sipNameNr_WizardPixmap 18167
#define sipName_WizardPixmap &sipStrings_QtWidgets[18167]
#define sipNameNr_CancelButton 3266
#define sipName_CancelButton &sipStrings_QtWidgets[3266]
#define sipNameNr_FinishButton 50644
#define sipName_FinishButton &sipStrings_QtWidgets[50644]
#define sipNameNr_CommitButton 50657
#define sipName_CommitButton &sipStrings_QtWidgets[50657]
#define sipNameNr_WizardButton 18189
#define sipName_WizardButton &sipStrings_QtWidgets[18189]
#define sipNameNr_deleteWidget 50670
#define sipName_deleteWidget &sipStrings_QtWidgets[50670]
#define sipNameNr_windowHandle 50683
#define sipName_windowHandle &sipStrings_QtWidgets[50683]
#define sipNameNr_sourceRegion 50696
#define sipName_sourceRegion &sipStrings_QtWidgets[50696]
#define sipNameNr_targetOffset 50709
#define sipName_targetOffset &sipStrings_QtWidgets[50709]
#define sipNameNr_DrawChildren 50722
#define sipName_DrawChildren &sipStrings_QtWidgets[50722]
#define sipNameNr_saveGeometry 50735
#define sipName_saveGeometry &sipStrings_QtWidgets[50735]
#define sipNameNr_isFullScreen 50748
#define sipName_isFullScreen &sipStrings_QtWidgets[50748]
#define sipNameNr_mouseGrabber 50761
#define sipName_mouseGrabber &sipStrings_QtWidgets[50761]
#define sipNameNr_releaseMouse 50774
#define sipName_releaseMouse &sipStrings_QtWidgets[50774]
#define sipNameNr_setFixedSize 50787
#define sipName_setFixedSize &sipStrings_QtWidgets[50787]
#define sipNameNr_childrenRect 50800
#define sipName_childrenRect &sipStrings_QtWidgets[50800]
#define sipNameNr_createAction 50813
#define sipName_createAction &sipStrings_QtWidgets[50813]
#define sipNameNr_setCleanIcon 50826
#define sipName_setCleanIcon &sipStrings_QtWidgets[50826]
#define sipNameNr_setUndoLimit 50839
#define sipName_setUndoLimit &sipStrings_QtWidgets[50839]
#define sipNameNr_QUndoCommand 50852
#define sipName_QUndoCommand &sipStrings_QtWidgets[50852]
#define sipNameNr_indexChanged 50865
#define sipName_indexChanged &sipStrings_QtWidgets[50865]
#define sipNameNr_cleanChanged 50878
#define sipName_cleanChanged &sipStrings_QtWidgets[50878]
#define sipNameNr_DropDisabled 50891
#define sipName_DropDisabled &sipStrings_QtWidgets[50891]
#define sipNameNr_DragDisabled 50904
#define sipName_DragDisabled &sipStrings_QtWidgets[50904]
#define sipNameNr_itemExpanded 50917
#define sipName_itemExpanded &sipStrings_QtWidgets[50917]
#define sipNameNr_collapseItem 50930
#define sipName_collapseItem &sipStrings_QtWidgets[50930]
#define sipNameNr_takeChildren 50943
#define sipName_takeChildren &sipStrings_QtWidgets[50943]
#define sipNameNr_indexOfChild 50956
#define sipName_indexOfChild &sipStrings_QtWidgets[50956]
#define sipNameNr_treePosition 50969
#define sipName_treePosition &sipStrings_QtWidgets[50969]
#define sipNameNr_drawBranches 50982
#define sipName_drawBranches &sipStrings_QtWidgets[50982]
#define sipNameNr_setAutoRaise 50995
#define sipName_setAutoRaise &sipStrings_QtWidgets[50995]
#define sipNameNr_setPopupMode 51008
#define sipName_setPopupMode &sipStrings_QtWidgets[51008]
#define sipNameNr_setArrowType 51021
#define sipName_setArrowType &sipStrings_QtWidgets[51021]
#define sipNameNr_InstantPopup 51034
#define sipName_InstantPopup &sipStrings_QtWidgets[51034]
#define sipNameNr_DelayedPopup 51047
#define sipName_DelayedPopup &sipStrings_QtWidgets[51047]
#define sipNameNr_itemInserted 51060
#define sipName_itemInserted &sipStrings_QtWidgets[51060]
#define sipNameNr_setFloatable 51073
#define sipName_setFloatable &sipStrings_QtWidgets[51073]
#define sipNameNr_setTextColor 51086
#define sipName_setTextColor &sipStrings_QtWidgets[51086]
#define sipNameNr_historyTitle 51099
#define sipName_historyTitle &sipStrings_QtWidgets[51099]
#define sipNameNr_setOpenLinks 51112
#define sipName_setOpenLinks &sipStrings_QtWidgets[51112]
#define sipNameNr_clearHistory 51125
#define sipName_clearHistory &sipStrings_QtWidgets[51125]
#define sipNameNr_QTextBrowser 51138
#define sipName_QTextBrowser &sipStrings_QtWidgets[51138]
#define sipNameNr_visualColumn 51151
#define sipName_visualColumn &sipStrings_QtWidgets[51151]
#define sipNameNr_QTableWidget 51164
#define sipName_QTableWidget &sipStrings_QtWidgets[51164]
#define sipNameNr_sortByColumn 51177
#define sipName_sortByColumn &sipStrings_QtWidgets[51177]
#define sipNameNr_selectColumn 51190
#define sipName_selectColumn &sipStrings_QtWidgets[51190]
#define sipNameNr_setGridStyle 51203
#define sipName_setGridStyle &sipStrings_QtWidgets[51203]
#define sipNameNr_setRowHeight 51216
#define sipName_setRowHeight &sipStrings_QtWidgets[51216]
#define sipNameNr_isTabVisible 51229
#define sipName_isTabVisible &sipStrings_QtWidgets[51229]
#define sipNameNr_setExpanding 51242
#define sipName_setExpanding &sipStrings_QtWidgets[51242]
#define sipNameNr_setTabButton 51255
#define sipName_setTabButton &sipStrings_QtWidgets[51255]
#define sipNameNr_setElideMode 51268
#define sipName_setElideMode &sipStrings_QtWidgets[51268]
#define sipNameNr_tabWhatsThis 51281
#define sipName_tabWhatsThis &sipStrings_QtWidgets[51281]
#define sipNameNr_tabTextColor 51294
#define sipName_tabTextColor &sipStrings_QtWidgets[51294]
#define sipNameNr_isTabEnabled 51307
#define sipName_isTabEnabled &sipStrings_QtWidgets[51307]
#define sipNameNr_RoundedSouth 51320
#define sipName_RoundedSouth &sipStrings_QtWidgets[51320]
#define sipNameNr_RoundedNorth 51333
#define sipName_RoundedNorth &sipStrings_QtWidgets[51333]
#define sipNameNr_dialWrapping 51346
#define sipName_dialWrapping &sipStrings_QtWidgets[51346]
#define sipNameNr_maxIconWidth 51359
#define sipName_maxIconWidth &sipStrings_QtWidgets[51359]
#define sipNameNr_menuItemType 51372
#define sipName_menuItemType &sipStrings_QtWidgets[51372]
#define sipNameNr_NonExclusive 51385
#define sipName_NonExclusive &sipStrings_QtWidgets[51385]
#define sipNameNr_NotCheckable 51398
#define sipName_NotCheckable &sipStrings_QtWidgets[51398]
#define sipNameNr_MenuItemType 3772
#define sipName_MenuItemType &sipStrings_QtWidgets[3772]
#define sipNameNr_CornerWidget 7119
#define sipName_CornerWidget &sipStrings_QtWidgets[7119]
#define sipNameNr_FrameFeature 5426
#define sipName_FrameFeature &sipStrings_QtWidgets[5426]
#define sipNameNr_SO_FocusRect 51411
#define sipName_SO_FocusRect &sipStrings_QtWidgets[51411]
#define sipNameNr_QStyleOption 51424
#define sipName_QStyleOption &sipStrings_QtWidgets[51424]
#define sipNameNr_SP_MediaStop 51437
#define sipName_SP_MediaStop &sipStrings_QtWidgets[51437]
#define sipNameNr_SP_MediaPlay 51450
#define sipName_SP_MediaPlay &sipStrings_QtWidgets[51450]
#define sipNameNr_SP_ArrowBack 51463
#define sipName_SP_ArrowBack &sipStrings_QtWidgets[51463]
#define sipNameNr_SP_ArrowLeft 51476
#define sipName_SP_ArrowLeft &sipStrings_QtWidgets[51476]
#define sipNameNr_SP_ArrowDown 51489
#define sipName_SP_ArrowDown &sipStrings_QtWidgets[51489]
#define sipNameNr_SP_TrashIcon 51502
#define sipName_SP_TrashIcon &sipStrings_QtWidgets[51502]
#define sipNameNr_SH_Menu_Mask 51515
#define sipName_SH_Menu_Mask &sipStrings_QtWidgets[51515]
#define sipNameNr_CT_TabWidget 51528
#define sipName_CT_TabWidget &sipStrings_QtWidgets[51528]
#define sipNameNr_CT_ScrollBar 51541
#define sipName_CT_ScrollBar &sipStrings_QtWidgets[51541]
#define sipNameNr_CT_TabBarTab 51554
#define sipName_CT_TabBarTab &sipStrings_QtWidgets[51554]
#define sipNameNr_ContentsType 21476
#define sipName_ContentsType &sipStrings_QtWidgets[21476]
#define sipNameNr_SC_SpinBoxUp 51567
#define sipName_SC_SpinBoxUp &sipStrings_QtWidgets[51567]
#define sipNameNr_CC_ScrollBar 51580
#define sipName_CC_ScrollBar &sipStrings_QtWidgets[51580]
#define sipNameNr_CE_TabBarTab 51593
#define sipName_CE_TabBarTab &sipStrings_QtWidgets[51593]
#define sipNameNr_PE_PanelMenu 51606
#define sipName_PE_PanelMenu &sipStrings_QtWidgets[51606]
#define sipNameNr_PE_FrameMenu 51619
#define sipName_PE_FrameMenu &sipStrings_QtWidgets[51619]
#define sipNameNr_State_Window 51632
#define sipName_State_Window &sipStrings_QtWidgets[51632]
#define sipNameNr_State_Active 51645
#define sipName_State_Active &sipStrings_QtWidgets[51645]
#define sipNameNr_State_Bottom 51658
#define sipName_State_Bottom &sipStrings_QtWidgets[51658]
#define sipNameNr_State_Sunken 51671
#define sipName_State_Sunken &sipStrings_QtWidgets[51671]
#define sipNameNr_State_Raised 51684
#define sipName_State_Raised &sipStrings_QtWidgets[51684]
#define sipNameNr_stackingMode 51697
#define sipName_stackingMode &sipStrings_QtWidgets[51697]
#define sipNameNr_StackingMode 8598
#define sipName_StackingMode &sipStrings_QtWidgets[8598]
#define sipNameNr_moveSplitter 51710
#define sipName_moveSplitter &sipStrings_QtWidgets[51710]
#define sipNameNr_createHandle 51723
#define sipName_createHandle &sipStrings_QtWidgets[51723]
#define sipNameNr_opaqueResize 51736
#define sipName_opaqueResize &sipStrings_QtWidgets[51736]
#define sipNameNr_clearMessage 51749
#define sipName_clearMessage &sipStrings_QtWidgets[51749]
#define sipNameNr_tickInterval 51762
#define sipName_tickInterval &sipStrings_QtWidgets[51762]
#define sipNameNr_tickPosition 51775
#define sipName_tickPosition &sipStrings_QtWidgets[51775]
#define sipNameNr_TickPosition 19267
#define sipName_TickPosition &sipStrings_QtWidgets[19267]
#define sipNameNr_ControlTypes 11884
#define sipName_ControlTypes &sipStrings_QtWidgets[11884]
#define sipNameNr_scrollMetric 51788
#define sipName_scrollMetric &sipStrings_QtWidgets[51788]
#define sipNameNr_ScrollMetric 4598
#define sipName_ScrollMetric &sipStrings_QtWidgets[4598]
#define sipNameNr_InputRelease 51801
#define sipName_InputRelease &sipStrings_QtWidgets[51801]
#define sipNameNr_TouchGesture 51814
#define sipName_TouchGesture &sipStrings_QtWidgets[51814]
#define sipNameNr_QRadioButton 51827
#define sipName_QRadioButton &sipStrings_QtWidgets[51827]
#define sipNameNr_itemTextRect 51840
#define sipName_itemTextRect &sipStrings_QtWidgets[51840]
#define sipNameNr_drawItemText 51853
#define sipName_drawItemText &sipStrings_QtWidgets[51853]
#define sipNameNr_setBaseStyle 51866
#define sipName_setBaseStyle &sipStrings_QtWidgets[51866]
#define sipNameNr_setAutoClose 51879
#define sipName_setAutoClose &sipStrings_QtWidgets[51879]
#define sipNameNr_setAutoReset 51892
#define sipName_setAutoReset &sipStrings_QtWidgets[51892]
#define sipNameNr_QProgressBar 51905
#define sipName_QProgressBar &sipStrings_QtWidgets[51905]
#define sipNameNr_centerCursor 51918
#define sipName_centerCursor &sipStrings_QtWidgets[51918]
#define sipNameNr_tabStopWidth 51931
#define sipName_tabStopWidth &sipStrings_QtWidgets[51931]
#define sipNameNr_wordWrapMode 51944
#define sipName_wordWrapMode &sipStrings_QtWidgets[51944]
#define sipNameNr_lineWrapMode 51957
#define sipName_lineWrapMode &sipStrings_QtWidgets[51957]
#define sipNameNr_LineWrapMode 8656
#define sipName_LineWrapMode &sipStrings_QtWidgets[8656]
#define sipNameNr_detailedText 51970
#define sipName_detailedText &sipStrings_QtWidgets[51970]
#define sipNameNr_escapeButton 51983
#define sipName_escapeButton &sipStrings_QtWidgets[51983]
#define sipNameNr_setDefaultUp 51996
#define sipName_setDefaultUp &sipStrings_QtWidgets[51996]
#define sipNameNr_activeAction 52009
#define sipName_activeAction &sipStrings_QtWidgets[52009]
#define sipNameNr_addSeparator 52022
#define sipName_addSeparator &sipStrings_QtWidgets[52022]
#define sipNameNr_tabsClosable 52035
#define sipName_tabsClosable &sipStrings_QtWidgets[52035]
#define sipNameNr_addSubWindow 52048
#define sipName_addSubWindow &sipStrings_QtWidgets[52048]
#define sipNameNr_documentMode 52061
#define sipName_documentMode &sipStrings_QtWidgets[52061]
#define sipNameNr_toolBarBreak 52074
#define sipName_toolBarBreak &sipStrings_QtWidgets[52074]
#define sipNameNr_VerticalTabs 52087
#define sipName_VerticalTabs &sipStrings_QtWidgets[52087]
#define sipNameNr_setStatusBar 52100
#define sipName_setStatusBar &sipStrings_QtWidgets[52100]
#define sipNameNr_scrollToItem 52113
#define sipName_scrollToItem &sipStrings_QtWidgets[52113]
#define sipNameNr_setBatchSize 52126
#define sipName_setBatchSize &sipStrings_QtWidgets[52126]
#define sipNameNr_rectForIndex 52139
#define sipName_rectForIndex &sipStrings_QtWidgets[52139]
#define sipNameNr_indexesMoved 52152
#define sipName_indexesMoved &sipStrings_QtWidgets[52152]
#define sipNameNr_setRowHidden 52165
#define sipName_setRowHidden &sipStrings_QtWidgets[52165]
#define sipNameNr_setInputMask 52178
#define sipName_setInputMask &sipStrings_QtWidgets[52178]
#define sipNameNr_setMaxLength 52191
#define sipName_setMaxLength &sipStrings_QtWidgets[52191]
#define sipNameNr_segmentStyle 52204
#define sipName_segmentStyle &sipStrings_QtWidgets[52204]
#define sipNameNr_setNumDigits 52217
#define sipName_setNumDigits &sipStrings_QtWidgets[52217]
#define sipNameNr_SegmentStyle 13558
#define sipName_SegmentStyle &sipStrings_QtWidgets[13558]
#define sipNameNr_controlTypes 52230
#define sipName_controlTypes &sipStrings_QtWidgets[52230]
#define sipNameNr_removeWidget 52243
#define sipName_removeWidget &sipStrings_QtWidgets[52243]
#define sipNameNr_SetFixedSize 52256
#define sipName_SetFixedSize &sipStrings_QtWidgets[52256]
#define sipNameNr_modifierMask 52269
#define sipName_modifierMask &sipStrings_QtWidgets[52269]
#define sipNameNr_createWidget 52282
#define sipName_createWidget &sipStrings_QtWidgets[52282]
#define sipNameNr_okButtonText 52295
#define sipName_okButtonText &sipStrings_QtWidgets[52295]
#define sipNameNr_textEchoMode 52308
#define sipName_textEchoMode &sipStrings_QtWidgets[52308]
#define sipNameNr_setTextValue 52321
#define sipName_setTextValue &sipStrings_QtWidgets[52321]
#define sipNameNr_setInputMode 52334
#define sipName_setInputMode &sipStrings_QtWidgets[52334]
#define sipNameNr_QInputDialog 52347
#define sipName_QInputDialog &sipStrings_QtWidgets[52347]
#define sipNameNr_swapSections 52360
#define sipName_swapSections &sipStrings_QtWidgets[52360]
#define sipNameNr_paintSection 52373
#define sipName_paintSection &sipStrings_QtWidgets[52373]
#define sipNameNr_sectionMoved 52386
#define sipName_sectionMoved &sipStrings_QtWidgets[52386]
#define sipNameNr_logicalIndex 52399
#define sipName_logicalIndex &sipStrings_QtWidgets[52399]
#define sipNameNr_originCorner 52412
#define sipName_originCorner &sipStrings_QtWidgets[52412]
#define sipNameNr_insertAction 52425
#define sipName_insertAction &sipStrings_QtWidgets[52425]
#define sipNameNr_grabShortcut 52438
#define sipName_grabShortcut &sipStrings_QtWidgets[52438]
#define sipNameNr_resizeAnchor 52451
#define sipName_resizeAnchor &sipStrings_QtWidgets[52451]
#define sipNameNr_angleChanged 52464
#define sipName_angleChanged &sipStrings_QtWidgets[52464]
#define sipNameNr_focusOnTouch 52477
#define sipName_focusOnTouch &sipStrings_QtWidgets[52477]
#define sipNameNr_bspTreeDepth 52490
#define sipName_bspTreeDepth &sipStrings_QtWidgets[52490]
#define sipNameNr_setFocusItem 52503
#define sipName_setFocusItem &sipStrings_QtWidgets[52503]
#define sipNameNr_setSceneRect 52516
#define sipName_setSceneRect &sipStrings_QtWidgets[52516]
#define sipNameNr_BspTreeIndex 52529
#define sipName_BspTreeIndex &sipStrings_QtWidgets[52529]
#define sipNameNr_graphicsItem 52542
#define sipName_graphicsItem &sipStrings_QtWidgets[52542]
#define sipNameNr_contentsRect 52555
#define sipName_contentsRect &sipStrings_QtWidgets[52555]
#define sipNameNr_scaleChanged 52568
#define sipName_scaleChanged &sipStrings_QtWidgets[52568]
#define sipNameNr_setShapeMode 52581
#define sipName_setShapeMode &sipStrings_QtWidgets[52581]
#define sipNameNr_setSpanAngle 52594
#define sipName_setSpanAngle &sipStrings_QtWidgets[52594]
#define sipNameNr_parentObject 52607
#define sipName_parentObject &sipStrings_QtWidgets[52607]
#define sipNameNr_isUnderMouse 52620
#define sipName_isUnderMouse &sipStrings_QtWidgets[52620]
#define sipNameNr_grabKeyboard 44677
#define sipName_grabKeyboard &sipStrings_QtWidgets[44677]
#define sipNameNr_mapFromScene 52633
#define sipName_mapFromScene &sipStrings_QtWidgets[52633]
#define sipNameNr_isObscuredBy 52646
#define sipName_isObscuredBy &sipStrings_QtWidgets[52646]
#define sipNameNr_topLevelItem 52659
#define sipName_topLevelItem &sipStrings_QtWidgets[52659]
#define sipNameNr_rowAlignment 13033
#define sipName_rowAlignment &sipStrings_QtWidgets[13033]
#define sipNameNr_setBlurHints 52672
#define sipName_setBlurHints &sipStrings_QtWidgets[52672]
#define sipNameNr_colorChanged 52685
#define sipName_colorChanged &sipStrings_QtWidgets[52685]
#define sipNameNr_sourcePixmap 52698
#define sipName_sourcePixmap &sipStrings_QtWidgets[52698]
#define sipNameNr_orientations 52711
#define sipName_orientations &sipStrings_QtWidgets[52711]
#define sipNameNr_unsetSpacing 52724
#define sipName_unsetSpacing &sipStrings_QtWidgets[52724]
#define sipNameNr_MayBeGesture 52737
#define sipName_MayBeGesture &sipStrings_QtWidgets[52737]
#define sipNameNr_acceleration 52750
#define sipName_acceleration &sipStrings_QtWidgets[52750]
#define sipNameNr_unsetHotSpot 52763
#define sipName_unsetHotSpot &sipStrings_QtWidgets[52763]
#define sipNameNr_setFrameRect 52776
#define sipName_setFrameRect &sipStrings_QtWidgets[52776]
#define sipNameNr_SpanningRole 52789
#define sipName_SpanningRole &sipStrings_QtWidgets[52789]
#define sipNameNr_WrapLongRows 52802
#define sipName_WrapLongRows &sipStrings_QtWidgets[52802]
#define sipNameNr_DontWrapRows 52815
#define sipName_DontWrapRows &sipStrings_QtWidgets[52815]
#define sipNameNr_fontSelected 52828
#define sipName_fontSelected &sipStrings_QtWidgets[52828]
#define sipNameNr_selectedFont 52841
#define sipName_selectedFont &sipStrings_QtWidgets[52841]
#define sipNameNr_fileNameHint 52854
#define sipName_fileNameHint &sipStrings_QtWidgets[52854]
#define sipNameNr_urlsSelected 52867
#define sipName_urlsSelected &sipStrings_QtWidgets[52867]
#define sipNameNr_selectedUrls 52880
#define sipName_selectedUrls &sipStrings_QtWidgets[52880]
#define sipNameNr_directoryUrl 52893
#define sipName_directoryUrl &sipStrings_QtWidgets[52893]
#define sipNameNr_restoreState 52906
#define sipName_restoreState &sipStrings_QtWidgets[52906]
#define sipNameNr_fileSelected 52919
#define sipName_fileSelected &sipStrings_QtWidgets[52919]
#define sipNameNr_setLabelText 52932
#define sipName_setLabelText &sipStrings_QtWidgets[52932]
#define sipNameNr_setDirectory 52945
#define sipName_setDirectory &sipStrings_QtWidgets[52945]
#define sipNameNr_DontUseSheet 52958
#define sipName_DontUseSheet &sipStrings_QtWidgets[52958]
#define sipNameNr_ShowDirsOnly 52971
#define sipName_ShowDirsOnly &sipStrings_QtWidgets[52971]
#define sipNameNr_ExistingFile 52984
#define sipName_ExistingFile &sipStrings_QtWidgets[52984]
#define sipNameNr_midLineWidth 52997
#define sipName_midLineWidth &sipStrings_QtWidgets[52997]
#define sipNameNr_allowedAreas 53010
#define sipName_allowedAreas &sipStrings_QtWidgets[53010]
#define sipNameNr_iconProvider 53023
#define sipName_iconProvider &sipStrings_QtWidgets[53023]
#define sipNameNr_FileNameRole 53036
#define sipName_FileNameRole &sipStrings_QtWidgets[53036]
#define sipNameNr_FilePathRole 53049
#define sipName_FilePathRole &sipStrings_QtWidgets[53049]
#define sipNameNr_FileIconRole 53062
#define sipName_FileIconRole &sipStrings_QtWidgets[53062]
#define sipNameNr_ButtonLayout 6966
#define sipName_ButtonLayout &sipStrings_QtWidgets[6966]
#define sipNameNr_screenNumber 53075
#define sipName_screenNumber &sipStrings_QtWidgets[53075]
#define sipNameNr_sectionCount 53088
#define sipName_sectionCount &sipStrings_QtWidgets[53088]
#define sipNameNr_setTimeRange 53101
#define sipName_setTimeRange &sipStrings_QtWidgets[53101]
#define sipNameNr_MonthSection 53114
#define sipName_MonthSection &sipStrings_QtWidgets[53114]
#define sipNameNr_clearMapping 53127
#define sipName_clearMapping &sipStrings_QtWidgets[53127]
#define sipNameNr_submitPolicy 53140
#define sipName_submitPolicy &sipStrings_QtWidgets[53140]
#define sipNameNr_ManualSubmit 53153
#define sipName_ManualSubmit &sipStrings_QtWidgets[53153]
#define sipNameNr_SubmitPolicy 5874
#define sipName_SubmitPolicy &sipStrings_QtWidgets[5874]
#define sipNameNr_modelSorting 53166
#define sipName_modelSorting &sipStrings_QtWidgets[53166]
#define sipNameNr_ModelSorting 13858
#define sipName_ModelSorting &sipStrings_QtWidgets[13858]
#define sipNameNr_standardIcon 53179
#define sipName_standardIcon &sipStrings_QtWidgets[53179]
#define sipNameNr_QCommonStyle 53192
#define sipName_QCommonStyle &sipStrings_QtWidgets[53192]
#define sipNameNr_setCompleter 53205
#define sipName_setCompleter &sipStrings_QtWidgets[53205]
#define sipNameNr_setValidator 53218
#define sipName_setValidator &sipStrings_QtWidgets[53218]
#define sipNameNr_insertPolicy 53231
#define sipName_insertPolicy &sipStrings_QtWidgets[53231]
#define sipNameNr_InsertPolicy 15906
#define sipName_InsertPolicy &sipStrings_QtWidgets[15906]
#define sipNameNr_createColumn 53244
#define sipName_createColumn &sipStrings_QtWidgets[53244]
#define sipNameNr_columnWidths 53257
#define sipName_columnWidths &sipStrings_QtWidgets[53257]
#define sipNameNr_currentColor 53270
#define sipName_currentColor &sipStrings_QtWidgets[53270]
#define sipNameNr_QColorDialog 53283
#define sipName_QColorDialog &sipStrings_QtWidgets[53283]
#define sipNameNr_showNextYear 53296
#define sipName_showNextYear &sipStrings_QtWidgets[53296]
#define sipNameNr_setDateRange 53309
#define sipName_setDateRange &sipStrings_QtWidgets[53309]
#define sipNameNr_selectedDate 53322
#define sipName_selectedDate &sipStrings_QtWidgets[53322]
#define sipNameNr_LongDayNames 53335
#define sipName_LongDayNames &sipStrings_QtWidgets[53335]
#define sipNameNr_removeButton 53348
#define sipName_removeButton &sipStrings_QtWidgets[53348]
#define sipNameNr_QButtonGroup 53361
#define sipName_QButtonGroup &sipStrings_QtWidgets[53361]
#define sipNameNr_insertLayout 53374
#define sipName_insertLayout &sipStrings_QtWidgets[53374]
#define sipNameNr_insertWidget 53387
#define sipName_insertWidget &sipStrings_QtWidgets[53387]
#define sipNameNr_focusChanged 53400
#define sipName_focusChanged &sipStrings_QtWidgets[53400]
#define sipNameNr_activeWindow 53413
#define sipName_activeWindow &sipStrings_QtWidgets[53413]
#define sipNameNr_setColorSpec 53426
#define sipName_setColorSpec &sipStrings_QtWidgets[53426]
#define sipNameNr_QApplication 53439
#define sipName_QApplication &sipStrings_QtWidgets[53439]
#define sipNameNr_setExclusive 53452
#define sipName_setExclusive &sipStrings_QtWidgets[53452]
#define sipNameNr_removeAction 53465
#define sipName_removeAction &sipStrings_QtWidgets[53465]
#define sipNameNr_QActionGroup 53478
#define sipName_QActionGroup &sipStrings_QtWidgets[53478]
#define sipNameNr_setShortcuts 53491
#define sipName_setShortcuts &sipStrings_QtWidgets[53491]
#define sipNameNr_parentWidget 53504
#define sipName_parentWidget &sipStrings_QtWidgets[53504]
#define sipNameNr_setSeparator 53517
#define sipName_setSeparator &sipStrings_QtWidgets[53517]
#define sipNameNr_UpDownArrows 53530
#define sipName_UpDownArrows &sipStrings_QtWidgets[53530]
#define sipNameNr_sliderChange 53543
#define sipName_sliderChange &sipStrings_QtWidgets[53543]
#define sipNameNr_SliderChange 7869
#define sipName_SliderChange &sipStrings_QtWidgets[7869]
#define sipNameNr_repeatAction 53556
#define sipName_repeatAction &sipStrings_QtWidgets[53556]
#define sipNameNr_rangeChanged 53569
#define sipName_rangeChanged &sipStrings_QtWidgets[53569]
#define sipNameNr_SliderAction 7899
#define sipName_SliderAction &sipStrings_QtWidgets[7899]
#define sipNameNr_isSliderDown 53582
#define sipName_isSliderDown &sipStrings_QtWidgets[53582]
#define sipNameNr_cornerWidget 53595
#define sipName_cornerWidget &sipStrings_QtWidgets[53595]
#define sipNameNr_dragDropMode 53608
#define sipName_dragDropMode &sipStrings_QtWidgets[53608]
#define sipNameNr_EditingState 53621
#define sipName_EditingState &sipStrings_QtWidgets[53621]
#define sipNameNr_setSelection 53634
#define sipName_setSelection &sipStrings_QtWidgets[53634]
#define sipNameNr_MovePrevious 53647
#define sipName_MovePrevious &sipStrings_QtWidgets[53647]
#define sipNameNr_MovePageDown 53660
#define sipName_MovePageDown &sipStrings_QtWidgets[53660]
#define sipNameNr_CursorAction 6002
#define sipName_CursorAction &sipStrings_QtWidgets[6002]
#define sipNameNr_setRootIndex 53673
#define sipName_setRootIndex &sipStrings_QtWidgets[53673]
#define sipNameNr_editTriggers 53686
#define sipName_editTriggers &sipStrings_QtWidgets[53686]
#define sipNameNr_itemDelegate 53699
#define sipName_itemDelegate &sipStrings_QtWidgets[53699]
#define sipNameNr_EditTriggers 6066
#define sipName_EditTriggers &sipStrings_QtWidgets[6066]
#define sipNameNr_InternalMove 53712
#define sipName_InternalMove &sipStrings_QtWidgets[53712]
#define sipNameNr_DragDropMode 6098
#define sipName_DragDropMode &sipStrings_QtWidgets[6098]
#define sipNameNr_setModelData 53725
#define sipName_setModelData &sipStrings_QtWidgets[53725]
#define sipNameNr_createEditor 53738
#define sipName_createEditor &sipStrings_QtWidgets[53738]
#define sipNameNr_EditNextItem 53751
#define sipName_EditNextItem &sipStrings_QtWidgets[53751]
#define sipNameNr_animateClick 53764
#define sipName_animateClick &sipStrings_QtWidgets[53764]
#define sipNameNr_focusInEvent 53777
#define sipName_focusInEvent &sipStrings_QtWidgets[53777]
#define sipNameNr_isAncestorOf 53790
#define sipName_isAncestorOf &sipStrings_QtWidgets[53790]
#define sipNameNr_setLineWidth 53803
#define sipName_setLineWidth &sipStrings_QtWidgets[53803]
#define sipNameNr_maximumWidth 53816
#define sipName_maximumWidth &sipStrings_QtWidgets[53816]
#define sipNameNr_minimumWidth 53829
#define sipName_minimumWidth &sipStrings_QtWidgets[53829]
#define sipNameNr_drawContents 53842
#define sipName_drawContents &sipStrings_QtWidgets[53842]
#define sipNameNr_loadResource 53855
#define sipName_loadResource &sipStrings_QtWidgets[53855]
#define sipNameNr_setPlainText 53868
#define sipName_setPlainText &sipStrings_QtWidgets[53868]
#define sipNameNr_selectedText 53881
#define sipName_selectedText &sipStrings_QtWidgets[53881]
#define sipNameNr_selectionEnd 53894
#define sipName_selectionEnd &sipStrings_QtWidgets[53894]
#define sipNameNr_setTextWidth 53907
#define sipName_setTextWidth &sipStrings_QtWidgets[53907]
#define sipNameNr_setWhatsThis 53920
#define sipName_setWhatsThis &sipStrings_QtWidgets[53920]
#define sipNameNr_setStatusTip 53933
#define sipName_setStatusTip &sipStrings_QtWidgets[53933]
#define sipNameNr_sortChildren 53946
#define sipName_sortChildren &sipStrings_QtWidgets[53946]
#define sipNameNr_setCheckable 53959
#define sipName_setCheckable &sipStrings_QtWidgets[53959]
#define sipNameNr_initializeGL 53972
#define sipName_initializeGL &sipStrings_QtWidgets[53972]
#define sipNameNr_frameSwapped 53985
#define sipName_frameSwapped &sipStrings_QtWidgets[53985]
#define sipNameNr_setAlignment 53998
#define sipName_setAlignment &sipStrings_QtWidgets[53998]
#define sipNameNr_setCacheMode 54011
#define sipName_setCacheMode &sipStrings_QtWidgets[54011]
#define sipNameNr_boundingRect 54024
#define sipName_boundingRect &sipStrings_QtWidgets[54024]
#define sipNameNr_lastScenePos 54037
#define sipName_lastScenePos &sipStrings_QtWidgets[54037]
#define sipNameNr_setTransform 46087
#define sipName_setTransform &sipStrings_QtWidgets[46087]
#define sipNameNr_documentSize 54050
#define sipName_documentSize &sipStrings_QtWidgets[54050]
#define sipNameNr_valueChanged 54063
#define sipName_valueChanged &sipStrings_QtWidgets[54063]
#define sipNameNr_HighPriority 54076
#define sipName_HighPriority &sipStrings_QtWidgets[54076]
#define sipNameNr_currentIndex 54089
#define sipName_currentIndex &sipStrings_QtWidgets[54089]
#define sipNameNr_lastModified 54102
#define sipName_lastModified &sipStrings_QtWidgets[54102]
#define sipNameNr_IteratorFlag 2137
#define sipName_IteratorFlag &sipStrings_QtWidgets[2137]
#define sipNameNr_setAttribute 54115
#define sipName_setAttribute &sipStrings_QtWidgets[54115]
#define sipNameNr_onTransition 54128
#define sipName_onTransition &sipStrings_QtWidgets[54128]
#define sipNameNr_removeColumn 54141
#define sipName_removeColumn &sipStrings_QtWidgets[54141]
#define sipNameNr_insertColumn 54154
#define sipName_insertColumn &sipStrings_QtWidgets[54154]
#define sipNameNr_rowsInserted 54167
#define sipName_rowsInserted &sipStrings_QtWidgets[54167]
#define sipNameNr_canFetchMore 54180
#define sipName_canFetchMore &sipStrings_QtWidgets[54180]
#define sipNameNr_dropMimeData 54193
#define sipName_dropMimeData &sipStrings_QtWidgets[54193]
#define sipNameNr_stateChanged 54206
#define sipName_stateChanged &sipStrings_QtWidgets[54206]
#define sipNameNr_setDirection 54219
#define sipName_setDirection &sipStrings_QtWidgets[54219]
#define sipNameNr_isFinalPage 54232
#define sipName_isFinalPage &sipStrings_QtWidgets[54232]
#define sipNameNr_setSubTitle 54244
#define sipName_setSubTitle &sipStrings_QtWidgets[54244]
#define sipNameNr_QWizardPage 54256
#define sipName_QWizardPage &sipStrings_QtWidgets[54256]
#define sipNameNr_pageRemoved 54268
#define sipName_pageRemoved &sipStrings_QtWidgets[54268]
#define sipNameNr_cleanupPage 54280
#define sipName_cleanupPage &sipStrings_QtWidgets[54280]
#define sipNameNr_titleFormat 54292
#define sipName_titleFormat &sipStrings_QtWidgets[54292]
#define sipNameNr_wizardStyle 54304
#define sipName_wizardStyle &sipStrings_QtWidgets[54304]
#define sipNameNr_currentPage 54316
#define sipName_currentPage &sipStrings_QtWidgets[54316]
#define sipNameNr_ModernStyle 54328
#define sipName_ModernStyle &sipStrings_QtWidgets[54328]
#define sipNameNr_WizardStyle 20763
#define sipName_WizardStyle &sipStrings_QtWidgets[20763]
#define sipNameNr_initPainter 54340
#define sipName_initPainter &sipStrings_QtWidgets[54340]
#define sipNameNr_nativeEvent 54352
#define sipName_nativeEvent &sipStrings_QtWidgets[54352]
#define sipNameNr_unsetLocale 54364
#define sipName_unsetLocale &sipStrings_QtWidgets[54364]
#define sipNameNr_isMaximized 54376
#define sipName_isMaximized &sipStrings_QtWidgets[54376]
#define sipNameNr_isMinimized 54388
#define sipName_isMinimized &sipStrings_QtWidgets[54388]
#define sipNameNr_isEnabledTo 54400
#define sipName_isEnabledTo &sipStrings_QtWidgets[54400]
#define sipNameNr_setObsolete 54412
#define sipName_setObsolete &sipStrings_QtWidgets[54412]
#define sipNameNr_activeStack 54424
#define sipName_activeStack &sipStrings_QtWidgets[54424]
#define sipNameNr_removeStack 54436
#define sipName_removeStack &sipStrings_QtWidgets[54436]
#define sipNameNr_NotEditable 54448
#define sipName_NotEditable &sipStrings_QtWidgets[54448]
#define sipNameNr_HasChildren 54460
#define sipName_HasChildren &sipStrings_QtWidgets[54460]
#define sipNameNr_DropEnabled 54472
#define sipName_DropEnabled &sipStrings_QtWidgets[54472]
#define sipNameNr_DragEnabled 46058
#define sipName_DragEnabled &sipStrings_QtWidgets[46058]
#define sipNameNr_QTreeWidget 54484
#define sipName_QTreeWidget &sipStrings_QtWidgets[54484]
#define sipNameNr_removeChild 54496
#define sipName_removeChild &sipStrings_QtWidgets[54496]
#define sipNameNr_addChildren 54508
#define sipName_addChildren &sipStrings_QtWidgets[54508]
#define sipNameNr_insertChild 54520
#define sipName_insertChild &sipStrings_QtWidgets[54520]
#define sipNameNr_collapseAll 54532
#define sipName_collapseAll &sipStrings_QtWidgets[54532]
#define sipNameNr_setExpanded 54544
#define sipName_setExpanded &sipStrings_QtWidgets[54544]
#define sipNameNr_indentation 54556
#define sipName_indentation &sipStrings_QtWidgets[54556]
#define sipNameNr_QToolButton 54568
#define sipName_QToolButton &sipStrings_QtWidgets[54568]
#define sipNameNr_itemRemoved 54580
#define sipName_itemRemoved &sipStrings_QtWidgets[54580]
#define sipNameNr_itemToolTip 54592
#define sipName_itemToolTip &sipStrings_QtWidgets[54592]
#define sipNameNr_isFloatable 54604
#define sipName_isFloatable &sipStrings_QtWidgets[54604]
#define sipNameNr_doSetSource 54616
#define sipName_doSetSource &sipStrings_QtWidgets[54616]
#define sipNameNr_cellChanged 54628
#define sipName_cellChanged &sipStrings_QtWidgets[54628]
#define sipNameNr_cellEntered 54640
#define sipName_cellEntered &sipStrings_QtWidgets[54640]
#define sipNameNr_cellClicked 54652
#define sipName_cellClicked &sipStrings_QtWidgets[54652]
#define sipNameNr_cellPressed 54664
#define sipName_cellPressed &sipStrings_QtWidgets[54664]
#define sipNameNr_tableWidget 54676
#define sipName_tableWidget &sipStrings_QtWidgets[54676]
#define sipNameNr_rightColumn 54688
#define sipName_rightColumn &sipStrings_QtWidgets[54688]
#define sipNameNr_columnMoved 54700
#define sipName_columnMoved &sipStrings_QtWidgets[54700]
#define sipNameNr_setShowGrid 54712
#define sipName_setShowGrid &sipStrings_QtWidgets[54712]
#define sipNameNr_columnWidth 54724
#define sipName_columnWidth &sipStrings_QtWidgets[54724]
#define sipNameNr_setAutoHide 54736
#define sipName_setAutoHide &sipStrings_QtWidgets[54736]
#define sipNameNr_tabInserted 54748
#define sipName_tabInserted &sipStrings_QtWidgets[54748]
#define sipNameNr_tabSizeHint 54760
#define sipName_tabSizeHint &sipStrings_QtWidgets[54760]
#define sipNameNr_setDrawBase 54772
#define sipName_setDrawBase &sipStrings_QtWidgets[54772]
#define sipNameNr_RoundedEast 54784
#define sipName_RoundedEast &sipStrings_QtWidgets[54784]
#define sipNameNr_RoundedWest 54796
#define sipName_RoundedWest &sipStrings_QtWidgets[54796]
#define sipNameNr_contextMenu 54808
#define sipName_contextMenu &sipStrings_QtWidgets[54808]
#define sipNameNr_MessageIcon 8135
#define sipName_MessageIcon &sipStrings_QtWidgets[8135]
#define sipNameNr_MiddleClick 54820
#define sipName_MiddleClick &sipStrings_QtWidgets[54820]
#define sipNameNr_DoubleClick 14275
#define sipName_DoubleClick &sipStrings_QtWidgets[14275]
#define sipNameNr_exposedRect 54832
#define sipName_exposedRect &sipStrings_QtWidgets[54832]
#define sipNameNr_currentIcon 54844
#define sipName_currentIcon &sipStrings_QtWidgets[54844]
#define sipNameNr_sliderValue 54856
#define sipName_sliderValue &sipStrings_QtWidgets[54856]
#define sipNameNr_subControls 54868
#define sipName_subControls &sipStrings_QtWidgets[54868]
#define sipNameNr_DefaultItem 54880
#define sipName_DefaultItem &sipStrings_QtWidgets[54880]
#define sipNameNr_bottomToTop 54892
#define sipName_bottomToTop &sipStrings_QtWidgets[54892]
#define sipNameNr_textVisible 54904
#define sipName_textVisible &sipStrings_QtWidgets[54904]
#define sipNameNr_TabFeatures 8164
#define sipName_TabFeatures &sipStrings_QtWidgets[8164]
#define sipNameNr_TabPosition 4901
#define sipName_TabPosition &sipStrings_QtWidgets[4901]
#define sipNameNr_NotAdjacent 54916
#define sipName_NotAdjacent &sipStrings_QtWidgets[54916]
#define sipNameNr_styleObject 54928
#define sipName_styleObject &sipStrings_QtWidgets[54928]
#define sipNameNr_SO_SizeGrip 54940
#define sipName_SO_SizeGrip &sipStrings_QtWidgets[54940]
#define sipNameNr_SO_GroupBox 54952
#define sipName_SO_GroupBox &sipStrings_QtWidgets[54952]
#define sipNameNr_SO_TitleBar 54964
#define sipName_SO_TitleBar &sipStrings_QtWidgets[54964]
#define sipNameNr_SO_ComboBox 54976
#define sipName_SO_ComboBox &sipStrings_QtWidgets[54976]
#define sipNameNr_SO_ViewItem 54988
#define sipName_SO_ViewItem &sipStrings_QtWidgets[54988]
#define sipNameNr_SO_MenuItem 55000
#define sipName_SO_MenuItem &sipStrings_QtWidgets[55000]
#define sipNameNr_alignedRect 55012
#define sipName_alignedRect &sipStrings_QtWidgets[55012]
#define sipNameNr_SP_FileIcon 55024
#define sipName_SP_FileIcon &sipStrings_QtWidgets[55024]
#define sipNameNr_CT_GroupBox 55036
#define sipName_CT_GroupBox &sipStrings_QtWidgets[55036]
#define sipNameNr_CT_SizeGrip 55048
#define sipName_CT_SizeGrip &sipStrings_QtWidgets[55048]
#define sipNameNr_CT_LineEdit 55060
#define sipName_CT_LineEdit &sipStrings_QtWidgets[55060]
#define sipNameNr_CT_MenuItem 55072
#define sipName_CT_MenuItem &sipStrings_QtWidgets[55072]
#define sipNameNr_CT_Splitter 55084
#define sipName_CT_Splitter &sipStrings_QtWidgets[55084]
#define sipNameNr_CT_ComboBox 55096
#define sipName_CT_ComboBox &sipStrings_QtWidgets[55096]
#define sipNameNr_CT_CheckBox 55108
#define sipName_CT_CheckBox &sipStrings_QtWidgets[55108]
#define sipNameNr_PixelMetric 24565
#define sipName_PixelMetric &sipStrings_QtWidgets[24565]
#define sipNameNr_SubControls 24585
#define sipName_SubControls &sipStrings_QtWidgets[24585]
#define sipNameNr_CC_GroupBox 55120
#define sipName_CC_GroupBox &sipStrings_QtWidgets[55120]
#define sipNameNr_CC_TitleBar 55132
#define sipName_CC_TitleBar &sipStrings_QtWidgets[55132]
#define sipNameNr_CC_ComboBox 55144
#define sipName_CC_ComboBox &sipStrings_QtWidgets[55144]
#define sipNameNr_CE_Splitter 55156
#define sipName_CE_Splitter &sipStrings_QtWidgets[55156]
#define sipNameNr_CE_SizeGrip 55168
#define sipName_CE_SizeGrip &sipStrings_QtWidgets[55168]
#define sipNameNr_CE_MenuItem 55180
#define sipName_CE_MenuItem &sipStrings_QtWidgets[55180]
#define sipNameNr_CE_CheckBox 55192
#define sipName_CE_CheckBox &sipStrings_QtWidgets[55192]
#define sipNameNr_State_Small 55204
#define sipName_State_Small &sipStrings_QtWidgets[55204]
#define sipNameNr_handleWidth 55216
#define sipName_handleWidth &sipStrings_QtWidgets[55216]
#define sipNameNr_setStepType 55228
#define sipName_setStepType &sipStrings_QtWidgets[55228]
#define sipNameNr_RadioButton 15019
#define sipName_RadioButton &sipStrings_QtWidgets[15019]
#define sipNameNr_DefaultType 55240
#define sipName_DefaultType &sipStrings_QtWidgets[55240]
#define sipNameNr_ControlType 13434
#define sipName_ControlType &sipStrings_QtWidgets[13434]
#define sipNameNr_handleInput 55252
#define sipName_handleInput &sipStrings_QtWidgets[55252]
#define sipNameNr_hasScroller 55264
#define sipName_hasScroller &sipStrings_QtWidgets[55264]
#define sipNameNr_QScrollArea 55276
#define sipName_QScrollArea &sipStrings_QtWidgets[55276]
#define sipNameNr_QRubberBand 55288
#define sipName_QRubberBand &sipStrings_QtWidgets[55288]
#define sipNameNr_autoDefault 55300
#define sipName_autoDefault &sipStrings_QtWidgets[55300]
#define sipNameNr_QProxyStyle 55312
#define sipName_QProxyStyle &sipStrings_QtWidgets[55312]
#define sipNameNr_wasCanceled 55324
#define sipName_wasCanceled &sipStrings_QtWidgets[55324]
#define sipNameNr_resetFormat 55336
#define sipName_resetFormat &sipStrings_QtWidgets[55336]
#define sipNameNr_cursorWidth 55348
#define sipName_cursorWidth &sipStrings_QtWidgets[55348]
#define sipNameNr_WidgetWidth 55360
#define sipName_WidgetWidth &sipStrings_QtWidgets[55360]
#define sipNameNr_hitTestPath 55372
#define sipName_hitTestPath &sipStrings_QtWidgets[55372]
#define sipNameNr_setCheckBox 55384
#define sipName_setCheckBox &sipStrings_QtWidgets[55384]
#define sipNameNr_information 55396
#define sipName_information &sipStrings_QtWidgets[55396]
#define sipNameNr_FirstButton 55408
#define sipName_FirstButton &sipStrings_QtWidgets[55408]
#define sipNameNr_Information 12759
#define sipName_Information &sipStrings_QtWidgets[12759]
#define sipNameNr_QMessageBox 55420
#define sipName_QMessageBox &sipStrings_QtWidgets[55420]
#define sipNameNr_isDefaultUp 55432
#define sipName_isDefaultUp &sipStrings_QtWidgets[55432]
#define sipNameNr_actionEvent 55444
#define sipName_actionEvent &sipStrings_QtWidgets[55444]
#define sipNameNr_aboutToShow 55456
#define sipName_aboutToShow &sipStrings_QtWidgets[55456]
#define sipNameNr_aboutToHide 55468
#define sipName_aboutToHide &sipStrings_QtWidgets[55468]
#define sipNameNr_tabsMovable 55480
#define sipName_tabsMovable &sipStrings_QtWidgets[55480]
#define sipNameNr_WindowOrder 19444
#define sipName_WindowOrder &sipStrings_QtWidgets[19444]
#define sipNameNr_AreaOptions 19466
#define sipName_AreaOptions &sipStrings_QtWidgets[19466]
#define sipNameNr_resizeDocks 55492
#define sipName_resizeDocks &sipStrings_QtWidgets[55492]
#define sipNameNr_tabPosition 55504
#define sipName_tabPosition &sipStrings_QtWidgets[55504]
#define sipNameNr_setTabShape 55516
#define sipName_setTabShape &sipStrings_QtWidgets[55516]
#define sipNameNr_dockOptions 55528
#define sipName_dockOptions &sipStrings_QtWidgets[55528]
#define sipNameNr_DockOptions 13534
#define sipName_DockOptions &sipStrings_QtWidgets[13534]
#define sipNameNr_toolBarArea 55540
#define sipName_toolBarArea &sipStrings_QtWidgets[55540]
#define sipNameNr_QMainWindow 55552
#define sipName_QMainWindow &sipStrings_QtWidgets[55552]
#define sipNameNr_itemEntered 55564
#define sipName_itemEntered &sipStrings_QtWidgets[55564]
#define sipNameNr_itemClicked 55576
#define sipName_itemClicked &sipStrings_QtWidgets[55576]
#define sipNameNr_itemPressed 55588
#define sipName_itemPressed &sipStrings_QtWidgets[55588]
#define sipNameNr_currentItem 55600
#define sipName_currentItem &sipStrings_QtWidgets[55600]
#define sipNameNr_QListWidget 55612
#define sipName_QListWidget &sipStrings_QtWidgets[55612]
#define sipNameNr_isRowHidden 55624
#define sipName_isRowHidden &sipStrings_QtWidgets[55624]
#define sipNameNr_setGridSize 55636
#define sipName_setGridSize &sipStrings_QtWidgets[55636]
#define sipNameNr_setMovement 55648
#define sipName_setMovement &sipStrings_QtWidgets[55648]
#define sipNameNr_textMargins 55660
#define sipName_textMargins &sipStrings_QtWidgets[55660]
#define sipNameNr_textChanged 55672
#define sipName_textChanged &sipStrings_QtWidgets[55672]
#define sipNameNr_setEchoMode 55684
#define sipName_setEchoMode &sipStrings_QtWidgets[55684]
#define sipNameNr_displayText 55696
#define sipName_displayText &sipStrings_QtWidgets[55696]
#define sipNameNr_QWidgetItem 55708
#define sipName_QWidgetItem &sipStrings_QtWidgets[55708]
#define sipNameNr_QSpacerItem 55720
#define sipName_QSpacerItem &sipStrings_QtWidgets[55720]
#define sipNameNr_QLayoutItem 55732
#define sipName_QLayoutItem &sipStrings_QtWidgets[55732]
#define sipNameNr_setWordWrap 55744
#define sipName_setWordWrap &sipStrings_QtWidgets[55744]
#define sipNameNr_keySequence 55756
#define sipName_keySequence &sipStrings_QtWidgets[55756]
#define sipNameNr_drawDisplay 55768
#define sipName_drawDisplay &sipStrings_QtWidgets[55768]
#define sipNameNr_doubleValue 55780
#define sipName_doubleValue &sipStrings_QtWidgets[55780]
#define sipNameNr_setIntRange 55792
#define sipName_setIntRange &sipStrings_QtWidgets[55792]
#define sipNameNr_setIntValue 55804
#define sipName_setIntValue &sipStrings_QtWidgets[55804]
#define sipNameNr_DoubleInput 55816
#define sipName_DoubleInput &sipStrings_QtWidgets[55816]
#define sipNameNr_showSection 55828
#define sipName_showSection &sipStrings_QtWidgets[55828]
#define sipNameNr_hideSection 55840
#define sipName_hideSection &sipStrings_QtWidgets[55840]
#define sipNameNr_visualIndex 55852
#define sipName_visualIndex &sipStrings_QtWidgets[55852]
#define sipNameNr_moveSection 55864
#define sipName_moveSection &sipStrings_QtWidgets[55864]
#define sipNameNr_sectionSize 55876
#define sipName_sectionSize &sipStrings_QtWidgets[55876]
#define sipNameNr_Interactive 44438
#define sipName_Interactive &sipStrings_QtWidgets[44438]
#define sipNameNr_QHeaderView 55888
#define sipName_QHeaderView &sipStrings_QtWidgets[55888]
#define sipNameNr_QGridLayout 55900
#define sipName_QGridLayout &sipStrings_QtWidgets[55900]
#define sipNameNr_polishEvent 55912
#define sipName_polishEvent &sipStrings_QtWidgets[55912]
#define sipNameNr_setTabOrder 55924
#define sipName_setTabOrder &sipStrings_QtWidgets[55924]
#define sipNameNr_focusPolicy 55936
#define sipName_focusPolicy &sipStrings_QtWidgets[55936]
#define sipNameNr_windowTitle 55948
#define sipName_windowTitle &sipStrings_QtWidgets[55948]
#define sipNameNr_windowFlags 55960
#define sipName_windowFlags &sipStrings_QtWidgets[55960]
#define sipNameNr_updateScene 55972
#define sipName_updateScene &sipStrings_QtWidgets[55972]
#define sipNameNr_setDragMode 55984
#define sipName_setDragMode &sipStrings_QtWidgets[55984]
#define sipNameNr_axisChanged 55996
#define sipName_axisChanged &sipStrings_QtWidgets[55996]
#define sipNameNr_activePanel 56008
#define sipName_activePanel &sipStrings_QtWidgets[56008]
#define sipNameNr_stickyFocus 56020
#define sipName_stickyFocus &sipStrings_QtWidgets[56020]
#define sipNameNr_SceneLayers 9590
#define sipName_SceneLayers &sipStrings_QtWidgets[9590]
#define sipNameNr_itemSpacing 56032
#define sipName_itemSpacing &sipStrings_QtWidgets[56032]
#define sipNameNr_controlType 56044
#define sipName_controlType &sipStrings_QtWidgets[56044]
#define sipNameNr_widgetEvent 56056
#define sipName_widgetEvent &sipStrings_QtWidgets[56056]
#define sipNameNr_isActivated 56068
#define sipName_isActivated &sipStrings_QtWidgets[56068]
#define sipNameNr_linkHovered 56080
#define sipName_linkHovered &sipStrings_QtWidgets[56080]
#define sipNameNr_grabGesture 48454
#define sipName_grabGesture &sipStrings_QtWidgets[48454]
#define sipNameNr_stackBefore 56092
#define sipName_stackBefore &sipStrings_QtWidgets[56092]
#define sipNameNr_setRotation 56104
#define sipName_setRotation &sipStrings_QtWidgets[56104]
#define sipNameNr_ungrabMouse 56116
#define sipName_ungrabMouse &sipStrings_QtWidgets[56116]
#define sipNameNr_isVisibleTo 56128
#define sipName_isVisibleTo &sipStrings_QtWidgets[56128]
#define sipNameNr_mapFromItem 56140
#define sipName_mapFromItem &sipStrings_QtWidgets[56140]
#define sipNameNr_mapToParent 56152
#define sipName_mapToParent &sipStrings_QtWidgets[56152]
#define sipNameNr_focusReason 56164
#define sipName_focusReason &sipStrings_QtWidgets[56164]
#define sipNameNr_acceptDrops 56176
#define sipName_acceptDrops &sipStrings_QtWidgets[56176]
#define sipNameNr_setSelected 56188
#define sipName_setSelected &sipStrings_QtWidgets[56188]
#define sipNameNr_ItemIsPanel 56200
#define sipName_ItemIsPanel &sipStrings_QtWidgets[56200]
#define sipNameNr_opacityMask 56212
#define sipName_opacityMask &sipStrings_QtWidgets[56212]
#define sipNameNr_QualityHint 56224
#define sipName_QualityHint &sipStrings_QtWidgets[56224]
#define sipNameNr_setStrength 56236
#define sipName_setStrength &sipStrings_QtWidgets[56236]
#define sipNameNr_QTapGesture 56248
#define sipName_QTapGesture &sipStrings_QtWidgets[56248]
#define sipNameNr_NoDirection 56260
#define sipName_NoDirection &sipStrings_QtWidgets[56260]
#define sipNameNr_centerPoint 56272
#define sipName_centerPoint &sipStrings_QtWidgets[56272]
#define sipNameNr_changeFlags 56284
#define sipName_changeFlags &sipStrings_QtWidgets[56284]
#define sipNameNr_ChangeFlags 8831
#define sipName_ChangeFlags &sipStrings_QtWidgets[8831]
#define sipNameNr_QPanGesture 56296
#define sipName_QPanGesture &sipStrings_QtWidgets[56296]
#define sipNameNr_frameShadow 56308
#define sipName_frameShadow &sipStrings_QtWidgets[56308]
#define sipNameNr_Shadow_Mask 56320
#define sipName_Shadow_Mask &sipStrings_QtWidgets[56320]
#define sipNameNr_StyledPanel 56332
#define sipName_StyledPanel &sipStrings_QtWidgets[56332]
#define sipNameNr_WrapAllRows 56344
#define sipName_WrapAllRows &sipStrings_QtWidgets[56344]
#define sipNameNr_QFormLayout 56356
#define sipName_QFormLayout &sipStrings_QtWidgets[56356]
#define sipNameNr_QFontDialog 56368
#define sipName_QFontDialog &sipStrings_QtWidgets[56368]
#define sipNameNr_currentFont 56380
#define sipName_currentFont &sipStrings_QtWidgets[56380]
#define sipNameNr_FontFilters 10786
#define sipName_FontFilters &sipStrings_QtWidgets[10786]
#define sipNameNr_fontFilters 56392
#define sipName_fontFilters &sipStrings_QtWidgets[56392]
#define sipNameNr_QFocusFrame 56404
#define sipName_QFocusFrame &sipStrings_QtWidgets[56404]
#define sipNameNr_fileRenamed 56416
#define sipName_fileRenamed &sipStrings_QtWidgets[56416]
#define sipNameNr_setRootPath 56428
#define sipName_setRootPath &sipStrings_QtWidgets[56428]
#define sipNameNr_urlSelected 56440
#define sipName_urlSelected &sipStrings_QtWidgets[56440]
#define sipNameNr_sidebarUrls 56452
#define sipName_sidebarUrls &sipStrings_QtWidgets[56452]
#define sipNameNr_setFileMode 56464
#define sipName_setFileMode &sipStrings_QtWidgets[56464]
#define sipNameNr_setViewMode 56476
#define sipName_setViewMode &sipStrings_QtWidgets[56476]
#define sipNameNr_DialogLabel 13834
#define sipName_DialogLabel &sipStrings_QtWidgets[13834]
#define sipNameNr_QFileDialog 56488
#define sipName_QFileDialog &sipStrings_QtWidgets[56488]
#define sipNameNr_showMessage 56500
#define sipName_showMessage &sipStrings_QtWidgets[56500]
#define sipNameNr_setFloating 56512
#define sipName_setFloating &sipStrings_QtWidgets[56512]
#define sipNameNr_setFeatures 56524
#define sipName_setFeatures &sipStrings_QtWidgets[56524]
#define sipNameNr_QDockWidget 56536
#define sipName_QDockWidget &sipStrings_QtWidgets[56536]
#define sipNameNr_InvalidRole 56548
#define sipName_InvalidRole &sipStrings_QtWidgets[56548]
#define sipNameNr_GnomeLayout 56560
#define sipName_GnomeLayout &sipStrings_QtWidgets[56560]
#define sipNameNr_notchTarget 56572
#define sipName_notchTarget &sipStrings_QtWidgets[56572]
#define sipNameNr_screenCount 56584
#define sipName_screenCount &sipStrings_QtWidgets[56584]
#define sipNameNr_setDateTime 56596
#define sipName_setDateTime &sipStrings_QtWidgets[56596]
#define sipNameNr_dateChanged 56608
#define sipName_dateChanged &sipStrings_QtWidgets[56608]
#define sipNameNr_timeChanged 56620
#define sipName_timeChanged &sipStrings_QtWidgets[56620]
#define sipNameNr_sectionText 56632
#define sipName_sectionText &sipStrings_QtWidgets[56632]
#define sipNameNr_minimumTime 56644
#define sipName_minimumTime &sipStrings_QtWidgets[56644]
#define sipNameNr_YearSection 56656
#define sipName_YearSection &sipStrings_QtWidgets[56656]
#define sipNameNr_HourSection 56668
#define sipName_HourSection &sipStrings_QtWidgets[56668]
#define sipNameNr_MSecSection 56680
#define sipName_MSecSection &sipStrings_QtWidgets[56680]
#define sipNameNr_AmPmSection 56692
#define sipName_AmPmSection &sipStrings_QtWidgets[56692]
#define sipNameNr_pixelMetric 56704
#define sipName_pixelMetric &sipStrings_QtWidgets[56704]
#define sipNameNr_drawControl 56716
#define sipName_drawControl &sipStrings_QtWidgets[56716]
#define sipNameNr_QPushButton 56728
#define sipName_QPushButton &sipStrings_QtWidgets[56728]
#define sipNameNr_currentData 56740
#define sipName_currentData &sipStrings_QtWidgets[56740]
#define sipNameNr_highlighted 56752
#define sipName_highlighted &sipStrings_QtWidgets[56752]
#define sipNameNr_setEditText 56764
#define sipName_setEditText &sipStrings_QtWidgets[56764]
#define sipNameNr_setItemIcon 56776
#define sipName_setItemIcon &sipStrings_QtWidgets[56776]
#define sipNameNr_setItemText 56788
#define sipName_setItemText &sipStrings_QtWidgets[56788]
#define sipNameNr_insertItems 56800
#define sipName_insertItems &sipStrings_QtWidgets[56800]
#define sipNameNr_currentText 56812
#define sipName_currentText &sipStrings_QtWidgets[56812]
#define sipNameNr_modelColumn 56824
#define sipName_modelColumn &sipStrings_QtWidgets[56824]
#define sipNameNr_InsertAtTop 56836
#define sipName_InsertAtTop &sipStrings_QtWidgets[56836]
#define sipNameNr_setMaxCount 56848
#define sipName_setMaxCount &sipStrings_QtWidgets[56848]
#define sipNameNr_QColumnView 56860
#define sipName_QColumnView &sipStrings_QtWidgets[56860]
#define sipNameNr_customColor 56872
#define sipName_customColor &sipStrings_QtWidgets[56872]
#define sipNameNr_customCount 56884
#define sipName_customCount &sipStrings_QtWidgets[56884]
#define sipNameNr_setCalendar 56896
#define sipName_setCalendar &sipStrings_QtWidgets[56896]
#define sipNameNr_updateCells 56908
#define sipName_updateCells &sipStrings_QtWidgets[56908]
#define sipNameNr_maximumDate 56920
#define sipName_maximumDate &sipStrings_QtWidgets[56920]
#define sipNameNr_minimumDate 56932
#define sipName_minimumDate &sipStrings_QtWidgets[56932]
#define sipNameNr_QVBoxLayout 56944
#define sipName_QVBoxLayout &sipStrings_QtWidgets[56944]
#define sipNameNr_QHBoxLayout 56956
#define sipName_QHBoxLayout &sipStrings_QtWidgets[56956]
#define sipNameNr_BottomToTop 56968
#define sipName_BottomToTop &sipStrings_QtWidgets[56968]
#define sipNameNr_TopToBottom 56980
#define sipName_TopToBottom &sipStrings_QtWidgets[56980]
#define sipNameNr_globalStrut 56992
#define sipName_globalStrut &sipStrings_QtWidgets[56992]
#define sipNameNr_focusWidget 57004
#define sipName_focusWidget &sipStrings_QtWidgets[57004]
#define sipNameNr_CustomColor 45428
#define sipName_CustomColor &sipStrings_QtWidgets[45428]
#define sipNameNr_NormalColor 57016
#define sipName_NormalColor &sipStrings_QtWidgets[57016]
#define sipNameNr_isExclusive 57028
#define sipName_isExclusive &sipStrings_QtWidgets[57028]
#define sipNameNr_setMenuRole 57040
#define sipName_setMenuRole &sipStrings_QtWidgets[57040]
#define sipNameNr_AboutQtRole 57052
#define sipName_AboutQtRole &sipStrings_QtWidgets[57052]
#define sipNameNr_setDisabled 57064
#define sipName_setDisabled &sipStrings_QtWidgets[57064]
#define sipNameNr_ActionEvent 23430
#define sipName_ActionEvent &sipStrings_QtWidgets[23430]
#define sipNameNr_isSeparator 57076
#define sipName_isSeparator &sipStrings_QtWidgets[57076]
#define sipNameNr_setIconText 57088
#define sipName_setIconText &sipStrings_QtWidgets[57088]
#define sipNameNr_actionGroup 57100
#define sipName_actionGroup &sipStrings_QtWidgets[57100]
#define sipNameNr_stepEnabled 57112
#define sipName_stepEnabled &sipStrings_QtWidgets[57112]
#define sipNameNr_setLineEdit 57124
#define sipName_setLineEdit &sipStrings_QtWidgets[57124]
#define sipNameNr_setReadOnly 57136
#define sipName_setReadOnly &sipStrings_QtWidgets[57136]
#define sipNameNr_setWrapping 57148
#define sipName_setWrapping &sipStrings_QtWidgets[57148]
#define sipNameNr_StepEnabled 7840
#define sipName_StepEnabled &sipStrings_QtWidgets[7840]
#define sipNameNr_sliderMoved 57160
#define sipName_sliderMoved &sipStrings_QtWidgets[57160]
#define sipNameNr_hasTracking 57172
#define sipName_hasTracking &sipStrings_QtWidgets[57172]
#define sipNameNr_setTracking 57184
#define sipName_setTracking &sipStrings_QtWidgets[57184]
#define sipNameNr_setPageStep 57196
#define sipName_setPageStep &sipStrings_QtWidgets[57196]
#define sipNameNr_viewOptions 57208
#define sipName_viewOptions &sipStrings_QtWidgets[57208]
#define sipNameNr_scrollToTop 57220
#define sipName_scrollToTop &sipStrings_QtWidgets[57220]
#define sipNameNr_indexWidget 57232
#define sipName_indexWidget &sipStrings_QtWidgets[57232]
#define sipNameNr_NoSelection 57244
#define sipName_NoSelection &sipStrings_QtWidgets[57244]
#define sipNameNr_SelectItems 57256
#define sipName_SelectItems &sipStrings_QtWidgets[57256]
#define sipNameNr_EditTrigger 7060
#define sipName_EditTrigger &sipStrings_QtWidgets[7060]
#define sipNameNr_closeEditor 57268
#define sipName_closeEditor &sipStrings_QtWidgets[57268]
#define sipNameNr_editorEvent 57280
#define sipName_editorEvent &sipStrings_QtWidgets[57280]
#define sipNameNr_EndEditHint 4123
#define sipName_EndEditHint &sipStrings_QtWidgets[4123]
#define sipNameNr_changeEvent 57292
#define sipName_changeEvent &sipStrings_QtWidgets[57292]
#define sipNameNr_setIconSize 57304
#define sipName_setIconSize &sipStrings_QtWidgets[57304]
#define sipNameNr_setShortcut 57316
#define sipName_setShortcut &sipStrings_QtWidgets[57316]
#define sipNameNr_tabletEvent 57328
#define sipName_tabletEvent &sipStrings_QtWidgets[57328]
#define sipNameNr_unsetCursor 57340
#define sipName_unsetCursor &sipStrings_QtWidgets[57340]
#define sipNameNr_mapToGlobal 57352
#define sipName_mapToGlobal &sipStrings_QtWidgets[57352]
#define sipNameNr_setGeometry 57364
#define sipName_setGeometry &sipStrings_QtWidgets[57364]
#define sipNameNr_setBaseSize 57376
#define sipName_setBaseSize &sipStrings_QtWidgets[57376]
#define sipNameNr_maximumSize 57388
#define sipName_maximumSize &sipStrings_QtWidgets[57388]
#define sipNameNr_minimumSize 57400
#define sipName_minimumSize &sipStrings_QtWidgets[57400]
#define sipNameNr_windowState 57412
#define sipName_windowState &sipStrings_QtWidgets[57412]
#define sipNameNr_setDecimals 57424
#define sipName_setDecimals &sipStrings_QtWidgets[57424]
#define sipNameNr_setMarkdown 57436
#define sipName_setMarkdown &sipStrings_QtWidgets[57436]
#define sipNameNr_setModified 57448
#define sipName_setModified &sipStrings_QtWidgets[57448]
#define sipNameNr_toPlainText 57460
#define sipName_toPlainText &sipStrings_QtWidgets[57460]
#define sipNameNr_setDocument 57472
#define sipName_setDocument &sipStrings_QtWidgets[57472]
#define sipNameNr_setSizeHint 57484
#define sipName_setSizeHint &sipStrings_QtWidgets[57484]
#define sipNameNr_dragEnabled 57496
#define sipName_dragEnabled &sipStrings_QtWidgets[57496]
#define sipNameNr_setTristate 57508
#define sipName_setTristate &sipStrings_QtWidgets[57508]
#define sipNameNr_isCheckable 57520
#define sipName_isCheckable &sipStrings_QtWidgets[57520]
#define sipNameNr_setEditable 57532
#define sipName_setEditable &sipStrings_QtWidgets[57532]
#define sipNameNr_itemChanged 57544
#define sipName_itemChanged &sipStrings_QtWidgets[57544]
#define sipNameNr_setRowCount 57556
#define sipName_setRowCount &sipStrings_QtWidgets[57556]
#define sipNameNr_setFillRule 57568
#define sipName_setFillRule &sipStrings_QtWidgets[57568]
#define sipNameNr_RenderFlags 20805
#define sipName_RenderFlags &sipStrings_QtWidgets[20805]
#define sipNameNr_renderHints 57580
#define sipName_renderHints &sipStrings_QtWidgets[57580]
#define sipNameNr_setViewport 57592
#define sipName_setViewport &sipStrings_QtWidgets[57592]
#define sipNameNr_hasClipping 57604
#define sipName_hasClipping &sipStrings_QtWidgets[57604]
#define sipNameNr_setClipping 57616
#define sipName_setClipping &sipStrings_QtWidgets[57616]
#define sipNameNr_fontMetrics 57628
#define sipName_fontMetrics &sipStrings_QtWidgets[57628]
#define sipNameNr_resizeEvent 57640
#define sipName_resizeEvent &sipStrings_QtWidgets[57640]
#define sipNameNr_doneCurrent 57652
#define sipName_doneCurrent &sipStrings_QtWidgets[57652]
#define sipNameNr_makeCurrent 57664
#define sipName_makeCurrent &sipStrings_QtWidgets[57664]
#define sipNameNr_scaleFactor 57676
#define sipName_scaleFactor &sipStrings_QtWidgets[57676]
#define sipNameNr_paintEngine 57688
#define sipName_paintEngine &sipStrings_QtWidgets[57688]
#define sipNameNr_gestureType 57700
#define sipName_gestureType &sipStrings_QtWidgets[57700]
#define sipNameNr_setPriority 57712
#define sipName_setPriority &sipStrings_QtWidgets[57712]
#define sipNameNr_LowPriority 57724
#define sipName_LowPriority &sipStrings_QtWidgets[57724]
#define sipNameNr_setPosition 57736
#define sipName_setPosition &sipStrings_QtWidgets[57736]
#define sipNameNr_setAnimated 57748
#define sipName_setAnimated &sipStrings_QtWidgets[57748]
#define sipNameNr_customEvent 57760
#define sipName_customEvent &sipStrings_QtWidgets[57760]
#define sipNameNr_eventFilter 57772
#define sipName_eventFilter &sipStrings_QtWidgets[57772]
#define sipNameNr_QSizePolicy 57784
#define sipName_QSizePolicy &sipStrings_QtWidgets[57784]
#define sipNameNr_permissions 57796
#define sipName_permissions &sipStrings_QtWidgets[57796]
#define sipNameNr_maximumTime 57808
#define sipName_maximumTime &sipStrings_QtWidgets[57808]
#define sipNameNr_searchPaths 57820
#define sipName_searchPaths &sipStrings_QtWidgets[57820]
#define sipNameNr_nameFilters 57832
#define sipName_nameFilters &sipStrings_QtWidgets[57832]
#define sipNameNr_setTimeSpec 57844
#define sipName_setTimeSpec &sipStrings_QtWidgets[57844]
#define sipNameNr_setAccepted 57856
#define sipName_setAccepted &sipStrings_QtWidgets[57856]
#define sipNameNr_description 57868
#define sipName_description &sipStrings_QtWidgets[57868]
#define sipNameNr_sourceState 57880
#define sipName_sourceState &sipStrings_QtWidgets[57880]
#define sipNameNr_moveColumns 50526
#define sipName_moveColumns &sipStrings_QtWidgets[50526]
#define sipNameNr_rowsRemoved 57892
#define sipName_rowsRemoved &sipStrings_QtWidgets[57892]
#define sipNameNr_dataChanged 57904
#define sipName_dataChanged &sipStrings_QtWidgets[57904]
#define sipNameNr_setItemData 57916
#define sipName_setItemData &sipStrings_QtWidgets[57916]
#define sipNameNr_orientation 57928
#define sipName_orientation &sipStrings_QtWidgets[57928]
#define sipNameNr_hasChildren 57940
#define sipName_hasChildren &sipStrings_QtWidgets[57940]
#define sipNameNr_columnCount 57952
#define sipName_columnCount &sipStrings_QtWidgets[57952]
#define sipNameNr_RightToLeft 50442
#define sipName_RightToLeft &sipStrings_QtWidgets[50442]
#define sipNameNr_LeftToRight 50414
#define sipName_LeftToRight &sipStrings_QtWidgets[50414]
#define sipNameNr_isComplete 57964
#define sipName_isComplete &sipStrings_QtWidgets[57964]
#define sipNameNr_visitedIds 57975
#define sipName_visitedIds &sipStrings_QtWidgets[57975]
#define sipNameNr_sideWidget 57986
#define sipName_sideWidget &sipStrings_QtWidgets[57986]
#define sipNameNr_removePage 57997
#define sipName_removePage &sipStrings_QtWidgets[57997]
#define sipNameNr_setStartId 58008
#define sipName_setStartId &sipStrings_QtWidgets[58008]
#define sipNameNr_LogoPixmap 58019
#define sipName_LogoPixmap &sipStrings_QtWidgets[58019]
#define sipNameNr_HelpButton 8223
#define sipName_HelpButton &sipStrings_QtWidgets[8223]
#define sipNameNr_NextButton 58030
#define sipName_NextButton &sipStrings_QtWidgets[58030]
#define sipNameNr_IgnoreMask 58041
#define sipName_IgnoreMask &sipStrings_QtWidgets[58041]
#define sipNameNr_underMouse 58052
#define sipName_underMouse &sipStrings_QtWidgets[58052]
#define sipNameNr_stackUnder 58063
#define sipName_stackUnder &sipStrings_QtWidgets[58063]
#define sipNameNr_windowRole 58074
#define sipName_windowRole &sipStrings_QtWidgets[58074]
#define sipNameNr_QWhatsThis 58085
#define sipName_QWhatsThis &sipStrings_QtWidgets[58085]
#define sipNameNr_emptyLabel 58096
#define sipName_emptyLabel &sipStrings_QtWidgets[58096]
#define sipNameNr_resetClean 58107
#define sipName_resetClean &sipStrings_QtWidgets[58107]
#define sipNameNr_beginMacro 58118
#define sipName_beginMacro &sipStrings_QtWidgets[58118]
#define sipNameNr_cleanIndex 58129
#define sipName_cleanIndex &sipStrings_QtWidgets[58129]
#define sipNameNr_QUndoStack 58140
#define sipName_QUndoStack &sipStrings_QtWidgets[58140]
#define sipNameNr_isObsolete 58151
#define sipName_isObsolete &sipStrings_QtWidgets[58151]
#define sipNameNr_actionText 58162
#define sipName_actionText &sipStrings_QtWidgets[58162]
#define sipNameNr_QUndoGroup 58173
#define sipName_QUndoGroup &sipStrings_QtWidgets[58173]
#define sipNameNr_NotChecked 58184
#define sipName_NotChecked &sipStrings_QtWidgets[58184]
#define sipNameNr_NoChildren 58195
#define sipName_NoChildren &sipStrings_QtWidgets[58195]
#define sipNameNr_Selectable 38076
#define sipName_Selectable &sipStrings_QtWidgets[38076]
#define sipNameNr_Unselected 58206
#define sipName_Unselected &sipStrings_QtWidgets[58206]
#define sipNameNr_expandItem 58217
#define sipName_expandItem &sipStrings_QtWidgets[58217]
#define sipNameNr_headerItem 58228
#define sipName_headerItem &sipStrings_QtWidgets[58228]
#define sipNameNr_isDisabled 58239
#define sipName_isDisabled &sipStrings_QtWidgets[58239]
#define sipNameNr_childCount 58250
#define sipName_childCount &sipStrings_QtWidgets[58250]
#define sipNameNr_treeWidget 58261
#define sipName_treeWidget &sipStrings_QtWidgets[58261]
#define sipNameNr_indexBelow 58272
#define sipName_indexBelow &sipStrings_QtWidgets[58272]
#define sipNameNr_indexAbove 58283
#define sipName_indexAbove &sipStrings_QtWidgets[58283]
#define sipNameNr_isExpanded 58294
#define sipName_isExpanded &sipStrings_QtWidgets[58294]
#define sipNameNr_historyUrl 58305
#define sipName_historyUrl &sipStrings_QtWidgets[58305]
#define sipNameNr_Triangular 58316
#define sipName_Triangular &sipStrings_QtWidgets[58316]
#define sipNameNr_QTabWidget 58327
#define sipName_QTabWidget &sipStrings_QtWidgets[58327]
#define sipNameNr_cellWidget 58338
#define sipName_cellWidget &sipStrings_QtWidgets[58338]
#define sipNameNr_leftColumn 58349
#define sipName_leftColumn &sipStrings_QtWidgets[58349]
#define sipNameNr_clearSpans 58360
#define sipName_clearSpans &sipStrings_QtWidgets[58360]
#define sipNameNr_rowResized 58371
#define sipName_rowResized &sipStrings_QtWidgets[58371]
#define sipNameNr_showColumn 58382
#define sipName_showColumn &sipStrings_QtWidgets[58382]
#define sipNameNr_hideColumn 58393
#define sipName_hideColumn &sipStrings_QtWidgets[58393]
#define sipNameNr_QTableView 58404
#define sipName_QTableView &sipStrings_QtWidgets[58404]
#define sipNameNr_setMovable 58415
#define sipName_setMovable &sipStrings_QtWidgets[58415]
#define sipNameNr_tabRemoved 58426
#define sipName_tabRemoved &sipStrings_QtWidgets[58426]
#define sipNameNr_setTabData 58437
#define sipName_setTabData &sipStrings_QtWidgets[58437]
#define sipNameNr_tabToolTip 58448
#define sipName_tabToolTip &sipStrings_QtWidgets[58448]
#define sipNameNr_setTabIcon 58459
#define sipName_setTabIcon &sipStrings_QtWidgets[58459]
#define sipNameNr_setTabText 58470
#define sipName_setTabText &sipStrings_QtWidgets[58470]
#define sipNameNr_SH_Variant 58481
#define sipName_SH_Variant &sipStrings_QtWidgets[58481]
#define sipNameNr_SH_Default 58492
#define sipName_SH_Default &sipStrings_QtWidgets[58492]
#define sipNameNr_PopupDelay 11236
#define sipName_PopupDelay &sipStrings_QtWidgets[11236]
#define sipNameNr_HasDisplay 58503
#define sipName_HasDisplay &sipStrings_QtWidgets[58503]
#define sipNameNr_TabFeature 8975
#define sipName_TabFeature &sipStrings_QtWidgets[8975]
#define sipNameNr_OnlyOneTab 58514
#define sipName_OnlyOneTab &sipStrings_QtWidgets[58514]
#define sipNameNr_tabBarRect 58525
#define sipName_tabBarRect &sipStrings_QtWidgets[58525]
#define sipNameNr_tabBarSize 58536
#define sipName_tabBarSize &sipStrings_QtWidgets[58536]
#define sipNameNr_SO_SpinBox 58547
#define sipName_SO_SpinBox &sipStrings_QtWidgets[58547]
#define sipNameNr_SO_Complex 58558
#define sipName_SO_Complex &sipStrings_QtWidgets[58558]
#define sipNameNr_SO_ToolBar 58569
#define sipName_SO_ToolBar &sipStrings_QtWidgets[58569]
#define sipNameNr_SO_ToolBox 58580
#define sipName_SO_ToolBox &sipStrings_QtWidgets[58580]
#define sipNameNr_SO_Default 58591
#define sipName_SO_Default &sipStrings_QtWidgets[58591]
#define sipNameNr_OptionType 308
#define sipName_OptionType &sipStrings_QtWidgets[308]
#define sipNameNr_upsideDown 58602
#define sipName_upsideDown &sipStrings_QtWidgets[58602]
#define sipNameNr_SP_ArrowUp 58613
#define sipName_SP_ArrowUp &sipStrings_QtWidgets[58613]
#define sipNameNr_SP_DirIcon 58624
#define sipName_SP_DirIcon &sipStrings_QtWidgets[58624]
#define sipNameNr_CT_SpinBox 58635
#define sipName_CT_SpinBox &sipStrings_QtWidgets[58635]
#define sipNameNr_CT_MenuBar 58646
#define sipName_CT_MenuBar &sipStrings_QtWidgets[58646]
#define sipNameNr_SubControl 27701
#define sipName_SubControl &sipStrings_QtWidgets[27701]
#define sipNameNr_CC_SpinBox 58657
#define sipName_CC_SpinBox &sipStrings_QtWidgets[58657]
#define sipNameNr_SubElement 27815
#define sipName_SubElement &sipStrings_QtWidgets[27815]
#define sipNameNr_CE_ToolBar 58668
#define sipName_CE_ToolBar &sipStrings_QtWidgets[58668]
#define sipNameNr_State_Mini 58679
#define sipName_State_Mini &sipStrings_QtWidgets[58679]
#define sipNameNr_State_Item 58690
#define sipName_State_Item &sipStrings_QtWidgets[58690]
#define sipNameNr_State_Open 58701
#define sipName_State_Open &sipStrings_QtWidgets[58701]
#define sipNameNr_State_None 58712
#define sipName_State_None &sipStrings_QtWidgets[58712]
#define sipNameNr_hideOrShow 58723
#define sipName_hideOrShow &sipStrings_QtWidgets[58723]
#define sipNameNr_QStatusBar 58734
#define sipName_QStatusBar &sipStrings_QtWidgets[58734]
#define sipNameNr_TicksRight 58745
#define sipName_TicksRight &sipStrings_QtWidgets[58745]
#define sipNameNr_TicksBelow 58756
#define sipName_TicksBelow &sipStrings_QtWidgets[58756]
#define sipNameNr_TicksAbove 58767
#define sipName_TicksAbove &sipStrings_QtWidgets[58767]
#define sipNameNr_ToolButton 16403
#define sipName_ToolButton &sipStrings_QtWidgets[16403]
#define sipNameNr_PushButton 47055
#define sipName_PushButton &sipStrings_QtWidgets[47055]
#define sipNameNr_IgnoreFlag 58778
#define sipName_IgnoreFlag &sipStrings_QtWidgets[58778]
#define sipNameNr_ShrinkFlag 58789
#define sipName_ShrinkFlag &sipStrings_QtWidgets[58789]
#define sipNameNr_ExpandFlag 58800
#define sipName_ExpandFlag &sipStrings_QtWidgets[58800]
#define sipNameNr_PolicyFlag 15092
#define sipName_PolicyFlag &sipStrings_QtWidgets[15092]
#define sipNameNr_setContext 58811
#define sipName_setContext &sipStrings_QtWidgets[58811]
#define sipNameNr_FrameRates 5620
#define sipName_FrameRates &sipStrings_QtWidgets[5620]
#define sipNameNr_InputPress 58822
#define sipName_InputPress &sipStrings_QtWidgets[58822]
#define sipNameNr_QScrollBar 58833
#define sipName_QScrollBar &sipStrings_QtWidgets[58833]
#define sipNameNr_takeWidget 58844
#define sipName_takeWidget &sipStrings_QtWidgets[58844]
#define sipNameNr_appendHtml 58855
#define sipName_appendHtml &sipStrings_QtWidgets[58855]
#define sipNameNr_iconPixmap 58866
#define sipName_iconPixmap &sipStrings_QtWidgets[58866]
#define sipNameNr_ButtonMask 58877
#define sipName_ButtonMask &sipStrings_QtWidgets[58877]
#define sipNameNr_LastButton 58888
#define sipName_LastButton &sipStrings_QtWidgets[58888]
#define sipNameNr_addSection 58899
#define sipName_addSection &sipStrings_QtWidgets[58899]
#define sipNameNr_enterEvent 58910
#define sipName_enterEvent &sipStrings_QtWidgets[58910]
#define sipNameNr_menuAction 58921
#define sipName_menuAction &sipStrings_QtWidgets[58921]
#define sipNameNr_insertMenu 58932
#define sipName_insertMenu &sipStrings_QtWidgets[58932]
#define sipNameNr_leaveEvent 58943
#define sipName_leaveEvent &sipStrings_QtWidgets[58943]
#define sipNameNr_showShaded 58954
#define sipName_showShaded &sipStrings_QtWidgets[58954]
#define sipNameNr_systemMenu 58965
#define sipName_systemMenu &sipStrings_QtWidgets[58965]
#define sipNameNr_TabbedView 58976
#define sipName_TabbedView &sipStrings_QtWidgets[58976]
#define sipNameNr_AreaOption 22234
#define sipName_AreaOption &sipStrings_QtWidgets[22234]
#define sipNameNr_DockOption 15236
#define sipName_DockOption &sipStrings_QtWidgets[15236]
#define sipNameNr_menuWidget 58987
#define sipName_menuWidget &sipStrings_QtWidgets[58987]
#define sipNameNr_addToolBar 58998
#define sipName_addToolBar &sipStrings_QtWidgets[58998]
#define sipNameNr_itemWidget 59009
#define sipName_itemWidget &sipStrings_QtWidgets[59009]
#define sipNameNr_listWidget 59020
#define sipName_listWidget &sipStrings_QtWidgets[59020]
#define sipNameNr_layoutMode 59031
#define sipName_layoutMode &sipStrings_QtWidgets[59031]
#define sipNameNr_resizeMode 59042
#define sipName_resizeMode &sipStrings_QtWidgets[59042]
#define sipNameNr_isWrapping 59053
#define sipName_isWrapping &sipStrings_QtWidgets[59053]
#define sipNameNr_SinglePass 59064
#define sipName_SinglePass &sipStrings_QtWidgets[59064]
#define sipNameNr_LayoutMode 19511
#define sipName_LayoutMode &sipStrings_QtWidgets[19511]
#define sipNameNr_cursorRect 59075
#define sipName_cursorRect &sipStrings_QtWidgets[59075]
#define sipNameNr_textEdited 59086
#define sipName_textEdited &sipStrings_QtWidgets[59086]
#define sipNameNr_setBinMode 59097
#define sipName_setBinMode &sipStrings_QtWidgets[59097]
#define sipNameNr_setOctMode 59108
#define sipName_setOctMode &sipStrings_QtWidgets[59108]
#define sipNameNr_setDecMode 59119
#define sipName_setDecMode &sipStrings_QtWidgets[59119]
#define sipNameNr_setHexMode 59130
#define sipName_setHexMode &sipStrings_QtWidgets[59130]
#define sipNameNr_digitCount 59141
#define sipName_digitCount &sipStrings_QtWidgets[59141]
#define sipNameNr_QLCDNumber 59152
#define sipName_QLCDNumber &sipStrings_QtWidgets[59152]
#define sipNameNr_changeSize 59163
#define sipName_changeSize &sipStrings_QtWidgets[59163]
#define sipNameNr_setMenuBar 59174
#define sipName_setMenuBar &sipStrings_QtWidgets[59174]
#define sipNameNr_doubleStep 59185
#define sipName_doubleStep &sipStrings_QtWidgets[59185]
#define sipNameNr_setIntStep 59196
#define sipName_setIntStep &sipStrings_QtWidgets[59196]
#define sipNameNr_intMaximum 59207
#define sipName_intMaximum &sipStrings_QtWidgets[59207]
#define sipNameNr_intMinimum 59218
#define sipName_intMinimum &sipStrings_QtWidgets[59218]
#define sipNameNr_ResizeMode 15452
#define sipName_ResizeMode &sipStrings_QtWidgets[15452]
#define sipNameNr_rowStretch 59229
#define sipName_rowStretch &sipStrings_QtWidgets[59229]
#define sipNameNr_addActions 59240
#define sipName_addActions &sipStrings_QtWidgets[59240]
#define sipNameNr_windowType 59251
#define sipName_windowType &sipStrings_QtWidgets[59251]
#define sipNameNr_SceneLayer 10571
#define sipName_SceneLayer &sipStrings_QtWidgets[10571]
#define sipNameNr_textCursor 59262
#define sipName_textCursor &sipStrings_QtWidgets[59262]
#define sipNameNr_addToGroup 59273
#define sipName_addToGroup &sipStrings_QtWidgets[59273]
#define sipNameNr_setPolygon 59284
#define sipName_setPolygon &sipStrings_QtWidgets[59284]
#define sipNameNr_focusProxy 59295
#define sipName_focusProxy &sipStrings_QtWidgets[59295]
#define sipNameNr_SceneModal 59306
#define sipName_SceneModal &sipStrings_QtWidgets[59306]
#define sipNameNr_PanelModal 59317
#define sipName_PanelModal &sipStrings_QtWidgets[59317]
#define sipNameNr_childItems 59328
#define sipName_childItems &sipStrings_QtWidgets[59328]
#define sipNameNr_isObscured 59339
#define sipName_isObscured &sipStrings_QtWidgets[59339]
#define sipNameNr_sceneEvent 59350
#define sipName_sceneEvent &sipStrings_QtWidgets[59350]
#define sipNameNr_itemChange 59361
#define sipName_itemChange &sipStrings_QtWidgets[59361]
#define sipNameNr_mapToScene 59372
#define sipName_mapToScene &sipStrings_QtWidgets[59372]
#define sipNameNr_opaqueArea 59383
#define sipName_opaqueArea &sipStrings_QtWidgets[59383]
#define sipNameNr_clearFocus 59394
#define sipName_clearFocus &sipStrings_QtWidgets[59394]
#define sipNameNr_parentItem 59405
#define sipName_parentItem &sipStrings_QtWidgets[59405]
#define sipNameNr_rowSpacing 59416
#define sipName_rowSpacing &sipStrings_QtWidgets[59416]
#define sipNameNr_setYOffset 59427
#define sipName_setYOffset &sipStrings_QtWidgets[59427]
#define sipNameNr_setXOffset 59438
#define sipName_setXOffset &sipStrings_QtWidgets[59438]
#define sipNameNr_blurRadius 59449
#define sipName_blurRadius &sipStrings_QtWidgets[59449]
#define sipNameNr_drawSource 59460
#define sipName_drawSource &sipStrings_QtWidgets[59460]
#define sipNameNr_constraint 59471
#define sipName_constraint &sipStrings_QtWidgets[59471]
#define sipNameNr_addAnchors 59482
#define sipName_addAnchors &sipStrings_QtWidgets[59482]
#define sipNameNr_sizePolicy 59493
#define sipName_sizePolicy &sipStrings_QtWidgets[59493]
#define sipNameNr_ResultFlag 6844
#define sipName_ResultFlag &sipStrings_QtWidgets[6844]
#define sipNameNr_setTimeout 59504
#define sipName_setTimeout &sipStrings_QtWidgets[59504]
#define sipNameNr_swipeAngle 59515
#define sipName_swipeAngle &sipStrings_QtWidgets[59515]
#define sipNameNr_ChangeFlag 9703
#define sipName_ChangeFlag &sipStrings_QtWidgets[9703]
#define sipNameNr_lastOffset 59526
#define sipName_lastOffset &sipStrings_QtWidgets[59526]
#define sipNameNr_CancelNone 59537
#define sipName_CancelNone &sipStrings_QtWidgets[59537]
#define sipNameNr_hasHotSpot 59548
#define sipName_hasHotSpot &sipStrings_QtWidgets[59548]
#define sipNameNr_frameShape 59559
#define sipName_frameShape &sipStrings_QtWidgets[59559]
#define sipNameNr_frameWidth 59570
#define sipName_frameWidth &sipStrings_QtWidgets[59570]
#define sipNameNr_frameStyle 59581
#define sipName_frameStyle &sipStrings_QtWidgets[59581]
#define sipNameNr_Shape_Mask 59592
#define sipName_Shape_Mask &sipStrings_QtWidgets[59592]
#define sipNameNr_FontFilter 12250
#define sipName_FontFilter &sipStrings_QtWidgets[12250]
#define sipNameNr_myComputer 59603
#define sipName_myComputer &sipStrings_QtWidgets[59603]
#define sipNameNr_proxyModel 59614
#define sipName_proxyModel &sipStrings_QtWidgets[59614]
#define sipNameNr_setHistory 59625
#define sipName_setHistory &sipStrings_QtWidgets[59625]
#define sipNameNr_acceptMode 59636
#define sipName_acceptMode &sipStrings_QtWidgets[59636]
#define sipNameNr_selectFile 59647
#define sipName_selectFile &sipStrings_QtWidgets[59647]
#define sipNameNr_AcceptSave 59658
#define sipName_AcceptSave &sipStrings_QtWidgets[59658]
#define sipNameNr_AcceptOpen 59669
#define sipName_AcceptOpen &sipStrings_QtWidgets[59669]
#define sipNameNr_AcceptMode 15860
#define sipName_AcceptMode &sipStrings_QtWidgets[15860]
#define sipNameNr_isFloating 59680
#define sipName_isFloating &sipStrings_QtWidgets[59680]
#define sipNameNr_buttonRole 59691
#define sipName_buttonRole &sipStrings_QtWidgets[59691]
#define sipNameNr_ActionRole 59702
#define sipName_ActionRole &sipStrings_QtWidgets[59702]
#define sipNameNr_RejectRole 59713
#define sipName_RejectRole &sipStrings_QtWidgets[59713]
#define sipNameNr_AcceptRole 59724
#define sipName_AcceptRole &sipStrings_QtWidgets[59724]
#define sipNameNr_ButtonRole 8861
#define sipName_ButtonRole &sipStrings_QtWidgets[8861]
#define sipNameNr_DialogCode 26286
#define sipName_DialogCode &sipStrings_QtWidgets[26286]
#define sipNameNr_DaySection 59735
#define sipName_DaySection &sipStrings_QtWidgets[59735]
#define sipNameNr_toPrevious 59746
#define sipName_toPrevious &sipStrings_QtWidgets[59746]
#define sipNameNr_addMapping 59757
#define sipName_addMapping &sipStrings_QtWidgets[59757]
#define sipNameNr_AutoSubmit 59768
#define sipName_AutoSubmit &sipStrings_QtWidgets[59768]
#define sipNameNr_filterMode 59779
#define sipName_filterMode &sipStrings_QtWidgets[59779]
#define sipNameNr_wrapAround 59790
#define sipName_wrapAround &sipStrings_QtWidgets[59790]
#define sipNameNr_currentRow 59801
#define sipName_currentRow &sipStrings_QtWidgets[59801]
#define sipNameNr_QCompleter 59812
#define sipName_QCompleter &sipStrings_QtWidgets[59812]
#define sipNameNr_returnData 59823
#define sipName_returnData &sipStrings_QtWidgets[59823]
#define sipNameNr_updateCell 59834
#define sipName_updateCell &sipStrings_QtWidgets[59834]
#define sipNameNr_monthShown 59845
#define sipName_monthShown &sipStrings_QtWidgets[59845]
#define sipNameNr_idReleased 59856
#define sipName_idReleased &sipStrings_QtWidgets[59856]
#define sipNameNr_insertItem 59867
#define sipName_insertItem &sipStrings_QtWidgets[59867]
#define sipNameNr_spacerItem 59878
#define sipName_spacerItem &sipStrings_QtWidgets[59878]
#define sipNameNr_setSpacing 52726
#define sipName_setSpacing &sipStrings_QtWidgets[52726]
#define sipNameNr_addStretch 59889
#define sipName_addStretch &sipStrings_QtWidgets[59889]
#define sipNameNr_addSpacing 59900
#define sipName_addSpacing &sipStrings_QtWidgets[59900]
#define sipNameNr_QBoxLayout 59911
#define sipName_QBoxLayout &sipStrings_QtWidgets[59911]
#define sipNameNr_styleSheet 59922
#define sipName_styleSheet &sipStrings_QtWidgets[59922]
#define sipNameNr_allWidgets 59933
#define sipName_allWidgets &sipStrings_QtWidgets[59933]
#define sipNameNr_closeEvent 59944
#define sipName_closeEvent &sipStrings_QtWidgets[59944]
#define sipNameNr_repeatTime 59955
#define sipName_repeatTime &sipStrings_QtWidgets[59955]
#define sipNameNr_SliderMove 59966
#define sipName_SliderMove &sipStrings_QtWidgets[59966]
#define sipNameNr_singleStep 59977
#define sipName_singleStep &sipStrings_QtWidgets[59977]
#define sipNameNr_setMaximum 59988
#define sipName_setMaximum &sipStrings_QtWidgets[59988]
#define sipNameNr_setMinimum 59999
#define sipName_setMinimum &sipStrings_QtWidgets[59999]
#define sipNameNr_OnViewport 60010
#define sipName_OnViewport &sipStrings_QtWidgets[60010]
#define sipNameNr_moveCursor 60021
#define sipName_moveCursor &sipStrings_QtWidgets[60021]
#define sipNameNr_MovePageUp 60032
#define sipName_MovePageUp &sipStrings_QtWidgets[60032]
#define sipNameNr_visualRect 60043
#define sipName_visualRect &sipStrings_QtWidgets[60043]
#define sipNameNr_SelectRows 60054
#define sipName_SelectRows &sipStrings_QtWidgets[60054]
#define sipNameNr_ScrollMode 7961
#define sipName_ScrollMode &sipStrings_QtWidgets[7961]
#define sipNameNr_ScrollHint 7991
#define sipName_ScrollHint &sipStrings_QtWidgets[7991]
#define sipNameNr_NoDragDrop 60065
#define sipName_NoDragDrop &sipStrings_QtWidgets[60065]
#define sipNameNr_commitData 60076
#define sipName_commitData &sipStrings_QtWidgets[60076]
#define sipNameNr_setChecked 60087
#define sipName_setChecked &sipStrings_QtWidgets[60087]
#define sipNameNr_autoRepeat 60098
#define sipName_autoRepeat &sipStrings_QtWidgets[60098]
#define sipNameNr_wheelEvent 60109
#define sipName_wheelEvent &sipStrings_QtWidgets[60109]
#define sipNameNr_showNormal 60120
#define sipName_showNormal &sipStrings_QtWidgets[60120]
#define sipNameNr_columnSpan 60131
#define sipName_columnSpan &sipStrings_QtWidgets[60131]
#define sipNameNr_removeItem 60142
#define sipName_removeItem &sipStrings_QtWidgets[60142]
#define sipNameNr_fontItalic 60153
#define sipName_fontItalic &sipStrings_QtWidgets[60153]
#define sipNameNr_fontWeight 60164
#define sipName_fontWeight &sipStrings_QtWidgets[60164]
#define sipNameNr_fontFamily 60175
#define sipName_fontFamily &sipStrings_QtWidgets[60175]
#define sipNameNr_toMarkdown 60186
#define sipName_toMarkdown &sipStrings_QtWidgets[60186]
#define sipNameNr_blockCount 60197
#define sipName_blockCount &sipStrings_QtWidgets[60197]
#define sipNameNr_adjustSize 60208
#define sipName_adjustSize &sipStrings_QtWidgets[60208]
#define sipNameNr_isModified 60219
#define sipName_isModified &sipStrings_QtWidgets[60219]
#define sipNameNr_insertHtml 60230
#define sipName_insertHtml &sipStrings_QtWidgets[60230]
#define sipNameNr_setOptions 60241
#define sipName_setOptions &sipStrings_QtWidgets[60241]
#define sipNameNr_testOption 60252
#define sipName_testOption &sipStrings_QtWidgets[60252]
#define sipNameNr_textFormat 60263
#define sipName_textFormat &sipStrings_QtWidgets[60263]
#define sipNameNr_setToolTip 60274
#define sipName_setToolTip &sipStrings_QtWidgets[60274]
#define sipNameNr_isTristate 60285
#define sipName_isTristate &sipStrings_QtWidgets[60285]
#define sipNameNr_isEditable 60296
#define sipName_isEditable &sipStrings_QtWidgets[60296]
#define sipNameNr_checkState 60307
#define sipName_checkState &sipStrings_QtWidgets[60307]
#define sipNameNr_setPicture 60318
#define sipName_setPicture &sipStrings_QtWidgets[60318]
#define sipNameNr_buttonText 60329
#define sipName_buttonText &sipStrings_QtWidgets[60329]
#define sipNameNr_foreground 60340
#define sipName_foreground &sipStrings_QtWidgets[60340]
#define sipNameNr_addPolygon 60351
#define sipName_addPolygon &sipStrings_QtWidgets[60351]
#define sipNameNr_addEllipse 60362
#define sipName_addEllipse &sipStrings_QtWidgets[60362]
#define sipNameNr_RenderFlag 23846
#define sipName_RenderFlag &sipStrings_QtWidgets[23846]
#define sipNameNr_background 60373
#define sipName_background &sipStrings_QtWidgets[60373]
#define sipNameNr_paintEvent 60384
#define sipName_paintEvent &sipStrings_QtWidgets[60384]
#define sipNameNr_setOpacity 60395
#define sipName_setOpacity &sipStrings_QtWidgets[60395]
#define sipNameNr_sourceType 60406
#define sipName_sourceType &sipStrings_QtWidgets[60406]
#define sipNameNr_setVisible 60417
#define sipName_setVisible &sipStrings_QtWidgets[60417]
#define sipNameNr_windowIcon 60428
#define sipName_windowIcon &sipStrings_QtWidgets[60428]
#define sipNameNr_setPalette 60439
#define sipName_setPalette &sipStrings_QtWidgets[60439]
#define sipNameNr_topLevelAt 60450
#define sipName_topLevelAt &sipStrings_QtWidgets[60450]
#define sipNameNr_initialize 60461
#define sipName_initialize &sipStrings_QtWidgets[60461]
#define sipNameNr_setStretch 60472
#define sipName_setStretch &sipStrings_QtWidgets[60472]
#define sipNameNr_dropAction 60483
#define sipName_dropAction &sipStrings_QtWidgets[60483]
#define sipNameNr_setHotSpot 52765
#define sipName_setHotSpot &sipStrings_QtWidgets[52765]
#define sipNameNr_startAngle 60494
#define sipName_startAngle &sipStrings_QtWidgets[60494]
#define sipNameNr_isReadOnly 60505
#define sipName_isReadOnly &sipStrings_QtWidgets[60505]
#define sipNameNr_isAnimated 60516
#define sipName_isAnimated &sipStrings_QtWidgets[60516]
#define sipNameNr_sortColumn 60527
#define sipName_sortColumn &sipStrings_QtWidgets[60527]
#define sipNameNr_transposed 60538
#define sipName_transposed &sipStrings_QtWidgets[60538]
#define sipNameNr_childEvent 60549
#define sipName_childEvent &sipStrings_QtWidgets[60549]
#define sipNameNr_timerEvent 60560
#define sipName_timerEvent &sipStrings_QtWidgets[60560]
#define sipNameNr_setEnabled 60571
#define sipName_setEnabled &sipStrings_QtWidgets[60571]
#define sipNameNr_setDefault 60582
#define sipName_setDefault &sipStrings_QtWidgets[60582]
#define sipNameNr_isSelected 60593
#define sipName_isSelected &sipStrings_QtWidgets[60593]
#define sipNameNr_invalidate 60604
#define sipName_invalidate &sipStrings_QtWidgets[60604]
#define sipNameNr_setSorting 60615
#define sipName_setSorting &sipStrings_QtWidgets[60615]
#define sipNameNr_isAccepted 60626
#define sipName_isAccepted &sipStrings_QtWidgets[60626]
#define sipNameNr___rshift__ 60637
#define sipName___rshift__ &sipStrings_QtWidgets[60637]
#define sipNameNr___lshift__ 60648
#define sipName___lshift__ &sipStrings_QtWidgets[60648]
#define sipNameNr_removeRows 60659
#define sipName_removeRows &sipStrings_QtWidgets[60659]
#define sipNameNr_insertRows 60670
#define sipName_insertRows &sipStrings_QtWidgets[60670]
#define sipNameNr_headerData 60681
#define sipName_headerData &sipStrings_QtWidgets[60681]
#define sipNameNr_BackButton 60692
#define sipName_BackButton &sipStrings_QtWidgets[60692]
#define sipNameNr___invert__ 60703
#define sipName___invert__ &sipStrings_QtWidgets[60703]
#define sipNameNr_pageAdded 60714
#define sipName_pageAdded &sipStrings_QtWidgets[60714]
#define sipNameNr_currentId 60724
#define sipName_currentId &sipStrings_QtWidgets[60724]
#define sipNameNr_AeroStyle 60734
#define sipName_AeroStyle &sipStrings_QtWidgets[60734]
#define sipNameNr_clearMask 60744
#define sipName_clearMask &sipStrings_QtWidgets[60744]
#define sipNameNr_frameSize 60754
#define sipName_frameSize &sipStrings_QtWidgets[60754]
#define sipNameNr_cleanIcon 60764
#define sipName_cleanIcon &sipStrings_QtWidgets[60764]
#define sipNameNr_QUndoView 60774
#define sipName_QUndoView &sipStrings_QtWidgets[60774]
#define sipNameNr_undoLimit 60784
#define sipName_undoLimit &sipStrings_QtWidgets[60784]
#define sipNameNr_mergeWith 60794
#define sipName_mergeWith &sipStrings_QtWidgets[60794]
#define sipNameNr_NotHidden 60804
#define sipName_NotHidden &sipStrings_QtWidgets[60804]
#define sipNameNr_itemBelow 60814
#define sipName_itemBelow &sipStrings_QtWidgets[60814]
#define sipNameNr_itemAbove 60824
#define sipName_itemAbove &sipStrings_QtWidgets[60824]
#define sipNameNr_expandAll 60834
#define sipName_expandAll &sipStrings_QtWidgets[60834]
#define sipNameNr_collapsed 60844
#define sipName_collapsed &sipStrings_QtWidgets[60844]
#define sipNameNr_setHeader 60854
#define sipName_setHeader &sipStrings_QtWidgets[60854]
#define sipNameNr_QTreeView 60864
#define sipName_QTreeView &sipStrings_QtWidgets[60864]
#define sipNameNr_autoRaise 60874
#define sipName_autoRaise &sipStrings_QtWidgets[60874]
#define sipNameNr_popupMode 60884
#define sipName_popupMode &sipStrings_QtWidgets[60884]
#define sipNameNr_openLinks 60894
#define sipName_openLinks &sipStrings_QtWidgets[60894]
#define sipNameNr_setSource 60904
#define sipName_setSource &sipStrings_QtWidgets[60904]
#define sipNameNr_QTextEdit 60914
#define sipName_QTextEdit &sipStrings_QtWidgets[60914]
#define sipNameNr_setTabBar 60924
#define sipName_setTabBar &sipStrings_QtWidgets[60924]
#define sipNameNr_visualRow 60934
#define sipName_visualRow &sipStrings_QtWidgets[60934]
#define sipNameNr_bottomRow 60944
#define sipName_bottomRow &sipStrings_QtWidgets[60944]
#define sipNameNr_selectRow 60954
#define sipName_selectRow &sipStrings_QtWidgets[60954]
#define sipNameNr_gridStyle 60964
#define sipName_gridStyle &sipStrings_QtWidgets[60964]
#define sipNameNr_rowHeight 60974
#define sipName_rowHeight &sipStrings_QtWidgets[60974]
#define sipNameNr_isMovable 60984
#define sipName_isMovable &sipStrings_QtWidgets[60984]
#define sipNameNr_expanding 60994
#define sipName_expanding &sipStrings_QtWidgets[60994]
#define sipNameNr_tabButton 61004
#define sipName_tabButton &sipStrings_QtWidgets[61004]
#define sipNameNr_RightSide 61014
#define sipName_RightSide &sipStrings_QtWidgets[61014]
#define sipNameNr_elideMode 61024
#define sipName_elideMode &sipStrings_QtWidgets[61024]
#define sipNameNr_removeTab 61034
#define sipName_removeTab &sipStrings_QtWidgets[61034]
#define sipNameNr_insertTab 61044
#define sipName_insertTab &sipStrings_QtWidgets[61044]
#define sipNameNr_textColor 61054
#define sipName_textColor &sipStrings_QtWidgets[61054]
#define sipNameNr_popupRect 61064
#define sipName_popupRect &sipStrings_QtWidgets[61064]
#define sipNameNr_arrowType 61074
#define sipName_arrowType &sipStrings_QtWidgets[61074]
#define sipNameNr_Alternate 61084
#define sipName_Alternate &sipStrings_QtWidgets[61084]
#define sipNameNr_floatable 61094
#define sipName_floatable &sipStrings_QtWidgets[61094]
#define sipNameNr_checkType 61104
#define sipName_checkType &sipStrings_QtWidgets[61104]
#define sipNameNr_CheckType 5397
#define sipName_CheckType &sipStrings_QtWidgets[5397]
#define sipNameNr_EmptyArea 40
#define sipName_EmptyArea &sipStrings_QtWidgets[40]
#define sipNameNr_Separator 8572
#define sipName_Separator &sipStrings_QtWidgets[8572]
#define sipNameNr_Beginning 61114
#define sipName_Beginning &sipStrings_QtWidgets[61114]
#define sipNameNr_SO_Slider 61124
#define sipName_SO_Slider &sipStrings_QtWidgets[61124]
#define sipNameNr_SO_Header 61134
#define sipName_SO_Header &sipStrings_QtWidgets[61134]
#define sipNameNr_SO_Button 61144
#define sipName_SO_Button &sipStrings_QtWidgets[61144]
#define sipNameNr_visualPos 61154
#define sipName_visualPos &sipStrings_QtWidgets[61154]
#define sipNameNr_CT_Slider 61164
#define sipName_CT_Slider &sipStrings_QtWidgets[61164]
#define sipNameNr_CC_Slider 61174
#define sipName_CC_Slider &sipStrings_QtWidgets[61174]
#define sipNameNr_CE_Header 61184
#define sipName_CE_Header &sipStrings_QtWidgets[61184]
#define sipNameNr_PE_Widget 61194
#define sipName_PE_Widget &sipStrings_QtWidgets[61194]
#define sipNameNr_State_Top 61204
#define sipName_State_Top &sipStrings_QtWidgets[61204]
#define sipNameNr_State_Off 61214
#define sipName_State_Off &sipStrings_QtWidgets[61214]
#define sipNameNr_StateFlag 31627
#define sipName_StateFlag &sipStrings_QtWidgets[31627]
#define sipNameNr_QSplitter 61224
#define sipName_QSplitter &sipStrings_QtWidgets[61224]
#define sipNameNr_cleanText 61234
#define sipName_cleanText &sipStrings_QtWidgets[61234]
#define sipNameNr_setSuffix 61244
#define sipName_setSuffix &sipStrings_QtWidgets[61244]
#define sipNameNr_setPrefix 61254
#define sipName_setPrefix &sipStrings_QtWidgets[61254]
#define sipNameNr_TicksLeft 61264
#define sipName_TicksLeft &sipStrings_QtWidgets[61264]
#define sipNameNr_TabWidget 31573
#define sipName_TabWidget &sipStrings_QtWidgets[31573]
#define sipNameNr_ButtonBox 36938
#define sipName_ButtonBox &sipStrings_QtWidgets[36938]
#define sipNameNr_Expanding 35272
#define sipName_Expanding &sipStrings_QtWidgets[35272]
#define sipNameNr_Preferred 61274
#define sipName_Preferred &sipStrings_QtWidgets[61274]
#define sipNameNr_QSizeGrip 61284
#define sipName_QSizeGrip &sipStrings_QtWidgets[61284]
#define sipNameNr_QShortcut 61294
#define sipName_QShortcut &sipStrings_QtWidgets[61294]
#define sipNameNr_FrameRate 61304
#define sipName_FrameRate &sipStrings_QtWidgets[61304]
#define sipNameNr_InputMove 61314
#define sipName_InputMove &sipStrings_QtWidgets[61314]
#define sipNameNr_Scrolling 5461
#define sipName_Scrolling &sipStrings_QtWidgets[5461]
#define sipNameNr_QScroller 61324
#define sipName_QScroller &sipStrings_QtWidgets[61324]
#define sipNameNr_baseStyle 61334
#define sipName_baseStyle &sipStrings_QtWidgets[61334]
#define sipNameNr_forceShow 61344
#define sipName_forceShow &sipStrings_QtWidgets[61344]
#define sipNameNr_autoClose 61354
#define sipName_autoClose &sipStrings_QtWidgets[61354]
#define sipNameNr_autoReset 61364
#define sipName_autoReset &sipStrings_QtWidgets[61364]
#define sipNameNr_setButton 21311
#define sipName_setButton &sipStrings_QtWidgets[21311]
#define sipNameNr_setCorner 61374
#define sipName_setCorner &sipStrings_QtWidgets[61374]
#define sipNameNr_statusBar 61384
#define sipName_statusBar &sipStrings_QtWidgets[61384]
#define sipNameNr_sortItems 61394
#define sipName_sortItems &sipStrings_QtWidgets[61394]
#define sipNameNr_batchSize 61404
#define sipName_batchSize &sipStrings_QtWidgets[61404]
#define sipNameNr_QListView 61414
#define sipName_QListView &sipStrings_QtWidgets[61414]
#define sipNameNr_inputMask 61424
#define sipName_inputMask &sipStrings_QtWidgets[61424]
#define sipNameNr_backspace 61434
#define sipName_backspace &sipStrings_QtWidgets[61434]
#define sipNameNr_QLineEdit 61444
#define sipName_QLineEdit &sipStrings_QtWidgets[61444]
#define sipNameNr_drawFocus 61454
#define sipName_drawFocus &sipStrings_QtWidgets[61454]
#define sipNameNr_drawCheck 61464
#define sipName_drawCheck &sipStrings_QtWidgets[61464]
#define sipNameNr_textValue 61474
#define sipName_textValue &sipStrings_QtWidgets[61474]
#define sipNameNr_inputMode 61484
#define sipName_inputMode &sipStrings_QtWidgets[61484]
#define sipNameNr_getDouble 61494
#define sipName_getDouble &sipStrings_QtWidgets[61494]
#define sipNameNr_TextInput 8717
#define sipName_TextInput &sipStrings_QtWidgets[8717]
#define sipNameNr_InputMode 15309
#define sipName_InputMode &sipStrings_QtWidgets[15309]
#define sipNameNr_QGroupBox 61504
#define sipName_QGroupBox &sipStrings_QtWidgets[61504]
#define sipNameNr_fitInView 61514
#define sipName_fitInView &sipStrings_QtWidgets[61514]
#define sipNameNr_setZScale 61524
#define sipName_setZScale &sipStrings_QtWidgets[61524]
#define sipNameNr_setYScale 61534
#define sipName_setYScale &sipStrings_QtWidgets[61534]
#define sipNameNr_setXScale 61544
#define sipName_setXScale &sipStrings_QtWidgets[61544]
#define sipNameNr_setOrigin 61554
#define sipName_setOrigin &sipStrings_QtWidgets[61554]
#define sipNameNr_AllLayers 61564
#define sipName_AllLayers &sipStrings_QtWidgets[61564]
#define sipNameNr_ItemLayer 61574
#define sipName_ItemLayer &sipStrings_QtWidgets[61574]
#define sipNameNr_shapeMode 61584
#define sipName_shapeMode &sipStrings_QtWidgets[61584]
#define sipNameNr_MaskShape 29165
#define sipName_MaskShape &sipStrings_QtWidgets[29165]
#define sipNameNr_ShapeMode 6721
#define sipName_ShapeMode &sipStrings_QtWidgets[6721]
#define sipNameNr_spanAngle 61594
#define sipName_spanAngle &sipStrings_QtWidgets[61594]
#define sipNameNr_focusItem 61604
#define sipName_focusItem &sipStrings_QtWidgets[61604]
#define sipNameNr_isClipped 61614
#define sipName_isClipped &sipStrings_QtWidgets[61614]
#define sipNameNr_grabMouse 56118
#define sipName_grabMouse &sipStrings_QtWidgets[56118]
#define sipNameNr_mapToItem 61624
#define sipName_mapToItem &sipStrings_QtWidgets[61624]
#define sipNameNr_setZValue 61634
#define sipName_setZValue &sipStrings_QtWidgets[61634]
#define sipNameNr_hasCursor 61644
#define sipName_hasCursor &sipStrings_QtWidgets[61644]
#define sipNameNr_blurHints 61654
#define sipName_blurHints &sipStrings_QtWidgets[61654]
#define sipNameNr_BlurHints 6783
#define sipName_BlurHints &sipStrings_QtWidgets[6783]
#define sipNameNr_addAnchor 61664
#define sipName_addAnchor &sipStrings_QtWidgets[61664]
#define sipNameNr_recognize 61674
#define sipName_recognize &sipStrings_QtWidgets[61674]
#define sipNameNr_drawFrame 61684
#define sipName_drawFrame &sipStrings_QtWidgets[61684]
#define sipNameNr_StyleMask 32941
#define sipName_StyleMask &sipStrings_QtWidgets[32941]
#define sipNameNr_fieldItem 61694
#define sipName_fieldItem &sipStrings_QtWidgets[61694]
#define sipNameNr_labelItem 61704
#define sipName_labelItem &sipStrings_QtWidgets[61704]
#define sipNameNr_setLayout 61714
#define sipName_setLayout &sipStrings_QtWidgets[61714]
#define sipNameNr_FieldRole 61724
#define sipName_FieldRole &sipStrings_QtWidgets[61724]
#define sipNameNr_LabelRole 61734
#define sipName_LabelRole &sipStrings_QtWidgets[61734]
#define sipNameNr_selectUrl 61744
#define sipName_selectUrl &sipStrings_QtWidgets[61744]
#define sipNameNr_saveState 61754
#define sipName_saveState &sipStrings_QtWidgets[61754]
#define sipNameNr_labelText 61764
#define sipName_labelText &sipStrings_QtWidgets[61764]
#define sipNameNr_Directory 23138
#define sipName_Directory &sipStrings_QtWidgets[23138]
#define sipNameNr_qtHandler 61774
#define sipName_qtHandler &sipStrings_QtWidgets[61774]
#define sipNameNr_QDirModel 61784
#define sipName_QDirModel &sipStrings_QtWidgets[61784]
#define sipNameNr_ApplyRole 61794
#define sipName_ApplyRole &sipStrings_QtWidgets[61794]
#define sipNameNr_ResetRole 61804
#define sipName_ResetRole &sipStrings_QtWidgets[61804]
#define sipNameNr_KdeLayout 61814
#define sipName_KdeLayout &sipStrings_QtWidgets[61814]
#define sipNameNr_MacLayout 61824
#define sipName_MacLayout &sipStrings_QtWidgets[61824]
#define sipNameNr_WinLayout 61834
#define sipName_WinLayout &sipStrings_QtWidgets[61834]
#define sipNameNr_setResult 61844
#define sipName_setResult &sipStrings_QtWidgets[61844]
#define sipNameNr_notchSize 61854
#define sipName_notchSize &sipStrings_QtWidgets[61854]
#define sipNameNr_QDateEdit 61864
#define sipName_QDateEdit &sipStrings_QtWidgets[61864]
#define sipNameNr_QTimeEdit 61874
#define sipName_QTimeEdit &sipStrings_QtWidgets[61874]
#define sipNameNr_sectionAt 61884
#define sipName_sectionAt &sipStrings_QtWidgets[61884]
#define sipNameNr_splitPath 61894
#define sipName_splitPath &sipStrings_QtWidgets[61894]
#define sipNameNr_setWidget 61904
#define sipName_setWidget &sipStrings_QtWidgets[61904]
#define sipNameNr_completer 61914
#define sipName_completer &sipStrings_QtWidgets[61914]
#define sipNameNr_hidePopup 61924
#define sipName_hidePopup &sipStrings_QtWidgets[61924]
#define sipNameNr_showPopup 61934
#define sipName_showPopup &sipStrings_QtWidgets[61934]
#define sipNameNr_validator 61944
#define sipName_validator &sipStrings_QtWidgets[61944]
#define sipNameNr_QComboBox 61954
#define sipName_QComboBox &sipStrings_QtWidgets[61954]
#define sipNameNr_QCheckBox 61964
#define sipName_QCheckBox &sipStrings_QtWidgets[61964]
#define sipNameNr_showToday 61974
#define sipName_showToday &sipStrings_QtWidgets[61974]
#define sipNameNr_paintCell 61984
#define sipName_paintCell &sipStrings_QtWidgets[61984]
#define sipNameNr_yearShown 61994
#define sipName_yearShown &sipStrings_QtWidgets[61994]
#define sipNameNr_idToggled 62004
#define sipName_idToggled &sipStrings_QtWidgets[62004]
#define sipNameNr_idPressed 62014
#define sipName_idPressed &sipStrings_QtWidgets[62014]
#define sipNameNr_idClicked 62024
#define sipName_idClicked &sipStrings_QtWidgets[62024]
#define sipNameNr_checkedId 62034
#define sipName_checkedId &sipStrings_QtWidgets[62034]
#define sipNameNr_addButton 62044
#define sipName_addButton &sipStrings_QtWidgets[62044]
#define sipNameNr_exclusive 62054
#define sipName_exclusive &sipStrings_QtWidgets[62054]
#define sipNameNr_addLayout 62064
#define sipName_addLayout &sipStrings_QtWidgets[62064]
#define sipNameNr_addWidget 62074
#define sipName_addWidget &sipStrings_QtWidgets[62074]
#define sipNameNr_ManyColor 62084
#define sipName_ManyColor &sipStrings_QtWidgets[62084]
#define sipNameNr_ColorSpec 15981
#define sipName_ColorSpec &sipStrings_QtWidgets[15981]
#define sipNameNr_Exclusive 37856
#define sipName_Exclusive &sipStrings_QtWidgets[37856]
#define sipNameNr_addAction 62094
#define sipName_addAction &sipStrings_QtWidgets[62094]
#define sipNameNr_shortcuts 62104
#define sipName_shortcuts &sipStrings_QtWidgets[62104]
#define sipNameNr_AboutRole 62114
#define sipName_AboutRole &sipStrings_QtWidgets[62114]
#define sipNameNr_NoButtons 62124
#define sipName_NoButtons &sipStrings_QtWidgets[62124]
#define sipNameNr_PlusMinus 62134
#define sipName_PlusMinus &sipStrings_QtWidgets[62134]
#define sipNameNr_BelowItem 62144
#define sipName_BelowItem &sipStrings_QtWidgets[62144]
#define sipNameNr_AboveItem 62154
#define sipName_AboveItem &sipStrings_QtWidgets[62154]
#define sipNameNr_dropEvent 62164
#define sipName_dropEvent &sipStrings_QtWidgets[62164]
#define sipNameNr_startDrag 62174
#define sipName_startDrag &sipStrings_QtWidgets[62174]
#define sipNameNr_MoveRight 62184
#define sipName_MoveRight &sipStrings_QtWidgets[62184]
#define sipNameNr_selectAll 62194
#define sipName_selectAll &sipStrings_QtWidgets[62194]
#define sipNameNr_rootIndex 62204
#define sipName_rootIndex &sipStrings_QtWidgets[62204]
#define sipNameNr_helpEvent 62214
#define sipName_helpEvent &sipStrings_QtWidgets[62214]
#define sipNameNr_hitButton 62224
#define sipName_hitButton &sipStrings_QtWidgets[62224]
#define sipNameNr_isChecked 62234
#define sipName_isChecked &sipStrings_QtWidgets[62234]
#define sipNameNr_hideEvent 62244
#define sipName_hideEvent &sipStrings_QtWidgets[62244]
#define sipNameNr_showEvent 62254
#define sipName_showEvent &sipStrings_QtWidgets[62254]
#define sipNameNr_moveEvent 62264
#define sipName_moveEvent &sipStrings_QtWidgets[62264]
#define sipNameNr_setCursor 57342
#define sipName_setCursor &sipStrings_QtWidgets[57342]
#define sipNameNr_setMargin 62274
#define sipName_setMargin &sipStrings_QtWidgets[62274]
#define sipNameNr_setIndent 62284
#define sipName_setIndent &sipStrings_QtWidgets[62284]
#define sipNameNr_textWidth 62294
#define sipName_textWidth &sipStrings_QtWidgets[62294]
#define sipNameNr_takeChild 62304
#define sipName_takeChild &sipStrings_QtWidgets[62304]
#define sipNameNr_whatsThis 62314
#define sipName_whatsThis &sipStrings_QtWidgets[62314]
#define sipNameNr_statusTip 62324
#define sipName_statusTip &sipStrings_QtWidgets[62324]
#define sipNameNr_findItems 62334
#define sipName_findItems &sipStrings_QtWidgets[62334]
#define sipNameNr_Rectangle 62344
#define sipName_Rectangle &sipStrings_QtWidgets[62344]
#define sipNameNr_setActive 62354
#define sipName_setActive &sipStrings_QtWidgets[62354]
#define sipNameNr_cacheMode 62364
#define sipName_cacheMode &sipStrings_QtWidgets[62364]
#define sipNameNr_frameRect 62374
#define sipName_frameRect &sipStrings_QtWidgets[62374]
#define sipNameNr_CacheNone 62384
#define sipName_CacheNone &sipStrings_QtWidgets[62384]
#define sipNameNr_CacheMode 13611
#define sipName_CacheMode &sipStrings_QtWidgets[13611]
#define sipNameNr_isVisible 62394
#define sipName_isVisible &sipStrings_QtWidgets[62394]
#define sipNameNr_setOption 62404
#define sipName_setOption &sipStrings_QtWidgets[62404]
#define sipNameNr_setFormat 55338
#define sipName_setFormat &sipStrings_QtWidgets[55338]
#define sipNameNr_setOffset 62414
#define sipName_setOffset &sipStrings_QtWidgets[62414]
#define sipNameNr_addPixmap 62424
#define sipName_addPixmap &sipStrings_QtWidgets[62424]
#define sipNameNr_lineWidth 62434
#define sipName_lineWidth &sipStrings_QtWidgets[62434]
#define sipNameNr_styleHint 62444
#define sipName_styleHint &sipStrings_QtWidgets[62444]
#define sipNameNr_StyleHint 31231
#define sipName_StyleHint &sipStrings_QtWidgets[31231]
#define sipNameNr_sceneRect 62454
#define sipName_sceneRect &sipStrings_QtWidgets[62454]
#define sipNameNr_screenPos 62464
#define sipName_screenPos &sipStrings_QtWidgets[62464]
#define sipNameNr_timestamp 62474
#define sipName_timestamp &sipStrings_QtWidgets[62474]
#define sipNameNr_modifiers 62484
#define sipName_modifiers &sipStrings_QtWidgets[62484]
#define sipNameNr_setPixmap 62494
#define sipName_setPixmap &sipStrings_QtWidgets[62494]
#define sipNameNr_transform 62504
#define sipName_transform &sipStrings_QtWidgets[62504]
#define sipNameNr_colorSpec 62514
#define sipName_colorSpec &sipStrings_QtWidgets[62514]
#define sipNameNr_pageCount 62524
#define sipName_pageCount &sipStrings_QtWidgets[62524]
#define sipNameNr_directory 62534
#define sipName_directory &sipStrings_QtWidgets[62534]
#define sipNameNr_alignment 62544
#define sipName_alignment &sipStrings_QtWidgets[62544]
#define sipNameNr_maxLength 62554
#define sipName_maxLength &sipStrings_QtWidgets[62554]
#define sipNameNr_activated 62564
#define sipName_activated &sipStrings_QtWidgets[62564]
#define sipNameNr_transpose 62574
#define sipName_transpose &sipStrings_QtWidgets[62574]
#define sipNameNr_className 62584
#define sipName_className &sipStrings_QtWidgets[62584]
#define sipNameNr_setParent 62594
#define sipName_setParent &sipStrings_QtWidgets[62594]
#define sipNameNr_isDefault 62604
#define sipName_isDefault &sipStrings_QtWidgets[62604]
#define sipNameNr_rectangle 62614
#define sipName_rectangle &sipStrings_QtWidgets[62614]
#define sipNameNr_isEnabled 62624
#define sipName_isEnabled &sipStrings_QtWidgets[62624]
#define sipNameNr_setFilter 62634
#define sipName_setFilter &sipStrings_QtWidgets[62634]
#define sipNameNr_translate 62644
#define sipName_translate &sipStrings_QtWidgets[62644]
#define sipNameNr_sendEvent 62654
#define sipName_sendEvent &sipStrings_QtWidgets[62654]
#define sipNameNr_setHidden 62664
#define sipName_setHidden &sipStrings_QtWidgets[62664]
#define sipNameNr_setLocale 54366
#define sipName_setLocale &sipStrings_QtWidgets[54366]
#define sipNameNr_eventTest 62674
#define sipName_eventTest &sipStrings_QtWidgets[62674]
#define sipNameNr_triggered 62684
#define sipName_triggered &sipStrings_QtWidgets[62684]
#define sipNameNr_roleNames 62694
#define sipName_roleNames &sipStrings_QtWidgets[62694]
#define sipNameNr_removeRow 62704
#define sipName_removeRow &sipStrings_QtWidgets[62704]
#define sipNameNr_insertRow 62714
#define sipName_insertRow &sipStrings_QtWidgets[62714]
#define sipNameNr_fetchMore 62724
#define sipName_fetchMore &sipStrings_QtWidgets[62724]
#define sipNameNr_mimeTypes 62734
#define sipName_mimeTypes &sipStrings_QtWidgets[62734]
#define sipNameNr_direction 62744
#define sipName_direction &sipStrings_QtWidgets[62744]
#define sipNameNr_Direction 7692
#define sipName_Direction &sipStrings_QtWidgets[7692]
#define sipNameNr_NoSection 62754
#define sipName_NoSection &sipStrings_QtWidgets[62754]
#define sipNameNr___index__ 62764
#define sipName___index__ &sipStrings_QtWidgets[62764]
#define sipNameNr_subTitle 62774
#define sipName_subTitle &sipStrings_QtWidgets[62774]
#define sipNameNr_setField 62783
#define sipName_setField &sipStrings_QtWidgets[62783]
#define sipNameNr_MacStyle 62792
#define sipName_MacStyle &sipStrings_QtWidgets[62792]
#define sipNameNr_setStack 62801
#define sipName_setStack &sipStrings_QtWidgets[62801]
#define sipNameNr_setIndex 62810
#define sipName_setIndex &sipStrings_QtWidgets[62810]
#define sipNameNr_setClean 58109
#define sipName_setClean &sipStrings_QtWidgets[58109]
#define sipNameNr_endMacro 62819
#define sipName_endMacro &sipStrings_QtWidgets[62819]
#define sipNameNr_redoText 62828
#define sipName_redoText &sipStrings_QtWidgets[62828]
#define sipNameNr_undoText 62837
#define sipName_undoText &sipStrings_QtWidgets[62837]
#define sipNameNr_addStack 62846
#define sipName_addStack &sipStrings_QtWidgets[62846]
#define sipNameNr_UserFlag 62855
#define sipName_UserFlag &sipStrings_QtWidgets[62855]
#define sipNameNr_Editable 25488
#define sipName_Editable &sipStrings_QtWidgets[25488]
#define sipNameNr_addChild 62864
#define sipName_addChild &sipStrings_QtWidgets[62864]
#define sipNameNr_drawTree 62873
#define sipName_drawTree &sipStrings_QtWidgets[62873]
#define sipNameNr_reexpand 62882
#define sipName_reexpand &sipStrings_QtWidgets[62882]
#define sipNameNr_expanded 62891
#define sipName_expanded &sipStrings_QtWidgets[62891]
#define sipNameNr_hideText 62900
#define sipName_hideText &sipStrings_QtWidgets[62900]
#define sipNameNr_showText 62909
#define sipName_showText &sipStrings_QtWidgets[62909]
#define sipNameNr_QToolTip 62918
#define sipName_QToolTip &sipStrings_QtWidgets[62918]
#define sipNameNr_QToolBox 62927
#define sipName_QToolBox &sipStrings_QtWidgets[62927]
#define sipNameNr_QToolBar 62936
#define sipName_QToolBar &sipStrings_QtWidgets[62936]
#define sipNameNr_AutoNone 62945
#define sipName_AutoNone &sipStrings_QtWidgets[62945]
#define sipNameNr_backward 62954
#define sipName_backward &sipStrings_QtWidgets[62954]
#define sipNameNr_TabShape 20976
#define sipName_TabShape &sipStrings_QtWidgets[20976]
#define sipNameNr_rowMoved 62963
#define sipName_rowMoved &sipStrings_QtWidgets[62963]
#define sipNameNr_showGrid 62972
#define sipName_showGrid &sipStrings_QtWidgets[62972]
#define sipNameNr_columnAt 62981
#define sipName_columnAt &sipStrings_QtWidgets[62981]
#define sipNameNr_autoHide 62990
#define sipName_autoHide &sipStrings_QtWidgets[62990]
#define sipNameNr_tabMoved 62999
#define sipName_tabMoved &sipStrings_QtWidgets[62999]
#define sipNameNr_LeftSide 63008
#define sipName_LeftSide &sipStrings_QtWidgets[63008]
#define sipNameNr_drawBase 63017
#define sipName_drawBase &sipStrings_QtWidgets[63017]
#define sipNameNr_WrapText 63026
#define sipName_WrapText &sipStrings_QtWidgets[63026]
#define sipNameNr_tabWidth 63035
#define sipName_tabWidth &sipStrings_QtWidgets[63035]
#define sipNameNr_menuRect 63044
#define sipName_menuRect &sipStrings_QtWidgets[63044]
#define sipNameNr_Scroller 38974
#define sipName_Scroller &sipStrings_QtWidgets[38974]
#define sipNameNr_tabIndex 63053
#define sipName_tabIndex &sipStrings_QtWidgets[63053]
#define sipNameNr_HasFrame 63062
#define sipName_HasFrame &sipStrings_QtWidgets[63062]
#define sipNameNr_SortDown 63071
#define sipName_SortDown &sipStrings_QtWidgets[63071]
#define sipNameNr_initFrom 63080
#define sipName_initFrom &sipStrings_QtWidgets[63080]
#define sipNameNr_SO_Frame 63089
#define sipName_SO_Frame &sipStrings_QtWidgets[63089]
#define sipNameNr_PE_Frame 63098
#define sipName_PE_Frame &sipStrings_QtWidgets[63098]
#define sipNameNr_State_On 63107
#define sipName_State_On &sipStrings_QtWidgets[63107]
#define sipNameNr_reformat 63116
#define sipName_reformat &sipStrings_QtWidgets[63116]
#define sipNameNr_StackAll 63125
#define sipName_StackAll &sipStrings_QtWidgets[63125]
#define sipNameNr_StackOne 63134
#define sipName_StackOne &sipStrings_QtWidgets[63134]
#define sipNameNr_splitter 63143
#define sipName_splitter &sipStrings_QtWidgets[63143]
#define sipNameNr_getRange 63152
#define sipName_getRange &sipStrings_QtWidgets[63152]
#define sipNameNr_setSizes 63161
#define sipName_setSizes &sipStrings_QtWidgets[63161]
#define sipNameNr_stepType 63170
#define sipName_stepType &sipStrings_QtWidgets[63170]
#define sipNameNr_QSpinBox 63179
#define sipName_QSpinBox &sipStrings_QtWidgets[63179]
#define sipNameNr_LineEdit 35171
#define sipName_LineEdit &sipStrings_QtWidgets[35171]
#define sipNameNr_GroupBox 21060
#define sipName_GroupBox &sipStrings_QtWidgets[21060]
#define sipNameNr_ComboBox 21123
#define sipName_ComboBox &sipStrings_QtWidgets[21123]
#define sipNameNr_CheckBox 22026
#define sipName_CheckBox &sipStrings_QtWidgets[22026]
#define sipNameNr_GrowFlag 63188
#define sipName_GrowFlag &sipStrings_QtWidgets[63188]
#define sipNameNr_SnapTime 63197
#define sipName_SnapTime &sipStrings_QtWidgets[63197]
#define sipNameNr_Standard 63206
#define sipName_Standard &sipStrings_QtWidgets[63206]
#define sipNameNr_scroller 63215
#define sipName_scroller &sipStrings_QtWidgets[63215]
#define sipNameNr_Dragging 39662
#define sipName_Dragging &sipStrings_QtWidgets[39662]
#define sipNameNr_showMenu 63224
#define sipName_showMenu &sipStrings_QtWidgets[63224]
#define sipNameNr_textRole 63233
#define sipName_textRole &sipStrings_QtWidgets[63233]
#define sipNameNr_canceled 63242
#define sipName_canceled &sipStrings_QtWidgets[63242]
#define sipNameNr_setLabel 63251
#define sipName_setLabel &sipStrings_QtWidgets[63251]
#define sipNameNr_canPaste 63260
#define sipName_canPaste &sipStrings_QtWidgets[63260]
#define sipNameNr_checkBox 63269
#define sipName_checkBox &sipStrings_QtWidgets[63269]
#define sipNameNr_question 63278
#define sipName_question &sipStrings_QtWidgets[63278]
#define sipNameNr_FlagMask 63287
#define sipName_FlagMask &sipStrings_QtWidgets[63287]
#define sipNameNr_Question 18545
#define sipName_Question &sipStrings_QtWidgets[18545]
#define sipNameNr_Critical 18567
#define sipName_Critical &sipStrings_QtWidgets[18567]
#define sipNameNr_QMenuBar 63296
#define sipName_QMenuBar &sipStrings_QtWidgets[63296]
#define sipNameNr_collapse 63305
#define sipName_collapse &sipStrings_QtWidgets[63305]
#define sipNameNr_actionAt 63314
#define sipName_actionAt &sipStrings_QtWidgets[63314]
#define sipNameNr_isShaded 63323
#define sipName_isShaded &sipStrings_QtWidgets[63323]
#define sipNameNr_closable 63332
#define sipName_closable &sipStrings_QtWidgets[63332]
#define sipNameNr_QMdiArea 63341
#define sipName_QMdiArea &sipStrings_QtWidgets[63341]
#define sipNameNr_tabShape 63350
#define sipName_tabShape &sipStrings_QtWidgets[63350]
#define sipNameNr_editItem 63359
#define sipName_editItem &sipStrings_QtWidgets[63359]
#define sipNameNr_gridSize 63368
#define sipName_gridSize &sipStrings_QtWidgets[63368]
#define sipNameNr_movement 63377
#define sipName_movement &sipStrings_QtWidgets[63377]
#define sipNameNr_IconMode 63386
#define sipName_IconMode &sipStrings_QtWidgets[63386]
#define sipNameNr_ListMode 63395
#define sipName_ListMode &sipStrings_QtWidgets[63395]
#define sipNameNr_Movement 25368
#define sipName_Movement &sipStrings_QtWidgets[25368]
#define sipNameNr_deselect 63404
#define sipName_deselect &sipStrings_QtWidgets[63404]
#define sipNameNr_echoMode 63413
#define sipName_echoMode &sipStrings_QtWidgets[63413]
#define sipNameNr_Password 63422
#define sipName_Password &sipStrings_QtWidgets[63422]
#define sipNameNr_EchoMode 25388
#define sipName_EchoMode &sipStrings_QtWidgets[25388]
#define sipNameNr_overflow 63431
#define sipName_overflow &sipStrings_QtWidgets[63431]
#define sipNameNr_setMovie 63440
#define sipName_setMovie &sipStrings_QtWidgets[63440]
#define sipNameNr_setBuddy 63449
#define sipName_setBuddy &sipStrings_QtWidgets[63449]
#define sipNameNr_wordWrap 63458
#define sipName_wordWrap &sipStrings_QtWidgets[63458]
#define sipNameNr_intValue 63467
#define sipName_intValue &sipStrings_QtWidgets[63467]
#define sipNameNr_IntInput 63476
#define sipName_IntInput &sipStrings_QtWidgets[63476]
#define sipNameNr_cellRect 63485
#define sipName_cellRect &sipStrings_QtWidgets[63485]
#define sipNameNr_centerOn 63494
#define sipName_centerOn &sipStrings_QtWidgets[63494]
#define sipNameNr_setScene 63503
#define sipName_setScene &sipStrings_QtWidgets[63503]
#define sipNameNr_dragMode 63512
#define sipName_dragMode &sipStrings_QtWidgets[63512]
#define sipNameNr_NoAnchor 63521
#define sipName_NoAnchor &sipStrings_QtWidgets[63521]
#define sipNameNr_DragMode 15550
#define sipName_DragMode &sipStrings_QtWidgets[15550]
#define sipNameNr_isLayout 63530
#define sipName_isLayout &sipStrings_QtWidgets[63530]
#define sipNameNr_zChanged 63539
#define sipName_zChanged &sipStrings_QtWidgets[63539]
#define sipNameNr_setScale 63548
#define sipName_setScale &sipStrings_QtWidgets[63548]
#define sipNameNr_isWindow 63557
#define sipName_isWindow &sipStrings_QtWidgets[63557]
#define sipNameNr_isWidget 63566
#define sipName_isWidget &sipStrings_QtWidgets[63566]
#define sipNameNr_setFocus 63575
#define sipName_setFocus &sipStrings_QtWidgets[63575]
#define sipNameNr_hasFocus 63584
#define sipName_hasFocus &sipStrings_QtWidgets[63584]
#define sipNameNr_setGroup 63593
#define sipName_setGroup &sipStrings_QtWidgets[63593]
#define sipNameNr_BlurHint 7663
#define sipName_BlurHint &sipStrings_QtWidgets[7663]
#define sipNameNr_strength 63602
#define sipName_strength &sipStrings_QtWidgets[63602]
#define sipNameNr_gestures 63611
#define sipName_gestures &sipStrings_QtWidgets[63611]
#define sipNameNr_QGesture 63620
#define sipName_QGesture &sipStrings_QtWidgets[63620]
#define sipNameNr_WinPanel 49087
#define sipName_WinPanel &sipStrings_QtWidgets[49087]
#define sipNameNr_ItemRole 20173
#define sipName_ItemRole &sipStrings_QtWidgets[20173]
#define sipNameNr_AllFonts 63629
#define sipName_AllFonts &sipStrings_QtWidgets[63629]
#define sipNameNr_Trashcan 63638
#define sipName_Trashcan &sipStrings_QtWidgets[63638]
#define sipNameNr_Computer 59605
#define sipName_Computer &sipStrings_QtWidgets[59605]
#define sipNameNr_IconType 9733
#define sipName_IconType &sipStrings_QtWidgets[9733]
#define sipNameNr_fileMode 63647
#define sipName_fileMode &sipStrings_QtWidgets[63647]
#define sipNameNr_viewMode 63656
#define sipName_viewMode &sipStrings_QtWidgets[63656]
#define sipNameNr_FileType 63665
#define sipName_FileType &sipStrings_QtWidgets[63665]
#define sipNameNr_FileName 40830
#define sipName_FileName &sipStrings_QtWidgets[40830]
#define sipNameNr_FileMode 20261
#define sipName_FileMode &sipStrings_QtWidgets[20261]
#define sipNameNr_ViewMode 20283
#define sipName_ViewMode &sipStrings_QtWidgets[20283]
#define sipNameNr_fileIcon 63674
#define sipName_fileIcon &sipStrings_QtWidgets[63674]
#define sipNameNr_YesToAll 63683
#define sipName_YesToAll &sipStrings_QtWidgets[63683]
#define sipNameNr_HelpRole 63692
#define sipName_HelpRole &sipStrings_QtWidgets[63692]
#define sipNameNr_rejected 63701
#define sipName_rejected &sipStrings_QtWidgets[63701]
#define sipNameNr_setModal 63710
#define sipName_setModal &sipStrings_QtWidgets[63710]
#define sipNameNr_Accepted 57859
#define sipName_Accepted &sipStrings_QtWidgets[57859]
#define sipNameNr_Rejected 47897
#define sipName_Rejected &sipStrings_QtWidgets[47897]
#define sipNameNr_Sections 12862
#define sipName_Sections &sipStrings_QtWidgets[12862]
#define sipNameNr_complete 63719
#define sipName_complete &sipStrings_QtWidgets[63719]
#define sipNameNr_setPopup 63728
#define sipName_setPopup &sipStrings_QtWidgets[63728]
#define sipNameNr_unpolish 63737
#define sipName_unpolish &sipStrings_QtWidgets[63737]
#define sipNameNr_addItems 63746
#define sipName_addItems &sipStrings_QtWidgets[63746]
#define sipNameNr_itemIcon 63755
#define sipName_itemIcon &sipStrings_QtWidgets[63755]
#define sipNameNr_NoInsert 63764
#define sipName_NoInsert &sipStrings_QtWidgets[63764]
#define sipNameNr_findData 63773
#define sipName_findData &sipStrings_QtWidgets[63773]
#define sipNameNr_findText 63782
#define sipName_findText &sipStrings_QtWidgets[63782]
#define sipNameNr_maxCount 63791
#define sipName_maxCount &sipStrings_QtWidgets[63791]
#define sipNameNr_getColor 63800
#define sipName_getColor &sipStrings_QtWidgets[63800]
#define sipNameNr_calendar 63809
#define sipName_calendar &sipStrings_QtWidgets[63809]
#define sipNameNr_addStrut 63818
#define sipName_addStrut &sipStrings_QtWidgets[63818]
#define sipNameNr_widgetAt 63827
#define sipName_widgetAt &sipStrings_QtWidgets[63827]
#define sipNameNr_menuRole 63836
#define sipName_menuRole &sipStrings_QtWidgets[63836]
#define sipNameNr_QuitRole 63845
#define sipName_QuitRole &sipStrings_QtWidgets[63845]
#define sipNameNr_MenuRole 33644
#define sipName_MenuRole &sipStrings_QtWidgets[33644]
#define sipNameNr_activate 63854
#define sipName_activate &sipStrings_QtWidgets[63854]
#define sipNameNr_iconText 63863
#define sipName_iconText &sipStrings_QtWidgets[63863]
#define sipNameNr_StepType 10924
#define sipName_StepType &sipStrings_QtWidgets[10924]
#define sipNameNr_lineEdit 63872
#define sipName_lineEdit &sipStrings_QtWidgets[63872]
#define sipNameNr_stepDown 63881
#define sipName_stepDown &sipStrings_QtWidgets[63881]
#define sipNameNr_hasFrame 63890
#define sipName_hasFrame &sipStrings_QtWidgets[63890]
#define sipNameNr_setFrame 63899
#define sipName_setFrame &sipStrings_QtWidgets[63899]
#define sipNameNr_wrapping 63908
#define sipName_wrapping &sipStrings_QtWidgets[63908]
#define sipNameNr_StepNone 63917
#define sipName_StepNone &sipStrings_QtWidgets[63917]
#define sipNameNr_pageStep 63926
#define sipName_pageStep &sipStrings_QtWidgets[63926]
#define sipNameNr_setState 63935
#define sipName_setState &sipStrings_QtWidgets[63935]
#define sipNameNr_MoveNext 63944
#define sipName_MoveNext &sipStrings_QtWidgets[63944]
#define sipNameNr_MoveHome 63953
#define sipName_MoveHome &sipStrings_QtWidgets[63953]
#define sipNameNr_MoveLeft 63962
#define sipName_MoveLeft &sipStrings_QtWidgets[63962]
#define sipNameNr_MoveDown 63971
#define sipName_MoveDown &sipStrings_QtWidgets[63971]
#define sipNameNr_scrollTo 63980
#define sipName_scrollTo &sipStrings_QtWidgets[63980]
#define sipNameNr_DragDrop 60067
#define sipName_DragDrop &sipStrings_QtWidgets[60067]
#define sipNameNr_DropOnly 63989
#define sipName_DropOnly &sipStrings_QtWidgets[63989]
#define sipNameNr_DragOnly 63998
#define sipName_DragOnly &sipStrings_QtWidgets[63998]
#define sipNameNr_released 64007
#define sipName_released &sipStrings_QtWidgets[64007]
#define sipNameNr_shortcut 64016
#define sipName_shortcut &sipStrings_QtWidgets[64016]
#define sipNameNr_iconSize 64025
#define sipName_iconSize &sipStrings_QtWidgets[64025]
#define sipNameNr_yChanged 33950
#define sipName_yChanged &sipStrings_QtWidgets[33950]
#define sipNameNr_xChanged 26388
#define sipName_xChanged &sipStrings_QtWidgets[26388]
#define sipNameNr_baseSize 64034
#define sipName_baseSize &sipStrings_QtWidgets[64034]
#define sipNameNr_decimals 64043
#define sipName_decimals &sipStrings_QtWidgets[64043]
#define sipNameNr_setRange 64052
#define sipName_setRange &sipStrings_QtWidgets[64052]
#define sipNameNr_validate 60606
#define sipName_validate &sipStrings_QtWidgets[60606]
#define sipNameNr_userData 64061
#define sipName_userData &sipStrings_QtWidgets[64061]
#define sipNameNr_itemText 64070
#define sipName_itemText &sipStrings_QtWidgets[64070]
#define sipNameNr_Position 1232
#define sipName_Position &sipStrings_QtWidgets[1232]
#define sipNameNr_ItemType 3776
#define sipName_ItemType &sipStrings_QtWidgets[3776]
#define sipNameNr_editable 64079
#define sipName_editable &sipStrings_QtWidgets[64079]
#define sipNameNr_sizeHint 64088
#define sipName_sizeHint &sipStrings_QtWidgets[64088]
#define sipNameNr_takeItem 64097
#define sipName_takeItem &sipStrings_QtWidgets[64097]
#define sipNameNr_geometry 64106
#define sipName_geometry &sipStrings_QtWidgets[64106]
#define sipNameNr_setTitle 64115
#define sipName_setTitle &sipStrings_QtWidgets[64115]
#define sipNameNr_Inactive 64124
#define sipName_Inactive &sipStrings_QtWidgets[64124]
#define sipNameNr_features 64133
#define sipName_features &sipStrings_QtWidgets[64133]
#define sipNameNr_fillRule 64142
#define sipName_fillRule &sipStrings_QtWidgets[64142]
#define sipNameNr_clipPath 64151
#define sipName_clipPath &sipStrings_QtWidgets[64151]
#define sipNameNr_setBrush 64160
#define sipName_setBrush &sipStrings_QtWidgets[64160]
#define sipNameNr_resizeGL 64169
#define sipName_resizeGL &sipStrings_QtWidgets[64169]
#define sipNameNr_viewport 64178
#define sipName_viewport &sipStrings_QtWidgets[64178]
#define sipNameNr_Selected 3951
#define sipName_Selected &sipStrings_QtWidgets[3951]
#define sipNameNr_Disabled 6443
#define sipName_Disabled &sipStrings_QtWidgets[6443]
#define sipNameNr_fontInfo 64187
#define sipName_fontInfo &sipStrings_QtWidgets[64187]
#define sipNameNr_velocity 64196
#define sipName_velocity &sipStrings_QtWidgets[64196]
#define sipNameNr_scenePos 64205
#define sipName_scenePos &sipStrings_QtWidgets[64205]
#define sipNameNr_Keyboard 38238
#define sipName_Keyboard &sipStrings_QtWidgets[38238]
#define sipNameNr_rotation 64214
#define sipName_rotation &sipStrings_QtWidgets[64214]
#define sipNameNr_setShape 64223
#define sipName_setShape &sipStrings_QtWidgets[64223]
#define sipNameNr_setColor 64232
#define sipName_setColor &sipStrings_QtWidgets[64232]
#define sipNameNr_setStyle 64241
#define sipName_setStyle &sipStrings_QtWidgets[64241]
#define sipNameNr_document 64250
#define sipName_document &sipStrings_QtWidgets[64250]
#define sipNameNr_anchorAt 64259
#define sipName_anchorAt &sipStrings_QtWidgets[64259]
#define sipNameNr_UserType 64268
#define sipName_UserType &sipStrings_QtWidgets[64268]
#define sipNameNr_Priority 33590
#define sipName_Priority &sipStrings_QtWidgets[33590]
#define sipNameNr_position 64277
#define sipName_position &sipStrings_QtWidgets[64277]
#define sipNameNr_setValue 64286
#define sipName_setValue &sipStrings_QtWidgets[64286]
#define sipNameNr_property 64295
#define sipName_property &sipStrings_QtWidgets[64295]
#define sipNameNr_critical 64304
#define sipName_critical &sipStrings_QtWidgets[64304]
#define sipNameNr_dateTime 64313
#define sipName_dateTime &sipStrings_QtWidgets[64313]
#define sipNameNr_setAngle 64322
#define sipName_setAngle &sipStrings_QtWidgets[64322]
#define sipNameNr_removeAt 64331
#define sipName_removeAt &sipStrings_QtWidgets[64331]
#define sipNameNr_setModel 64340
#define sipName_setModel &sipStrings_QtWidgets[64340]
#define sipNameNr_ReadOnly 43451
#define sipName_ReadOnly &sipStrings_QtWidgets[43451]
#define sipNameNr_progress 64349
#define sipName_progress &sipStrings_QtWidgets[64349]
#define sipNameNr_fileInfo 64358
#define sipName_fileInfo &sipStrings_QtWidgets[64358]
#define sipNameNr_rootPath 64367
#define sipName_rootPath &sipStrings_QtWidgets[64367]
#define sipNameNr_filePath 64376
#define sipName_filePath &sipStrings_QtWidgets[64376]
#define sipNameNr_fileName 64385
#define sipName_fileName &sipStrings_QtWidgets[64385]
#define sipNameNr___isub__ 64394
#define sipName___isub__ &sipStrings_QtWidgets[64394]
#define sipNameNr_timeSpec 64403
#define sipName_timeSpec &sipStrings_QtWidgets[64403]
#define sipNameNr_accepted 64412
#define sipName_accepted &sipStrings_QtWidgets[64412]
#define sipNameNr_priority 64421
#define sipName_priority &sipStrings_QtWidgets[64421]
#define sipNameNr_setFlags 64430
#define sipName_setFlags &sipStrings_QtWidgets[64430]
#define sipNameNr_isHidden 64439
#define sipName_isHidden &sipStrings_QtWidgets[64439]
#define sipNameNr_contains 64448
#define sipName_contains &sipStrings_QtWidgets[64448]
#define sipNameNr___iadd__ 64457
#define sipName___iadd__ &sipStrings_QtWidgets[64457]
#define sipNameNr_isActive 64466
#define sipName_isActive &sipStrings_QtWidgets[64466]
#define sipNameNr_moveRows 60661
#define sipName_moveRows &sipStrings_QtWidgets[60661]
#define sipNameNr_mimeData 64475
#define sipName_mimeData &sipStrings_QtWidgets[64475]
#define sipNameNr_itemData 64484
#define sipName_itemData &sipStrings_QtWidgets[64484]
#define sipNameNr_rowCount 64493
#define sipName_rowCount &sipStrings_QtWidgets[64493]
#define sipNameNr_finished 64502
#define sipName_finished &sipStrings_QtWidgets[64502]
#define sipNameNr_NonModal 64511
#define sipName_NonModal &sipStrings_QtWidgets[64511]
#define sipNameNr_NoButton 31142
#define sipName_NoButton &sipStrings_QtWidgets[31142]
#define sipNameNr___hash__ 64520
#define sipName___hash__ &sipStrings_QtWidgets[64520]
#define sipNameNr___bool__ 64529
#define sipName___bool__ &sipStrings_QtWidgets[64529]
#define sipNameNr___ixor__ 64538
#define sipName___ixor__ &sipStrings_QtWidgets[64538]
#define sipNameNr___iand__ 64547
#define sipName___iand__ &sipStrings_QtWidgets[64547]
#define sipNameNr_pageIds 64556
#define sipName_pageIds &sipStrings_QtWidgets[64556]
#define sipNameNr_startId 64564
#define sipName_startId &sipStrings_QtWidgets[64564]
#define sipNameNr_setPage 64572
#define sipName_setPage &sipStrings_QtWidgets[64572]
#define sipNameNr_addPage 64580
#define sipName_addPage &sipStrings_QtWidgets[64580]
#define sipNameNr_QWizard 64588
#define sipName_QWizard &sipStrings_QtWidgets[64588]
#define sipNameNr_childAt 64596
#define sipName_childAt &sipStrings_QtWidgets[64596]
#define sipNameNr_mapFrom 64604
#define sipName_mapFrom &sipStrings_QtWidgets[64604]
#define sipNameNr_isClean 64612
#define sipName_isClean &sipStrings_QtWidgets[64612]
#define sipNameNr_canRedo 64620
#define sipName_canRedo &sipStrings_QtWidgets[64620]
#define sipNameNr_canUndo 64628
#define sipName_canUndo &sipStrings_QtWidgets[64628]
#define sipNameNr_Enabled 7844
#define sipName_Enabled &sipStrings_QtWidgets[7844]
#define sipNameNr_drawRow 64636
#define sipName_drawRow &sipStrings_QtWidgets[64636]
#define sipNameNr_AutoAll 64644
#define sipName_AutoAll &sipStrings_QtWidgets[64644]
#define sipNameNr_forward 64652
#define sipName_forward &sipStrings_QtWidgets[64652]
#define sipNameNr_setSpan 64660
#define sipName_setSpan &sipStrings_QtWidgets[64660]
#define sipNameNr_showRow 64668
#define sipName_showRow &sipStrings_QtWidgets[64668]
#define sipNameNr_hideRow 64676
#define sipName_hideRow &sipStrings_QtWidgets[64676]
#define sipNameNr_moveTab 61036
#define sipName_moveTab &sipStrings_QtWidgets[61036]
#define sipNameNr_tabRect 64684
#define sipName_tabRect &sipStrings_QtWidgets[64684]
#define sipNameNr_tabData 64692
#define sipName_tabData &sipStrings_QtWidgets[64692]
#define sipNameNr_tabIcon 64700
#define sipName_tabIcon &sipStrings_QtWidgets[64700]
#define sipNameNr_tabText 64708
#define sipName_tabText &sipStrings_QtWidgets[64708]
#define sipNameNr_QTabBar 64716
#define sipName_QTabBar &sipStrings_QtWidgets[64716]
#define sipNameNr_Context 29585
#define sipName_Context &sipStrings_QtWidgets[29585]
#define sipNameNr_Movable 17487
#define sipName_Movable &sipStrings_QtWidgets[17487]
#define sipNameNr_SH_Mask 64724
#define sipName_SH_Mask &sipStrings_QtWidgets[64724]
#define sipNameNr_OnlyOne 64732
#define sipName_OnlyOne &sipStrings_QtWidgets[64732]
#define sipNameNr_TearOff 64740
#define sipName_TearOff &sipStrings_QtWidgets[64740]
#define sipNameNr_SubMenu 64748
#define sipName_SubMenu &sipStrings_QtWidgets[64748]
#define sipNameNr_HasMenu 64756
#define sipName_HasMenu &sipStrings_QtWidgets[64756]
#define sipNameNr_Rounded 64764
#define sipName_Rounded &sipStrings_QtWidgets[64764]
#define sipNameNr_CT_Menu 64772
#define sipName_CT_Menu &sipStrings_QtWidgets[64772]
#define sipNameNr_SC_None 64780
#define sipName_SC_None &sipStrings_QtWidgets[64780]
#define sipNameNr_CC_Dial 64788
#define sipName_CC_Dial &sipStrings_QtWidgets[64788]
#define sipNameNr_repaint 64796
#define sipName_repaint &sipStrings_QtWidgets[64796]
#define sipNameNr_NoTicks 64804
#define sipName_NoTicks &sipStrings_QtWidgets[64804]
#define sipNameNr_QSlider 64812
#define sipName_QSlider &sipStrings_QtWidgets[64812]
#define sipNameNr_SpinBox 24149
#define sipName_SpinBox &sipStrings_QtWidgets[24149]
#define sipNameNr_Ignored 49732
#define sipName_Ignored &sipStrings_QtWidgets[49732]
#define sipNameNr_Maximum 35835
#define sipName_Maximum &sipStrings_QtWidgets[35835]
#define sipNameNr_Minimum 35852
#define sipName_Minimum &sipStrings_QtWidgets[35852]
#define sipNameNr_Pressed 44307
#define sipName_Pressed &sipStrings_QtWidgets[44307]
#define sipNameNr_zoomOut 64820
#define sipName_zoomOut &sipStrings_QtWidgets[64820]
#define sipNameNr_Default 43707
#define sipName_Default &sipStrings_QtWidgets[43707]
#define sipNameNr_Warning 21376
#define sipName_Warning &sipStrings_QtWidgets[21376]
#define sipNameNr_addMenu 64828
#define sipName_addMenu &sipStrings_QtWidgets[64828]
#define sipNameNr_mdiArea 64836
#define sipName_mdiArea &sipStrings_QtWidgets[64836]
#define sipNameNr_setFlow 64844
#define sipName_setFlow &sipStrings_QtWidgets[64844]
#define sipNameNr_Batched 64852
#define sipName_Batched &sipStrings_QtWidgets[64852]
#define sipNameNr_display 64860
#define sipName_display &sipStrings_QtWidgets[64860]
#define sipNameNr_Outline 64868
#define sipName_Outline &sipStrings_QtWidgets[64868]
#define sipNameNr_menuBar 64876
#define sipName_menuBar &sipStrings_QtWidgets[64876]
#define sipNameNr_intStep 64884
#define sipName_intStep &sipStrings_QtWidgets[64884]
#define sipNameNr_getItem 34594
#define sipName_getItem &sipStrings_QtWidgets[34594]
#define sipNameNr_getText 64892
#define sipName_getText &sipStrings_QtWidgets[64892]
#define sipNameNr_movable 64900
#define sipName_movable &sipStrings_QtWidgets[64900]
#define sipNameNr_setFlat 64908
#define sipName_setFlat &sipStrings_QtWidgets[64908]
#define sipNameNr_setAxis 64916
#define sipName_setAxis &sipStrings_QtWidgets[64916]
#define sipNameNr_applyTo 64924
#define sipName_applyTo &sipStrings_QtWidgets[64924]
#define sipNameNr_addLine 64932
#define sipName_addLine &sipStrings_QtWidgets[64932]
#define sipNameNr_NoIndex 64940
#define sipName_NoIndex &sipStrings_QtWidgets[64940]
#define sipNameNr_vPolicy 64948
#define sipName_vPolicy &sipStrings_QtWidgets[64948]
#define sipNameNr_hPolicy 6258
#define sipName_hPolicy &sipStrings_QtWidgets[6258]
#define sipNameNr_isPanel 64956
#define sipName_isPanel &sipStrings_QtWidgets[64956]
#define sipNameNr_advance 64964
#define sipName_advance &sipStrings_QtWidgets[64964]
#define sipNameNr_yMargin 64972
#define sipName_yMargin &sipStrings_QtWidgets[64972]
#define sipNameNr_xMargin 64980
#define sipName_xMargin &sipStrings_QtWidgets[64980]
#define sipNameNr_NoCache 64988
#define sipName_NoCache &sipStrings_QtWidgets[64988]
#define sipNameNr_gesture 64996
#define sipName_gesture &sipStrings_QtWidgets[64996]
#define sipNameNr_NoFrame 65004
#define sipName_NoFrame &sipStrings_QtWidgets[65004]
#define sipNameNr_getFont 65012
#define sipName_getFont &sipStrings_QtWidgets[65012]
#define sipNameNr_Network 65020
#define sipName_Network &sipStrings_QtWidgets[65020]
#define sipNameNr_history 65028
#define sipName_history &sipStrings_QtWidgets[65028]
#define sipNameNr_caption 65036
#define sipName_caption &sipStrings_QtWidgets[65036]
#define sipNameNr_Options 5169
#define sipName_Options &sipStrings_QtWidgets[5169]
#define sipNameNr_AnyFile 65044
#define sipName_AnyFile &sipStrings_QtWidgets[65044]
#define sipNameNr_Discard 65052
#define sipName_Discard &sipStrings_QtWidgets[65052]
#define sipNameNr_NoToAll 65060
#define sipName_NoToAll &sipStrings_QtWidgets[65060]
#define sipNameNr_SaveAll 65068
#define sipName_SaveAll &sipStrings_QtWidgets[65068]
#define sipNameNr_YesRole 65076
#define sipName_YesRole &sipStrings_QtWidgets[65076]
#define sipNameNr_Section 17510
#define sipName_Section &sipStrings_QtWidgets[17510]
#define sipNameNr_toFirst 65084
#define sipName_toFirst &sipStrings_QtWidgets[65084]
#define sipNameNr_setView 65092
#define sipName_setView &sipStrings_QtWidgets[65092]
#define sipNameNr_initial 65100
#define sipName_initial &sipStrings_QtWidgets[65100]
#define sipNameNr_QDialog 65108
#define sipName_QDialog &sipStrings_QtWidgets[65108]
#define sipNameNr_addItem 65116
#define sipName_addItem &sipStrings_QtWidgets[65116]
#define sipNameNr_QLayout 65124
#define sipName_QLayout &sipStrings_QtWidgets[65124]
#define sipNameNr_aboutQt 65132
#define sipName_aboutQt &sipStrings_QtWidgets[65132]
#define sipNameNr_desktop 65140
#define sipName_desktop &sipStrings_QtWidgets[65140]
#define sipNameNr_hovered 65148
#define sipName_hovered &sipStrings_QtWidgets[65148]
#define sipNameNr_Trigger 7064
#define sipName_Trigger &sipStrings_QtWidgets[7064]
#define sipNameNr_setMenu 65156
#define sipName_setMenu &sipStrings_QtWidgets[65156]
#define sipNameNr_NoState 65164
#define sipName_NoState &sipStrings_QtWidgets[65164]
#define sipNameNr_trigger 65172
#define sipName_trigger &sipStrings_QtWidgets[65172]
#define sipNameNr_MoveEnd 65180
#define sipName_MoveEnd &sipStrings_QtWidgets[65180]
#define sipNameNr_indexAt 65188
#define sipName_indexAt &sipStrings_QtWidgets[65188]
#define sipNameNr_toggled 65196
#define sipName_toggled &sipStrings_QtWidgets[65196]
#define sipNameNr_clicked 65204
#define sipName_clicked &sipStrings_QtWidgets[65204]
#define sipNameNr_checked 65212
#define sipName_checked &sipStrings_QtWidgets[65212]
#define sipNameNr_pressed 65220
#define sipName_pressed &sipStrings_QtWidgets[65220]
#define sipNameNr_setDown 65228
#define sipName_setDown &sipStrings_QtWidgets[65228]
#define sipNameNr_isModal 65236
#define sipName_isModal &sipStrings_QtWidgets[65236]
#define sipNameNr_minimum 65244
#define sipName_minimum &sipStrings_QtWidgets[65244]
#define sipNameNr_rowSpan 65252
#define sipName_rowSpan &sipStrings_QtWidgets[65252]
#define sipNameNr_maximum 65260
#define sipName_maximum &sipStrings_QtWidgets[65260]
#define sipNameNr_setIcon 65268
#define sipName_setIcon &sipStrings_QtWidgets[65268]
#define sipNameNr_toolTip 65276
#define sipName_toolTip &sipStrings_QtWidgets[65276]
#define sipNameNr_takeRow 65284
#define sipName_takeRow &sipStrings_QtWidgets[65284]
#define sipNameNr_setItem 65292
#define sipName_setItem &sipStrings_QtWidgets[65292]
#define sipNameNr_setMask 65300
#define sipName_setMask &sipStrings_QtWidgets[65300]
#define sipNameNr_addText 65308
#define sipName_addText &sipStrings_QtWidgets[65308]
#define sipNameNr_polygon 65316
#define sipName_polygon &sipStrings_QtWidgets[65316]
#define sipNameNr_addRect 65324
#define sipName_addRect &sipStrings_QtWidgets[65324]
#define sipNameNr_combine 65332
#define sipName_combine &sipStrings_QtWidgets[65332]
#define sipNameNr_picture 65340
#define sipName_picture &sipStrings_QtWidgets[65340]
#define sipNameNr_setMode 65348
#define sipName_setMode &sipStrings_QtWidgets[65348]
#define sipNameNr_paintGL 65356
#define sipName_paintGL &sipStrings_QtWidgets[65356]
#define sipNameNr_opacity 65364
#define sipName_opacity &sipStrings_QtWidgets[65364]
#define sipNameNr_yOffset 65372
#define sipName_yOffset &sipStrings_QtWidgets[65372]
#define sipNameNr_xOffset 65380
#define sipName_xOffset &sipStrings_QtWidgets[65380]
#define sipNameNr_destroy 65388
#define sipName_destroy &sipStrings_QtWidgets[65388]
#define sipNameNr_resized 65396
#define sipName_resized &sipStrings_QtWidgets[65396]
#define sipNameNr_devType 65404
#define sipName_devType &sipStrings_QtWidgets[65404]
#define sipNameNr_setFont 65412
#define sipName_setFont &sipStrings_QtWidgets[65412]
#define sipNameNr_setFlag 65420
#define sipName_setFlag &sipStrings_QtWidgets[65420]
#define sipNameNr_spacing 65428
#define sipName_spacing &sipStrings_QtWidgets[65428]
#define sipNameNr_stretch 65436
#define sipName_stretch &sipStrings_QtWidgets[65436]
#define sipNameNr_Stretch 22090
#define sipName_Stretch &sipStrings_QtWidgets[22090]
#define sipNameNr_QAction 65444
#define sipName_QAction &sipStrings_QtWidgets[65444]
#define sipNameNr_lastPos 65452
#define sipName_lastPos &sipStrings_QtWidgets[65452]
#define sipNameNr_actions 65460
#define sipName_actions &sipStrings_QtWidgets[65460]
#define sipNameNr_oldSize 65468
#define sipName_oldSize &sipStrings_QtWidgets[65468]
#define sipNameNr_buttons 65476
#define sipName_buttons &sipStrings_QtWidgets[65476]
#define sipNameNr_hotSpot 65484
#define sipName_hotSpot &sipStrings_QtWidgets[65484]
#define sipNameNr_changed 65492
#define sipName_changed &sipStrings_QtWidgets[65492]
#define sipNameNr_newSize 65500
#define sipName_newSize &sipStrings_QtWidgets[65500]
#define sipNameNr_hitTest 65508
#define sipName_hitTest &sipStrings_QtWidgets[65508]
#define sipNameNr_palette 65516
#define sipName_palette &sipStrings_QtWidgets[65516]
#define sipNameNr_QWidget 65524
#define sipName_QWidget &sipStrings_QtWidgets[65524]
#define sipNameNr_setRect 65532
#define sipName_setRect &sipStrings_QtWidgets[65532]
#define sipNameNr_Unknown 65540
#define sipName_Unknown &sipStrings_QtWidgets[65540]
#define sipNameNr_setHtml 65548
#define sipName_setHtml &sipStrings_QtWidgets[65548]
#define sipNameNr_setText 65556
#define sipName_setText &sipStrings_QtWidgets[65556]
#define sipNameNr_warning 65564
#define sipName_warning &sipStrings_QtWidgets[65564]
#define sipNameNr_setLine 65572
#define sipName_setLine &sipStrings_QtWidgets[65572]
#define sipNameNr_variant 65580
#define sipName_variant &sipStrings_QtWidgets[65580]
#define sipNameNr_command 65588
#define sipName_command &sipStrings_QtWidgets[65588]
#define sipNameNr_addPath 65596
#define sipName_addPath &sipStrings_QtWidgets[65596]
#define sipNameNr_timeout 65604
#define sipName_timeout &sipStrings_QtWidgets[65604]
#define sipNameNr_refresh 65612
#define sipName_refresh &sipStrings_QtWidgets[65612]
#define sipNameNr_sorting 65620
#define sipName_sorting &sipStrings_QtWidgets[65620]
#define sipNameNr_setPath 65628
#define sipName_setPath &sipStrings_QtWidgets[65628]
#define sipNameNr_current 65636
#define sipName_current &sipStrings_QtWidgets[65636]
#define sipNameNr_setTime 65644
#define sipName_setTime &sipStrings_QtWidgets[65644]
#define sipNameNr_restart 65652
#define sipName_restart &sipStrings_QtWidgets[65652]
#define sipNameNr_setDate 65660
#define sipName_setDate &sipStrings_QtWidgets[65660]
#define sipNameNr_Version 89
#define sipName_Version &sipStrings_QtWidgets[89]
#define sipNameNr_enabled 65668
#define sipName_enabled &sipStrings_QtWidgets[65668]
#define sipNameNr_version 65676
#define sipName_version &sipStrings_QtWidgets[65676]
#define sipNameNr_context 65684
#define sipName_context &sipStrings_QtWidgets[65684]
#define sipNameNr_Invalid 65692
#define sipName_Invalid &sipStrings_QtWidgets[65692]
#define sipNameNr_indexOf 65700
#define sipName_indexOf &sipStrings_QtWidgets[65700]
#define sipNameNr_isEmpty 65708
#define sipName_isEmpty &sipStrings_QtWidgets[65708]
#define sipNameNr___len__ 65716
#define sipName___len__ &sipStrings_QtWidgets[65716]
#define sipNameNr_entered 65724
#define sipName_entered &sipStrings_QtWidgets[65724]
#define sipNameNr_options 65732
#define sipName_options &sipStrings_QtWidgets[65732]
#define sipNameNr_section 65740
#define sipName_section &sipStrings_QtWidgets[65740]
#define sipNameNr_setData 65748
#define sipName_setData &sipStrings_QtWidgets[65748]
#define sipNameNr_sibling 65756
#define sipName_sibling &sipStrings_QtWidgets[65756]
#define sipNameNr_isValid 65764
#define sipName_isValid &sipStrings_QtWidgets[65764]
#define sipNameNr_message 65772
#define sipName_message &sipStrings_QtWidgets[65772]
#define sipNameNr_Checked 58187
#define sipName_Checked &sipStrings_QtWidgets[58187]
#define sipNameNr_Desktop 36957
#define sipName_Desktop &sipStrings_QtWidgets[36957]
#define sipNameNr___xor__ 65780
#define sipName___xor__ &sipStrings_QtWidgets[65780]
#define sipNameNr___ior__ 65788
#define sipName___ior__ &sipStrings_QtWidgets[65788]
#define sipNameNr___and__ 65796
#define sipName___and__ &sipStrings_QtWidgets[65796]
#define sipNameNr___int__ 65804
#define sipName___int__ &sipStrings_QtWidgets[65804]
#define sipNameNr_wizard 65812
#define sipName_wizard &sipStrings_QtWidgets[65812]
#define sipNameNr_nextId 65819
#define sipName_nextId &sipStrings_QtWidgets[65819]
#define sipNameNr_expand 62884
#define sipName_expand &sipStrings_QtWidgets[62884]
#define sipNameNr_reload 65826
#define sipName_reload &sipStrings_QtWidgets[65826]
#define sipNameNr_tabBar 65833
#define sipName_tabBar &sipStrings_QtWidgets[65833]
#define sipNameNr_topRow 65840
#define sipName_topRow &sipStrings_QtWidgets[65840]
#define sipNameNr_addTab 65847
#define sipName_addTab &sipStrings_QtWidgets[65847]
#define sipNameNr_Bottom 37791
#define sipName_Bottom &sipStrings_QtWidgets[37791]
#define sipNameNr_Margin 4570
#define sipName_Margin &sipStrings_QtWidgets[4570]
#define sipNameNr_SortUp 65854
#define sipName_SortUp &sipStrings_QtWidgets[65854]
#define sipNameNr_Middle 65861
#define sipName_Middle &sipStrings_QtWidgets[65861]
#define sipNameNr_SO_Tab 65868
#define sipName_SO_Tab &sipStrings_QtWidgets[65868]
#define sipNameNr_SC_All 65875
#define sipName_SC_All &sipStrings_QtWidgets[65875]
#define sipNameNr_opaque 65882
#define sipName_opaque &sipStrings_QtWidgets[65882]
#define sipNameNr_finish 65889
#define sipName_finish &sipStrings_QtWidgets[65889]
#define sipNameNr_Slider 5071
#define sipName_Slider &sipStrings_QtWidgets[5071]
#define sipNameNr_Policy 2181
#define sipName_Policy &sipStrings_QtWidgets[2181]
#define sipNameNr_setBar 65896
#define sipName_setBar &sipStrings_QtWidgets[65896]
#define sipNameNr_zoomIn 65903
#define sipName_zoomIn &sipStrings_QtWidgets[65903]
#define sipNameNr_Escape 65910
#define sipName_Escape &sipStrings_QtWidgets[65910]
#define sipNameNr_YesAll 65917
#define sipName_YesAll &sipStrings_QtWidgets[65917]
#define sipNameNr_NoIcon 65924
#define sipName_NoIcon &sipStrings_QtWidgets[65924]
#define sipNameNr_corner 65931
#define sipName_corner &sipStrings_QtWidgets[65931]
#define sipNameNr_Adjust 65938
#define sipName_Adjust &sipStrings_QtWidgets[65938]
#define sipNameNr_Static 65945
#define sipName_Static &sipStrings_QtWidgets[65945]
#define sipNameNr_NoEcho 65952
#define sipName_NoEcho &sipStrings_QtWidgets[65952]
#define sipNameNr_Filled 65959
#define sipName_Filled &sipStrings_QtWidgets[65959]
#define sipNameNr_QLabel 65966
#define sipName_QLabel &sipStrings_QtWidgets[65966]
#define sipNameNr_getInt 65973
#define sipName_getInt &sipStrings_QtWidgets[65973]
#define sipNameNr_isFlat 65980
#define sipName_isFlat &sipStrings_QtWidgets[65980]
#define sipNameNr_NoDrag 65987
#define sipName_NoDrag &sipStrings_QtWidgets[65987]
#define sipNameNr_zScale 65994
#define sipName_zScale &sipStrings_QtWidgets[65994]
#define sipNameNr_yScale 66001
#define sipName_yScale &sipStrings_QtWidgets[66001]
#define sipNameNr_xScale 66008
#define sipName_xScale &sipStrings_QtWidgets[66008]
#define sipNameNr_newPos 66015
#define sipName_newPos &sipStrings_QtWidgets[66015]
#define sipNameNr_render 66022
#define sipName_render &sipStrings_QtWidgets[66022]
#define sipNameNr_zValue 66029
#define sipName_zValue &sipStrings_QtWidgets[66029]
#define sipNameNr_moveBy 66036
#define sipName_moveBy &sipStrings_QtWidgets[66036]
#define sipNameNr_Result 10683
#define sipName_Result &sipStrings_QtWidgets[10683]
#define sipNameNr_Sunken 51677
#define sipName_Sunken &sipStrings_QtWidgets[51677]
#define sipNameNr_Raised 51690
#define sipName_Raised &sipStrings_QtWidgets[51690]
#define sipNameNr_addRow 66043
#define sipName_addRow &sipStrings_QtWidgets[66043]
#define sipNameNr_Folder 16614
#define sipName_Folder &sipStrings_QtWidgets[16614]
#define sipNameNr_Option 5688
#define sipName_Option &sipStrings_QtWidgets[5688]
#define sipNameNr_Reject 66050
#define sipName_Reject &sipStrings_QtWidgets[66050]
#define sipNameNr_Accept 66057
#define sipName_Accept &sipStrings_QtWidgets[66057]
#define sipNameNr_LookIn 66064
#define sipName_LookIn &sipStrings_QtWidgets[66064]
#define sipNameNr_Detail 66071
#define sipName_Detail &sipStrings_QtWidgets[66071]
#define sipNameNr_sunken 66078
#define sipName_sunken &sipStrings_QtWidgets[66078]
#define sipNameNr_Ignore 66085
#define sipName_Ignore &sipStrings_QtWidgets[66085]
#define sipNameNr_reject 66092
#define sipName_reject &sipStrings_QtWidgets[66092]
#define sipNameNr_toNext 66099
#define sipName_toNext &sipStrings_QtWidgets[66099]
#define sipNameNr_toLast 66106
#define sipName_toLast &sipStrings_QtWidgets[66106]
#define sipNameNr_polish 63739
#define sipName_polish &sipStrings_QtWidgets[63739]
#define sipNameNr_QStyle 66113
#define sipName_QStyle &sipStrings_QtWidgets[66113]
#define sipNameNr_itemAt 66120
#define sipName_itemAt &sipStrings_QtWidgets[66120]
#define sipNameNr_stepUp 66127
#define sipName_stepUp &sipStrings_QtWidgets[66127]
#define sipNameNr_stepBy 66134
#define sipName_stepBy &sipStrings_QtWidgets[66134]
#define sipNameNr_QFrame 66141
#define sipName_QFrame &sipStrings_QtWidgets[66141]
#define sipNameNr_OnItem 66148
#define sipName_OnItem &sipStrings_QtWidgets[66148]
#define sipNameNr_MoveUp 66155
#define sipName_MoveUp &sipStrings_QtWidgets[66155]
#define sipNameNr_NoHint 66162
#define sipName_NoHint &sipStrings_QtWidgets[66162]
#define sipNameNr_toggle 66169
#define sipName_toggle &sipStrings_QtWidgets[66169]
#define sipNameNr_isDown 66176
#define sipName_isDown &sipStrings_QtWidgets[66176]
#define sipNameNr_raise_ 66183
#define sipName_raise_ &sipStrings_QtWidgets[66183]
#define sipNameNr_NoWrap 66190
#define sipName_NoWrap &sipStrings_QtWidgets[66190]
#define sipNameNr_indent 66197
#define sipName_indent &sipStrings_QtWidgets[66197]
#define sipNameNr_stacks 66204
#define sipName_stacks &sipStrings_QtWidgets[66204]
#define sipNameNr_print_ 66211
#define sipName_print_ &sipStrings_QtWidgets[66211]
#define sipNameNr_toHtml 66218
#define sipName_toHtml &sipStrings_QtWidgets[66218]
#define sipNameNr_anchor 66225
#define sipName_anchor &sipStrings_QtWidgets[66225]
#define sipNameNr_layout 66232
#define sipName_layout &sipStrings_QtWidgets[66232]
#define sipNameNr_header 66239
#define sipName_header &sipStrings_QtWidgets[66239]
#define sipNameNr_NoRole 66246
#define sipName_NoRole &sipStrings_QtWidgets[66246]
#define sipNameNr_Shadow 44923
#define sipName_Shadow &sipStrings_QtWidgets[44923]
#define sipNameNr_setPen 66253
#define sipName_setPen &sipStrings_QtWidgets[66253]
#define sipNameNr_origin 66260
#define sipName_origin &sipStrings_QtWidgets[66260]
#define sipNameNr_layers 66267
#define sipName_layers &sipStrings_QtWidgets[66267]
#define sipNameNr_rotate 66274
#define sipName_rotate &sipStrings_QtWidgets[66274]
#define sipNameNr_Cancel 66281
#define sipName_Cancel &sipStrings_QtWidgets[66281]
#define sipNameNr_metric 66288
#define sipName_metric &sipStrings_QtWidgets[66288]
#define sipNameNr_Normal 60124
#define sipName_Normal &sipStrings_QtWidgets[60124]
#define sipNameNr_Reason 2105
#define sipName_Reason &sipStrings_QtWidgets[2105]
#define sipNameNr_reason 66295
#define sipName_reason &sipStrings_QtWidgets[66295]
#define sipNameNr_oldPos 66302
#define sipName_oldPos &sipStrings_QtWidgets[66302]
#define sipNameNr_button 66309
#define sipName_button &sipStrings_QtWidgets[66309]
#define sipNameNr_source 53861
#define sipName_source &sipStrings_QtWidgets[53861]
#define sipNameNr_screen 66316
#define sipName_screen &sipStrings_QtWidgets[66316]
#define sipNameNr_setPos 66323
#define sipName_setPos &sipStrings_QtWidgets[66323]
#define sipNameNr_pixmap 66330
#define sipName_pixmap &sipStrings_QtWidgets[66330]
#define sipNameNr_scroll 66337
#define sipName_scroll &sipStrings_QtWidgets[66337]
#define sipNameNr_region 66344
#define sipName_region &sipStrings_QtWidgets[66344]
#define sipNameNr_window 66351
#define sipName_window &sipStrings_QtWidgets[66351]
#define sipNameNr_update 66358
#define sipName_update &sipStrings_QtWidgets[66358]
#define sipNameNr_cursor 66365
#define sipName_cursor &sipStrings_QtWidgets[66365]
#define sipNameNr_widget 66372
#define sipName_widget &sipStrings_QtWidgets[66372]
#define sipNameNr_cancel 66379
#define sipName_cancel &sipStrings_QtWidgets[66379]
#define sipNameNr_create 66386
#define sipName_create &sipStrings_QtWidgets[66386]
#define sipNameNr_member 66393
#define sipName_member &sipStrings_QtWidgets[66393]
#define sipNameNr_setKey 66400
#define sipName_setKey &sipStrings_QtWidgets[66400]
#define sipNameNr_margin 66407
#define sipName_margin &sipStrings_QtWidgets[66407]
#define sipNameNr_takeAt 66414
#define sipName_takeAt &sipStrings_QtWidgets[66414]
#define sipNameNr_height 66421
#define sipName_height &sipStrings_QtWidgets[66421]
#define sipNameNr_suffix 66428
#define sipName_suffix &sipStrings_QtWidgets[66428]
#define sipNameNr_offset 66435
#define sipName_offset &sipStrings_QtWidgets[66435]
#define sipNameNr_handle 66442
#define sipName_handle &sipStrings_QtWidgets[66442]
#define sipNameNr_Custom 66449
#define sipName_Custom &sipStrings_QtWidgets[66449]
#define sipNameNr_prefix 66456
#define sipName_prefix &sipStrings_QtWidgets[66456]
#define sipNameNr_filter 66463
#define sipName_filter &sipStrings_QtWidgets[66463]
#define sipNameNr_Hidden 15072
#define sipName_Hidden &sipStrings_QtWidgets[15072]
#define sipNameNr_ignore 66470
#define sipName_ignore &sipStrings_QtWidgets[66470]
#define sipNameNr_accept 66477
#define sipName_accept &sipStrings_QtWidgets[66477]
#define sipNameNr_notify 66484
#define sipName_notify &sipStrings_QtWidgets[66484]
#define sipNameNr_option 66491
#define sipName_option &sipStrings_QtWidgets[66491]
#define sipNameNr_locale 66498
#define sipName_locale &sipStrings_QtWidgets[66498]
#define sipNameNr_system 66505
#define sipName_system &sipStrings_QtWidgets[66505]
#define sipNameNr_setNum 66512
#define sipName_setNum &sipStrings_QtWidgets[66512]
#define sipNameNr_format 63118
#define sipName_format &sipStrings_QtWidgets[63118]
#define sipNameNr___ge__ 66519
#define sipName___ge__ &sipStrings_QtWidgets[66519]
#define sipNameNr_remove 66526
#define sipName_remove &sipStrings_QtWidgets[66526]
#define sipNameNr_insert 66533
#define sipName_insert &sipStrings_QtWidgets[66533]
#define sipNameNr_append 66540
#define sipName_append &sipStrings_QtWidgets[66540]
#define sipNameNr_length 66547
#define sipName_length &sipStrings_QtWidgets[66547]
#define sipNameNr_resize 66554
#define sipName_resize &sipStrings_QtWidgets[66554]
#define sipNameNr_target 66561
#define sipName_target &sipStrings_QtWidgets[66561]
#define sipNameNr_active 44443
#define sipName_active &sipStrings_QtWidgets[44443]
#define sipNameNr_revert 66568
#define sipName_revert &sipStrings_QtWidgets[66568]
#define sipNameNr_submit 66575
#define sipName_submit &sipStrings_QtWidgets[66575]
#define sipNameNr_action 66582
#define sipName_action &sipStrings_QtWidgets[66582]
#define sipNameNr___lt__ 66589
#define sipName___lt__ &sipStrings_QtWidgets[66589]
#define sipNameNr_column 66596
#define sipName_column &sipStrings_QtWidgets[66596]
#define sipNameNr_result 66603
#define sipName_result &sipStrings_QtWidgets[66603]
#define sipNameNr_parent 66610
#define sipName_parent &sipStrings_QtWidgets[66610]
#define sipNameNr___ne__ 66617
#define sipName___ne__ &sipStrings_QtWidgets[66617]
#define sipNameNr___eq__ 66624
#define sipName___eq__ &sipStrings_QtWidgets[66624]
#define sipNameNr___or__ 66631
#define sipName___or__ &sipStrings_QtWidgets[66631]
#define sipNameNr_mapTo 66638
#define sipName_mapTo &sipStrings_QtWidgets[66638]
#define sipNameNr_stack 66644
#define sipName_stack &sipStrings_QtWidgets[66644]
#define sipNameNr_South 38561
#define sipName_South &sipStrings_QtWidgets[38561]
#define sipNameNr_North 38577
#define sipName_North &sipStrings_QtWidgets[38577]
#define sipNameNr_rowAt 66650
#define sipName_rowAt &sipStrings_QtWidgets[66650]
#define sipNameNr_tabAt 66656
#define sipName_tabAt &sipStrings_QtWidgets[66656]
#define sipNameNr_Arrow 9316
#define sipName_Arrow &sipStrings_QtWidgets[9316]
#define sipNameNr_proxy 66662
#define sipName_proxy &sipStrings_QtWidgets[66662]
#define sipNameNr_Label 13840
#define sipName_Label &sipStrings_QtWidgets[13840]
#define sipNameNr_Frame 6229
#define sipName_Frame &sipStrings_QtWidgets[6229]
#define sipNameNr_Fps20 66668
#define sipName_Fps20 &sipStrings_QtWidgets[66668]
#define sipNameNr_Fps30 66674
#define sipName_Fps30 &sipStrings_QtWidgets[66674]
#define sipNameNr_Fps60 66680
#define sipName_Fps60 &sipStrings_QtWidgets[66680]
#define sipNameNr_Input 8721
#define sipName_Input &sipStrings_QtWidgets[8721]
#define sipNameNr_about 66686
#define sipName_about &sipStrings_QtWidgets[66686]
#define sipNameNr_NoAll 66692
#define sipName_NoAll &sipStrings_QtWidgets[66692]
#define sipNameNr_QMenu 66698
#define sipName_QMenu &sipStrings_QtWidgets[66698]
#define sipNameNr_paste 66704
#define sipName_paste &sipStrings_QtWidgets[66704]
#define sipNameNr_movie 66710
#define sipName_movie &sipStrings_QtWidgets[66710]
#define sipNameNr_Fixed 66716
#define sipName_Fixed &sipStrings_QtWidgets[66716]
#define sipNameNr_views 66722
#define sipName_views &sipStrings_QtWidgets[66722]
#define sipNameNr_panel 66728
#define sipName_panel &sipStrings_QtWidgets[66728]
#define sipNameNr_scene 66734
#define sipName_scene &sipStrings_QtWidgets[66734]
#define sipNameNr_NoPad 66740
#define sipName_NoPad &sipStrings_QtWidgets[66740]
#define sipNameNr_delta 66746
#define sipName_delta &sipStrings_QtWidgets[66746]
#define sipNameNr_VLine 66752
#define sipName_VLine &sipStrings_QtWidgets[66752]
#define sipNameNr_HLine 66758
#define sipName_HLine &sipStrings_QtWidgets[66758]
#define sipNameNr_Panel 4367
#define sipName_Panel &sipStrings_QtWidgets[4367]
#define sipNameNr_Shape 9624
#define sipName_Shape &sipStrings_QtWidgets[9624]
#define sipNameNr_Plain 66764
#define sipName_Plain &sipStrings_QtWidgets[66764]
#define sipNameNr_field 66770
#define sipName_field &sipStrings_QtWidgets[66770]
#define sipNameNr_Drive 66776
#define sipName_Drive &sipStrings_QtWidgets[66776]
#define sipNameNr_Roles 15817
#define sipName_Roles &sipStrings_QtWidgets[15817]
#define sipNameNr_Reset 51899
#define sipName_Reset &sipStrings_QtWidgets[51899]
#define sipNameNr_Apply 66782
#define sipName_Apply &sipStrings_QtWidgets[66782]
#define sipNameNr_Retry 66788
#define sipName_Retry &sipStrings_QtWidgets[66788]
#define sipNameNr_Abort 66794
#define sipName_Abort &sipStrings_QtWidgets[66794]
#define sipNameNr_QDial 66800
#define sipName_QDial &sipStrings_QtWidgets[66800]
#define sipNameNr_popup 66806
#define sipName_popup &sipStrings_QtWidgets[66806]
#define sipNameNr_setId 66812
#define sipName_setId &sipStrings_QtWidgets[66812]
#define sipNameNr_hover 66818
#define sipName_hover &sipStrings_QtWidgets[66818]
#define sipNameNr_Hover 66824
#define sipName_Hover &sipStrings_QtWidgets[66824]
#define sipNameNr_steps 66830
#define sipName_steps &sipStrings_QtWidgets[66830]
#define sipNameNr_click 66836
#define sipName_click &sipStrings_QtWidgets[66836]
#define sipNameNr_alert 66842
#define sipName_alert &sipStrings_QtWidgets[66842]
#define sipNameNr_lower 66848
#define sipName_lower &sipStrings_QtWidgets[66848]
#define sipNameNr_winId 66854
#define sipName_winId &sipStrings_QtWidgets[66854]
#define sipNameNr_fixup 66860
#define sipName_fixup &sipStrings_QtWidgets[66860]
#define sipNameNr_print 66866
#define sipName_print &sipStrings_QtWidgets[66866]
#define sipNameNr_Right 9288
#define sipName_Right &sipStrings_QtWidgets[9288]
#define sipNameNr_items 66872
#define sipName_items &sipStrings_QtWidgets[66872]
#define sipNameNr_title 66878
#define sipName_title &sipStrings_QtWidgets[66878]
#define sipNameNr_shear 66884
#define sipName_shear &sipStrings_QtWidgets[66884]
#define sipNameNr_begin 66890
#define sipName_begin &sipStrings_QtWidgets[66890]
#define sipNameNr_depth 66896
#define sipName_depth &sipStrings_QtWidgets[66896]
#define sipNameNr_sizes 10441
#define sipName_sizes &sipStrings_QtWidgets[10441]
#define sipNameNr_clone 66902
#define sipName_clone &sipStrings_QtWidgets[66902]
#define sipNameNr_paint 64798
#define sipName_paint &sipStrings_QtWidgets[64798]
#define sipNameNr_Other 66908
#define sipName_Other &sipStrings_QtWidgets[66908]
#define sipNameNr_Mouse 36058
#define sipName_Mouse &sipStrings_QtWidgets[36058]
#define sipNameNr_brush 66914
#define sipName_brush &sipStrings_QtWidgets[66914]
#define sipNameNr_shape 66920
#define sipName_shape &sipStrings_QtWidgets[66920]
#define sipNameNr_frame 66926
#define sipName_frame &sipStrings_QtWidgets[66926]
#define sipNameNr_scale 66932
#define sipName_scale &sipStrings_QtWidgets[66932]
#define sipNameNr_color 66938
#define sipName_color &sipStrings_QtWidgets[66938]
#define sipNameNr_style 66944
#define sipName_style &sipStrings_QtWidgets[66944]
#define sipNameNr_angle 62348
#define sipName_angle &sipStrings_QtWidgets[62348]
#define sipNameNr_range 66950
#define sipName_range &sipStrings_QtWidgets[66950]
#define sipNameNr_write 23184
#define sipName_write &sipStrings_QtWidgets[23184]
#define sipNameNr_isDir 66956
#define sipName_isDir &sipStrings_QtWidgets[66956]
#define sipNameNr_rmdir 66962
#define sipName_rmdir &sipStrings_QtWidgets[66962]
#define sipNameNr_mkdir 66968
#define sipName_mkdir &sipStrings_QtWidgets[66968]
#define sipNameNr_Close 21945
#define sipName_Close &sipStrings_QtWidgets[21945]
#define sipNameNr_None_ 66974
#define sipName_None_ &sipStrings_QtWidgets[66974]
#define sipNameNr_exec_ 66980
#define sipName_exec_ &sipStrings_QtWidgets[66980]
#define sipNameNr_reset 66986
#define sipName_reset &sipStrings_QtWidgets[66986]
#define sipNameNr_width 66992
#define sipName_width &sipStrings_QtWidgets[66992]
#define sipNameNr_close 66998
#define sipName_close &sipStrings_QtWidgets[66998]
#define sipNameNr_clear 67004
#define sipName_clear &sipStrings_QtWidgets[67004]
#define sipNameNr_match 67010
#define sipName_match &sipStrings_QtWidgets[67010]
#define sipNameNr_buddy 67016
#define sipName_buddy &sipStrings_QtWidgets[67016]
#define sipNameNr_order 17742
#define sipName_order &sipStrings_QtWidgets[17742]
#define sipNameNr_count 67022
#define sipName_count &sipStrings_QtWidgets[67022]
#define sipNameNr_roles 67028
#define sipName_roles &sipStrings_QtWidgets[67028]
#define sipNameNr_value 67034
#define sipName_value &sipStrings_QtWidgets[67034]
#define sipNameNr_index 67040
#define sipName_index &sipStrings_QtWidgets[67040]
#define sipNameNr_model 67046
#define sipName_model &sipStrings_QtWidgets[67046]
#define sipNameNr_child 67052
#define sipName_child &sipStrings_QtWidgets[67052]
#define sipNameNr_flags 67058
#define sipName_flags &sipStrings_QtWidgets[67058]
#define sipNameNr_event 67064
#define sipName_event &sipStrings_QtWidgets[67064]
#define sipNameNr_msecs 67070
#define sipName_msecs &sipStrings_QtWidgets[67070]
#define sipNameNr_group 67076
#define sipName_group &sipStrings_QtWidgets[67076]
#define sipNameNr_state 57514
#define sipName_state &sipStrings_QtWidgets[57514]
#define sipNameNr_State 13990
#define sipName_State &sipStrings_QtWidgets[13990]
#define sipNameNr_back 67082
#define sipName_back &sipStrings_QtWidgets[67082]
#define sipNameNr_page 67087
#define sipName_page &sipStrings_QtWidgets[67087]
#define sipNameNr_push 67092
#define sipName_push &sipStrings_QtWidgets[67092]
#define sipNameNr_East 42825
#define sipName_East &sipStrings_QtWidgets[42825]
#define sipNameNr_West 42840
#define sipName_West &sipStrings_QtWidgets[42840]
#define sipNameNr_Menu 5946
#define sipName_Menu &sipStrings_QtWidgets[5946]
#define sipNameNr_flow 47943
#define sipName_flow &sipStrings_QtWidgets[47943]
#define sipNameNr_Flow 39762
#define sipName_Flow &sipStrings_QtWidgets[39762]
#define sipNameNr_Snap 67097
#define sipName_Snap &sipStrings_QtWidgets[67097]
#define sipNameNr_Free 67102
#define sipName_Free &sipStrings_QtWidgets[67102]
#define sipNameNr_del_ 67107
#define sipName_del_ &sipStrings_QtWidgets[67107]
#define sipNameNr_Flat 64911
#define sipName_Flat &sipStrings_QtWidgets[64911]
#define sipNameNr_echo 67112
#define sipName_echo &sipStrings_QtWidgets[67112]
#define sipNameNr_File 52992
#define sipName_File &sipStrings_QtWidgets[52992]
#define sipNameNr_Help 67117
#define sipName_Help &sipStrings_QtWidgets[67117]
#define sipNameNr_done 67122
#define sipName_done &sipStrings_QtWidgets[67122]
#define sipNameNr_beep 67127
#define sipName_beep &sipStrings_QtWidgets[67127]
#define sipNameNr_qApp 67132
#define sipName_qApp &sipStrings_QtWidgets[67132]
#define sipNameNr_None 58718
#define sipName_None &sipStrings_QtWidgets[58718]
#define sipNameNr_menu 67137
#define sipName_menu &sipStrings_QtWidgets[67137]
#define sipNameNr_edit 67142
#define sipName_edit &sipStrings_QtWidgets[67142]
#define sipNameNr_view 67147
#define sipName_view &sipStrings_QtWidgets[67147]
#define sipNameNr_grab 67152
#define sipName_grab &sipStrings_QtWidgets[67152]
#define sipNameNr_redo 67157
#define sipName_redo &sipStrings_QtWidgets[67157]
#define sipNameNr_undo 67162
#define sipName_undo &sipStrings_QtWidgets[67162]
#define sipNameNr_Down 10388
#define sipName_Down &sipStrings_QtWidgets[10388]
#define sipNameNr_Left 10361
#define sipName_Left &sipStrings_QtWidgets[10361]
#define sipNameNr_axis 67167
#define sipName_axis &sipStrings_QtWidgets[67167]
#define sipNameNr_find 67172
#define sipName_find &sipStrings_QtWidgets[67172]
#define sipNameNr_Save 59664
#define sipName_Save &sipStrings_QtWidgets[59664]
#define sipNameNr_hide 67177
#define sipName_hide &sipStrings_QtWidgets[67177]
#define sipNameNr_show 67182
#define sipName_show &sipStrings_QtWidgets[67182]
#define sipNameNr_icon 67187
#define sipName_icon &sipStrings_QtWidgets[67187]
#define sipNameNr_font 67192
#define sipName_font &sipStrings_QtWidgets[67192]
#define sipNameNr_Mode 4674
#define sipName_Mode &sipStrings_QtWidgets[4674]
#define sipNameNr_area 67197
#define sipName_area &sipStrings_QtWidgets[67197]
#define sipNameNr_item 67202
#define sipName_item &sipStrings_QtWidgets[67202]
#define sipNameNr_rect 67207
#define sipName_rect &sipStrings_QtWidgets[67207]
#define sipNameNr_draw 67212
#define sipName_draw &sipStrings_QtWidgets[67212]
#define sipNameNr_step 67217
#define sipName_step &sipStrings_QtWidgets[67217]
#define sipNameNr_Icon 2791
#define sipName_Icon &sipStrings_QtWidgets[2791]
#define sipNameNr_List 42690
#define sipName_List &sipStrings_QtWidgets[42690]
#define sipNameNr_mask 67222
#define sipName_mask &sipStrings_QtWidgets[67222]
#define sipNameNr_Line 24712
#define sipName_Line &sipStrings_QtWidgets[24712]
#define sipNameNr_Open 18019
#define sipName_Open &sipStrings_QtWidgets[18019]
#define sipNameNr_setY 67227
#define sipName_setY &sipStrings_QtWidgets[67227]
#define sipNameNr_setX 67232
#define sipName_setX &sipStrings_QtWidgets[67232]
#define sipNameNr_text 29588
#define sipName_text &sipStrings_QtWidgets[29588]
#define sipNameNr_keys 67237
#define sipName_keys &sipStrings_QtWidgets[67237]
#define sipNameNr_line 37946
#define sipName_line &sipStrings_QtWidgets[37946]
#define sipNameNr_move 8113
#define sipName_move &sipStrings_QtWidgets[8113]
#define sipNameNr_read 67242
#define sipName_read &sipStrings_QtWidgets[67242]
#define sipNameNr_copy 67247
#define sipName_copy &sipStrings_QtWidgets[67247]
#define sipNameNr_home 67252
#define sipName_home &sipStrings_QtWidgets[67252]
#define sipNameNr_path 67257
#define sipName_path &sipStrings_QtWidgets[67257]
#define sipNameNr_time 67262
#define sipName_time &sipStrings_QtWidgets[67262]
#define sipNameNr_exec 67267
#define sipName_exec &sipStrings_QtWidgets[67267]
#define sipNameNr_mode 67272
#define sipName_mode &sipStrings_QtWidgets[67272]
#define sipNameNr_next 67277
#define sipName_next &sipStrings_QtWidgets[67277]
#define sipNameNr_Type 314
#define sipName_Type &sipStrings_QtWidgets[314]
#define sipNameNr_date 10550
#define sipName_date &sipStrings_QtWidgets[10550]
#define sipNameNr_open 67282
#define sipName_open &sipStrings_QtWidgets[67282]
#define sipNameNr_fill 67287
#define sipName_fill &sipStrings_QtWidgets[67287]
#define sipNameNr_size 12841
#define sipName_size &sipStrings_QtWidgets[12841]
#define sipNameNr_type 38014
#define sipName_type &sipStrings_QtWidgets[38014]
#define sipNameNr_hint 67292
#define sipName_hint &sipStrings_QtWidgets[67292]
#define sipNameNr_span 67297
#define sipName_span &sipStrings_QtWidgets[67297]
#define sipNameNr_sort 67302
#define sipName_sort &sipStrings_QtWidgets[67302]
#define sipNameNr_data 67307
#define sipName_data &sipStrings_QtWidgets[67307]
#define sipNameNr_role 67312
#define sipName_role &sipStrings_QtWidgets[67312]
#define sipNameNr_stop 67317
#define sipName_stop &sipStrings_QtWidgets[67317]
#define sipNameNr_Top 49918
#define sipName_Top &sipStrings_QtWidgets[49918]
#define sipNameNr_cut 21443
#define sipName_cut &sipStrings_QtWidgets[21443]
#define sipNameNr_Bin 67322
#define sipName_Bin &sipStrings_QtWidgets[67322]
#define sipNameNr_Oct 67326
#define sipName_Oct &sipStrings_QtWidgets[67326]
#define sipNameNr_Dec 67330
#define sipName_Dec &sipStrings_QtWidgets[67330]
#define sipNameNr_Hex 67334
#define sipName_Hex &sipStrings_QtWidgets[67334]
#define sipNameNr_Box 21065
#define sipName_Box &sipStrings_QtWidgets[21065]
#define sipNameNr_Yes 67338
#define sipName_Yes &sipStrings_QtWidgets[67338]
#define sipNameNr_End 34768
#define sipName_End &sipStrings_QtWidgets[34768]
#define sipNameNr_All 54540
#define sipName_All &sipStrings_QtWidgets[54540]
#define sipNameNr_pen 18020
#define sipName_pen &sipStrings_QtWidgets[18020]
#define sipNameNr_max 67342
#define sipName_max &sipStrings_QtWidgets[67342]
#define sipNameNr_min 67346
#define sipName_min &sipStrings_QtWidgets[67346]
#define sipNameNr_key 67350
#define sipName_key &sipStrings_QtWidgets[67350]
#define sipNameNr_pos 67354
#define sipName_pos &sipStrings_QtWidgets[67354]
#define sipNameNr_end 66543
#define sipName_end &sipStrings_QtWidgets[66543]
#define sipNameNr_row 9318
#define sipName_row &sipStrings_QtWidgets[9318]
#define sipNameNr_No 67358
#define sipName_No &sipStrings_QtWidgets[67358]
#define sipNameNr_Up 25054
#define sipName_Up &sipStrings_QtWidgets[25054]
#define sipNameNr_Ok 67361
#define sipName_Ok &sipStrings_QtWidgets[67361]
#define sipNameNr_ok 67364
#define sipName_ok &sipStrings_QtWidgets[67364]
#define sipNameNr_at 360
#define sipName_at &sipStrings_QtWidgets[360]
#define sipNameNr_on 94
#define sipName_on &sipStrings_QtWidgets[94]
#define sipNameNr_id 54721
#define sipName_id &sipStrings_QtWidgets[54721]
#define sipNameNr_x 17815
#define sipName_x &sipStrings_QtWidgets[17815]
#define sipNameNr_y 2186
#define sipName_y &sipStrings_QtWidgets[2186]

#define sipMalloc                   sipAPI_QtWidgets->api_malloc
#define sipFree                     sipAPI_QtWidgets->api_free
#define sipBuildResult              sipAPI_QtWidgets->api_build_result
#define sipCallMethod               sipAPI_QtWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWidgets->api_trace
#define sipTransferBack             sipAPI_QtWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtWidgets->api_transfer_to
#define sipTransferBreak            sipAPI_QtWidgets->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWidgets->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtWidgets->api_is_py_method
#define sipCallHook                 sipAPI_QtWidgets->api_call_hook
#define sipEndThread                sipAPI_QtWidgets->api_end_thread
#define sipConnectRx                sipAPI_QtWidgets->api_connect_rx
#define sipDisconnectRx             sipAPI_QtWidgets->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWidgets->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtWidgets->api_free_sipslot
#define sipSameSlot                 sipAPI_QtWidgets->api_same_slot
#define sipPySlotExtend             sipAPI_QtWidgets->api_pyslot_extend
#define sipConvertRx                sipAPI_QtWidgets->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWidgets->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtWidgets->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtWidgets->api_find_type
#define sipFindNamedEnum            sipAPI_QtWidgets->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWidgets->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtWidgets->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtWidgets->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtWidgets->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtWidgets->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtWidgets->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtWidgets->api_deprecated
#define sipGetReference             sipAPI_QtWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWidgets->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtWidgets->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtWidgets->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtWidgets->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtWidgets->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtWidgets->api_export_module
#define sipInitModule               sipAPI_QtWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtWidgets->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtWidgets->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtWidgets->api_get_method
#define sipFromMethod               sipAPI_QtWidgets->api_from_method
#define sipGetDate                  sipAPI_QtWidgets->api_get_date
#define sipFromDate                 sipAPI_QtWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtWidgets->api_get_time
#define sipFromTime                 sipAPI_QtWidgets->api_from_time
#define sipIsUserType               sipAPI_QtWidgets->api_is_user_type
#define sipGetFrame                 sipAPI_QtWidgets->api_get_frame
#define sipCheckPluginForType       sipAPI_QtWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWidgets->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWidgets->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtWidgets->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtWidgets->api_map_int_to_class
#define sipFindClass                sipAPI_QtWidgets->api_find_class
#define sipFindMappedType           sipAPI_QtWidgets->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtWidgets->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtWidgets->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtWidgets[];

#define sipType_QWidget sipExportedTypes_QtWidgets[463]
#define sipClass_QWidget sipExportedTypes_QtWidgets[463]->u.td_wrapper_type

#define sipType_QWidget_RenderFlag sipExportedTypes_QtWidgets[464]
#define sipEnum_QWidget_RenderFlag sipExportedTypes_QtWidgets[464]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidget;

#define sipType_QAbstractButton sipExportedTypes_QtWidgets[0]
#define sipClass_QAbstractButton sipExportedTypes_QtWidgets[0]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractButton;

#define sipType_QAbstractItemDelegate sipExportedTypes_QtWidgets[2]
#define sipClass_QAbstractItemDelegate sipExportedTypes_QtWidgets[2]->u.td_wrapper_type

#define sipType_QAbstractItemDelegate_EndEditHint sipExportedTypes_QtWidgets[3]
#define sipEnum_QAbstractItemDelegate_EndEditHint sipExportedTypes_QtWidgets[3]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemDelegate;

#define sipType_QFrame sipExportedTypes_QtWidgets[103]
#define sipClass_QFrame sipExportedTypes_QtWidgets[103]->u.td_wrapper_type

#define sipType_QFrame_StyleMask sipExportedTypes_QtWidgets[106]
#define sipEnum_QFrame_StyleMask sipExportedTypes_QtWidgets[106]->u.td_py_type

#define sipType_QFrame_Shape sipExportedTypes_QtWidgets[105]
#define sipEnum_QFrame_Shape sipExportedTypes_QtWidgets[105]->u.td_py_type

#define sipType_QFrame_Shadow sipExportedTypes_QtWidgets[104]
#define sipEnum_QFrame_Shadow sipExportedTypes_QtWidgets[104]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFrame;

#define sipType_QAbstractScrollArea sipExportedTypes_QtWidgets[15]
#define sipClass_QAbstractScrollArea sipExportedTypes_QtWidgets[15]->u.td_wrapper_type

#define sipType_QAbstractScrollArea_SizeAdjustPolicy sipExportedTypes_QtWidgets[16]
#define sipEnum_QAbstractScrollArea_SizeAdjustPolicy sipExportedTypes_QtWidgets[16]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractScrollArea;

#define sipType_QAbstractItemView sipExportedTypes_QtWidgets[4]
#define sipClass_QAbstractItemView sipExportedTypes_QtWidgets[4]->u.td_wrapper_type

#define sipType_QAbstractItemView_DropIndicatorPosition sipExportedTypes_QtWidgets[7]
#define sipEnum_QAbstractItemView_DropIndicatorPosition sipExportedTypes_QtWidgets[7]->u.td_py_type

#define sipType_QAbstractItemView_State sipExportedTypes_QtWidgets[14]
#define sipEnum_QAbstractItemView_State sipExportedTypes_QtWidgets[14]->u.td_py_type

#define sipType_QAbstractItemView_CursorAction sipExportedTypes_QtWidgets[5]
#define sipEnum_QAbstractItemView_CursorAction sipExportedTypes_QtWidgets[5]->u.td_py_type

#define sipType_QAbstractItemView_SelectionMode sipExportedTypes_QtWidgets[13]
#define sipEnum_QAbstractItemView_SelectionMode sipExportedTypes_QtWidgets[13]->u.td_py_type

#define sipType_QAbstractItemView_SelectionBehavior sipExportedTypes_QtWidgets[12]
#define sipEnum_QAbstractItemView_SelectionBehavior sipExportedTypes_QtWidgets[12]->u.td_py_type

#define sipType_QAbstractItemView_ScrollMode sipExportedTypes_QtWidgets[11]
#define sipEnum_QAbstractItemView_ScrollMode sipExportedTypes_QtWidgets[11]->u.td_py_type

#define sipType_QAbstractItemView_ScrollHint sipExportedTypes_QtWidgets[10]
#define sipEnum_QAbstractItemView_ScrollHint sipExportedTypes_QtWidgets[10]->u.td_py_type

#define sipType_QAbstractItemView_EditTrigger sipExportedTypes_QtWidgets[8]
#define sipEnum_QAbstractItemView_EditTrigger sipExportedTypes_QtWidgets[8]->u.td_py_type

#define sipType_QAbstractItemView_DragDropMode sipExportedTypes_QtWidgets[6]
#define sipEnum_QAbstractItemView_DragDropMode sipExportedTypes_QtWidgets[6]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemView;

#define sipType_QAbstractItemView_EditTriggers sipExportedTypes_QtWidgets[9]
#define sipClass_QAbstractItemView_EditTriggers sipExportedTypes_QtWidgets[9]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemView_EditTriggers;

#define sipType_QAbstractSlider sipExportedTypes_QtWidgets[17]
#define sipClass_QAbstractSlider sipExportedTypes_QtWidgets[17]->u.td_wrapper_type

#define sipType_QAbstractSlider_SliderChange sipExportedTypes_QtWidgets[19]
#define sipEnum_QAbstractSlider_SliderChange sipExportedTypes_QtWidgets[19]->u.td_py_type

#define sipType_QAbstractSlider_SliderAction sipExportedTypes_QtWidgets[18]
#define sipEnum_QAbstractSlider_SliderAction sipExportedTypes_QtWidgets[18]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSlider;

#define sipType_QAbstractSpinBox sipExportedTypes_QtWidgets[20]
#define sipClass_QAbstractSpinBox sipExportedTypes_QtWidgets[20]->u.td_wrapper_type

#define sipType_QAbstractSpinBox_StepType sipExportedTypes_QtWidgets[25]
#define sipEnum_QAbstractSpinBox_StepType sipExportedTypes_QtWidgets[25]->u.td_py_type

#define sipType_QAbstractSpinBox_CorrectionMode sipExportedTypes_QtWidgets[22]
#define sipEnum_QAbstractSpinBox_CorrectionMode sipExportedTypes_QtWidgets[22]->u.td_py_type

#define sipType_QAbstractSpinBox_ButtonSymbols sipExportedTypes_QtWidgets[21]
#define sipEnum_QAbstractSpinBox_ButtonSymbols sipExportedTypes_QtWidgets[21]->u.td_py_type

#define sipType_QAbstractSpinBox_StepEnabledFlag sipExportedTypes_QtWidgets[24]
#define sipEnum_QAbstractSpinBox_StepEnabledFlag sipExportedTypes_QtWidgets[24]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox;

#define sipType_QAbstractSpinBox_StepEnabled sipExportedTypes_QtWidgets[23]
#define sipClass_QAbstractSpinBox_StepEnabled sipExportedTypes_QtWidgets[23]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox_StepEnabled;

#define sipType_QAction sipExportedTypes_QtWidgets[26]
#define sipClass_QAction sipExportedTypes_QtWidgets[26]->u.td_wrapper_type

#define sipType_QAction_Priority sipExportedTypes_QtWidgets[29]
#define sipEnum_QAction_Priority sipExportedTypes_QtWidgets[29]->u.td_py_type

#define sipType_QAction_MenuRole sipExportedTypes_QtWidgets[28]
#define sipEnum_QAction_MenuRole sipExportedTypes_QtWidgets[28]->u.td_py_type

#define sipType_QAction_ActionEvent sipExportedTypes_QtWidgets[27]
#define sipEnum_QAction_ActionEvent sipExportedTypes_QtWidgets[27]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAction;

#define sipType_QActionGroup sipExportedTypes_QtWidgets[30]
#define sipClass_QActionGroup sipExportedTypes_QtWidgets[30]->u.td_wrapper_type

#define sipType_QActionGroup_ExclusionPolicy sipExportedTypes_QtWidgets[31]
#define sipEnum_QActionGroup_ExclusionPolicy sipExportedTypes_QtWidgets[31]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QActionGroup;

#define sipType_QApplication sipExportedTypes_QtWidgets[32]
#define sipClass_QApplication sipExportedTypes_QtWidgets[32]->u.td_wrapper_type

#define sipType_QApplication_ColorSpec sipExportedTypes_QtWidgets[33]
#define sipEnum_QApplication_ColorSpec sipExportedTypes_QtWidgets[33]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QApplication;

#define sipType_QLayoutItem sipExportedTypes_QtWidgets[193]
#define sipClass_QLayoutItem sipExportedTypes_QtWidgets[193]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayoutItem;

#define sipType_QLayout sipExportedTypes_QtWidgets[191]
#define sipClass_QLayout sipExportedTypes_QtWidgets[191]->u.td_wrapper_type

#define sipType_QLayout_SizeConstraint sipExportedTypes_QtWidgets[192]
#define sipEnum_QLayout_SizeConstraint sipExportedTypes_QtWidgets[192]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayout;

#define sipType_QBoxLayout sipExportedTypes_QtWidgets[34]
#define sipClass_QBoxLayout sipExportedTypes_QtWidgets[34]->u.td_wrapper_type

#define sipType_QBoxLayout_Direction sipExportedTypes_QtWidgets[35]
#define sipEnum_QBoxLayout_Direction sipExportedTypes_QtWidgets[35]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QBoxLayout;

#define sipType_QHBoxLayout sipExportedTypes_QtWidgets[175]
#define sipClass_QHBoxLayout sipExportedTypes_QtWidgets[175]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QHBoxLayout;

#define sipType_QVBoxLayout sipExportedTypes_QtWidgets[461]
#define sipClass_QVBoxLayout sipExportedTypes_QtWidgets[461]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QVBoxLayout;

#define sipType_QButtonGroup sipExportedTypes_QtWidgets[36]
#define sipClass_QButtonGroup sipExportedTypes_QtWidgets[36]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QButtonGroup;

#define sipType_QCalendarWidget sipExportedTypes_QtWidgets[37]
#define sipClass_QCalendarWidget sipExportedTypes_QtWidgets[37]->u.td_wrapper_type

#define sipType_QCalendarWidget_SelectionMode sipExportedTypes_QtWidgets[39]
#define sipEnum_QCalendarWidget_SelectionMode sipExportedTypes_QtWidgets[39]->u.td_py_type

#define sipType_QCalendarWidget_VerticalHeaderFormat sipExportedTypes_QtWidgets[40]
#define sipEnum_QCalendarWidget_VerticalHeaderFormat sipExportedTypes_QtWidgets[40]->u.td_py_type

#define sipType_QCalendarWidget_HorizontalHeaderFormat sipExportedTypes_QtWidgets[38]
#define sipEnum_QCalendarWidget_HorizontalHeaderFormat sipExportedTypes_QtWidgets[38]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QCalendarWidget;

#define sipType_QCheckBox sipExportedTypes_QtWidgets[41]
#define sipClass_QCheckBox sipExportedTypes_QtWidgets[41]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QCheckBox;

#define sipType_QDialog sipExportedTypes_QtWidgets[62]
#define sipClass_QDialog sipExportedTypes_QtWidgets[62]->u.td_wrapper_type

#define sipType_QDialog_DialogCode sipExportedTypes_QtWidgets[63]
#define sipEnum_QDialog_DialogCode sipExportedTypes_QtWidgets[63]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialog;

#define sipType_QColorDialog sipExportedTypes_QtWidgets[42]
#define sipClass_QColorDialog sipExportedTypes_QtWidgets[42]->u.td_wrapper_type

#define sipType_QColorDialog_ColorDialogOption sipExportedTypes_QtWidgets[43]
#define sipEnum_QColorDialog_ColorDialogOption sipExportedTypes_QtWidgets[43]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QColorDialog;

#define sipType_QColorDialog_ColorDialogOptions sipExportedTypes_QtWidgets[44]
#define sipClass_QColorDialog_ColorDialogOptions sipExportedTypes_QtWidgets[44]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QColorDialog_ColorDialogOptions;

#define sipType_QColumnView sipExportedTypes_QtWidgets[45]
#define sipClass_QColumnView sipExportedTypes_QtWidgets[45]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QColumnView;

#define sipType_QComboBox sipExportedTypes_QtWidgets[46]
#define sipClass_QComboBox sipExportedTypes_QtWidgets[46]->u.td_wrapper_type

#define sipType_QComboBox_SizeAdjustPolicy sipExportedTypes_QtWidgets[48]
#define sipEnum_QComboBox_SizeAdjustPolicy sipExportedTypes_QtWidgets[48]->u.td_py_type

#define sipType_QComboBox_InsertPolicy sipExportedTypes_QtWidgets[47]
#define sipEnum_QComboBox_InsertPolicy sipExportedTypes_QtWidgets[47]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QComboBox;

#define sipType_QPushButton sipExportedTypes_QtWidgets[258]
#define sipClass_QPushButton sipExportedTypes_QtWidgets[258]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPushButton;

#define sipType_QCommandLinkButton sipExportedTypes_QtWidgets[49]
#define sipClass_QCommandLinkButton sipExportedTypes_QtWidgets[49]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommandLinkButton;

#define sipType_QStyle sipExportedTypes_QtWidgets[290]
#define sipClass_QStyle sipExportedTypes_QtWidgets[290]->u.td_wrapper_type

#define sipType_QStyle_RequestSoftwareInputPanel sipExportedTypes_QtWidgets[296]
#define sipEnum_QStyle_RequestSoftwareInputPanel sipExportedTypes_QtWidgets[296]->u.td_py_type

#define sipType_QStyle_StandardPixmap sipExportedTypes_QtWidgets[297]
#define sipEnum_QStyle_StandardPixmap sipExportedTypes_QtWidgets[297]->u.td_py_type

#define sipType_QStyle_StyleHint sipExportedTypes_QtWidgets[300]
#define sipEnum_QStyle_StyleHint sipExportedTypes_QtWidgets[300]->u.td_py_type

#define sipType_QStyle_ContentsType sipExportedTypes_QtWidgets[292]
#define sipEnum_QStyle_ContentsType sipExportedTypes_QtWidgets[292]->u.td_py_type

#define sipType_QStyle_PixelMetric sipExportedTypes_QtWidgets[294]
#define sipEnum_QStyle_PixelMetric sipExportedTypes_QtWidgets[294]->u.td_py_type

#define sipType_QStyle_SubControl sipExportedTypes_QtWidgets[301]
#define sipEnum_QStyle_SubControl sipExportedTypes_QtWidgets[301]->u.td_py_type

#define sipType_QStyle_ComplexControl sipExportedTypes_QtWidgets[291]
#define sipEnum_QStyle_ComplexControl sipExportedTypes_QtWidgets[291]->u.td_py_type

#define sipType_QStyle_SubElement sipExportedTypes_QtWidgets[303]
#define sipEnum_QStyle_SubElement sipExportedTypes_QtWidgets[303]->u.td_py_type

#define sipType_QStyle_ControlElement sipExportedTypes_QtWidgets[293]
#define sipEnum_QStyle_ControlElement sipExportedTypes_QtWidgets[293]->u.td_py_type

#define sipType_QStyle_PrimitiveElement sipExportedTypes_QtWidgets[295]
#define sipEnum_QStyle_PrimitiveElement sipExportedTypes_QtWidgets[295]->u.td_py_type

#define sipType_QStyle_StateFlag sipExportedTypes_QtWidgets[299]
#define sipEnum_QStyle_StateFlag sipExportedTypes_QtWidgets[299]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle;

#define sipType_QCommonStyle sipExportedTypes_QtWidgets[50]
#define sipClass_QCommonStyle sipExportedTypes_QtWidgets[50]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommonStyle;

#define sipType_QCompleter sipExportedTypes_QtWidgets[51]
#define sipClass_QCompleter sipExportedTypes_QtWidgets[51]->u.td_wrapper_type

#define sipType_QCompleter_ModelSorting sipExportedTypes_QtWidgets[53]
#define sipEnum_QCompleter_ModelSorting sipExportedTypes_QtWidgets[53]->u.td_py_type

#define sipType_QCompleter_CompletionMode sipExportedTypes_QtWidgets[52]
#define sipEnum_QCompleter_CompletionMode sipExportedTypes_QtWidgets[52]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QCompleter;

#define sipType_QDataWidgetMapper sipExportedTypes_QtWidgets[54]
#define sipClass_QDataWidgetMapper sipExportedTypes_QtWidgets[54]->u.td_wrapper_type

#define sipType_QDataWidgetMapper_SubmitPolicy sipExportedTypes_QtWidgets[55]
#define sipEnum_QDataWidgetMapper_SubmitPolicy sipExportedTypes_QtWidgets[55]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDataWidgetMapper;

#define sipType_QDateTimeEdit sipExportedTypes_QtWidgets[57]
#define sipClass_QDateTimeEdit sipExportedTypes_QtWidgets[57]->u.td_wrapper_type

#define sipType_QDateTimeEdit_Section sipExportedTypes_QtWidgets[58]
#define sipEnum_QDateTimeEdit_Section sipExportedTypes_QtWidgets[58]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateTimeEdit;

#define sipType_QDateTimeEdit_Sections sipExportedTypes_QtWidgets[59]
#define sipClass_QDateTimeEdit_Sections sipExportedTypes_QtWidgets[59]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateTimeEdit_Sections;

#define sipType_QTimeEdit sipExportedTypes_QtWidgets[443]
#define sipClass_QTimeEdit sipExportedTypes_QtWidgets[443]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTimeEdit;

#define sipType_QDateEdit sipExportedTypes_QtWidgets[56]
#define sipClass_QDateEdit sipExportedTypes_QtWidgets[56]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateEdit;

#define sipType_QDesktopWidget sipExportedTypes_QtWidgets[60]
#define sipClass_QDesktopWidget sipExportedTypes_QtWidgets[60]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDesktopWidget;

#define sipType_QDial sipExportedTypes_QtWidgets[61]
#define sipClass_QDial sipExportedTypes_QtWidgets[61]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDial;

#define sipType_QDialogButtonBox sipExportedTypes_QtWidgets[64]
#define sipClass_QDialogButtonBox sipExportedTypes_QtWidgets[64]->u.td_wrapper_type

#define sipType_QDialogButtonBox_StandardButton sipExportedTypes_QtWidgets[67]
#define sipEnum_QDialogButtonBox_StandardButton sipExportedTypes_QtWidgets[67]->u.td_py_type

#define sipType_QDialogButtonBox_ButtonRole sipExportedTypes_QtWidgets[66]
#define sipEnum_QDialogButtonBox_ButtonRole sipExportedTypes_QtWidgets[66]->u.td_py_type

#define sipType_QDialogButtonBox_ButtonLayout sipExportedTypes_QtWidgets[65]
#define sipEnum_QDialogButtonBox_ButtonLayout sipExportedTypes_QtWidgets[65]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialogButtonBox;

#define sipType_QDialogButtonBox_StandardButtons sipExportedTypes_QtWidgets[68]
#define sipClass_QDialogButtonBox_StandardButtons sipExportedTypes_QtWidgets[68]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialogButtonBox_StandardButtons;

#define sipType_QDirModel sipExportedTypes_QtWidgets[69]
#define sipClass_QDirModel sipExportedTypes_QtWidgets[69]->u.td_wrapper_type

#define sipType_QDirModel_Roles sipExportedTypes_QtWidgets[70]
#define sipEnum_QDirModel_Roles sipExportedTypes_QtWidgets[70]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDirModel;

#define sipType_QDockWidget sipExportedTypes_QtWidgets[71]
#define sipClass_QDockWidget sipExportedTypes_QtWidgets[71]->u.td_wrapper_type

#define sipType_QDockWidget_DockWidgetFeature sipExportedTypes_QtWidgets[72]
#define sipEnum_QDockWidget_DockWidgetFeature sipExportedTypes_QtWidgets[72]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDockWidget;

#define sipType_QDockWidget_DockWidgetFeatures sipExportedTypes_QtWidgets[73]
#define sipClass_QDockWidget_DockWidgetFeatures sipExportedTypes_QtWidgets[73]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDockWidget_DockWidgetFeatures;

#define sipType_QErrorMessage sipExportedTypes_QtWidgets[75]
#define sipClass_QErrorMessage sipExportedTypes_QtWidgets[75]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QErrorMessage;

#define sipType_QFileDialog sipExportedTypes_QtWidgets[76]
#define sipClass_QFileDialog sipExportedTypes_QtWidgets[76]->u.td_wrapper_type

#define sipType_QFileDialog_Option sipExportedTypes_QtWidgets[80]
#define sipEnum_QFileDialog_Option sipExportedTypes_QtWidgets[80]->u.td_py_type

#define sipType_QFileDialog_DialogLabel sipExportedTypes_QtWidgets[78]
#define sipEnum_QFileDialog_DialogLabel sipExportedTypes_QtWidgets[78]->u.td_py_type

#define sipType_QFileDialog_AcceptMode sipExportedTypes_QtWidgets[77]
#define sipEnum_QFileDialog_AcceptMode sipExportedTypes_QtWidgets[77]->u.td_py_type

#define sipType_QFileDialog_FileMode sipExportedTypes_QtWidgets[79]
#define sipEnum_QFileDialog_FileMode sipExportedTypes_QtWidgets[79]->u.td_py_type

#define sipType_QFileDialog_ViewMode sipExportedTypes_QtWidgets[82]
#define sipEnum_QFileDialog_ViewMode sipExportedTypes_QtWidgets[82]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileDialog;

#define sipType_QFileDialog_Options sipExportedTypes_QtWidgets[81]
#define sipClass_QFileDialog_Options sipExportedTypes_QtWidgets[81]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileDialog_Options;

#define sipType_QFileIconProvider sipExportedTypes_QtWidgets[83]
#define sipClass_QFileIconProvider sipExportedTypes_QtWidgets[83]->u.td_wrapper_type

#define sipType_QFileIconProvider_Option sipExportedTypes_QtWidgets[85]
#define sipEnum_QFileIconProvider_Option sipExportedTypes_QtWidgets[85]->u.td_py_type

#define sipType_QFileIconProvider_IconType sipExportedTypes_QtWidgets[84]
#define sipEnum_QFileIconProvider_IconType sipExportedTypes_QtWidgets[84]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileIconProvider;

#define sipType_QFileIconProvider_Options sipExportedTypes_QtWidgets[86]
#define sipClass_QFileIconProvider_Options sipExportedTypes_QtWidgets[86]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileIconProvider_Options;

#define sipType_QFileSystemModel sipExportedTypes_QtWidgets[87]
#define sipClass_QFileSystemModel sipExportedTypes_QtWidgets[87]->u.td_wrapper_type

#define sipType_QFileSystemModel_Option sipExportedTypes_QtWidgets[88]
#define sipEnum_QFileSystemModel_Option sipExportedTypes_QtWidgets[88]->u.td_py_type

#define sipType_QFileSystemModel_Roles sipExportedTypes_QtWidgets[90]
#define sipEnum_QFileSystemModel_Roles sipExportedTypes_QtWidgets[90]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileSystemModel;

#define sipType_QFileSystemModel_Options sipExportedTypes_QtWidgets[89]
#define sipClass_QFileSystemModel_Options sipExportedTypes_QtWidgets[89]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileSystemModel_Options;

#define sipType_QFocusFrame sipExportedTypes_QtWidgets[91]
#define sipClass_QFocusFrame sipExportedTypes_QtWidgets[91]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFocusFrame;

#define sipType_QFontComboBox sipExportedTypes_QtWidgets[92]
#define sipClass_QFontComboBox sipExportedTypes_QtWidgets[92]->u.td_wrapper_type

#define sipType_QFontComboBox_FontFilter sipExportedTypes_QtWidgets[93]
#define sipEnum_QFontComboBox_FontFilter sipExportedTypes_QtWidgets[93]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontComboBox;

#define sipType_QFontComboBox_FontFilters sipExportedTypes_QtWidgets[94]
#define sipClass_QFontComboBox_FontFilters sipExportedTypes_QtWidgets[94]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontComboBox_FontFilters;

#define sipType_QFontDialog sipExportedTypes_QtWidgets[95]
#define sipClass_QFontDialog sipExportedTypes_QtWidgets[95]->u.td_wrapper_type

#define sipType_QFontDialog_FontDialogOption sipExportedTypes_QtWidgets[96]
#define sipEnum_QFontDialog_FontDialogOption sipExportedTypes_QtWidgets[96]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontDialog;

#define sipType_QFontDialog_FontDialogOptions sipExportedTypes_QtWidgets[97]
#define sipClass_QFontDialog_FontDialogOptions sipExportedTypes_QtWidgets[97]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontDialog_FontDialogOptions;

#define sipType_QFormLayout sipExportedTypes_QtWidgets[98]
#define sipClass_QFormLayout sipExportedTypes_QtWidgets[98]->u.td_wrapper_type

#define sipType_QFormLayout_ItemRole sipExportedTypes_QtWidgets[100]
#define sipEnum_QFormLayout_ItemRole sipExportedTypes_QtWidgets[100]->u.td_py_type

#define sipType_QFormLayout_RowWrapPolicy sipExportedTypes_QtWidgets[101]
#define sipEnum_QFormLayout_RowWrapPolicy sipExportedTypes_QtWidgets[101]->u.td_py_type

#define sipType_QFormLayout_FieldGrowthPolicy sipExportedTypes_QtWidgets[99]
#define sipEnum_QFormLayout_FieldGrowthPolicy sipExportedTypes_QtWidgets[99]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout;

#define sipType_QFormLayout_TakeRowResult sipExportedTypes_QtWidgets[102]
#define sipClass_QFormLayout_TakeRowResult sipExportedTypes_QtWidgets[102]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout_TakeRowResult;

#define sipType_QGesture sipExportedTypes_QtWidgets[107]
#define sipClass_QGesture sipExportedTypes_QtWidgets[107]->u.td_wrapper_type

#define sipType_QGesture_GestureCancelPolicy sipExportedTypes_QtWidgets[108]
#define sipEnum_QGesture_GestureCancelPolicy sipExportedTypes_QtWidgets[108]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGesture;

#define sipType_QPanGesture sipExportedTypes_QtWidgets[247]
#define sipClass_QPanGesture sipExportedTypes_QtWidgets[247]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPanGesture;

#define sipType_QPinchGesture sipExportedTypes_QtWidgets[248]
#define sipClass_QPinchGesture sipExportedTypes_QtWidgets[248]->u.td_wrapper_type

#define sipType_QPinchGesture_ChangeFlag sipExportedTypes_QtWidgets[249]
#define sipEnum_QPinchGesture_ChangeFlag sipExportedTypes_QtWidgets[249]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPinchGesture;

#define sipType_QPinchGesture_ChangeFlags sipExportedTypes_QtWidgets[250]
#define sipClass_QPinchGesture_ChangeFlags sipExportedTypes_QtWidgets[250]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPinchGesture_ChangeFlags;

#define sipType_QSwipeGesture sipExportedTypes_QtWidgets[418]
#define sipClass_QSwipeGesture sipExportedTypes_QtWidgets[418]->u.td_wrapper_type

#define sipType_QSwipeGesture_SwipeDirection sipExportedTypes_QtWidgets[419]
#define sipEnum_QSwipeGesture_SwipeDirection sipExportedTypes_QtWidgets[419]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSwipeGesture;

#define sipType_QTapGesture sipExportedTypes_QtWidgets[436]
#define sipClass_QTapGesture sipExportedTypes_QtWidgets[436]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapGesture;

#define sipType_QTapAndHoldGesture sipExportedTypes_QtWidgets[435]
#define sipClass_QTapAndHoldGesture sipExportedTypes_QtWidgets[435]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapAndHoldGesture;

#define sipType_QGestureEvent sipExportedTypes_QtWidgets[109]
#define sipClass_QGestureEvent sipExportedTypes_QtWidgets[109]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureEvent;

#define sipType_QGestureRecognizer sipExportedTypes_QtWidgets[110]
#define sipClass_QGestureRecognizer sipExportedTypes_QtWidgets[110]->u.td_wrapper_type

#define sipType_QGestureRecognizer_ResultFlag sipExportedTypes_QtWidgets[112]
#define sipEnum_QGestureRecognizer_ResultFlag sipExportedTypes_QtWidgets[112]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureRecognizer;

#define sipType_QGestureRecognizer_Result sipExportedTypes_QtWidgets[111]
#define sipClass_QGestureRecognizer_Result sipExportedTypes_QtWidgets[111]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureRecognizer_Result;

#define sipType_QGraphicsAnchor sipExportedTypes_QtWidgets[113]
#define sipClass_QGraphicsAnchor sipExportedTypes_QtWidgets[113]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchor;

#define sipType_QGraphicsLayoutItem sipExportedTypes_QtWidgets[134]
#define sipClass_QGraphicsLayoutItem sipExportedTypes_QtWidgets[134]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayoutItem;

#define sipType_QGraphicsLayout sipExportedTypes_QtWidgets[133]
#define sipClass_QGraphicsLayout sipExportedTypes_QtWidgets[133]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayout;

#define sipType_QGraphicsAnchorLayout sipExportedTypes_QtWidgets[114]
#define sipClass_QGraphicsAnchorLayout sipExportedTypes_QtWidgets[114]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchorLayout;

#define sipType_QGraphicsEffect sipExportedTypes_QtWidgets[120]
#define sipClass_QGraphicsEffect sipExportedTypes_QtWidgets[120]->u.td_wrapper_type

#define sipType_QGraphicsEffect_PixmapPadMode sipExportedTypes_QtWidgets[123]
#define sipEnum_QGraphicsEffect_PixmapPadMode sipExportedTypes_QtWidgets[123]->u.td_py_type

#define sipType_QGraphicsEffect_ChangeFlag sipExportedTypes_QtWidgets[121]
#define sipEnum_QGraphicsEffect_ChangeFlag sipExportedTypes_QtWidgets[121]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEffect;

#define sipType_QGraphicsEffect_ChangeFlags sipExportedTypes_QtWidgets[122]
#define sipClass_QGraphicsEffect_ChangeFlags sipExportedTypes_QtWidgets[122]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEffect_ChangeFlags;

#define sipType_QGraphicsColorizeEffect sipExportedTypes_QtWidgets[118]
#define sipClass_QGraphicsColorizeEffect sipExportedTypes_QtWidgets[118]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsColorizeEffect;

#define sipType_QGraphicsBlurEffect sipExportedTypes_QtWidgets[115]
#define sipClass_QGraphicsBlurEffect sipExportedTypes_QtWidgets[115]->u.td_wrapper_type

#define sipType_QGraphicsBlurEffect_BlurHint sipExportedTypes_QtWidgets[116]
#define sipEnum_QGraphicsBlurEffect_BlurHint sipExportedTypes_QtWidgets[116]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect;

#define sipType_QGraphicsBlurEffect_BlurHints sipExportedTypes_QtWidgets[117]
#define sipClass_QGraphicsBlurEffect_BlurHints sipExportedTypes_QtWidgets[117]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect_BlurHints;

#define sipType_QGraphicsDropShadowEffect sipExportedTypes_QtWidgets[119]
#define sipClass_QGraphicsDropShadowEffect sipExportedTypes_QtWidgets[119]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsDropShadowEffect;

#define sipType_QGraphicsOpacityEffect sipExportedTypes_QtWidgets[138]
#define sipClass_QGraphicsOpacityEffect sipExportedTypes_QtWidgets[138]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsOpacityEffect;

#define sipType_QGraphicsGridLayout sipExportedTypes_QtWidgets[125]
#define sipClass_QGraphicsGridLayout sipExportedTypes_QtWidgets[125]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsGridLayout;

#define sipType_QGraphicsItem sipExportedTypes_QtWidgets[126]
#define sipClass_QGraphicsItem sipExportedTypes_QtWidgets[126]->u.td_wrapper_type

#define sipType_QGraphicsItem_PanelModality sipExportedTypes_QtWidgets[131]
#define sipEnum_QGraphicsItem_PanelModality sipExportedTypes_QtWidgets[131]->u.td_py_type

#define sipType_QGraphicsItem_GraphicsItemFlag sipExportedTypes_QtWidgets[129]
#define sipEnum_QGraphicsItem_GraphicsItemFlag sipExportedTypes_QtWidgets[129]->u.td_py_type

#define sipType_QGraphicsItem_GraphicsItemChange sipExportedTypes_QtWidgets[128]
#define sipEnum_QGraphicsItem_GraphicsItemChange sipExportedTypes_QtWidgets[128]->u.td_py_type

#define sipType_QGraphicsItem_CacheMode sipExportedTypes_QtWidgets[127]
#define sipEnum_QGraphicsItem_CacheMode sipExportedTypes_QtWidgets[127]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItem;

#define sipType_QGraphicsItem_GraphicsItemFlags sipExportedTypes_QtWidgets[130]
#define sipClass_QGraphicsItem_GraphicsItemFlags sipExportedTypes_QtWidgets[130]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItem_GraphicsItemFlags;

#define sipType_QAbstractGraphicsShapeItem sipExportedTypes_QtWidgets[1]
#define sipClass_QAbstractGraphicsShapeItem sipExportedTypes_QtWidgets[1]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractGraphicsShapeItem;

#define sipType_QGraphicsPathItem sipExportedTypes_QtWidgets[139]
#define sipClass_QGraphicsPathItem sipExportedTypes_QtWidgets[139]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPathItem;

#define sipType_QGraphicsRectItem sipExportedTypes_QtWidgets[144]
#define sipClass_QGraphicsRectItem sipExportedTypes_QtWidgets[144]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRectItem;

#define sipType_QGraphicsEllipseItem sipExportedTypes_QtWidgets[124]
#define sipClass_QGraphicsEllipseItem sipExportedTypes_QtWidgets[124]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEllipseItem;

#define sipType_QGraphicsPolygonItem sipExportedTypes_QtWidgets[142]
#define sipClass_QGraphicsPolygonItem sipExportedTypes_QtWidgets[142]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPolygonItem;

#define sipType_QGraphicsLineItem sipExportedTypes_QtWidgets[135]
#define sipClass_QGraphicsLineItem sipExportedTypes_QtWidgets[135]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLineItem;

#define sipType_QGraphicsPixmapItem sipExportedTypes_QtWidgets[140]
#define sipClass_QGraphicsPixmapItem sipExportedTypes_QtWidgets[140]->u.td_wrapper_type

#define sipType_QGraphicsPixmapItem_ShapeMode sipExportedTypes_QtWidgets[141]
#define sipEnum_QGraphicsPixmapItem_ShapeMode sipExportedTypes_QtWidgets[141]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPixmapItem;

#define sipType_QGraphicsSimpleTextItem sipExportedTypes_QtWidgets[161]
#define sipClass_QGraphicsSimpleTextItem sipExportedTypes_QtWidgets[161]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSimpleTextItem;

#define sipType_QGraphicsItemGroup sipExportedTypes_QtWidgets[132]
#define sipClass_QGraphicsItemGroup sipExportedTypes_QtWidgets[132]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItemGroup;

#define sipType_QGraphicsObject sipExportedTypes_QtWidgets[137]
#define sipClass_QGraphicsObject sipExportedTypes_QtWidgets[137]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsObject;

#define sipType_QGraphicsTextItem sipExportedTypes_QtWidgets[162]
#define sipClass_QGraphicsTextItem sipExportedTypes_QtWidgets[162]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTextItem;

#define sipType_QGraphicsLinearLayout sipExportedTypes_QtWidgets[136]
#define sipClass_QGraphicsLinearLayout sipExportedTypes_QtWidgets[136]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLinearLayout;

#define sipType_QGraphicsWidget sipExportedTypes_QtWidgets[172]
#define sipClass_QGraphicsWidget sipExportedTypes_QtWidgets[172]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsWidget;

#define sipType_QGraphicsProxyWidget sipExportedTypes_QtWidgets[143]
#define sipClass_QGraphicsProxyWidget sipExportedTypes_QtWidgets[143]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsProxyWidget;

#define sipType_QGraphicsScene sipExportedTypes_QtWidgets[147]
#define sipClass_QGraphicsScene sipExportedTypes_QtWidgets[147]->u.td_wrapper_type

#define sipType_QGraphicsScene_SceneLayer sipExportedTypes_QtWidgets[149]
#define sipEnum_QGraphicsScene_SceneLayer sipExportedTypes_QtWidgets[149]->u.td_py_type

#define sipType_QGraphicsScene_ItemIndexMethod sipExportedTypes_QtWidgets[148]
#define sipEnum_QGraphicsScene_ItemIndexMethod sipExportedTypes_QtWidgets[148]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScene;

#define sipType_QGraphicsScene_SceneLayers sipExportedTypes_QtWidgets[150]
#define sipClass_QGraphicsScene_SceneLayers sipExportedTypes_QtWidgets[150]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScene_SceneLayers;

#define sipType_QGraphicsSceneEvent sipExportedTypes_QtWidgets[154]
#define sipClass_QGraphicsSceneEvent sipExportedTypes_QtWidgets[154]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneEvent;

#define sipType_QGraphicsSceneMouseEvent sipExportedTypes_QtWidgets[157]
#define sipClass_QGraphicsSceneMouseEvent sipExportedTypes_QtWidgets[157]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMouseEvent;

#define sipType_QGraphicsSceneWheelEvent sipExportedTypes_QtWidgets[160]
#define sipClass_QGraphicsSceneWheelEvent sipExportedTypes_QtWidgets[160]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneWheelEvent;

#define sipType_QGraphicsSceneContextMenuEvent sipExportedTypes_QtWidgets[151]
#define sipClass_QGraphicsSceneContextMenuEvent sipExportedTypes_QtWidgets[151]->u.td_wrapper_type

#define sipType_QGraphicsSceneContextMenuEvent_Reason sipExportedTypes_QtWidgets[152]
#define sipEnum_QGraphicsSceneContextMenuEvent_Reason sipExportedTypes_QtWidgets[152]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneContextMenuEvent;

#define sipType_QGraphicsSceneHoverEvent sipExportedTypes_QtWidgets[156]
#define sipClass_QGraphicsSceneHoverEvent sipExportedTypes_QtWidgets[156]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHoverEvent;

#define sipType_QGraphicsSceneHelpEvent sipExportedTypes_QtWidgets[155]
#define sipClass_QGraphicsSceneHelpEvent sipExportedTypes_QtWidgets[155]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHelpEvent;

#define sipType_QGraphicsSceneDragDropEvent sipExportedTypes_QtWidgets[153]
#define sipClass_QGraphicsSceneDragDropEvent sipExportedTypes_QtWidgets[153]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneDragDropEvent;

#define sipType_QGraphicsSceneResizeEvent sipExportedTypes_QtWidgets[159]
#define sipClass_QGraphicsSceneResizeEvent sipExportedTypes_QtWidgets[159]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneResizeEvent;

#define sipType_QGraphicsSceneMoveEvent sipExportedTypes_QtWidgets[158]
#define sipClass_QGraphicsSceneMoveEvent sipExportedTypes_QtWidgets[158]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMoveEvent;

#define sipType_QGraphicsTransform sipExportedTypes_QtWidgets[163]
#define sipClass_QGraphicsTransform sipExportedTypes_QtWidgets[163]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTransform;

#define sipType_QGraphicsScale sipExportedTypes_QtWidgets[146]
#define sipClass_QGraphicsScale sipExportedTypes_QtWidgets[146]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScale;

#define sipType_QGraphicsRotation sipExportedTypes_QtWidgets[145]
#define sipClass_QGraphicsRotation sipExportedTypes_QtWidgets[145]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRotation;

#define sipType_QGraphicsView sipExportedTypes_QtWidgets[164]
#define sipClass_QGraphicsView sipExportedTypes_QtWidgets[164]->u.td_wrapper_type

#define sipType_QGraphicsView_OptimizationFlag sipExportedTypes_QtWidgets[168]
#define sipEnum_QGraphicsView_OptimizationFlag sipExportedTypes_QtWidgets[168]->u.td_py_type

#define sipType_QGraphicsView_ViewportUpdateMode sipExportedTypes_QtWidgets[171]
#define sipEnum_QGraphicsView_ViewportUpdateMode sipExportedTypes_QtWidgets[171]->u.td_py_type

#define sipType_QGraphicsView_ViewportAnchor sipExportedTypes_QtWidgets[170]
#define sipEnum_QGraphicsView_ViewportAnchor sipExportedTypes_QtWidgets[170]->u.td_py_type

#define sipType_QGraphicsView_DragMode sipExportedTypes_QtWidgets[167]
#define sipEnum_QGraphicsView_DragMode sipExportedTypes_QtWidgets[167]->u.td_py_type

#define sipType_QGraphicsView_CacheModeFlag sipExportedTypes_QtWidgets[166]
#define sipEnum_QGraphicsView_CacheModeFlag sipExportedTypes_QtWidgets[166]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView;

#define sipType_QGraphicsView_CacheMode sipExportedTypes_QtWidgets[165]
#define sipClass_QGraphicsView_CacheMode sipExportedTypes_QtWidgets[165]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView_CacheMode;

#define sipType_QGraphicsView_OptimizationFlags sipExportedTypes_QtWidgets[169]
#define sipClass_QGraphicsView_OptimizationFlags sipExportedTypes_QtWidgets[169]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView_OptimizationFlags;

#define sipType_QGridLayout sipExportedTypes_QtWidgets[173]
#define sipClass_QGridLayout sipExportedTypes_QtWidgets[173]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGridLayout;

#define sipType_QGroupBox sipExportedTypes_QtWidgets[174]
#define sipClass_QGroupBox sipExportedTypes_QtWidgets[174]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QGroupBox;

#define sipType_QHeaderView sipExportedTypes_QtWidgets[176]
#define sipClass_QHeaderView sipExportedTypes_QtWidgets[176]->u.td_wrapper_type

#define sipType_QHeaderView_ResizeMode sipExportedTypes_QtWidgets[177]
#define sipEnum_QHeaderView_ResizeMode sipExportedTypes_QtWidgets[177]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QHeaderView;

#define sipType_QInputDialog sipExportedTypes_QtWidgets[178]
#define sipClass_QInputDialog sipExportedTypes_QtWidgets[178]->u.td_wrapper_type

#define sipType_QInputDialog_InputMode sipExportedTypes_QtWidgets[181]
#define sipEnum_QInputDialog_InputMode sipExportedTypes_QtWidgets[181]->u.td_py_type

#define sipType_QInputDialog_InputDialogOption sipExportedTypes_QtWidgets[179]
#define sipEnum_QInputDialog_InputDialogOption sipExportedTypes_QtWidgets[179]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog;

#define sipType_QInputDialog_InputDialogOptions sipExportedTypes_QtWidgets[180]
#define sipClass_QInputDialog_InputDialogOptions sipExportedTypes_QtWidgets[180]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog_InputDialogOptions;

#define sipType_QItemDelegate sipExportedTypes_QtWidgets[182]
#define sipClass_QItemDelegate sipExportedTypes_QtWidgets[182]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemDelegate;

#define sipType_QItemEditorCreatorBase sipExportedTypes_QtWidgets[183]
#define sipClass_QItemEditorCreatorBase sipExportedTypes_QtWidgets[183]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorCreatorBase;

#define sipType_QItemEditorFactory sipExportedTypes_QtWidgets[184]
#define sipClass_QItemEditorFactory sipExportedTypes_QtWidgets[184]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorFactory;

#define sipType_QKeyEventTransition sipExportedTypes_QtWidgets[185]
#define sipClass_QKeyEventTransition sipExportedTypes_QtWidgets[185]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QKeyEventTransition;

#define sipType_QKeySequenceEdit sipExportedTypes_QtWidgets[186]
#define sipClass_QKeySequenceEdit sipExportedTypes_QtWidgets[186]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QKeySequenceEdit;

#define sipType_QLabel sipExportedTypes_QtWidgets[190]
#define sipClass_QLabel sipExportedTypes_QtWidgets[190]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QLabel;

#define sipType_QSpacerItem sipExportedTypes_QtWidgets[281]
#define sipClass_QSpacerItem sipExportedTypes_QtWidgets[281]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpacerItem;

#define sipType_QWidgetItem sipExportedTypes_QtWidgets[467]
#define sipClass_QWidgetItem sipExportedTypes_QtWidgets[467]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetItem;

#define sipType_QLCDNumber sipExportedTypes_QtWidgets[187]
#define sipClass_QLCDNumber sipExportedTypes_QtWidgets[187]->u.td_wrapper_type

#define sipType_QLCDNumber_SegmentStyle sipExportedTypes_QtWidgets[189]
#define sipEnum_QLCDNumber_SegmentStyle sipExportedTypes_QtWidgets[189]->u.td_py_type

#define sipType_QLCDNumber_Mode sipExportedTypes_QtWidgets[188]
#define sipEnum_QLCDNumber_Mode sipExportedTypes_QtWidgets[188]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QLCDNumber;

#define sipType_QLineEdit sipExportedTypes_QtWidgets[194]
#define sipClass_QLineEdit sipExportedTypes_QtWidgets[194]->u.td_wrapper_type

#define sipType_QLineEdit_ActionPosition sipExportedTypes_QtWidgets[195]
#define sipEnum_QLineEdit_ActionPosition sipExportedTypes_QtWidgets[195]->u.td_py_type

#define sipType_QLineEdit_EchoMode sipExportedTypes_QtWidgets[196]
#define sipEnum_QLineEdit_EchoMode sipExportedTypes_QtWidgets[196]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QLineEdit;

#define sipType_QListView sipExportedTypes_QtWidgets[216]
#define sipClass_QListView sipExportedTypes_QtWidgets[216]->u.td_wrapper_type

#define sipType_QListView_ViewMode sipExportedTypes_QtWidgets[221]
#define sipEnum_QListView_ViewMode sipExportedTypes_QtWidgets[221]->u.td_py_type

#define sipType_QListView_LayoutMode sipExportedTypes_QtWidgets[218]
#define sipEnum_QListView_LayoutMode sipExportedTypes_QtWidgets[218]->u.td_py_type

#define sipType_QListView_ResizeMode sipExportedTypes_QtWidgets[220]
#define sipEnum_QListView_ResizeMode sipExportedTypes_QtWidgets[220]->u.td_py_type

#define sipType_QListView_Flow sipExportedTypes_QtWidgets[217]
#define sipEnum_QListView_Flow sipExportedTypes_QtWidgets[217]->u.td_py_type

#define sipType_QListView_Movement sipExportedTypes_QtWidgets[219]
#define sipEnum_QListView_Movement sipExportedTypes_QtWidgets[219]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QListView;

#define sipType_QListWidgetItem sipExportedTypes_QtWidgets[223]
#define sipClass_QListWidgetItem sipExportedTypes_QtWidgets[223]->u.td_wrapper_type

#define sipType_QListWidgetItem_ItemType sipExportedTypes_QtWidgets[224]
#define sipEnum_QListWidgetItem_ItemType sipExportedTypes_QtWidgets[224]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidgetItem;

#define sipType_QListWidget sipExportedTypes_QtWidgets[222]
#define sipClass_QListWidget sipExportedTypes_QtWidgets[222]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidget;

#define sipType_QMainWindow sipExportedTypes_QtWidgets[225]
#define sipClass_QMainWindow sipExportedTypes_QtWidgets[225]->u.td_wrapper_type

#define sipType_QMainWindow_DockOption sipExportedTypes_QtWidgets[226]
#define sipEnum_QMainWindow_DockOption sipExportedTypes_QtWidgets[226]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMainWindow;

#define sipType_QMainWindow_DockOptions sipExportedTypes_QtWidgets[227]
#define sipClass_QMainWindow_DockOptions sipExportedTypes_QtWidgets[227]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMainWindow_DockOptions;

#define sipType_QMdiArea sipExportedTypes_QtWidgets[229]
#define sipClass_QMdiArea sipExportedTypes_QtWidgets[229]->u.td_wrapper_type

#define sipType_QMdiArea_WindowOrder sipExportedTypes_QtWidgets[233]
#define sipEnum_QMdiArea_WindowOrder sipExportedTypes_QtWidgets[233]->u.td_py_type

#define sipType_QMdiArea_ViewMode sipExportedTypes_QtWidgets[232]
#define sipEnum_QMdiArea_ViewMode sipExportedTypes_QtWidgets[232]->u.td_py_type

#define sipType_QMdiArea_AreaOption sipExportedTypes_QtWidgets[230]
#define sipEnum_QMdiArea_AreaOption sipExportedTypes_QtWidgets[230]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiArea;

#define sipType_QMdiArea_AreaOptions sipExportedTypes_QtWidgets[231]
#define sipClass_QMdiArea_AreaOptions sipExportedTypes_QtWidgets[231]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiArea_AreaOptions;

#define sipType_QMdiSubWindow sipExportedTypes_QtWidgets[234]
#define sipClass_QMdiSubWindow sipExportedTypes_QtWidgets[234]->u.td_wrapper_type

#define sipType_QMdiSubWindow_SubWindowOption sipExportedTypes_QtWidgets[235]
#define sipEnum_QMdiSubWindow_SubWindowOption sipExportedTypes_QtWidgets[235]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiSubWindow;

#define sipType_QMdiSubWindow_SubWindowOptions sipExportedTypes_QtWidgets[236]
#define sipClass_QMdiSubWindow_SubWindowOptions sipExportedTypes_QtWidgets[236]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiSubWindow_SubWindowOptions;

#define sipType_QMenu sipExportedTypes_QtWidgets[237]
#define sipClass_QMenu sipExportedTypes_QtWidgets[237]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenu;

#define sipType_QMenuBar sipExportedTypes_QtWidgets[238]
#define sipClass_QMenuBar sipExportedTypes_QtWidgets[238]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenuBar;

#define sipType_QMessageBox sipExportedTypes_QtWidgets[239]
#define sipClass_QMessageBox sipExportedTypes_QtWidgets[239]->u.td_wrapper_type

#define sipType_QMessageBox_StandardButton sipExportedTypes_QtWidgets[242]
#define sipEnum_QMessageBox_StandardButton sipExportedTypes_QtWidgets[242]->u.td_py_type

#define sipType_QMessageBox_Icon sipExportedTypes_QtWidgets[241]
#define sipEnum_QMessageBox_Icon sipExportedTypes_QtWidgets[241]->u.td_py_type

#define sipType_QMessageBox_ButtonRole sipExportedTypes_QtWidgets[240]
#define sipEnum_QMessageBox_ButtonRole sipExportedTypes_QtWidgets[240]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMessageBox;

#define sipType_QMessageBox_StandardButtons sipExportedTypes_QtWidgets[243]
#define sipClass_QMessageBox_StandardButtons sipExportedTypes_QtWidgets[243]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMessageBox_StandardButtons;

#define sipType_QMouseEventTransition sipExportedTypes_QtWidgets[244]
#define sipClass_QMouseEventTransition sipExportedTypes_QtWidgets[244]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QMouseEventTransition;

#define sipType_QOpenGLWidget sipExportedTypes_QtWidgets[245]
#define sipClass_QOpenGLWidget sipExportedTypes_QtWidgets[245]->u.td_wrapper_type

#define sipType_QOpenGLWidget_UpdateBehavior sipExportedTypes_QtWidgets[246]
#define sipEnum_QOpenGLWidget_UpdateBehavior sipExportedTypes_QtWidgets[246]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QOpenGLWidget;

#define sipType_QPlainTextEdit sipExportedTypes_QtWidgets[252]
#define sipClass_QPlainTextEdit sipExportedTypes_QtWidgets[252]->u.td_wrapper_type

#define sipType_QPlainTextEdit_LineWrapMode sipExportedTypes_QtWidgets[253]
#define sipEnum_QPlainTextEdit_LineWrapMode sipExportedTypes_QtWidgets[253]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextEdit;

#define sipType_QPlainTextDocumentLayout sipExportedTypes_QtWidgets[251]
#define sipClass_QPlainTextDocumentLayout sipExportedTypes_QtWidgets[251]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextDocumentLayout;

#define sipType_QProgressBar sipExportedTypes_QtWidgets[254]
#define sipClass_QProgressBar sipExportedTypes_QtWidgets[254]->u.td_wrapper_type

#define sipType_QProgressBar_Direction sipExportedTypes_QtWidgets[255]
#define sipEnum_QProgressBar_Direction sipExportedTypes_QtWidgets[255]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressBar;

#define sipType_QProgressDialog sipExportedTypes_QtWidgets[256]
#define sipClass_QProgressDialog sipExportedTypes_QtWidgets[256]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressDialog;

#define sipType_QProxyStyle sipExportedTypes_QtWidgets[257]
#define sipClass_QProxyStyle sipExportedTypes_QtWidgets[257]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QProxyStyle;

#define sipType_QRadioButton sipExportedTypes_QtWidgets[259]
#define sipClass_QRadioButton sipExportedTypes_QtWidgets[259]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QRadioButton;

#define sipType_QRubberBand sipExportedTypes_QtWidgets[260]
#define sipClass_QRubberBand sipExportedTypes_QtWidgets[260]->u.td_wrapper_type

#define sipType_QRubberBand_Shape sipExportedTypes_QtWidgets[261]
#define sipEnum_QRubberBand_Shape sipExportedTypes_QtWidgets[261]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QRubberBand;

#define sipType_QScrollArea sipExportedTypes_QtWidgets[262]
#define sipClass_QScrollArea sipExportedTypes_QtWidgets[262]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollArea;

#define sipType_QScrollBar sipExportedTypes_QtWidgets[263]
#define sipClass_QScrollBar sipExportedTypes_QtWidgets[263]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollBar;

#define sipType_QScroller sipExportedTypes_QtWidgets[264]
#define sipClass_QScroller sipExportedTypes_QtWidgets[264]->u.td_wrapper_type

#define sipType_QScroller_Input sipExportedTypes_QtWidgets[265]
#define sipEnum_QScroller_Input sipExportedTypes_QtWidgets[265]->u.td_py_type

#define sipType_QScroller_ScrollerGestureType sipExportedTypes_QtWidgets[266]
#define sipEnum_QScroller_ScrollerGestureType sipExportedTypes_QtWidgets[266]->u.td_py_type

#define sipType_QScroller_State sipExportedTypes_QtWidgets[267]
#define sipEnum_QScroller_State sipExportedTypes_QtWidgets[267]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QScroller;

#define sipType_QScrollerProperties sipExportedTypes_QtWidgets[268]
#define sipClass_QScrollerProperties sipExportedTypes_QtWidgets[268]->u.td_wrapper_type

#define sipType_QScrollerProperties_ScrollMetric sipExportedTypes_QtWidgets[271]
#define sipEnum_QScrollerProperties_ScrollMetric sipExportedTypes_QtWidgets[271]->u.td_py_type

#define sipType_QScrollerProperties_FrameRates sipExportedTypes_QtWidgets[269]
#define sipEnum_QScrollerProperties_FrameRates sipExportedTypes_QtWidgets[269]->u.td_py_type

#define sipType_QScrollerProperties_OvershootPolicy sipExportedTypes_QtWidgets[270]
#define sipEnum_QScrollerProperties_OvershootPolicy sipExportedTypes_QtWidgets[270]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollerProperties;

#define sipType_QShortcut sipExportedTypes_QtWidgets[272]
#define sipClass_QShortcut sipExportedTypes_QtWidgets[272]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QShortcut;

#define sipType_QSizeGrip sipExportedTypes_QtWidgets[273]
#define sipClass_QSizeGrip sipExportedTypes_QtWidgets[273]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizeGrip;

#define sipType_QSizePolicy sipExportedTypes_QtWidgets[274]
#define sipClass_QSizePolicy sipExportedTypes_QtWidgets[274]->u.td_wrapper_type

#define sipType_QSizePolicy_ControlType sipExportedTypes_QtWidgets[275]
#define sipEnum_QSizePolicy_ControlType sipExportedTypes_QtWidgets[275]->u.td_py_type

#define sipType_QSizePolicy_Policy sipExportedTypes_QtWidgets[277]
#define sipEnum_QSizePolicy_Policy sipExportedTypes_QtWidgets[277]->u.td_py_type

#define sipType_QSizePolicy_PolicyFlag sipExportedTypes_QtWidgets[278]
#define sipEnum_QSizePolicy_PolicyFlag sipExportedTypes_QtWidgets[278]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizePolicy;

#define sipType_QSizePolicy_ControlTypes sipExportedTypes_QtWidgets[276]
#define sipClass_QSizePolicy_ControlTypes sipExportedTypes_QtWidgets[276]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizePolicy_ControlTypes;

#define sipType_QSlider sipExportedTypes_QtWidgets[279]
#define sipClass_QSlider sipExportedTypes_QtWidgets[279]->u.td_wrapper_type

#define sipType_QSlider_TickPosition sipExportedTypes_QtWidgets[280]
#define sipEnum_QSlider_TickPosition sipExportedTypes_QtWidgets[280]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSlider;

#define sipType_QSpinBox sipExportedTypes_QtWidgets[282]
#define sipClass_QSpinBox sipExportedTypes_QtWidgets[282]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpinBox;

#define sipType_QDoubleSpinBox sipExportedTypes_QtWidgets[74]
#define sipClass_QDoubleSpinBox sipExportedTypes_QtWidgets[74]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QDoubleSpinBox;

#define sipType_QSplashScreen sipExportedTypes_QtWidgets[283]
#define sipClass_QSplashScreen sipExportedTypes_QtWidgets[283]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplashScreen;

#define sipType_QSplitter sipExportedTypes_QtWidgets[284]
#define sipClass_QSplitter sipExportedTypes_QtWidgets[284]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitter;

#define sipType_QSplitterHandle sipExportedTypes_QtWidgets[285]
#define sipClass_QSplitterHandle sipExportedTypes_QtWidgets[285]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitterHandle;

#define sipType_QStackedLayout sipExportedTypes_QtWidgets[286]
#define sipClass_QStackedLayout sipExportedTypes_QtWidgets[286]->u.td_wrapper_type

#define sipType_QStackedLayout_StackingMode sipExportedTypes_QtWidgets[287]
#define sipEnum_QStackedLayout_StackingMode sipExportedTypes_QtWidgets[287]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedLayout;

#define sipType_QStackedWidget sipExportedTypes_QtWidgets[288]
#define sipClass_QStackedWidget sipExportedTypes_QtWidgets[288]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedWidget;

#define sipType_QStatusBar sipExportedTypes_QtWidgets[289]
#define sipClass_QStatusBar sipExportedTypes_QtWidgets[289]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStatusBar;

#define sipType_QStyle_State sipExportedTypes_QtWidgets[298]
#define sipClass_QStyle_State sipExportedTypes_QtWidgets[298]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle_State;

#define sipType_QStyle_SubControls sipExportedTypes_QtWidgets[302]
#define sipClass_QStyle_SubControls sipExportedTypes_QtWidgets[302]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle_SubControls;

#define sipType_QStyledItemDelegate sipExportedTypes_QtWidgets[417]
#define sipClass_QStyledItemDelegate sipExportedTypes_QtWidgets[417]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyledItemDelegate;

#define sipType_QStyleFactory sipExportedTypes_QtWidgets[304]
#define sipClass_QStyleFactory sipExportedTypes_QtWidgets[304]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleFactory;

#define sipType_QStyleOption sipExportedTypes_QtWidgets[315]
#define sipClass_QStyleOption sipExportedTypes_QtWidgets[315]->u.td_wrapper_type

#define sipType_QStyleOption_StyleOptionVersion sipExportedTypes_QtWidgets[318]
#define sipEnum_QStyleOption_StyleOptionVersion sipExportedTypes_QtWidgets[318]->u.td_py_type

#define sipType_QStyleOption_StyleOptionType sipExportedTypes_QtWidgets[317]
#define sipEnum_QStyleOption_StyleOptionType sipExportedTypes_QtWidgets[317]->u.td_py_type

#define sipType_QStyleOption_OptionType sipExportedTypes_QtWidgets[316]
#define sipEnum_QStyleOption_OptionType sipExportedTypes_QtWidgets[316]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOption;

#define sipType_QStyleOptionFocusRect sipExportedTypes_QtWidgets[333]
#define sipClass_QStyleOptionFocusRect sipExportedTypes_QtWidgets[333]->u.td_wrapper_type

#define sipType_QStyleOptionFocusRect_StyleOptionVersion sipExportedTypes_QtWidgets[335]
#define sipEnum_QStyleOptionFocusRect_StyleOptionVersion sipExportedTypes_QtWidgets[335]->u.td_py_type

#define sipType_QStyleOptionFocusRect_StyleOptionType sipExportedTypes_QtWidgets[334]
#define sipEnum_QStyleOptionFocusRect_StyleOptionType sipExportedTypes_QtWidgets[334]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFocusRect;

#define sipType_QStyleOptionFrame sipExportedTypes_QtWidgets[336]
#define sipClass_QStyleOptionFrame sipExportedTypes_QtWidgets[336]->u.td_wrapper_type

#define sipType_QStyleOptionFrame_FrameFeature sipExportedTypes_QtWidgets[337]
#define sipEnum_QStyleOptionFrame_FrameFeature sipExportedTypes_QtWidgets[337]->u.td_py_type

#define sipType_QStyleOptionFrame_StyleOptionVersion sipExportedTypes_QtWidgets[340]
#define sipEnum_QStyleOptionFrame_StyleOptionVersion sipExportedTypes_QtWidgets[340]->u.td_py_type

#define sipType_QStyleOptionFrame_StyleOptionType sipExportedTypes_QtWidgets[339]
#define sipEnum_QStyleOptionFrame_StyleOptionType sipExportedTypes_QtWidgets[339]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFrame;

#define sipType_QStyleOptionFrame_FrameFeatures sipExportedTypes_QtWidgets[338]
#define sipClass_QStyleOptionFrame_FrameFeatures sipExportedTypes_QtWidgets[338]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFrame_FrameFeatures;

#define sipType_QStyleOptionTabWidgetFrame sipExportedTypes_QtWidgets[387]
#define sipClass_QStyleOptionTabWidgetFrame sipExportedTypes_QtWidgets[387]->u.td_wrapper_type

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionVersion sipExportedTypes_QtWidgets[389]
#define sipEnum_QStyleOptionTabWidgetFrame_StyleOptionVersion sipExportedTypes_QtWidgets[389]->u.td_py_type

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionType sipExportedTypes_QtWidgets[388]
#define sipEnum_QStyleOptionTabWidgetFrame_StyleOptionType sipExportedTypes_QtWidgets[388]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabWidgetFrame;

#define sipType_QStyleOptionTabBarBase sipExportedTypes_QtWidgets[382]
#define sipClass_QStyleOptionTabBarBase sipExportedTypes_QtWidgets[382]->u.td_wrapper_type

#define sipType_QStyleOptionTabBarBase_StyleOptionVersion sipExportedTypes_QtWidgets[384]
#define sipEnum_QStyleOptionTabBarBase_StyleOptionVersion sipExportedTypes_QtWidgets[384]->u.td_py_type

#define sipType_QStyleOptionTabBarBase_StyleOptionType sipExportedTypes_QtWidgets[383]
#define sipEnum_QStyleOptionTabBarBase_StyleOptionType sipExportedTypes_QtWidgets[383]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabBarBase;

#define sipType_QStyleOptionHeader sipExportedTypes_QtWidgets[347]
#define sipClass_QStyleOptionHeader sipExportedTypes_QtWidgets[347]->u.td_wrapper_type

#define sipType_QStyleOptionHeader_SortIndicator sipExportedTypes_QtWidgets[350]
#define sipEnum_QStyleOptionHeader_SortIndicator sipExportedTypes_QtWidgets[350]->u.td_py_type

#define sipType_QStyleOptionHeader_SelectedPosition sipExportedTypes_QtWidgets[349]
#define sipEnum_QStyleOptionHeader_SelectedPosition sipExportedTypes_QtWidgets[349]->u.td_py_type

#define sipType_QStyleOptionHeader_SectionPosition sipExportedTypes_QtWidgets[348]
#define sipEnum_QStyleOptionHeader_SectionPosition sipExportedTypes_QtWidgets[348]->u.td_py_type

#define sipType_QStyleOptionHeader_StyleOptionVersion sipExportedTypes_QtWidgets[352]
#define sipEnum_QStyleOptionHeader_StyleOptionVersion sipExportedTypes_QtWidgets[352]->u.td_py_type

#define sipType_QStyleOptionHeader_StyleOptionType sipExportedTypes_QtWidgets[351]
#define sipEnum_QStyleOptionHeader_StyleOptionType sipExportedTypes_QtWidgets[351]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionHeader;

#define sipType_QStyleOptionButton sipExportedTypes_QtWidgets[319]
#define sipClass_QStyleOptionButton sipExportedTypes_QtWidgets[319]->u.td_wrapper_type

#define sipType_QStyleOptionButton_ButtonFeature sipExportedTypes_QtWidgets[320]
#define sipEnum_QStyleOptionButton_ButtonFeature sipExportedTypes_QtWidgets[320]->u.td_py_type

#define sipType_QStyleOptionButton_StyleOptionVersion sipExportedTypes_QtWidgets[323]
#define sipEnum_QStyleOptionButton_StyleOptionVersion sipExportedTypes_QtWidgets[323]->u.td_py_type

#define sipType_QStyleOptionButton_StyleOptionType sipExportedTypes_QtWidgets[322]
#define sipEnum_QStyleOptionButton_StyleOptionType sipExportedTypes_QtWidgets[322]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionButton;

#define sipType_QStyleOptionButton_ButtonFeatures sipExportedTypes_QtWidgets[321]
#define sipClass_QStyleOptionButton_ButtonFeatures sipExportedTypes_QtWidgets[321]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionButton_ButtonFeatures;

#define sipType_QStyleOptionTab sipExportedTypes_QtWidgets[373]
#define sipClass_QStyleOptionTab sipExportedTypes_QtWidgets[373]->u.td_wrapper_type

#define sipType_QStyleOptionTab_TabFeature sipExportedTypes_QtWidgets[379]
#define sipEnum_QStyleOptionTab_TabFeature sipExportedTypes_QtWidgets[379]->u.td_py_type

#define sipType_QStyleOptionTab_CornerWidget sipExportedTypes_QtWidgets[374]
#define sipEnum_QStyleOptionTab_CornerWidget sipExportedTypes_QtWidgets[374]->u.td_py_type

#define sipType_QStyleOptionTab_SelectedPosition sipExportedTypes_QtWidgets[376]
#define sipEnum_QStyleOptionTab_SelectedPosition sipExportedTypes_QtWidgets[376]->u.td_py_type

#define sipType_QStyleOptionTab_TabPosition sipExportedTypes_QtWidgets[381]
#define sipEnum_QStyleOptionTab_TabPosition sipExportedTypes_QtWidgets[381]->u.td_py_type

#define sipType_QStyleOptionTab_StyleOptionVersion sipExportedTypes_QtWidgets[378]
#define sipEnum_QStyleOptionTab_StyleOptionVersion sipExportedTypes_QtWidgets[378]->u.td_py_type

#define sipType_QStyleOptionTab_StyleOptionType sipExportedTypes_QtWidgets[377]
#define sipEnum_QStyleOptionTab_StyleOptionType sipExportedTypes_QtWidgets[377]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab;

#define sipType_QStyleOptionTab_CornerWidgets sipExportedTypes_QtWidgets[375]
#define sipClass_QStyleOptionTab_CornerWidgets sipExportedTypes_QtWidgets[375]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab_CornerWidgets;

#define sipType_QStyleOptionTab_TabFeatures sipExportedTypes_QtWidgets[380]
#define sipClass_QStyleOptionTab_TabFeatures sipExportedTypes_QtWidgets[380]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab_TabFeatures;

#define sipType_QStyleOptionTabV4 sipExportedTypes_QtWidgets[385]
#define sipClass_QStyleOptionTabV4 sipExportedTypes_QtWidgets[385]->u.td_wrapper_type

#define sipType_QStyleOptionTabV4_StyleOptionVersion sipExportedTypes_QtWidgets[386]
#define sipEnum_QStyleOptionTabV4_StyleOptionVersion sipExportedTypes_QtWidgets[386]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabV4;

#define sipType_QStyleOptionProgressBar sipExportedTypes_QtWidgets[358]
#define sipClass_QStyleOptionProgressBar sipExportedTypes_QtWidgets[358]->u.td_wrapper_type

#define sipType_QStyleOptionProgressBar_StyleOptionVersion sipExportedTypes_QtWidgets[360]
#define sipEnum_QStyleOptionProgressBar_StyleOptionVersion sipExportedTypes_QtWidgets[360]->u.td_py_type

#define sipType_QStyleOptionProgressBar_StyleOptionType sipExportedTypes_QtWidgets[359]
#define sipEnum_QStyleOptionProgressBar_StyleOptionType sipExportedTypes_QtWidgets[359]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionProgressBar;

#define sipType_QStyleOptionMenuItem sipExportedTypes_QtWidgets[353]
#define sipClass_QStyleOptionMenuItem sipExportedTypes_QtWidgets[353]->u.td_wrapper_type

#define sipType_QStyleOptionMenuItem_CheckType sipExportedTypes_QtWidgets[354]
#define sipEnum_QStyleOptionMenuItem_CheckType sipExportedTypes_QtWidgets[354]->u.td_py_type

#define sipType_QStyleOptionMenuItem_MenuItemType sipExportedTypes_QtWidgets[355]
#define sipEnum_QStyleOptionMenuItem_MenuItemType sipExportedTypes_QtWidgets[355]->u.td_py_type

#define sipType_QStyleOptionMenuItem_StyleOptionVersion sipExportedTypes_QtWidgets[357]
#define sipEnum_QStyleOptionMenuItem_StyleOptionVersion sipExportedTypes_QtWidgets[357]->u.td_py_type

#define sipType_QStyleOptionMenuItem_StyleOptionType sipExportedTypes_QtWidgets[356]
#define sipEnum_QStyleOptionMenuItem_StyleOptionType sipExportedTypes_QtWidgets[356]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionMenuItem;

#define sipType_QStyleOptionDockWidget sipExportedTypes_QtWidgets[330]
#define sipClass_QStyleOptionDockWidget sipExportedTypes_QtWidgets[330]->u.td_wrapper_type

#define sipType_QStyleOptionDockWidget_StyleOptionVersion sipExportedTypes_QtWidgets[332]
#define sipEnum_QStyleOptionDockWidget_StyleOptionVersion sipExportedTypes_QtWidgets[332]->u.td_py_type

#define sipType_QStyleOptionDockWidget_StyleOptionType sipExportedTypes_QtWidgets[331]
#define sipEnum_QStyleOptionDockWidget_StyleOptionType sipExportedTypes_QtWidgets[331]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionDockWidget;

#define sipType_QStyleOptionViewItem sipExportedTypes_QtWidgets[409]
#define sipClass_QStyleOptionViewItem sipExportedTypes_QtWidgets[409]->u.td_wrapper_type

#define sipType_QStyleOptionViewItem_ViewItemPosition sipExportedTypes_QtWidgets[415]
#define sipEnum_QStyleOptionViewItem_ViewItemPosition sipExportedTypes_QtWidgets[415]->u.td_py_type

#define sipType_QStyleOptionViewItem_ViewItemFeature sipExportedTypes_QtWidgets[413]
#define sipEnum_QStyleOptionViewItem_ViewItemFeature sipExportedTypes_QtWidgets[413]->u.td_py_type

#define sipType_QStyleOptionViewItem_Position sipExportedTypes_QtWidgets[410]
#define sipEnum_QStyleOptionViewItem_Position sipExportedTypes_QtWidgets[410]->u.td_py_type

#define sipType_QStyleOptionViewItem_StyleOptionVersion sipExportedTypes_QtWidgets[412]
#define sipEnum_QStyleOptionViewItem_StyleOptionVersion sipExportedTypes_QtWidgets[412]->u.td_py_type

#define sipType_QStyleOptionViewItem_StyleOptionType sipExportedTypes_QtWidgets[411]
#define sipEnum_QStyleOptionViewItem_StyleOptionType sipExportedTypes_QtWidgets[411]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionViewItem;

#define sipType_QStyleOptionViewItem_ViewItemFeatures sipExportedTypes_QtWidgets[414]
#define sipClass_QStyleOptionViewItem_ViewItemFeatures sipExportedTypes_QtWidgets[414]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionViewItem_ViewItemFeatures;

#define sipType_QStyleOptionToolBox sipExportedTypes_QtWidgets[399]
#define sipClass_QStyleOptionToolBox sipExportedTypes_QtWidgets[399]->u.td_wrapper_type

#define sipType_QStyleOptionToolBox_SelectedPosition sipExportedTypes_QtWidgets[400]
#define sipEnum_QStyleOptionToolBox_SelectedPosition sipExportedTypes_QtWidgets[400]->u.td_py_type

#define sipType_QStyleOptionToolBox_TabPosition sipExportedTypes_QtWidgets[403]
#define sipEnum_QStyleOptionToolBox_TabPosition sipExportedTypes_QtWidgets[403]->u.td_py_type

#define sipType_QStyleOptionToolBox_StyleOptionVersion sipExportedTypes_QtWidgets[402]
#define sipEnum_QStyleOptionToolBox_StyleOptionVersion sipExportedTypes_QtWidgets[402]->u.td_py_type

#define sipType_QStyleOptionToolBox_StyleOptionType sipExportedTypes_QtWidgets[401]
#define sipEnum_QStyleOptionToolBox_StyleOptionType sipExportedTypes_QtWidgets[401]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBox;

#define sipType_QStyleOptionRubberBand sipExportedTypes_QtWidgets[361]
#define sipClass_QStyleOptionRubberBand sipExportedTypes_QtWidgets[361]->u.td_wrapper_type

#define sipType_QStyleOptionRubberBand_StyleOptionVersion sipExportedTypes_QtWidgets[363]
#define sipEnum_QStyleOptionRubberBand_StyleOptionVersion sipExportedTypes_QtWidgets[363]->u.td_py_type

#define sipType_QStyleOptionRubberBand_StyleOptionType sipExportedTypes_QtWidgets[362]
#define sipEnum_QStyleOptionRubberBand_StyleOptionType sipExportedTypes_QtWidgets[362]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionRubberBand;

#define sipType_QStyleOptionComplex sipExportedTypes_QtWidgets[327]
#define sipClass_QStyleOptionComplex sipExportedTypes_QtWidgets[327]->u.td_wrapper_type

#define sipType_QStyleOptionComplex_StyleOptionVersion sipExportedTypes_QtWidgets[329]
#define sipEnum_QStyleOptionComplex_StyleOptionVersion sipExportedTypes_QtWidgets[329]->u.td_py_type

#define sipType_QStyleOptionComplex_StyleOptionType sipExportedTypes_QtWidgets[328]
#define sipEnum_QStyleOptionComplex_StyleOptionType sipExportedTypes_QtWidgets[328]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComplex;

#define sipType_QStyleOptionSlider sipExportedTypes_QtWidgets[367]
#define sipClass_QStyleOptionSlider sipExportedTypes_QtWidgets[367]->u.td_wrapper_type

#define sipType_QStyleOptionSlider_StyleOptionVersion sipExportedTypes_QtWidgets[369]
#define sipEnum_QStyleOptionSlider_StyleOptionVersion sipExportedTypes_QtWidgets[369]->u.td_py_type

#define sipType_QStyleOptionSlider_StyleOptionType sipExportedTypes_QtWidgets[368]
#define sipEnum_QStyleOptionSlider_StyleOptionType sipExportedTypes_QtWidgets[368]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSlider;

#define sipType_QStyleOptionSpinBox sipExportedTypes_QtWidgets[370]
#define sipClass_QStyleOptionSpinBox sipExportedTypes_QtWidgets[370]->u.td_wrapper_type

#define sipType_QStyleOptionSpinBox_StyleOptionVersion sipExportedTypes_QtWidgets[372]
#define sipEnum_QStyleOptionSpinBox_StyleOptionVersion sipExportedTypes_QtWidgets[372]->u.td_py_type

#define sipType_QStyleOptionSpinBox_StyleOptionType sipExportedTypes_QtWidgets[371]
#define sipEnum_QStyleOptionSpinBox_StyleOptionType sipExportedTypes_QtWidgets[371]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSpinBox;

#define sipType_QStyleOptionToolButton sipExportedTypes_QtWidgets[404]
#define sipClass_QStyleOptionToolButton sipExportedTypes_QtWidgets[404]->u.td_wrapper_type

#define sipType_QStyleOptionToolButton_ToolButtonFeature sipExportedTypes_QtWidgets[407]
#define sipEnum_QStyleOptionToolButton_ToolButtonFeature sipExportedTypes_QtWidgets[407]->u.td_py_type

#define sipType_QStyleOptionToolButton_StyleOptionVersion sipExportedTypes_QtWidgets[406]
#define sipEnum_QStyleOptionToolButton_StyleOptionVersion sipExportedTypes_QtWidgets[406]->u.td_py_type

#define sipType_QStyleOptionToolButton_StyleOptionType sipExportedTypes_QtWidgets[405]
#define sipEnum_QStyleOptionToolButton_StyleOptionType sipExportedTypes_QtWidgets[405]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolButton;

#define sipType_QStyleOptionToolButton_ToolButtonFeatures sipExportedTypes_QtWidgets[408]
#define sipClass_QStyleOptionToolButton_ToolButtonFeatures sipExportedTypes_QtWidgets[408]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolButton_ToolButtonFeatures;

#define sipType_QStyleOptionComboBox sipExportedTypes_QtWidgets[324]
#define sipClass_QStyleOptionComboBox sipExportedTypes_QtWidgets[324]->u.td_wrapper_type

#define sipType_QStyleOptionComboBox_StyleOptionVersion sipExportedTypes_QtWidgets[326]
#define sipEnum_QStyleOptionComboBox_StyleOptionVersion sipExportedTypes_QtWidgets[326]->u.td_py_type

#define sipType_QStyleOptionComboBox_StyleOptionType sipExportedTypes_QtWidgets[325]
#define sipEnum_QStyleOptionComboBox_StyleOptionType sipExportedTypes_QtWidgets[325]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComboBox;

#define sipType_QStyleOptionTitleBar sipExportedTypes_QtWidgets[390]
#define sipClass_QStyleOptionTitleBar sipExportedTypes_QtWidgets[390]->u.td_wrapper_type

#define sipType_QStyleOptionTitleBar_StyleOptionVersion sipExportedTypes_QtWidgets[392]
#define sipEnum_QStyleOptionTitleBar_StyleOptionVersion sipExportedTypes_QtWidgets[392]->u.td_py_type

#define sipType_QStyleOptionTitleBar_StyleOptionType sipExportedTypes_QtWidgets[391]
#define sipEnum_QStyleOptionTitleBar_StyleOptionType sipExportedTypes_QtWidgets[391]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTitleBar;

#define sipType_QStyleHintReturn sipExportedTypes_QtWidgets[305]
#define sipClass_QStyleHintReturn sipExportedTypes_QtWidgets[305]->u.td_wrapper_type

#define sipType_QStyleHintReturn_StyleOptionVersion sipExportedTypes_QtWidgets[308]
#define sipEnum_QStyleHintReturn_StyleOptionVersion sipExportedTypes_QtWidgets[308]->u.td_py_type

#define sipType_QStyleHintReturn_StyleOptionType sipExportedTypes_QtWidgets[307]
#define sipEnum_QStyleHintReturn_StyleOptionType sipExportedTypes_QtWidgets[307]->u.td_py_type

#define sipType_QStyleHintReturn_HintReturnType sipExportedTypes_QtWidgets[306]
#define sipEnum_QStyleHintReturn_HintReturnType sipExportedTypes_QtWidgets[306]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturn;

#define sipType_QStyleHintReturnMask sipExportedTypes_QtWidgets[309]
#define sipClass_QStyleHintReturnMask sipExportedTypes_QtWidgets[309]->u.td_wrapper_type

#define sipType_QStyleHintReturnMask_StyleOptionVersion sipExportedTypes_QtWidgets[311]
#define sipEnum_QStyleHintReturnMask_StyleOptionVersion sipExportedTypes_QtWidgets[311]->u.td_py_type

#define sipType_QStyleHintReturnMask_StyleOptionType sipExportedTypes_QtWidgets[310]
#define sipEnum_QStyleHintReturnMask_StyleOptionType sipExportedTypes_QtWidgets[310]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnMask;

#define sipType_QStyleOptionToolBar sipExportedTypes_QtWidgets[393]
#define sipClass_QStyleOptionToolBar sipExportedTypes_QtWidgets[393]->u.td_wrapper_type

#define sipType_QStyleOptionToolBar_ToolBarFeature sipExportedTypes_QtWidgets[396]
#define sipEnum_QStyleOptionToolBar_ToolBarFeature sipExportedTypes_QtWidgets[396]->u.td_py_type

#define sipType_QStyleOptionToolBar_ToolBarPosition sipExportedTypes_QtWidgets[398]
#define sipEnum_QStyleOptionToolBar_ToolBarPosition sipExportedTypes_QtWidgets[398]->u.td_py_type

#define sipType_QStyleOptionToolBar_StyleOptionVersion sipExportedTypes_QtWidgets[395]
#define sipEnum_QStyleOptionToolBar_StyleOptionVersion sipExportedTypes_QtWidgets[395]->u.td_py_type

#define sipType_QStyleOptionToolBar_StyleOptionType sipExportedTypes_QtWidgets[394]
#define sipEnum_QStyleOptionToolBar_StyleOptionType sipExportedTypes_QtWidgets[394]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBar;

#define sipType_QStyleOptionToolBar_ToolBarFeatures sipExportedTypes_QtWidgets[397]
#define sipClass_QStyleOptionToolBar_ToolBarFeatures sipExportedTypes_QtWidgets[397]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBar_ToolBarFeatures;

#define sipType_QStyleOptionGroupBox sipExportedTypes_QtWidgets[344]
#define sipClass_QStyleOptionGroupBox sipExportedTypes_QtWidgets[344]->u.td_wrapper_type

#define sipType_QStyleOptionGroupBox_StyleOptionVersion sipExportedTypes_QtWidgets[346]
#define sipEnum_QStyleOptionGroupBox_StyleOptionVersion sipExportedTypes_QtWidgets[346]->u.td_py_type

#define sipType_QStyleOptionGroupBox_StyleOptionType sipExportedTypes_QtWidgets[345]
#define sipEnum_QStyleOptionGroupBox_StyleOptionType sipExportedTypes_QtWidgets[345]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGroupBox;

#define sipType_QStyleOptionSizeGrip sipExportedTypes_QtWidgets[364]
#define sipClass_QStyleOptionSizeGrip sipExportedTypes_QtWidgets[364]->u.td_wrapper_type

#define sipType_QStyleOptionSizeGrip_StyleOptionVersion sipExportedTypes_QtWidgets[366]
#define sipEnum_QStyleOptionSizeGrip_StyleOptionVersion sipExportedTypes_QtWidgets[366]->u.td_py_type

#define sipType_QStyleOptionSizeGrip_StyleOptionType sipExportedTypes_QtWidgets[365]
#define sipEnum_QStyleOptionSizeGrip_StyleOptionType sipExportedTypes_QtWidgets[365]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSizeGrip;

#define sipType_QStyleOptionGraphicsItem sipExportedTypes_QtWidgets[341]
#define sipClass_QStyleOptionGraphicsItem sipExportedTypes_QtWidgets[341]->u.td_wrapper_type

#define sipType_QStyleOptionGraphicsItem_StyleOptionVersion sipExportedTypes_QtWidgets[343]
#define sipEnum_QStyleOptionGraphicsItem_StyleOptionVersion sipExportedTypes_QtWidgets[343]->u.td_py_type

#define sipType_QStyleOptionGraphicsItem_StyleOptionType sipExportedTypes_QtWidgets[342]
#define sipEnum_QStyleOptionGraphicsItem_StyleOptionType sipExportedTypes_QtWidgets[342]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGraphicsItem;

#define sipType_QStyleHintReturnVariant sipExportedTypes_QtWidgets[312]
#define sipClass_QStyleHintReturnVariant sipExportedTypes_QtWidgets[312]->u.td_wrapper_type

#define sipType_QStyleHintReturnVariant_StyleOptionVersion sipExportedTypes_QtWidgets[314]
#define sipEnum_QStyleHintReturnVariant_StyleOptionVersion sipExportedTypes_QtWidgets[314]->u.td_py_type

#define sipType_QStyleHintReturnVariant_StyleOptionType sipExportedTypes_QtWidgets[313]
#define sipEnum_QStyleHintReturnVariant_StyleOptionType sipExportedTypes_QtWidgets[313]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnVariant;

#define sipType_QStylePainter sipExportedTypes_QtWidgets[416]
#define sipClass_QStylePainter sipExportedTypes_QtWidgets[416]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QStylePainter;

#define sipType_QSystemTrayIcon sipExportedTypes_QtWidgets[420]
#define sipClass_QSystemTrayIcon sipExportedTypes_QtWidgets[420]->u.td_wrapper_type

#define sipType_QSystemTrayIcon_MessageIcon sipExportedTypes_QtWidgets[422]
#define sipEnum_QSystemTrayIcon_MessageIcon sipExportedTypes_QtWidgets[422]->u.td_py_type

#define sipType_QSystemTrayIcon_ActivationReason sipExportedTypes_QtWidgets[421]
#define sipEnum_QSystemTrayIcon_ActivationReason sipExportedTypes_QtWidgets[421]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QSystemTrayIcon;

#define sipType_QTabBar sipExportedTypes_QtWidgets[423]
#define sipClass_QTabBar sipExportedTypes_QtWidgets[423]->u.td_wrapper_type

#define sipType_QTabBar_SelectionBehavior sipExportedTypes_QtWidgets[425]
#define sipEnum_QTabBar_SelectionBehavior sipExportedTypes_QtWidgets[425]->u.td_py_type

#define sipType_QTabBar_ButtonPosition sipExportedTypes_QtWidgets[424]
#define sipEnum_QTabBar_ButtonPosition sipExportedTypes_QtWidgets[424]->u.td_py_type

#define sipType_QTabBar_Shape sipExportedTypes_QtWidgets[426]
#define sipEnum_QTabBar_Shape sipExportedTypes_QtWidgets[426]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabBar;

#define sipType_QTableView sipExportedTypes_QtWidgets[430]
#define sipClass_QTableView sipExportedTypes_QtWidgets[430]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableView;

#define sipType_QTableWidgetSelectionRange sipExportedTypes_QtWidgets[434]
#define sipClass_QTableWidgetSelectionRange sipExportedTypes_QtWidgets[434]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetSelectionRange;

#define sipType_QTableWidgetItem sipExportedTypes_QtWidgets[432]
#define sipClass_QTableWidgetItem sipExportedTypes_QtWidgets[432]->u.td_wrapper_type

#define sipType_QTableWidgetItem_ItemType sipExportedTypes_QtWidgets[433]
#define sipEnum_QTableWidgetItem_ItemType sipExportedTypes_QtWidgets[433]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetItem;

#define sipType_QTableWidget sipExportedTypes_QtWidgets[431]
#define sipClass_QTableWidget sipExportedTypes_QtWidgets[431]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidget;

#define sipType_QTabWidget sipExportedTypes_QtWidgets[427]
#define sipClass_QTabWidget sipExportedTypes_QtWidgets[427]->u.td_wrapper_type

#define sipType_QTabWidget_TabShape sipExportedTypes_QtWidgets[429]
#define sipEnum_QTabWidget_TabShape sipExportedTypes_QtWidgets[429]->u.td_py_type

#define sipType_QTabWidget_TabPosition sipExportedTypes_QtWidgets[428]
#define sipEnum_QTabWidget_TabPosition sipExportedTypes_QtWidgets[428]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabWidget;

#define sipType_QTextEdit sipExportedTypes_QtWidgets[438]
#define sipClass_QTextEdit sipExportedTypes_QtWidgets[438]->u.td_wrapper_type

#define sipType_QTextEdit_AutoFormattingFlag sipExportedTypes_QtWidgets[440]
#define sipEnum_QTextEdit_AutoFormattingFlag sipExportedTypes_QtWidgets[440]->u.td_py_type

#define sipType_QTextEdit_LineWrapMode sipExportedTypes_QtWidgets[442]
#define sipEnum_QTextEdit_LineWrapMode sipExportedTypes_QtWidgets[442]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit;

#define sipType_QTextBrowser sipExportedTypes_QtWidgets[437]
#define sipClass_QTextBrowser sipExportedTypes_QtWidgets[437]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextBrowser;

#define sipType_QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[441]
#define sipClass_QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[441]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit_ExtraSelection;

#define sipType_QTextEdit_AutoFormatting sipExportedTypes_QtWidgets[439]
#define sipClass_QTextEdit_AutoFormatting sipExportedTypes_QtWidgets[439]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit_AutoFormatting;

#define sipType_QToolBar sipExportedTypes_QtWidgets[444]
#define sipClass_QToolBar sipExportedTypes_QtWidgets[444]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBar;

#define sipType_QToolBox sipExportedTypes_QtWidgets[445]
#define sipClass_QToolBox sipExportedTypes_QtWidgets[445]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBox;

#define sipType_QToolButton sipExportedTypes_QtWidgets[446]
#define sipClass_QToolButton sipExportedTypes_QtWidgets[446]->u.td_wrapper_type

#define sipType_QToolButton_ToolButtonPopupMode sipExportedTypes_QtWidgets[447]
#define sipEnum_QToolButton_ToolButtonPopupMode sipExportedTypes_QtWidgets[447]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolButton;

#define sipType_QToolTip sipExportedTypes_QtWidgets[448]
#define sipClass_QToolTip sipExportedTypes_QtWidgets[448]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolTip;

#define sipType_QTreeView sipExportedTypes_QtWidgets[449]
#define sipClass_QTreeView sipExportedTypes_QtWidgets[449]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeView;

#define sipType_QTreeWidgetItem sipExportedTypes_QtWidgets[451]
#define sipClass_QTreeWidgetItem sipExportedTypes_QtWidgets[451]->u.td_wrapper_type

#define sipType_QTreeWidgetItem_ChildIndicatorPolicy sipExportedTypes_QtWidgets[452]
#define sipEnum_QTreeWidgetItem_ChildIndicatorPolicy sipExportedTypes_QtWidgets[452]->u.td_py_type

#define sipType_QTreeWidgetItem_ItemType sipExportedTypes_QtWidgets[453]
#define sipEnum_QTreeWidgetItem_ItemType sipExportedTypes_QtWidgets[453]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItem;

#define sipType_QTreeWidget sipExportedTypes_QtWidgets[450]
#define sipClass_QTreeWidget sipExportedTypes_QtWidgets[450]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidget;

#define sipType_QTreeWidgetItemIterator sipExportedTypes_QtWidgets[454]
#define sipClass_QTreeWidgetItemIterator sipExportedTypes_QtWidgets[454]->u.td_wrapper_type

#define sipType_QTreeWidgetItemIterator_IteratorFlag sipExportedTypes_QtWidgets[455]
#define sipEnum_QTreeWidgetItemIterator_IteratorFlag sipExportedTypes_QtWidgets[455]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItemIterator;

#define sipType_QTreeWidgetItemIterator_IteratorFlags sipExportedTypes_QtWidgets[456]
#define sipClass_QTreeWidgetItemIterator_IteratorFlags sipExportedTypes_QtWidgets[456]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItemIterator_IteratorFlags;

#define sipType_QUndoGroup sipExportedTypes_QtWidgets[458]
#define sipClass_QUndoGroup sipExportedTypes_QtWidgets[458]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoGroup;

#define sipType_QUndoCommand sipExportedTypes_QtWidgets[457]
#define sipClass_QUndoCommand sipExportedTypes_QtWidgets[457]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoCommand;

#define sipType_QUndoStack sipExportedTypes_QtWidgets[459]
#define sipClass_QUndoStack sipExportedTypes_QtWidgets[459]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoStack;

#define sipType_QUndoView sipExportedTypes_QtWidgets[460]
#define sipClass_QUndoView sipExportedTypes_QtWidgets[460]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoView;

#define sipType_QWhatsThis sipExportedTypes_QtWidgets[462]
#define sipClass_QWhatsThis sipExportedTypes_QtWidgets[462]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWhatsThis;

#define sipType_QWidget_RenderFlags sipExportedTypes_QtWidgets[465]
#define sipClass_QWidget_RenderFlags sipExportedTypes_QtWidgets[465]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidget_RenderFlags;

#define sipType_QWidgetAction sipExportedTypes_QtWidgets[466]
#define sipClass_QWidgetAction sipExportedTypes_QtWidgets[466]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetAction;

#define sipType_QWizard sipExportedTypes_QtWidgets[468]
#define sipClass_QWizard sipExportedTypes_QtWidgets[468]->u.td_wrapper_type

#define sipType_QWizard_WizardOption sipExportedTypes_QtWidgets[470]
#define sipEnum_QWizard_WizardOption sipExportedTypes_QtWidgets[470]->u.td_py_type

#define sipType_QWizard_WizardStyle sipExportedTypes_QtWidgets[473]
#define sipEnum_QWizard_WizardStyle sipExportedTypes_QtWidgets[473]->u.td_py_type

#define sipType_QWizard_WizardPixmap sipExportedTypes_QtWidgets[472]
#define sipEnum_QWizard_WizardPixmap sipExportedTypes_QtWidgets[472]->u.td_py_type

#define sipType_QWizard_WizardButton sipExportedTypes_QtWidgets[469]
#define sipEnum_QWizard_WizardButton sipExportedTypes_QtWidgets[469]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizard;

#define sipType_QWizard_WizardOptions sipExportedTypes_QtWidgets[471]
#define sipClass_QWizard_WizardOptions sipExportedTypes_QtWidgets[471]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizard_WizardOptions;

#define sipType_QWizardPage sipExportedTypes_QtWidgets[474]
#define sipClass_QWizardPage sipExportedTypes_QtWidgets[474]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizardPage;

#define sipType_QList_0101QUndoStack sipExportedTypes_QtWidgets[213]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QUndoStack;

#define sipType_QList_0101QTreeWidgetItem sipExportedTypes_QtWidgets[212]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTreeWidgetItem;

#define sipType_QList_0101QTableWidgetItem sipExportedTypes_QtWidgets[209]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTableWidgetItem;

#define sipType_QList_0100QTableWidgetSelectionRange sipExportedTypes_QtWidgets[210]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTableWidgetSelectionRange;

#define sipType_QList_0101QScroller sipExportedTypes_QtWidgets[208]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QScroller;

#define sipType_QList_0100QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[211]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTextEdit_ExtraSelection;

#define sipType_QList_0101QMdiSubWindow sipExportedTypes_QtWidgets[206]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QMdiSubWindow;

#define sipType_QList_0101QDockWidget sipExportedTypes_QtWidgets[199]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QDockWidget;

#define sipType_QList_0101QListWidgetItem sipExportedTypes_QtWidgets[205]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QListWidgetItem;

#define sipType_QList_0100QRectF sipExportedTypes_QtWidgets[207]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QRectF;

#define sipType_QList_0101QGraphicsView sipExportedTypes_QtWidgets[203]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsView;

#define sipType_QList_0101QGraphicsTransform sipExportedTypes_QtWidgets[202]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsTransform;

#define sipType_QList_0101QGraphicsItem sipExportedTypes_QtWidgets[201]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsItem;

#define sipType_QList_0101QGesture sipExportedTypes_QtWidgets[200]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGesture;

#define sipType_QMap_0100QDate_0100QTextCharFormat sipExportedTypes_QtWidgets[228]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QMap_0100QDate_0100QTextCharFormat;

#define sipType_QList_0101QAbstractButton sipExportedTypes_QtWidgets[197]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QAbstractButton;

#define sipType_QList_0101QGraphicsWidget sipExportedTypes_QtWidgets[204]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsWidget;

#define sipType_QList_0101QAction sipExportedTypes_QtWidgets[198]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QAction;

#define sipType_QList_0101QWidget sipExportedTypes_QtWidgets[214]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QWidget;

#define sipType_QList_0100QWizard_WizardButton sipExportedTypes_QtWidgets[215]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QWizard_WizardButton;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWidgets;
extern sipExportedModuleDef sipModuleAPI_QtWidgets;
extern sipTypeDef *sipExportedTypes_QtWidgets[];

#define sipType_Qt_ItemSelectionOperation sipImportedTypes_QtWidgets_QtCore[79].it_td
#define sipEnum_Qt_ItemSelectionOperation sipImportedTypes_QtWidgets_QtCore[79].it_td->u.td_py_type

#define sipType_Qt_MouseEventSource sipImportedTypes_QtWidgets_QtCore[86].it_td
#define sipEnum_Qt_MouseEventSource sipImportedTypes_QtWidgets_QtCore[86].it_td->u.td_py_type

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtWidgets_QtCore[74].it_td
#define sipEnum_Qt_HitTestAccuracy sipImportedTypes_QtWidgets_QtCore[74].it_td->u.td_py_type

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtWidgets_QtCore[61].it_td
#define sipEnum_Qt_CursorMoveStyle sipImportedTypes_QtWidgets_QtCore[61].it_td->u.td_py_type

#define sipType_Qt_GestureType sipImportedTypes_QtWidgets_QtCore[73].it_td
#define sipEnum_Qt_GestureType sipImportedTypes_QtWidgets_QtCore[73].it_td->u.td_py_type

#define sipType_Qt_GestureState sipImportedTypes_QtWidgets_QtCore[72].it_td
#define sipEnum_Qt_GestureState sipImportedTypes_QtWidgets_QtCore[72].it_td->u.td_py_type

#define sipType_Qt_CoordinateSystem sipImportedTypes_QtWidgets_QtCore[59].it_td
#define sipEnum_Qt_CoordinateSystem sipImportedTypes_QtWidgets_QtCore[59].it_td->u.td_py_type

#define sipType_Qt_AnchorPoint sipImportedTypes_QtWidgets_QtCore[52].it_td
#define sipEnum_Qt_AnchorPoint sipImportedTypes_QtWidgets_QtCore[52].it_td->u.td_py_type

#define sipType_Qt_WindowFrameSection sipImportedTypes_QtWidgets_QtCore[105].it_td
#define sipEnum_Qt_WindowFrameSection sipImportedTypes_QtWidgets_QtCore[105].it_td->u.td_py_type

#define sipType_Qt_SizeHint sipImportedTypes_QtWidgets_QtCore[92].it_td
#define sipEnum_Qt_SizeHint sipImportedTypes_QtWidgets_QtCore[92].it_td->u.td_py_type

#define sipType_Qt_Axis sipImportedTypes_QtWidgets_QtCore[55].it_td
#define sipEnum_Qt_Axis sipImportedTypes_QtWidgets_QtCore[55].it_td->u.td_py_type

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtWidgets_QtCore[78].it_td
#define sipEnum_Qt_ItemSelectionMode sipImportedTypes_QtWidgets_QtCore[78].it_td->u.td_py_type

#define sipType_Qt_WindowModality sipImportedTypes_QtWidgets_QtCore[106].it_td
#define sipEnum_Qt_WindowModality sipImportedTypes_QtWidgets_QtCore[106].it_td->u.td_py_type

#define sipType_Qt_CheckState sipImportedTypes_QtWidgets_QtCore[57].it_td
#define sipEnum_Qt_CheckState sipImportedTypes_QtWidgets_QtCore[57].it_td->u.td_py_type

#define sipType_Qt_DropAction sipImportedTypes_QtWidgets_QtCore[65].it_td
#define sipEnum_Qt_DropAction sipImportedTypes_QtWidgets_QtCore[65].it_td->u.td_py_type

#define sipType_Qt_LayoutDirection sipImportedTypes_QtWidgets_QtCore[81].it_td
#define sipEnum_Qt_LayoutDirection sipImportedTypes_QtWidgets_QtCore[81].it_td->u.td_py_type

#define sipType_Qt_ToolButtonStyle sipImportedTypes_QtWidgets_QtCore[100].it_td
#define sipEnum_Qt_ToolButtonStyle sipImportedTypes_QtWidgets_QtCore[100].it_td->u.td_py_type

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtWidgets_QtCore[76].it_td
#define sipEnum_Qt_InputMethodQuery sipImportedTypes_QtWidgets_QtCore[76].it_td->u.td_py_type

#define sipType_Qt_ContextMenuPolicy sipImportedTypes_QtWidgets_QtCore[58].it_td
#define sipEnum_Qt_ContextMenuPolicy sipImportedTypes_QtWidgets_QtCore[58].it_td->u.td_py_type

#define sipType_Qt_FocusReason sipImportedTypes_QtWidgets_QtCore[70].it_td
#define sipEnum_Qt_FocusReason sipImportedTypes_QtWidgets_QtCore[70].it_td->u.td_py_type

#define sipType_Qt_TransformationMode sipImportedTypes_QtWidgets_QtCore[101].it_td
#define sipEnum_Qt_TransformationMode sipImportedTypes_QtWidgets_QtCore[101].it_td->u.td_py_type

#define sipType_Qt_FillRule sipImportedTypes_QtWidgets_QtCore[67].it_td
#define sipEnum_Qt_FillRule sipImportedTypes_QtWidgets_QtCore[67].it_td->u.td_py_type

#define sipType_Qt_ShortcutContext sipImportedTypes_QtWidgets_QtCore[91].it_td
#define sipEnum_Qt_ShortcutContext sipImportedTypes_QtWidgets_QtCore[91].it_td->u.td_py_type

#define sipType_Qt_Corner sipImportedTypes_QtWidgets_QtCore[60].it_td
#define sipEnum_Qt_Corner sipImportedTypes_QtWidgets_QtCore[60].it_td->u.td_py_type

#define sipType_Qt_CaseSensitivity sipImportedTypes_QtWidgets_QtCore[56].it_td
#define sipEnum_Qt_CaseSensitivity sipImportedTypes_QtWidgets_QtCore[56].it_td->u.td_py_type

#define sipType_Qt_ScrollBarPolicy sipImportedTypes_QtWidgets_QtCore[90].it_td
#define sipEnum_Qt_ScrollBarPolicy sipImportedTypes_QtWidgets_QtCore[90].it_td->u.td_py_type

#define sipType_Qt_DayOfWeek sipImportedTypes_QtWidgets_QtCore[62].it_td
#define sipEnum_Qt_DayOfWeek sipImportedTypes_QtWidgets_QtCore[62].it_td->u.td_py_type

#define sipType_Qt_TimeSpec sipImportedTypes_QtWidgets_QtCore[97].it_td
#define sipEnum_Qt_TimeSpec sipImportedTypes_QtWidgets_QtCore[97].it_td->u.td_py_type

#define sipType_Qt_ToolBarArea sipImportedTypes_QtWidgets_QtCore[98].it_td
#define sipEnum_Qt_ToolBarArea sipImportedTypes_QtWidgets_QtCore[98].it_td->u.td_py_type

#define sipType_Qt_DockWidgetArea sipImportedTypes_QtWidgets_QtCore[63].it_td
#define sipEnum_Qt_DockWidgetArea sipImportedTypes_QtWidgets_QtCore[63].it_td->u.td_py_type

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtWidgets_QtCore[54].it_td
#define sipEnum_Qt_AspectRatioMode sipImportedTypes_QtWidgets_QtCore[54].it_td->u.td_py_type

#define sipType_Qt_TextFormat sipImportedTypes_QtWidgets_QtCore[95].it_td
#define sipEnum_Qt_TextFormat sipImportedTypes_QtWidgets_QtCore[95].it_td->u.td_py_type

#define sipType_Qt_UIEffect sipImportedTypes_QtWidgets_QtCore[102].it_td
#define sipEnum_Qt_UIEffect sipImportedTypes_QtWidgets_QtCore[102].it_td->u.td_py_type

#define sipType_Qt_PenStyle sipImportedTypes_QtWidgets_QtCore[89].it_td
#define sipEnum_Qt_PenStyle sipImportedTypes_QtWidgets_QtCore[89].it_td->u.td_py_type

#define sipType_Qt_ArrowType sipImportedTypes_QtWidgets_QtCore[53].it_td
#define sipEnum_Qt_ArrowType sipImportedTypes_QtWidgets_QtCore[53].it_td->u.td_py_type

#define sipType_Qt_WidgetAttribute sipImportedTypes_QtWidgets_QtCore[103].it_td
#define sipEnum_Qt_WidgetAttribute sipImportedTypes_QtWidgets_QtCore[103].it_td->u.td_py_type

#define sipType_Qt_WindowType sipImportedTypes_QtWidgets_QtCore[108].it_td
#define sipEnum_Qt_WindowType sipImportedTypes_QtWidgets_QtCore[108].it_td->u.td_py_type

#define sipType_Qt_TextElideMode sipImportedTypes_QtWidgets_QtCore[94].it_td
#define sipEnum_Qt_TextElideMode sipImportedTypes_QtWidgets_QtCore[94].it_td->u.td_py_type

#define sipType_Qt_SortOrder sipImportedTypes_QtWidgets_QtCore[93].it_td
#define sipEnum_Qt_SortOrder sipImportedTypes_QtWidgets_QtCore[93].it_td->u.td_py_type

#define sipType_Qt_FocusPolicy sipImportedTypes_QtWidgets_QtCore[69].it_td
#define sipEnum_Qt_FocusPolicy sipImportedTypes_QtWidgets_QtCore[69].it_td->u.td_py_type

#define sipType_Qt_Orientation sipImportedTypes_QtWidgets_QtCore[87].it_td
#define sipEnum_Qt_Orientation sipImportedTypes_QtWidgets_QtCore[87].it_td->u.td_py_type

#define sipType_Qt_MouseButton sipImportedTypes_QtWidgets_QtCore[83].it_td
#define sipEnum_Qt_MouseButton sipImportedTypes_QtWidgets_QtCore[83].it_td->u.td_py_type

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtWidgets_QtCore[80].it_td
#define sipClass_Qt_KeyboardModifiers sipImportedTypes_QtWidgets_QtCore[80].it_td->u.td_wrapper_type

#define sipType_Qt_MouseButtons sipImportedTypes_QtWidgets_QtCore[84].it_td
#define sipClass_Qt_MouseButtons sipImportedTypes_QtWidgets_QtCore[84].it_td->u.td_wrapper_type

#define sipType_Qt_Orientations sipImportedTypes_QtWidgets_QtCore[88].it_td
#define sipClass_Qt_Orientations sipImportedTypes_QtWidgets_QtCore[88].it_td->u.td_wrapper_type

#define sipType_Qt_Alignment sipImportedTypes_QtWidgets_QtCore[51].it_td
#define sipClass_Qt_Alignment sipImportedTypes_QtWidgets_QtCore[51].it_td->u.td_wrapper_type

#define sipType_Qt_WindowFlags sipImportedTypes_QtWidgets_QtCore[104].it_td
#define sipClass_Qt_WindowFlags sipImportedTypes_QtWidgets_QtCore[104].it_td->u.td_wrapper_type

#define sipType_Qt_WindowStates sipImportedTypes_QtWidgets_QtCore[107].it_td
#define sipClass_Qt_WindowStates sipImportedTypes_QtWidgets_QtCore[107].it_td->u.td_wrapper_type

#define sipType_Qt_DockWidgetAreas sipImportedTypes_QtWidgets_QtCore[64].it_td
#define sipClass_Qt_DockWidgetAreas sipImportedTypes_QtWidgets_QtCore[64].it_td->u.td_wrapper_type

#define sipType_Qt_ToolBarAreas sipImportedTypes_QtWidgets_QtCore[99].it_td
#define sipClass_Qt_ToolBarAreas sipImportedTypes_QtWidgets_QtCore[99].it_td->u.td_wrapper_type

#define sipType_Qt_DropActions sipImportedTypes_QtWidgets_QtCore[66].it_td
#define sipClass_Qt_DropActions sipImportedTypes_QtWidgets_QtCore[66].it_td->u.td_wrapper_type

#define sipType_Qt_ItemFlags sipImportedTypes_QtWidgets_QtCore[77].it_td
#define sipClass_Qt_ItemFlags sipImportedTypes_QtWidgets_QtCore[77].it_td->u.td_wrapper_type

#define sipType_Qt_MatchFlags sipImportedTypes_QtWidgets_QtCore[82].it_td
#define sipClass_Qt_MatchFlags sipImportedTypes_QtWidgets_QtCore[82].it_td->u.td_wrapper_type

#define sipType_Qt_TextInteractionFlags sipImportedTypes_QtWidgets_QtCore[96].it_td
#define sipClass_Qt_TextInteractionFlags sipImportedTypes_QtWidgets_QtCore[96].it_td->u.td_wrapper_type

#define sipType_Qt_InputMethodHints sipImportedTypes_QtWidgets_QtCore[75].it_td
#define sipClass_Qt_InputMethodHints sipImportedTypes_QtWidgets_QtCore[75].it_td->u.td_wrapper_type

#define sipType_Qt_GestureFlags sipImportedTypes_QtWidgets_QtCore[71].it_td
#define sipClass_Qt_GestureFlags sipImportedTypes_QtWidgets_QtCore[71].it_td->u.td_wrapper_type

#define sipType_Qt_FindChildOptions sipImportedTypes_QtWidgets_QtCore[68].it_td
#define sipClass_Qt_FindChildOptions sipImportedTypes_QtWidgets_QtCore[68].it_td->u.td_wrapper_type

#define sipType_Qt_MouseEventFlags sipImportedTypes_QtWidgets_QtCore[85].it_td
#define sipClass_Qt_MouseEventFlags sipImportedTypes_QtWidgets_QtCore[85].it_td->u.td_wrapper_type

#define sipType_QObject sipImportedTypes_QtWidgets_QtCore[34].it_td
#define sipClass_QObject sipImportedTypes_QtWidgets_QtCore[34].it_td->u.td_wrapper_type

#define sipType_QModelIndex sipImportedTypes_QtWidgets_QtCore[33].it_td
#define sipClass_QModelIndex sipImportedTypes_QtWidgets_QtCore[33].it_td->u.td_wrapper_type

#define sipType_QAbstractItemModel sipImportedTypes_QtWidgets_QtCore[0].it_td
#define sipClass_QAbstractItemModel sipImportedTypes_QtWidgets_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QAbstractProxyModel sipImportedTypes_QtWidgets_QtCore[1].it_td
#define sipClass_QAbstractProxyModel sipImportedTypes_QtWidgets_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QAbstractTransition sipImportedTypes_QtWidgets_QtCore[2].it_td
#define sipClass_QAbstractTransition sipImportedTypes_QtWidgets_QtCore[2].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtWidgets_QtCore[3].it_td
#define sipClass_QByteArray sipImportedTypes_QtWidgets_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QCalendar sipImportedTypes_QtWidgets_QtCore[4].it_td
#define sipClass_QCalendar sipImportedTypes_QtWidgets_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QCoreApplication sipImportedTypes_QtWidgets_QtCore[6].it_td
#define sipClass_QCoreApplication sipImportedTypes_QtWidgets_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtWidgets_QtCore[13].it_td
#define sipClass_QEvent sipImportedTypes_QtWidgets_QtCore[13].it_td->u.td_wrapper_type

#define sipType_QEvent_Type sipImportedTypes_QtWidgets_QtCore[14].it_td
#define sipEnum_QEvent_Type sipImportedTypes_QtWidgets_QtCore[14].it_td->u.td_py_type

#define sipType_QTimerEvent sipImportedTypes_QtWidgets_QtCore[47].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtWidgets_QtCore[47].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtWidgets_QtCore[5].it_td
#define sipClass_QChildEvent sipImportedTypes_QtWidgets_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QDataStream sipImportedTypes_QtWidgets_QtCore[7].it_td
#define sipClass_QDataStream sipImportedTypes_QtWidgets_QtCore[7].it_td->u.td_wrapper_type

#define sipType_QDate sipImportedTypes_QtWidgets_QtCore[8].it_td
#define sipClass_QDate sipImportedTypes_QtWidgets_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QTime sipImportedTypes_QtWidgets_QtCore[46].it_td
#define sipClass_QTime sipImportedTypes_QtWidgets_QtCore[46].it_td->u.td_wrapper_type

#define sipType_QDateTime sipImportedTypes_QtWidgets_QtCore[9].it_td
#define sipClass_QDateTime sipImportedTypes_QtWidgets_QtCore[9].it_td->u.td_wrapper_type

#define sipType_QDir sipImportedTypes_QtWidgets_QtCore[10].it_td
#define sipClass_QDir sipImportedTypes_QtWidgets_QtCore[10].it_td->u.td_wrapper_type

#define sipType_QDir_Filters sipImportedTypes_QtWidgets_QtCore[11].it_td
#define sipClass_QDir_Filters sipImportedTypes_QtWidgets_QtCore[11].it_td->u.td_wrapper_type

#define sipType_QDir_SortFlags sipImportedTypes_QtWidgets_QtCore[12].it_td
#define sipClass_QDir_SortFlags sipImportedTypes_QtWidgets_QtCore[12].it_td->u.td_wrapper_type

#define sipType_QEventTransition sipImportedTypes_QtWidgets_QtCore[15].it_td
#define sipClass_QEventTransition sipImportedTypes_QtWidgets_QtCore[15].it_td->u.td_wrapper_type

#define sipType_QFileDevice_Permissions sipImportedTypes_QtWidgets_QtCore[16].it_td
#define sipClass_QFileDevice_Permissions sipImportedTypes_QtWidgets_QtCore[16].it_td->u.td_wrapper_type

#define sipType_QFileInfo sipImportedTypes_QtWidgets_QtCore[17].it_td
#define sipClass_QFileInfo sipImportedTypes_QtWidgets_QtCore[17].it_td->u.td_wrapper_type

#define sipType_QItemSelectionModel sipImportedTypes_QtWidgets_QtCore[20].it_td
#define sipClass_QItemSelectionModel sipImportedTypes_QtWidgets_QtCore[20].it_td->u.td_wrapper_type

#define sipType_QItemSelectionModel_SelectionFlags sipImportedTypes_QtWidgets_QtCore[21].it_td
#define sipClass_QItemSelectionModel_SelectionFlags sipImportedTypes_QtWidgets_QtCore[21].it_td->u.td_wrapper_type

#define sipType_QItemSelection sipImportedTypes_QtWidgets_QtCore[19].it_td
#define sipClass_QItemSelection sipImportedTypes_QtWidgets_QtCore[19].it_td->u.td_wrapper_type

#define sipType_QLineF sipImportedTypes_QtWidgets_QtCore[22].it_td
#define sipClass_QLineF sipImportedTypes_QtWidgets_QtCore[22].it_td->u.td_wrapper_type

#define sipType_QLocale sipImportedTypes_QtWidgets_QtCore[27].it_td
#define sipClass_QLocale sipImportedTypes_QtWidgets_QtCore[27].it_td->u.td_wrapper_type

#define sipType_QMargins sipImportedTypes_QtWidgets_QtCore[29].it_td
#define sipClass_QMargins sipImportedTypes_QtWidgets_QtCore[29].it_td->u.td_wrapper_type

#define sipType_QMarginsF sipImportedTypes_QtWidgets_QtCore[30].it_td
#define sipClass_QMarginsF sipImportedTypes_QtWidgets_QtCore[30].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtWidgets_QtCore[31].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtWidgets_QtCore[31].it_td->u.td_wrapper_type

#define sipType_QMimeData sipImportedTypes_QtWidgets_QtCore[32].it_td
#define sipClass_QMimeData sipImportedTypes_QtWidgets_QtCore[32].it_td->u.td_wrapper_type

#define sipType_QPoint sipImportedTypes_QtWidgets_QtCore[35].it_td
#define sipClass_QPoint sipImportedTypes_QtWidgets_QtCore[35].it_td->u.td_wrapper_type

#define sipType_QPointF sipImportedTypes_QtWidgets_QtCore[36].it_td
#define sipClass_QPointF sipImportedTypes_QtWidgets_QtCore[36].it_td->u.td_wrapper_type

#define sipType_QRect sipImportedTypes_QtWidgets_QtCore[37].it_td
#define sipClass_QRect sipImportedTypes_QtWidgets_QtCore[37].it_td->u.td_wrapper_type

#define sipType_QRectF sipImportedTypes_QtWidgets_QtCore[38].it_td
#define sipClass_QRectF sipImportedTypes_QtWidgets_QtCore[38].it_td->u.td_wrapper_type

#define sipType_QRegExp sipImportedTypes_QtWidgets_QtCore[39].it_td
#define sipClass_QRegExp sipImportedTypes_QtWidgets_QtCore[39].it_td->u.td_wrapper_type

#define sipType_QRegularExpression sipImportedTypes_QtWidgets_QtCore[40].it_td
#define sipClass_QRegularExpression sipImportedTypes_QtWidgets_QtCore[40].it_td->u.td_wrapper_type

#define sipType_QSize sipImportedTypes_QtWidgets_QtCore[41].it_td
#define sipClass_QSize sipImportedTypes_QtWidgets_QtCore[41].it_td->u.td_wrapper_type

#define sipType_QSizeF sipImportedTypes_QtWidgets_QtCore[42].it_td
#define sipClass_QSizeF sipImportedTypes_QtWidgets_QtCore[42].it_td->u.td_wrapper_type

#define sipType_QState sipImportedTypes_QtWidgets_QtCore[43].it_td
#define sipClass_QState sipImportedTypes_QtWidgets_QtCore[43].it_td->u.td_wrapper_type

#define sipType_QUrl sipImportedTypes_QtWidgets_QtCore[48].it_td
#define sipClass_QUrl sipImportedTypes_QtWidgets_QtCore[48].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtWidgets_QtCore[49].it_td
#define sipClass_QVariant sipImportedTypes_QtWidgets_QtCore[49].it_td->u.td_wrapper_type

#define sipType_QList_0100QUrl sipImportedTypes_QtWidgets_QtCore[24].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtWidgets_QtCore[18].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtWidgets_QtCore[28].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtWidgets_QtCore[23].it_td

#define sipType_QVector_1800 sipImportedTypes_QtWidgets_QtCore[50].it_td

#define sipType_QStringList sipImportedTypes_QtWidgets_QtCore[45].it_td

#define sipType_QList_2400 sipImportedTypes_QtWidgets_QtCore[26].it_td

#define sipType_QList_1800 sipImportedTypes_QtWidgets_QtCore[25].it_td

#define sipType_QString sipImportedTypes_QtWidgets_QtCore[44].it_td

#define sipType_quintptr sipImportedTypes_QtWidgets_QtCore[109].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWidgets_QtCore[];

#define sipType_QAbstractTextDocumentLayout sipImportedTypes_QtWidgets_QtGui[0].it_td
#define sipClass_QAbstractTextDocumentLayout sipImportedTypes_QtWidgets_QtGui[0].it_td->u.td_wrapper_type

#define sipType_QAbstractTextDocumentLayout_PaintContext sipImportedTypes_QtWidgets_QtGui[1].it_td
#define sipClass_QAbstractTextDocumentLayout_PaintContext sipImportedTypes_QtWidgets_QtGui[1].it_td->u.td_wrapper_type

#define sipType_QPaintDevice sipImportedTypes_QtWidgets_QtGui[35].it_td
#define sipClass_QPaintDevice sipImportedTypes_QtWidgets_QtGui[35].it_td->u.td_wrapper_type

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtWidgets_QtGui[36].it_td
#define sipEnum_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtWidgets_QtGui[36].it_td->u.td_py_type

#define sipType_QPixmap sipImportedTypes_QtWidgets_QtGui[47].it_td
#define sipClass_QPixmap sipImportedTypes_QtWidgets_QtGui[47].it_td->u.td_wrapper_type

#define sipType_QBitmap sipImportedTypes_QtWidgets_QtGui[3].it_td
#define sipClass_QBitmap sipImportedTypes_QtWidgets_QtGui[3].it_td->u.td_wrapper_type

#define sipType_QColor sipImportedTypes_QtWidgets_QtGui[6].it_td
#define sipClass_QColor sipImportedTypes_QtWidgets_QtGui[6].it_td->u.td_wrapper_type

#define sipType_QBrush sipImportedTypes_QtWidgets_QtGui[4].it_td
#define sipClass_QBrush sipImportedTypes_QtWidgets_QtGui[4].it_td->u.td_wrapper_type

#define sipType_QCursor sipImportedTypes_QtWidgets_QtGui[8].it_td
#define sipClass_QCursor sipImportedTypes_QtWidgets_QtGui[8].it_td->u.td_wrapper_type

#define sipType_QMouseEvent sipImportedTypes_QtWidgets_QtGui[30].it_td
#define sipClass_QMouseEvent sipImportedTypes_QtWidgets_QtGui[30].it_td->u.td_wrapper_type

#define sipType_QWheelEvent sipImportedTypes_QtWidgets_QtGui[73].it_td
#define sipClass_QWheelEvent sipImportedTypes_QtWidgets_QtGui[73].it_td->u.td_wrapper_type

#define sipType_QTabletEvent sipImportedTypes_QtWidgets_QtGui[55].it_td
#define sipClass_QTabletEvent sipImportedTypes_QtWidgets_QtGui[55].it_td->u.td_wrapper_type

#define sipType_QKeyEvent sipImportedTypes_QtWidgets_QtGui[25].it_td
#define sipClass_QKeyEvent sipImportedTypes_QtWidgets_QtGui[25].it_td->u.td_wrapper_type

#define sipType_QFocusEvent sipImportedTypes_QtWidgets_QtGui[13].it_td
#define sipClass_QFocusEvent sipImportedTypes_QtWidgets_QtGui[13].it_td->u.td_wrapper_type

#define sipType_QPaintEvent sipImportedTypes_QtWidgets_QtGui[38].it_td
#define sipClass_QPaintEvent sipImportedTypes_QtWidgets_QtGui[38].it_td->u.td_wrapper_type

#define sipType_QMoveEvent sipImportedTypes_QtWidgets_QtGui[31].it_td
#define sipClass_QMoveEvent sipImportedTypes_QtWidgets_QtGui[31].it_td->u.td_wrapper_type

#define sipType_QResizeEvent sipImportedTypes_QtWidgets_QtGui[51].it_td
#define sipClass_QResizeEvent sipImportedTypes_QtWidgets_QtGui[51].it_td->u.td_wrapper_type

#define sipType_QCloseEvent sipImportedTypes_QtWidgets_QtGui[5].it_td
#define sipClass_QCloseEvent sipImportedTypes_QtWidgets_QtGui[5].it_td->u.td_wrapper_type

#define sipType_QShowEvent sipImportedTypes_QtWidgets_QtGui[53].it_td
#define sipClass_QShowEvent sipImportedTypes_QtWidgets_QtGui[53].it_td->u.td_wrapper_type

#define sipType_QHideEvent sipImportedTypes_QtWidgets_QtGui[20].it_td
#define sipClass_QHideEvent sipImportedTypes_QtWidgets_QtGui[20].it_td->u.td_wrapper_type

#define sipType_QContextMenuEvent sipImportedTypes_QtWidgets_QtGui[7].it_td
#define sipClass_QContextMenuEvent sipImportedTypes_QtWidgets_QtGui[7].it_td->u.td_wrapper_type

#define sipType_QInputMethodEvent sipImportedTypes_QtWidgets_QtGui[24].it_td
#define sipClass_QInputMethodEvent sipImportedTypes_QtWidgets_QtGui[24].it_td->u.td_wrapper_type

#define sipType_QDropEvent sipImportedTypes_QtWidgets_QtGui[12].it_td
#define sipClass_QDropEvent sipImportedTypes_QtWidgets_QtGui[12].it_td->u.td_wrapper_type

#define sipType_QDragMoveEvent sipImportedTypes_QtWidgets_QtGui[11].it_td
#define sipClass_QDragMoveEvent sipImportedTypes_QtWidgets_QtGui[11].it_td->u.td_wrapper_type

#define sipType_QDragEnterEvent sipImportedTypes_QtWidgets_QtGui[9].it_td
#define sipClass_QDragEnterEvent sipImportedTypes_QtWidgets_QtGui[9].it_td->u.td_wrapper_type

#define sipType_QDragLeaveEvent sipImportedTypes_QtWidgets_QtGui[10].it_td
#define sipClass_QDragLeaveEvent sipImportedTypes_QtWidgets_QtGui[10].it_td->u.td_wrapper_type

#define sipType_QHelpEvent sipImportedTypes_QtWidgets_QtGui[19].it_td
#define sipClass_QHelpEvent sipImportedTypes_QtWidgets_QtGui[19].it_td->u.td_wrapper_type

#define sipType_QActionEvent sipImportedTypes_QtWidgets_QtGui[2].it_td
#define sipClass_QActionEvent sipImportedTypes_QtWidgets_QtGui[2].it_td->u.td_wrapper_type

#define sipType_QFont sipImportedTypes_QtWidgets_QtGui[14].it_td
#define sipClass_QFont sipImportedTypes_QtWidgets_QtGui[14].it_td->u.td_wrapper_type

#define sipType_QFontDatabase_WritingSystem sipImportedTypes_QtWidgets_QtGui[15].it_td
#define sipEnum_QFontDatabase_WritingSystem sipImportedTypes_QtWidgets_QtGui[15].it_td->u.td_py_type

#define sipType_QFontInfo sipImportedTypes_QtWidgets_QtGui[16].it_td
#define sipClass_QFontInfo sipImportedTypes_QtWidgets_QtGui[16].it_td->u.td_wrapper_type

#define sipType_QFontMetrics sipImportedTypes_QtWidgets_QtGui[17].it_td
#define sipClass_QFontMetrics sipImportedTypes_QtWidgets_QtGui[17].it_td->u.td_wrapper_type

#define sipType_QGuiApplication sipImportedTypes_QtWidgets_QtGui[18].it_td
#define sipClass_QGuiApplication sipImportedTypes_QtWidgets_QtGui[18].it_td->u.td_wrapper_type

#define sipType_QIcon sipImportedTypes_QtWidgets_QtGui[21].it_td
#define sipClass_QIcon sipImportedTypes_QtWidgets_QtGui[21].it_td->u.td_wrapper_type

#define sipType_QIcon_Mode sipImportedTypes_QtWidgets_QtGui[22].it_td
#define sipEnum_QIcon_Mode sipImportedTypes_QtWidgets_QtGui[22].it_td->u.td_py_type

#define sipType_QImage sipImportedTypes_QtWidgets_QtGui[23].it_td
#define sipClass_QImage sipImportedTypes_QtWidgets_QtGui[23].it_td->u.td_wrapper_type

#define sipType_QKeySequence sipImportedTypes_QtWidgets_QtGui[26].it_td
#define sipClass_QKeySequence sipImportedTypes_QtWidgets_QtGui[26].it_td->u.td_wrapper_type

#define sipType_QKeySequence_StandardKey sipImportedTypes_QtWidgets_QtGui[27].it_td
#define sipEnum_QKeySequence_StandardKey sipImportedTypes_QtWidgets_QtGui[27].it_td->u.td_py_type

#define sipType_QMatrix4x4 sipImportedTypes_QtWidgets_QtGui[29].it_td
#define sipClass_QMatrix4x4 sipImportedTypes_QtWidgets_QtGui[29].it_td->u.td_wrapper_type

#define sipType_QMovie sipImportedTypes_QtWidgets_QtGui[32].it_td
#define sipClass_QMovie sipImportedTypes_QtWidgets_QtGui[32].it_td->u.td_wrapper_type

#define sipType_QOpenGLContext sipImportedTypes_QtWidgets_QtGui[33].it_td
#define sipClass_QOpenGLContext sipImportedTypes_QtWidgets_QtGui[33].it_td->u.td_wrapper_type

#define sipType_QWindow sipImportedTypes_QtWidgets_QtGui[74].it_td
#define sipClass_QWindow sipImportedTypes_QtWidgets_QtGui[74].it_td->u.td_wrapper_type

#define sipType_QPagedPaintDevice sipImportedTypes_QtWidgets_QtGui[34].it_td
#define sipClass_QPagedPaintDevice sipImportedTypes_QtWidgets_QtGui[34].it_td->u.td_wrapper_type

#define sipType_QPainter sipImportedTypes_QtWidgets_QtGui[39].it_td
#define sipClass_QPainter sipImportedTypes_QtWidgets_QtGui[39].it_td->u.td_wrapper_type

#define sipType_QPainter_RenderHint sipImportedTypes_QtWidgets_QtGui[40].it_td
#define sipEnum_QPainter_RenderHint sipImportedTypes_QtWidgets_QtGui[40].it_td->u.td_py_type

#define sipType_QPainter_RenderHints sipImportedTypes_QtWidgets_QtGui[41].it_td
#define sipClass_QPainter_RenderHints sipImportedTypes_QtWidgets_QtGui[41].it_td->u.td_wrapper_type

#define sipType_QPaintEngine sipImportedTypes_QtWidgets_QtGui[37].it_td
#define sipClass_QPaintEngine sipImportedTypes_QtWidgets_QtGui[37].it_td->u.td_wrapper_type

#define sipType_QPainterPath sipImportedTypes_QtWidgets_QtGui[42].it_td
#define sipClass_QPainterPath sipImportedTypes_QtWidgets_QtGui[42].it_td->u.td_wrapper_type

#define sipType_QPalette sipImportedTypes_QtWidgets_QtGui[43].it_td
#define sipClass_QPalette sipImportedTypes_QtWidgets_QtGui[43].it_td->u.td_wrapper_type

#define sipType_QPalette_ColorRole sipImportedTypes_QtWidgets_QtGui[44].it_td
#define sipEnum_QPalette_ColorRole sipImportedTypes_QtWidgets_QtGui[44].it_td->u.td_py_type

#define sipType_QPen sipImportedTypes_QtWidgets_QtGui[45].it_td
#define sipClass_QPen sipImportedTypes_QtWidgets_QtGui[45].it_td->u.td_wrapper_type

#define sipType_QPicture sipImportedTypes_QtWidgets_QtGui[46].it_td
#define sipClass_QPicture sipImportedTypes_QtWidgets_QtGui[46].it_td->u.td_wrapper_type

#define sipType_QPolygon sipImportedTypes_QtWidgets_QtGui[48].it_td
#define sipClass_QPolygon sipImportedTypes_QtWidgets_QtGui[48].it_td->u.td_wrapper_type

#define sipType_QPolygonF sipImportedTypes_QtWidgets_QtGui[49].it_td
#define sipClass_QPolygonF sipImportedTypes_QtWidgets_QtGui[49].it_td->u.td_wrapper_type

#define sipType_QRegion sipImportedTypes_QtWidgets_QtGui[50].it_td
#define sipClass_QRegion sipImportedTypes_QtWidgets_QtGui[50].it_td->u.td_wrapper_type

#define sipType_QScreen sipImportedTypes_QtWidgets_QtGui[52].it_td
#define sipClass_QScreen sipImportedTypes_QtWidgets_QtGui[52].it_td->u.td_wrapper_type

#define sipType_QSurfaceFormat sipImportedTypes_QtWidgets_QtGui[54].it_td
#define sipClass_QSurfaceFormat sipImportedTypes_QtWidgets_QtGui[54].it_td->u.td_wrapper_type

#define sipType_QTextCursor sipImportedTypes_QtWidgets_QtGui[58].it_td
#define sipClass_QTextCursor sipImportedTypes_QtWidgets_QtGui[58].it_td->u.td_wrapper_type

#define sipType_QTextCursor_MoveOperation sipImportedTypes_QtWidgets_QtGui[60].it_td
#define sipEnum_QTextCursor_MoveOperation sipImportedTypes_QtWidgets_QtGui[60].it_td->u.td_py_type

#define sipType_QTextCursor_MoveMode sipImportedTypes_QtWidgets_QtGui[59].it_td
#define sipEnum_QTextCursor_MoveMode sipImportedTypes_QtWidgets_QtGui[59].it_td->u.td_py_type

#define sipType_QTextDocument sipImportedTypes_QtWidgets_QtGui[61].it_td
#define sipClass_QTextDocument sipImportedTypes_QtWidgets_QtGui[61].it_td->u.td_wrapper_type

#define sipType_QTextDocument_ResourceType sipImportedTypes_QtWidgets_QtGui[64].it_td
#define sipEnum_QTextDocument_ResourceType sipImportedTypes_QtWidgets_QtGui[64].it_td->u.td_py_type

#define sipType_QTextDocument_FindFlags sipImportedTypes_QtWidgets_QtGui[62].it_td
#define sipClass_QTextDocument_FindFlags sipImportedTypes_QtWidgets_QtGui[62].it_td->u.td_wrapper_type

#define sipType_QTextDocument_MarkdownFeatures sipImportedTypes_QtWidgets_QtGui[63].it_td
#define sipClass_QTextDocument_MarkdownFeatures sipImportedTypes_QtWidgets_QtGui[63].it_td->u.td_wrapper_type

#define sipType_QTextFormat sipImportedTypes_QtWidgets_QtGui[65].it_td
#define sipClass_QTextFormat sipImportedTypes_QtWidgets_QtGui[65].it_td->u.td_wrapper_type

#define sipType_QTextCharFormat sipImportedTypes_QtWidgets_QtGui[57].it_td
#define sipClass_QTextCharFormat sipImportedTypes_QtWidgets_QtGui[57].it_td->u.td_wrapper_type

#define sipType_QTextInlineObject sipImportedTypes_QtWidgets_QtGui[67].it_td
#define sipClass_QTextInlineObject sipImportedTypes_QtWidgets_QtGui[67].it_td->u.td_wrapper_type

#define sipType_QTextFrame sipImportedTypes_QtWidgets_QtGui[66].it_td
#define sipClass_QTextFrame sipImportedTypes_QtWidgets_QtGui[66].it_td->u.td_wrapper_type

#define sipType_QTextBlock sipImportedTypes_QtWidgets_QtGui[56].it_td
#define sipClass_QTextBlock sipImportedTypes_QtWidgets_QtGui[56].it_td->u.td_wrapper_type

#define sipType_QTextOption_WrapMode sipImportedTypes_QtWidgets_QtGui[68].it_td
#define sipEnum_QTextOption_WrapMode sipImportedTypes_QtWidgets_QtGui[68].it_td->u.td_py_type

#define sipType_QTransform sipImportedTypes_QtWidgets_QtGui[69].it_td
#define sipClass_QTransform sipImportedTypes_QtWidgets_QtGui[69].it_td->u.td_wrapper_type

#define sipType_QValidator sipImportedTypes_QtWidgets_QtGui[70].it_td
#define sipClass_QValidator sipImportedTypes_QtWidgets_QtGui[70].it_td->u.td_wrapper_type

#define sipType_QValidator_State sipImportedTypes_QtWidgets_QtGui[71].it_td
#define sipEnum_QValidator_State sipImportedTypes_QtWidgets_QtGui[71].it_td->u.td_py_type

#define sipType_QVector3D sipImportedTypes_QtWidgets_QtGui[72].it_td
#define sipClass_QVector3D sipImportedTypes_QtWidgets_QtGui[72].it_td->u.td_wrapper_type

#define sipType_QList_0100QKeySequence sipImportedTypes_QtWidgets_QtGui[28].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWidgets_qt_metacast;
#line 310 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qapplication.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtwidgets_cleanup_qobjects_t)();
extern pyqt5_qtwidgets_cleanup_qobjects_t pyqt5_qtwidgets_cleanup_qobjects;

typedef char **(*pyqt5_qtwidgets_from_argv_list_t)(PyObject *, int &);
extern pyqt5_qtwidgets_from_argv_list_t pyqt5_qtwidgets_from_argv_list;

typedef sipErrorState (*pyqt5_qtwidgets_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt5_qtwidgets_get_connection_parts_t pyqt5_qtwidgets_get_connection_parts;

typedef sipErrorState (*pyqt5_qtwidgets_get_signal_signature_t)(PyObject *, QObject *, QByteArray &);
extern pyqt5_qtwidgets_get_signal_signature_t pyqt5_qtwidgets_get_signal_signature;

typedef void (*pyqt5_qtwidgets_update_argv_list_t)(PyObject *, int, char **);
extern pyqt5_qtwidgets_update_argv_list_t pyqt5_qtwidgets_update_argv_list;

// This is needed for Qt v5.0.0.
#if defined(B0)
#undef B0
#endif
#line 11740 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipAPIQtWidgets.h"

#endif
