/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtGuiAPI_H
#define _QtGuiAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtGui[0]
#define sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior 53
#define sipName_QTextCharFormat__FontPropertiesInheritanceBehavior &sipStrings_QtGui[53]
#define sipNameNr_QOpenGLFramebufferObject__FramebufferRestorePolicy 104
#define sipName_QOpenGLFramebufferObject__FramebufferRestorePolicy &sipStrings_QtGui[104]
#define sipNameNr_155 155
#define sipName_155 &sipStrings_QtGui[155]
#define sipNameNr_QAbstractTextDocumentLayout__PaintContext 203
#define sipName_QAbstractTextDocumentLayout__PaintContext &sipStrings_QtGui[203]
#define sipNameNr_QPlatformSurfaceEvent__SurfaceEventType 245
#define sipName_QPlatformSurfaceEvent__SurfaceEventType &sipStrings_QtGui[245]
#define sipNameNr_QAbstractTextDocumentLayout__Selection 285
#define sipName_QAbstractTextDocumentLayout__Selection &sipStrings_QtGui[285]
#define sipNameNr_AddSpaceForLineAndParagraphSeparators 324
#define sipName_AddSpaceForLineAndParagraphSeparators &sipStrings_QtGui[324]
#define sipNameNr_QSurfaceFormat__OpenGLContextProfile 362
#define sipName_QSurfaceFormat__OpenGLContextProfile &sipStrings_QtGui[362]
#define sipNameNr_QOpenGLFramebufferObject__Attachment 399
#define sipName_QOpenGLFramebufferObject__Attachment &sipStrings_QtGui[399]
#define sipNameNr_436 436
#define sipName_436 &sipStrings_QtGui[436]
#define sipNameNr_472 472
#define sipName_472 &sipStrings_QtGui[472]
#define sipNameNr_mouseQuickSelectionThresholdChanged 508
#define sipName_mouseQuickSelectionThresholdChanged &sipStrings_QtGui[508]
#define sipNameNr_RasterOp_NotSourceAndNotDestination 544
#define sipName_RasterOp_NotSourceAndNotDestination &sipStrings_QtGui[544]
#define sipNameNr_QOpenGLTexture__CoordinateDirection 580
#define sipName_QOpenGLTexture__CoordinateDirection &sipStrings_QtGui[580]
#define sipNameNr_QIconEngine__AvailableSizesArgument 616
#define sipName_QIconEngine__AvailableSizesArgument &sipStrings_QtGui[616]
#define sipNameNr_setHighDpiScaleFactorRoundingPolicy 652
#define sipName_setHighDpiScaleFactorRoundingPolicy &sipStrings_QtGui[652]
#define sipNameNr_QTextCharFormat__VerticalAlignment 688
#define sipName_QTextCharFormat__VerticalAlignment &sipStrings_QtGui[688]
#define sipNameNr_showShortcutsInContextMenusChanged 723
#define sipName_showShortcutsInContextMenusChanged &sipStrings_QtGui[723]
#define sipNameNr_RasterOp_NotSourceOrNotDestination 758
#define sipName_RasterOp_NotSourceOrNotDestination &sipStrings_QtGui[758]
#define sipNameNr_QOpenGLTexture__ComparisonFunction 793
#define sipName_QOpenGLTexture__ComparisonFunction &sipStrings_QtGui[793]
#define sipNameNr_RestoreFramebufferBindingToDefault 828
#define sipName_RestoreFramebufferBindingToDefault &sipStrings_QtGui[828]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlags 863
#define sipName_QTouchEvent__TouchPoint__InfoFlags &sipStrings_QtGui[863]
#define sipNameNr_898 898
#define sipName_898 &sipStrings_QtGui[898]
#define sipNameNr_QTextBlockFormat__LineHeightTypes 932
#define sipName_QTextBlockFormat__LineHeightTypes &sipStrings_QtGui[932]
#define sipNameNr_FontPropertiesInheritanceBehavior 70
#define sipName_FontPropertiesInheritanceBehavior &sipStrings_QtGui[70]
#define sipNameNr_BlockTrailingHorizontalRulerWidth 966
#define sipName_BlockTrailingHorizontalRulerWidth &sipStrings_QtGui[966]
#define sipNameNr_QPaintEngine__PaintEngineFeatures 1000
#define sipName_QPaintEngine__PaintEngineFeatures &sipStrings_QtGui[1000]
#define sipNameNr_setDefaultInnerTessellationLevels 1034
#define sipName_setDefaultInnerTessellationLevels &sipStrings_QtGui[1034]
#define sipNameNr_setDefaultOuterTessellationLevels 1068
#define sipName_setDefaultOuterTessellationLevels &sipStrings_QtGui[1068]
#define sipNameNr_QIconEngine__ScaledPixmapArgument 1102
#define sipName_QIconEngine__ScaledPixmapArgument &sipStrings_QtGui[1102]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlag 1136
#define sipName_QTouchEvent__TouchPoint__InfoFlag &sipStrings_QtGui[1136]
#define sipNameNr_mousePressAndHoldIntervalChanged 1170
#define sipName_mousePressAndHoldIntervalChanged &sipStrings_QtGui[1170]
#define sipNameNr_QPixelFormat__TypeInterpretation 1203
#define sipName_QPixelFormat__TypeInterpretation &sipStrings_QtGui[1203]
#define sipNameNr_QPixelFormat__AlphaPremultiplied 1236
#define sipName_QPixelFormat__AlphaPremultiplied &sipStrings_QtGui[1236]
#define sipNameNr_QPaintEngine__PaintEngineFeature 1269
#define sipName_QPaintEngine__PaintEngineFeature &sipStrings_QtGui[1269]
#define sipNameNr_RasterOp_SourceAndNotDestination 1302
#define sipName_RasterOp_SourceAndNotDestination &sipStrings_QtGui[1302]
#define sipNameNr_RasterOp_NotSourceAndDestination 1335
#define sipName_RasterOp_NotSourceAndDestination &sipStrings_QtGui[1335]
#define sipNameNr_RasterOp_NotSourceXorDestination 1368
#define sipName_RasterOp_NotSourceXorDestination &sipStrings_QtGui[1368]
#define sipNameNr_QOpenGLVertexArrayObject__Binder 1401
#define sipName_QOpenGLVertexArrayObject__Binder &sipStrings_QtGui[1401]
#define sipNameNr_QOpenGLTexture__DepthStencilMode 1434
#define sipName_QOpenGLTexture__DepthStencilMode &sipStrings_QtGui[1434]
#define sipNameNr_QOpenGLTexture__SwizzleComponent 1467
#define sipName_QOpenGLTexture__SwizzleComponent &sipStrings_QtGui[1467]
#define sipNameNr_QOpenGLTexture__TextureUnitReset 1500
#define sipName_QOpenGLTexture__TextureUnitReset &sipStrings_QtGui[1500]
#define sipNameNr_QOpenGLTexture__MipMapGeneration 1533
#define sipName_QOpenGLTexture__MipMapGeneration &sipStrings_QtGui[1533]
#define sipNameNr_addCacheableShaderFromSourceFile 1566
#define sipName_addCacheableShaderFromSourceFile &sipStrings_QtGui[1566]
#define sipNameNr_addCacheableShaderFromSourceCode 1599
#define sipName_addCacheableShaderFromSourceCode &sipStrings_QtGui[1599]
#define sipNameNr_QOpenGLContext__OpenGLModuleType 1632
#define sipName_QOpenGLContext__OpenGLModuleType &sipStrings_QtGui[1632]
#define sipNameNr_QImageIOHandler__Transformations 1665
#define sipName_QImageIOHandler__Transformations &sipStrings_QtGui[1665]
#define sipNameNr_highDpiScaleFactorRoundingPolicy 1698
#define sipName_highDpiScaleFactorRoundingPolicy &sipStrings_QtGui[1698]
#define sipNameNr_QInputMethodEvent__AttributeType 1731
#define sipName_QInputMethodEvent__AttributeType &sipStrings_QtGui[1731]
#define sipNameNr_1764 1764
#define sipName_1764 &sipStrings_QtGui[1764]
#define sipNameNr_QTextCharFormat__UnderlineStyle 1796
#define sipName_QTextCharFormat__UnderlineStyle &sipStrings_QtGui[1796]
#define sipNameNr_QTextDocument__MarkdownFeatures 1828
#define sipName_QTextDocument__MarkdownFeatures &sipStrings_QtGui[1828]
#define sipNameNr_mouseDoubleClickIntervalChanged 1860
#define sipName_mouseDoubleClickIntervalChanged &sipStrings_QtGui[1860]
#define sipNameNr_QPaintDevice__PaintDeviceMetric 1892
#define sipName_QPaintDevice__PaintDeviceMetric &sipStrings_QtGui[1892]
#define sipNameNr_RasterOp_SourceOrNotDestination 1924
#define sipName_RasterOp_SourceOrNotDestination &sipStrings_QtGui[1924]
#define sipNameNr_RasterOp_NotSourceOrDestination 1956
#define sipName_RasterOp_NotSourceOrDestination &sipStrings_QtGui[1956]
#define sipNameNr_CompositionMode_DestinationAtop 1988
#define sipName_CompositionMode_DestinationAtop &sipStrings_QtGui[1988]
#define sipNameNr_CompositionMode_DestinationOver 2020
#define sipName_CompositionMode_DestinationOver &sipStrings_QtGui[2020]
#define sipNameNr_BindingTarget2DMultisampleArray 2052
#define sipName_BindingTarget2DMultisampleArray &sipStrings_QtGui[2052]
#define sipNameNr_QOpenGLDebugLogger__LoggingMode 2084
#define sipName_QOpenGLDebugLogger__LoggingMode &sipStrings_QtGui[2084]
#define sipNameNr_QOpenGLDebugMessage__Severities 2116
#define sipName_QOpenGLDebugMessage__Severities &sipStrings_QtGui[2116]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlags 2148
#define sipName_QOpenGLBuffer__RangeAccessFlags &sipStrings_QtGui[2148]
#define sipNameNr_TransformationMirrorAndRotate90 2180
#define sipName_TransformationMirrorAndRotate90 &sipStrings_QtGui[2180]
#define sipNameNr_QImageIOHandler__Transformation 2212
#define sipName_QImageIOHandler__Transformation &sipStrings_QtGui[2212]
#define sipNameNr_2244 2244
#define sipName_2244 &sipStrings_QtGui[2244]
#define sipNameNr_reportContentOrientationChange 2275
#define sipName_reportContentOrientationChange &sipStrings_QtGui[2275]
#define sipNameNr_QTransform__TransformationType 2306
#define sipName_QTransform__TransformationType &sipStrings_QtGui[2306]
#define sipNameNr_ShowLineAndParagraphSeparators 2337
#define sipName_ShowLineAndParagraphSeparators &sipStrings_QtGui[2337]
#define sipNameNr_QTextDocument__MarkdownFeature 2368
#define sipName_QTextDocument__MarkdownFeature &sipStrings_QtGui[2368]
#define sipNameNr_QTextDocument__MetaInformation 2399
#define sipName_QTextDocument__MetaInformation &sipStrings_QtGui[2399]
#define sipNameNr_QSurfaceFormat__RenderableType 2430
#define sipName_QSurfaceFormat__RenderableType &sipStrings_QtGui[2430]
#define sipNameNr_setShowShortcutsInContextMenus 2461
#define sipName_setShowShortcutsInContextMenus &sipStrings_QtGui[2461]
#define sipNameNr_CompositionMode_DestinationOut 2492
#define sipName_CompositionMode_DestinationOut &sipStrings_QtGui[2492]
#define sipNameNr_QOpenGLTexture__ComparisonMode 2523
#define sipName_QOpenGLTexture__ComparisonMode &sipStrings_QtGui[2523]
#define sipNameNr_setAutoMipMapGenerationEnabled 2554
#define sipName_setAutoMipMapGenerationEnabled &sipStrings_QtGui[2554]
#define sipNameNr_SRGB8_PunchThrough_Alpha1_ETC2 2585
#define sipName_SRGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2585]
#define sipNameNr_defaultInnerTessellationLevels 2616
#define sipName_defaultInnerTessellationLevels &sipStrings_QtGui[2616]
#define sipNameNr_defaultOuterTessellationLevels 2647
#define sipName_defaultOuterTessellationLevels &sipStrings_QtGui[2647]
#define sipNameNr_QOpenGLFramebufferObjectFormat 2678
#define sipName_QOpenGLFramebufferObjectFormat &sipStrings_QtGui[2678]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlag 2709
#define sipName_QOpenGLBuffer__RangeAccessFlag &sipStrings_QtGui[2709]
#define sipNameNr_QImageWriter__ImageWriterError 2740
#define sipName_QImageWriter__ImageWriterError &sipStrings_QtGui[2740]
#define sipNameNr_QImageReader__ImageReaderError 2771
#define sipName_QImageReader__ImageReaderError &sipStrings_QtGui[2771]
#define sipNameNr_2802 2802
#define sipName_2802 &sipStrings_QtGui[2802]
#define sipNameNr_QTextFrameFormat__BorderStyle 2832
#define sipName_QTextFrameFormat__BorderStyle &sipStrings_QtGui[2832]
#define sipNameNr_QSurfaceFormat__FormatOptions 2862
#define sipName_QSurfaceFormat__FormatOptions &sipStrings_QtGui[2862]
#define sipNameNr_QPaintEngine__PolygonDrawMode 2892
#define sipName_QPaintEngine__PolygonDrawMode &sipStrings_QtGui[2892]
#define sipNameNr_QPainter__PixmapFragmentHints 2922
#define sipName_QPainter__PixmapFragmentHints &sipStrings_QtGui[2922]
#define sipNameNr_RasterOp_SourceXorDestination 2952
#define sipName_RasterOp_SourceXorDestination &sipStrings_QtGui[2952]
#define sipNameNr_RasterOp_SourceAndDestination 2982
#define sipName_RasterOp_SourceAndDestination &sipStrings_QtGui[2982]
#define sipNameNr_CompositionMode_DestinationIn 3012
#define sipName_CompositionMode_DestinationIn &sipStrings_QtGui[3012]
#define sipNameNr_QPagedPaintDevice__PdfVersion 3042
#define sipName_QPagedPaintDevice__PdfVersion &sipStrings_QtGui[3042]
#define sipNameNr_QOpenGLWindow__UpdateBehavior 3072
#define sipName_QOpenGLWindow__UpdateBehavior &sipStrings_QtGui[3072]
#define sipNameNr_QOpenGLTextureBlitter__Origin 3102
#define sipName_QOpenGLTextureBlitter__Origin &sipStrings_QtGui[3102]
#define sipNameNr_isAutoMipMapGenerationEnabled 3132
#define sipName_isAutoMipMapGenerationEnabled &sipStrings_QtGui[3132]
#define sipNameNr_RGB8_PunchThrough_Alpha1_ETC2 2586
#define sipName_RGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2586]
#define sipNameNr_QOpenGLTexture__TextureFormat 3162
#define sipName_QOpenGLTexture__TextureFormat &sipStrings_QtGui[3162]
#define sipNameNr_QOpenGLTexture__BindingTarget 3192
#define sipName_QOpenGLTexture__BindingTarget &sipStrings_QtGui[3192]
#define sipNameNr_DontRestoreFramebufferBinding 3222
#define sipName_DontRestoreFramebufferBinding &sipStrings_QtGui[3222]
#define sipNameNr_QOpenGLDebugMessage__Severity 3252
#define sipName_QOpenGLDebugMessage__Severity &sipStrings_QtGui[3252]
#define sipNameNr_qt_set_sequence_auto_mnemonic 3282
#define sipName_qt_set_sequence_auto_mnemonic &sipStrings_QtGui[3282]
#define sipNameNr_inputItemClipRectangleChanged 3312
#define sipName_inputItemClipRectangleChanged &sipStrings_QtGui[3312]
#define sipNameNr_TransformationFlipAndRotate90 3342
#define sipName_TransformationFlipAndRotate90 &sipStrings_QtGui[3342]
#define sipNameNr_Format_RGBA8888_Premultiplied 3372
#define sipName_Format_RGBA8888_Premultiplied &sipStrings_QtGui[3372]
#define sipNameNr_Format_ARGB4444_Premultiplied 3402
#define sipName_Format_ARGB4444_Premultiplied &sipStrings_QtGui[3402]
#define sipNameNr_Format_ARGB8555_Premultiplied 3432
#define sipName_Format_ARGB8555_Premultiplied &sipStrings_QtGui[3432]
#define sipNameNr_Format_ARGB6666_Premultiplied 3462
#define sipName_Format_ARGB6666_Premultiplied &sipStrings_QtGui[3462]
#define sipNameNr_Format_ARGB8565_Premultiplied 3492
#define sipName_Format_ARGB8565_Premultiplied &sipStrings_QtGui[3492]
#define sipNameNr_applicationDisplayNameChanged 3522
#define sipName_applicationDisplayNameChanged &sipStrings_QtGui[3522]
#define sipNameNr_supportsThreadedFontRendering 3552
#define sipName_supportsThreadedFontRendering &sipStrings_QtGui[3552]
#define sipNameNr_QColorSpace__TransferFunction 3582
#define sipName_QColorSpace__TransferFunction &sipStrings_QtGui[3582]
#define sipNameNr_QTouchDevice__CapabilityFlag 3612
#define sipName_QTouchDevice__CapabilityFlag &sipStrings_QtGui[3612]
#define sipNameNr_WrapAtWordBoundaryOrAnywhere 3641
#define sipName_WrapAtWordBoundaryOrAnywhere &sipStrings_QtGui[3641]
#define sipNameNr_QTextBlockFormat__MarkerType 3670
#define sipName_QTextBlockFormat__MarkerType &sipStrings_QtGui[3670]
#define sipNameNr_QSurfaceFormat__SwapBehavior 3699
#define sipName_QSurfaceFormat__SwapBehavior &sipStrings_QtGui[3699]
#define sipNameNr_QSurfaceFormat__FormatOption 3728
#define sipName_QSurfaceFormat__FormatOption &sipStrings_QtGui[3728]
#define sipNameNr_mouseQuickSelectionThreshold 3757
#define sipName_mouseQuickSelectionThreshold &sipStrings_QtGui[3757]
#define sipNameNr_keyboardInputIntervalChanged 3786
#define sipName_keyboardInputIntervalChanged &sipStrings_QtGui[3786]
#define sipNameNr_QStaticText__PerformanceHint 3815
#define sipName_QStaticText__PerformanceHint &sipStrings_QtGui[3815]
#define sipNameNr_QPainter__PixmapFragmentHint 3844
#define sipName_QPainter__PixmapFragmentHint &sipStrings_QtGui[3844]
#define sipNameNr_RasterOp_SourceOrDestination 3873
#define sipName_RasterOp_SourceOrDestination &sipStrings_QtGui[3873]
#define sipNameNr_QOpenGLTexture__SwizzleValue 3902
#define sipName_QOpenGLTexture__SwizzleValue &sipStrings_QtGui[3902]
#define sipNameNr_QOpenGLShader__ShaderTypeBit 3931
#define sipName_QOpenGLShader__ShaderTypeBit &sipStrings_QtGui[3931]
#define sipNameNr_setLeastSignificantByteFirst 3960
#define sipName_setLeastSignificantByteFirst &sipStrings_QtGui[3960]
#define sipNameNr_QOpenGLDebugMessage__Sources 3989
#define sipName_QOpenGLDebugMessage__Sources &sipStrings_QtGui[3989]
#define sipNameNr_QKeySequence__SequenceFormat 4018
#define sipName_QKeySequence__SequenceFormat &sipStrings_QtGui[4018]
#define sipNameNr_QImageIOHandler__ImageOption 4047
#define sipName_QImageIOHandler__ImageOption &sipStrings_QtGui[4047]
#define sipNameNr_Format_A2RGB30_Premultiplied 4076
#define sipName_Format_A2RGB30_Premultiplied &sipStrings_QtGui[4076]
#define sipNameNr_Format_A2BGR30_Premultiplied 4105
#define sipName_Format_A2BGR30_Premultiplied &sipStrings_QtGui[4105]
#define sipNameNr_QFontDatabase__WritingSystem 4134
#define sipName_QFontDatabase__WritingSystem &sipStrings_QtGui[4134]
#define sipNameNr_QInputMethodEvent__Attribute 4163
#define sipName_QInputMethodEvent__Attribute &sipStrings_QtGui[4163]
#define sipNameNr_QColorSpace__NamedColorSpace 4192
#define sipName_QColorSpace__NamedColorSpace &sipStrings_QtGui[4192]
#define sipNameNr_QRegularExpressionValidator 4221
#define sipName_QRegularExpressionValidator &sipStrings_QtGui[4221]
#define sipNameNr_clearColumnWidthConstraints 4249
#define sipName_clearColumnWidthConstraints &sipStrings_QtGui[4249]
#define sipNameNr_FontPropertiesSpecifiedOnly 4277
#define sipName_FontPropertiesSpecifiedOnly &sipStrings_QtGui[4277]
#define sipNameNr_TableColumnWidthConstraints 4305
#define sipName_TableColumnWidthConstraints &sipStrings_QtGui[4305]
#define sipNameNr_QTextFormat__PageBreakFlags 4333
#define sipName_QTextFormat__PageBreakFlags &sipStrings_QtGui[4333]
#define sipNameNr_QTextDocument__ResourceType 4361
#define sipName_QTextDocument__ResourceType &sipStrings_QtGui[4361]
#define sipNameNr_showShortcutsInContextMenus 4389
#define sipName_showShortcutsInContextMenus &sipStrings_QtGui[4389]
#define sipNameNr_QPixelFormat__AlphaPosition 4417
#define sipName_QPixelFormat__AlphaPosition &sipStrings_QtGui[4417]
#define sipNameNr_ObjectBoundingModeGradients 4445
#define sipName_ObjectBoundingModeGradients &sipStrings_QtGui[4445]
#define sipNameNr_CompositionMode_Destination 4473
#define sipName_CompositionMode_Destination &sipStrings_QtGui[4473]
#define sipNameNr_QPagedPaintDevice__PageSize 4501
#define sipName_QPagedPaintDevice__PageSize &sipStrings_QtGui[4501]
#define sipNameNr_ImmutableMultisampleStorage 4529
#define sipName_ImmutableMultisampleStorage &sipStrings_QtGui[4529]
#define sipNameNr_QOpenGLTexture__PixelFormat 4557
#define sipName_QOpenGLTexture__PixelFormat &sipStrings_QtGui[4557]
#define sipNameNr_QOpenGLTexture__CubeMapFace 4585
#define sipName_QOpenGLTexture__CubeMapFace &sipStrings_QtGui[4585]
#define sipNameNr_QOpenGLPixelTransferOptions 4613
#define sipName_QOpenGLPixelTransferOptions &sipStrings_QtGui[4613]
#define sipNameNr_hasOpenGLFramebufferObjects 4641
#define sipName_hasOpenGLFramebufferObjects &sipStrings_QtGui[4641]
#define sipNameNr_QOpenGLDebugMessage__Source 4669
#define sipName_QOpenGLDebugMessage__Source &sipStrings_QtGui[4669]
#define sipNameNr_QOpenGLBuffer__UsagePattern 4697
#define sipName_QOpenGLBuffer__UsagePattern &sipStrings_QtGui[4697]
#define sipNameNr_QKeySequence__SequenceMatch 4725
#define sipName_QKeySequence__SequenceMatch &sipStrings_QtGui[4725]
#define sipNameNr_Format_RGBA64_Premultiplied 4753
#define sipName_Format_RGBA64_Premultiplied &sipStrings_QtGui[4753]
#define sipNameNr_Format_ARGB32_Premultiplied 4781
#define sipName_Format_ARGB32_Premultiplied &sipStrings_QtGui[4781]
#define sipNameNr_QIconEngine__IconEngineHook 4809
#define sipName_QIconEngine__IconEngineHook &sipStrings_QtGui[4809]
#define sipNameNr_QAbstractTextDocumentLayout 4837
#define sipName_QAbstractTextDocumentLayout &sipStrings_QtGui[4837]
#define sipNameNr_4865 4865
#define sipName_4865 &sipStrings_QtGui[4865]
#define sipNameNr_QDoubleValidator__Notation 4892
#define sipName_QDoubleValidator__Notation &sipStrings_QtGui[4892]
#define sipNameNr_QTouchDevice__Capabilities 4919
#define sipName_QTouchDevice__Capabilities &sipStrings_QtGui[4919]
#define sipNameNr_QTextFrameFormat__Position 4946
#define sipName_QTextFrameFormat__Position &sipStrings_QtGui[4946]
#define sipNameNr_TableCellBottomBorderBrush 4973
#define sipName_TableCellBottomBorderBrush &sipStrings_QtGui[4973]
#define sipNameNr_TableCellBottomBorderStyle 5000
#define sipName_TableCellBottomBorderStyle &sipStrings_QtGui[5000]
#define sipNameNr_QTextFormat__PageBreakFlag 5027
#define sipName_QTextFormat__PageBreakFlag &sipStrings_QtGui[5027]
#define sipNameNr_QTextCursor__SelectionType 5054
#define sipName_QTextCursor__SelectionType &sipStrings_QtGui[5054]
#define sipNameNr_QTextCursor__MoveOperation 5081
#define sipName_QTextCursor__MoveOperation &sipStrings_QtGui[5081]
#define sipNameNr_QSurfaceFormat__ColorSpace 5108
#define sipName_QSurfaceFormat__ColorSpace &sipStrings_QtGui[5108]
#define sipNameNr_physicalDotsPerInchChanged 5135
#define sipName_physicalDotsPerInchChanged &sipStrings_QtGui[5135]
#define sipNameNr_QRawFont__AntialiasingType 5162
#define sipName_QRawFont__AntialiasingType &sipStrings_QtGui[5162]
#define sipNameNr_CompositionMode_Difference 5189
#define sipName_CompositionMode_Difference &sipStrings_QtGui[5189]
#define sipNameNr_CompositionMode_ColorDodge 5216
#define sipName_CompositionMode_ColorDodge &sipStrings_QtGui[5216]
#define sipNameNr_CompositionMode_SourceAtop 5243
#define sipName_CompositionMode_SourceAtop &sipStrings_QtGui[5243]
#define sipNameNr_CompositionMode_SourceOver 5270
#define sipName_CompositionMode_SourceOver &sipStrings_QtGui[5270]
#define sipNameNr_QPageSize__SizeMatchPolicy 5297
#define sipName_QPageSize__SizeMatchPolicy &sipStrings_QtGui[5297]
#define sipNameNr_QPagedPaintDevice__Margins 5324
#define sipName_QPagedPaintDevice__Margins &sipStrings_QtGui[5324]
#define sipNameNr_TextureComparisonOperators 5351
#define sipName_TextureComparisonOperators &sipStrings_QtGui[5351]
#define sipNameNr_BindingTarget2DMultisample 5378
#define sipName_BindingTarget2DMultisample &sipStrings_QtGui[5378]
#define sipNameNr_isLeastSignificantBitFirst 5405
#define sipName_isLeastSignificantBitFirst &sipStrings_QtGui[5405]
#define sipNameNr_QOpenGLDebugMessage__Types 5432
#define sipName_QOpenGLDebugMessage__Types &sipStrings_QtGui[5432]
#define sipNameNr_setDecideFormatFromContent 5459
#define sipName_setDecideFormatFromContent &sipStrings_QtGui[5459]
#define sipNameNr_addApplicationFontFromData 5486
#define sipName_addApplicationFontFromData &sipStrings_QtGui[5486]
#define sipNameNr_QTabletEvent__TabletDevice 5513
#define sipName_QTabletEvent__TabletDevice &sipStrings_QtGui[5513]
#define sipNameNr_transformationToColorSpace 5540
#define sipName_transformationToColorSpace &sipStrings_QtGui[5540]
#define sipNameNr_contentOrientationChanged 5567
#define sipName_contentOrientationChanged &sipStrings_QtGui[5567]
#define sipNameNr_QTextLine__CursorPosition 5593
#define sipName_QTextLine__CursorPosition &sipStrings_QtGui[5593]
#define sipNameNr_setColumnWidthConstraints 5619
#define sipName_setColumnWidthConstraints &sipStrings_QtGui[5619]
#define sipNameNr_TableCellRightBorderBrush 5645
#define sipName_TableCellRightBorderBrush &sipStrings_QtGui[5645]
#define sipNameNr_TableCellRightBorderStyle 5671
#define sipName_TableCellRightBorderStyle &sipStrings_QtGui[5671]
#define sipNameNr_MarkdownDialectCommonMark 5697
#define sipName_MarkdownDialectCommonMark &sipStrings_QtGui[5697]
#define sipNameNr_setDefaultCursorMoveStyle 5723
#define sipName_setDefaultCursorMoveStyle &sipStrings_QtGui[5723]
#define sipNameNr_mousePressAndHoldInterval 5749
#define sipName_mousePressAndHoldInterval &sipStrings_QtGui[5749]
#define sipNameNr_setHorizontalHeaderLabels 5775
#define sipName_setHorizontalHeaderLabels &sipStrings_QtGui[5775]
#define sipNameNr_primaryOrientationChanged 5801
#define sipName_primaryOrientationChanged &sipStrings_QtGui[5801]
#define sipNameNr_logicalDotsPerInchChanged 5827
#define sipName_logicalDotsPerInchChanged &sipStrings_QtGui[5827]
#define sipNameNr_QPainterPath__ElementType 5853
#define sipName_QPainterPath__ElementType &sipStrings_QtGui[5853]
#define sipNameNr_PdmDevicePixelRatioScaled 5879
#define sipName_PdmDevicePixelRatioScaled &sipStrings_QtGui[5879]
#define sipNameNr_RasterOp_ClearDestination 5905
#define sipName_RasterOp_ClearDestination &sipStrings_QtGui[5905]
#define sipNameNr_CompositionMode_Exclusion 5931
#define sipName_CompositionMode_Exclusion &sipStrings_QtGui[5931]
#define sipNameNr_CompositionMode_SoftLight 5957
#define sipName_CompositionMode_SoftLight &sipStrings_QtGui[5957]
#define sipNameNr_CompositionMode_HardLight 5983
#define sipName_CompositionMode_HardLight &sipStrings_QtGui[5983]
#define sipNameNr_CompositionMode_ColorBurn 6009
#define sipName_CompositionMode_ColorBurn &sipStrings_QtGui[6009]
#define sipNameNr_CompositionMode_SourceOut 6035
#define sipName_CompositionMode_SourceOut &sipStrings_QtGui[6035]
#define sipNameNr_QPainter__CompositionMode 6061
#define sipName_QPainter__CompositionMode &sipStrings_QtGui[6061]
#define sipNameNr_supportsExternalOESTarget 6087
#define sipName_supportsExternalOESTarget &sipStrings_QtGui[6087]
#define sipNameNr_Float32_D32_UInt32_S8_X24 6113
#define sipName_Float32_D32_UInt32_S8_X24 &sipStrings_QtGui[6113]
#define sipNameNr_QOpenGLTexture__PixelType 6139
#define sipName_QOpenGLTexture__PixelType &sipStrings_QtGui[6139]
#define sipNameNr_BindingTargetCubeMapArray 6165
#define sipName_BindingTargetCubeMapArray &sipStrings_QtGui[6165]
#define sipNameNr_maxGeometryOutputVertices 6191
#define sipName_maxGeometryOutputVertices &sipStrings_QtGui[6191]
#define sipNameNr_QOpenGLShader__ShaderType 6217
#define sipName_QOpenGLShader__ShaderType &sipStrings_QtGui[6217]
#define sipNameNr_RestoreFrameBufferBinding 6243
#define sipName_RestoreFrameBufferBinding &sipStrings_QtGui[6243]
#define sipNameNr_QOpenGLDebugMessage__Type 6269
#define sipName_QOpenGLDebugMessage__Type &sipStrings_QtGui[6269]
#define sipNameNr_QKeySequence__StandardKey 6295
#define sipName_QKeySequence__StandardKey &sipStrings_QtGui[6295]
#define sipNameNr_setApplicationDisplayName 6321
#define sipName_setApplicationDisplayName &sipStrings_QtGui[6321]
#define sipNameNr_setQuitOnLastWindowClosed 6347
#define sipName_setQuitOnLastWindowClosed &sipStrings_QtGui[6347]
#define sipNameNr_QFontDatabase__SystemFont 6373
#define sipName_QFontDatabase__SystemFont &sipStrings_QtGui[6373]
#define sipNameNr_removeAllApplicationFonts 6399
#define sipName_removeAllApplicationFonts &sipStrings_QtGui[6399]
#define sipNameNr_SurfaceAboutToBeDestroyed 6425
#define sipName_SurfaceAboutToBeDestroyed &sipStrings_QtGui[6425]
#define sipNameNr_QScrollEvent__ScrollState 6451
#define sipName_QScrollEvent__ScrollState &sipStrings_QtGui[6451]
#define sipNameNr_QContextMenuEvent__Reason 6477
#define sipName_QContextMenuEvent__Reason &sipStrings_QtGui[6477]
#define sipNameNr_QTabletEvent__PointerType 6503
#define sipName_QTabletEvent__PointerType &sipStrings_QtGui[6503]
#define sipNameNr_QGradient__CoordinateMode 6529
#define sipName_QGradient__CoordinateMode &sipStrings_QtGui[6529]
#define sipNameNr_QTouchDevice__DeviceType 6555
#define sipName_QTouchDevice__DeviceType &sipStrings_QtGui[6555]
#define sipNameNr_QTextLayout__FormatRange 6580
#define sipName_QTextLayout__FormatRange &sipStrings_QtGui[6580]
#define sipNameNr_setFontLetterSpacingType 6605
#define sipName_setFontLetterSpacingType &sipStrings_QtGui[6605]
#define sipNameNr_setFontHintingPreference 6630
#define sipName_setFontHintingPreference &sipStrings_QtGui[6630]
#define sipNameNr_TableCellLeftBorderBrush 6655
#define sipName_TableCellLeftBorderBrush &sipStrings_QtGui[6655]
#define sipNameNr_TableCellLeftBorderStyle 6680
#define sipName_TableCellLeftBorderStyle &sipStrings_QtGui[6680]
#define sipNameNr_QTextFormat__ObjectTypes 6705
#define sipName_QTextFormat__ObjectTypes &sipStrings_QtGui[6705]
#define sipNameNr_supportedDocumentFormats 6730
#define sipName_supportedDocumentFormats &sipStrings_QtGui[6730]
#define sipNameNr_QTextDocument__FindFlags 6755
#define sipName_QTextDocument__FindFlags &sipStrings_QtGui[6755]
#define sipNameNr_mouseDoubleClickDistance 6780
#define sipName_mouseDoubleClickDistance &sipStrings_QtGui[6780]
#define sipNameNr_startDragDistanceChanged 6805
#define sipName_startDragDistanceChanged &sipStrings_QtGui[6805]
#define sipNameNr_mouseDoubleClickInterval 6830
#define sipName_mouseDoubleClickInterval &sipStrings_QtGui[6830]
#define sipNameNr_setAccessibleDescription 6855
#define sipName_setAccessibleDescription &sipStrings_QtGui[6855]
#define sipNameNr_takeHorizontalHeaderItem 6880
#define sipName_takeHorizontalHeaderItem &sipStrings_QtGui[6880]
#define sipNameNr_availableGeometryChanged 6905
#define sipName_availableGeometryChanged &sipStrings_QtGui[6905]
#define sipNameNr_setOrientationUpdateMask 6930
#define sipName_setOrientationUpdateMask &sipStrings_QtGui[6930]
#define sipNameNr_availableVirtualGeometry 6955
#define sipName_availableVirtualGeometry &sipStrings_QtGui[6955]
#define sipNameNr_QPixelFormat__AlphaUsage 6980
#define sipName_QPixelFormat__AlphaUsage &sipStrings_QtGui[6980]
#define sipNameNr_QPixelFormat__ColorModel 7005
#define sipName_QPixelFormat__ColorModel &sipStrings_QtGui[7005]
#define sipNameNr_QPaintEngine__DirtyFlags 7030
#define sipName_QPaintEngine__DirtyFlags &sipStrings_QtGui[7030]
#define sipNameNr_QPainter__PixmapFragment 7055
#define sipName_QPainter__PixmapFragment &sipStrings_QtGui[7055]
#define sipNameNr_CompositionMode_Multiply 7080
#define sipName_CompositionMode_Multiply &sipStrings_QtGui[7080]
#define sipNameNr_CompositionMode_SourceIn 7105
#define sipName_CompositionMode_SourceIn &sipStrings_QtGui[7105]
#define sipNameNr_QPageLayout__Orientation 7130
#define sipName_QPageLayout__Orientation &sipStrings_QtGui[7130]
#define sipNameNr_QOpenGLVertexArrayObject 7155
#define sipName_QOpenGLVertexArrayObject &sipStrings_QtGui[7155]
#define sipNameNr_QAbstractOpenGLFunctions 7180
#define sipName_QAbstractOpenGLFunctions &sipStrings_QtGui[7180]
#define sipNameNr_QOpenGLTexture__WrapMode 7205
#define sipName_QOpenGLTexture__WrapMode &sipStrings_QtGui[7205]
#define sipNameNr_QOpenGLTexture__Features 7230
#define sipName_QOpenGLTexture__Features &sipStrings_QtGui[7230]
#define sipNameNr_Target2DMultisampleArray 2059
#define sipName_Target2DMultisampleArray &sipStrings_QtGui[2059]
#define sipNameNr_setInternalTextureFormat 7255
#define sipName_setInternalTextureFormat &sipStrings_QtGui[7255]
#define sipNameNr_FramebufferRestorePolicy 130
#define sipName_FramebufferRestorePolicy &sipStrings_QtGui[130]
#define sipNameNr_hasOpenGLFramebufferBlit 7280
#define sipName_hasOpenGLFramebufferBlit &sipStrings_QtGui[7280]
#define sipNameNr_QOpenGLFramebufferObject 7305
#define sipName_QOpenGLFramebufferObject &sipStrings_QtGui[7305]
#define sipNameNr_createApplicationMessage 7330
#define sipName_createApplicationMessage &sipStrings_QtGui[7330]
#define sipNameNr_defaultFramebufferObject 7355
#define sipName_defaultFramebufferObject &sipStrings_QtGui[7355]
#define sipNameNr_InsertParagraphSeparator 7380
#define sipName_InsertParagraphSeparator &sipStrings_QtGui[7380]
#define sipNameNr_keyboardRectangleChanged 7405
#define sipName_keyboardRectangleChanged &sipStrings_QtGui[7405]
#define sipNameNr_setAutoDetectImageFormat 7430
#define sipName_setAutoDetectImageFormat &sipStrings_QtGui[7430]
#define sipNameNr_QGlyphRun__GlyphRunFlags 7455
#define sipName_QGlyphRun__GlyphRunFlags &sipStrings_QtGui[7455]
#define sipNameNr_QFont__HintingPreference 7480
#define sipName_QFont__HintingPreference &sipStrings_QtGui[7480]
#define sipNameNr_7505 7505
#define sipName_7505 &sipStrings_QtGui[7505]
#define sipNameNr_CursorBetweenCharacters 7529
#define sipName_CursorBetweenCharacters &sipStrings_QtGui[7529]
#define sipNameNr_QTextLayout__CursorMode 7553
#define sipName_QTextLayout__CursorMode &sipStrings_QtGui[7553]
#define sipNameNr_TableCellTopBorderBrush 7577
#define sipName_TableCellTopBorderBrush &sipStrings_QtGui[7577]
#define sipNameNr_TableCellTopBorderStyle 7601
#define sipName_TableCellTopBorderStyle &sipStrings_QtGui[7601]
#define sipNameNr_QTextFormat__FormatType 7625
#define sipName_QTextFormat__FormatType &sipStrings_QtGui[7625]
#define sipNameNr_QTextDocument__FindFlag 7649
#define sipName_QTextDocument__FindFlag &sipStrings_QtGui[7649]
#define sipNameNr_setKeepPositionOnInsert 7673
#define sipName_setKeepPositionOnInsert &sipStrings_QtGui[7673]
#define sipNameNr_setCurrentBlockUserData 7697
#define sipName_setCurrentBlockUserData &sipStrings_QtGui[7697]
#define sipNameNr_wheelScrollLinesChanged 7721
#define sipName_wheelScrollLinesChanged &sipStrings_QtGui[7721]
#define sipNameNr_tabFocusBehaviorChanged 7745
#define sipName_tabFocusBehaviorChanged &sipStrings_QtGui[7745]
#define sipNameNr_QStandardItem__ItemType 7769
#define sipName_QStandardItem__ItemType &sipStrings_QtGui[7769]
#define sipNameNr_setVerticalHeaderLabels 7793
#define sipName_setVerticalHeaderLabels &sipStrings_QtGui[7793]
#define sipNameNr_setHorizontalHeaderItem 7817
#define sipName_setHorizontalHeaderItem &sipStrings_QtGui[7817]
#define sipNameNr_supportedWritingSystems 7841
#define sipName_supportedWritingSystems &sipStrings_QtGui[7841]
#define sipNameNr_advancesForGlyphIndexes 7865
#define sipName_advancesForGlyphIndexes &sipStrings_QtGui[7865]
#define sipNameNr_QPixelFormat__ByteOrder 7889
#define sipName_QPixelFormat__ByteOrder &sipStrings_QtGui[7889]
#define sipNameNr_QPixelFormat__YUVLayout 7913
#define sipName_QPixelFormat__YUVLayout &sipStrings_QtGui[7913]
#define sipNameNr_QPaintEngine__DirtyFlag 7937
#define sipName_QPaintEngine__DirtyFlag &sipStrings_QtGui[7937]
#define sipNameNr_setViewTransformEnabled 7961
#define sipName_setViewTransformEnabled &sipStrings_QtGui[7961]
#define sipNameNr_RasterOp_NotDestination 7985
#define sipName_RasterOp_NotDestination &sipStrings_QtGui[7985]
#define sipNameNr_RasterOp_SetDestination 8009
#define sipName_RasterOp_SetDestination &sipStrings_QtGui[8009]
#define sipNameNr_CompositionMode_Lighten 8033
#define sipName_CompositionMode_Lighten &sipStrings_QtGui[8033]
#define sipNameNr_CompositionMode_Overlay 8057
#define sipName_CompositionMode_Overlay &sipStrings_QtGui[8057]
#define sipNameNr_HighQualityAntialiasing 8081
#define sipName_HighQualityAntialiasing &sipStrings_QtGui[8081]
#define sipNameNr_setFixedSamplePositions 8105
#define sipName_setFixedSamplePositions &sipStrings_QtGui[8105]
#define sipNameNr_setMaximumLevelOfDetail 8129
#define sipName_setMaximumLevelOfDetail &sipStrings_QtGui[8129]
#define sipNameNr_setMinimumLevelOfDetail 8153
#define sipName_setMinimumLevelOfDetail &sipStrings_QtGui[8153]
#define sipNameNr_QOpenGLTexture__Feature 8177
#define sipName_QOpenGLTexture__Feature &sipStrings_QtGui[8177]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x12 8201
#define sipName_SRGB8_Alpha8_ASTC_12x12 &sipStrings_QtGui[8201]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x10 8225
#define sipName_SRGB8_Alpha8_ASTC_12x10 &sipStrings_QtGui[8225]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x10 8249
#define sipName_SRGB8_Alpha8_ASTC_10x10 &sipStrings_QtGui[8249]
#define sipNameNr_hasOpenGLShaderPrograms 8273
#define sipName_hasOpenGLShaderPrograms &sipStrings_QtGui[8273]
#define sipNameNr_addShaderFromSourceFile 8297
#define sipName_addShaderFromSourceFile &sipStrings_QtGui[8297]
#define sipNameNr_addShaderFromSourceCode 8321
#define sipName_addShaderFromSourceCode &sipStrings_QtGui[8321]
#define sipNameNr_createThirdPartyMessage 8345
#define sipName_createThirdPartyMessage &sipStrings_QtGui[8345]
#define sipNameNr_setProgressiveScanWrite 8369
#define sipName_setProgressiveScanWrite &sipStrings_QtGui[8369]
#define sipNameNr_imageFormatsForMimeType 8393
#define sipName_imageFormatsForMimeType &sipStrings_QtGui[8393]
#define sipNameNr_decideFormatFromContent 8417
#define sipName_decideFormatFromContent &sipStrings_QtGui[8417]
#define sipNameNr_TransformationRotate270 8441
#define sipName_TransformationRotate270 &sipStrings_QtGui[8441]
#define sipNameNr_TransformationRotate180 8465
#define sipName_TransformationRotate180 &sipStrings_QtGui[8465]
#define sipNameNr_applicationStateChanged 8489
#define sipName_applicationStateChanged &sipStrings_QtGui[8489]
#define sipNameNr_setDesktopSettingsAware 8513
#define sipName_setDesktopSettingsAware &sipStrings_QtGui[8513]
#define sipNameNr_QGlyphRun__GlyphRunFlag 8537
#define sipName_QGlyphRun__GlyphRunFlag &sipStrings_QtGui[8537]
#define sipNameNr_applicationFontFamilies 8561
#define sipName_applicationFontFamilies &sipStrings_QtGui[8561]
#define sipNameNr_QPointingDeviceUniqueId 8585
#define sipName_QPointingDeviceUniqueId &sipStrings_QtGui[8585]
#define sipNameNr_QTouchEvent__TouchPoint 8609
#define sipName_QTouchEvent__TouchPoint &sipStrings_QtGui[8609]
#define sipNameNr_QWindowStateChangeEvent 8633
#define sipName_QWindowStateChangeEvent &sipStrings_QtGui[8633]
#define sipNameNr_8657 8657
#define sipName_8657 &sipStrings_QtGui[8657]
#define sipNameNr_setKeyboardGrabEnabled 8680
#define sipName_setKeyboardGrabEnabled &sipStrings_QtGui[8680]
#define sipNameNr_ShowDocumentTerminator 8703
#define sipName_ShowDocumentTerminator &sipStrings_QtGui[8703]
#define sipNameNr_previousCursorPosition 8726
#define sipName_previousCursorPosition &sipStrings_QtGui[8726]
#define sipNameNr_clearAdditionalFormats 8749
#define sipName_clearAdditionalFormats &sipStrings_QtGui[8749]
#define sipNameNr_columnWidthConstraints 8772
#define sipName_columnWidthConstraints &sipStrings_QtGui[8772]
#define sipNameNr_BorderStyle_DotDotDash 8795
#define sipName_BorderStyle_DotDotDash &sipStrings_QtGui[8795]
#define sipNameNr_QTextListFormat__Style 8818
#define sipName_QTextListFormat__Style &sipStrings_QtGui[8818]
#define sipNameNr_setTableCellColumnSpan 8841
#define sipName_setTableCellColumnSpan &sipStrings_QtGui[8841]
#define sipNameNr_TableCellBottomPadding 8864
#define sipName_TableCellBottomPadding &sipStrings_QtGui[8864]
#define sipNameNr_BlockNonBreakableLines 8887
#define sipName_BlockNonBreakableLines &sipStrings_QtGui[8887]
#define sipNameNr_PageBreak_AlwaysBefore 8910
#define sipName_PageBreak_AlwaysBefore &sipStrings_QtGui[8910]
#define sipNameNr_defaultCursorMoveStyle 8933
#define sipName_defaultCursorMoveStyle &sipStrings_QtGui[8933]
#define sipNameNr_QSurface__SurfaceClass 8956
#define sipName_QSurface__SurfaceClass &sipStrings_QtGui[8956]
#define sipNameNr_touchDoubleTapDistance 8979
#define sipName_touchDoubleTapDistance &sipStrings_QtGui[8979]
#define sipNameNr_useHoverEffectsChanged 9002
#define sipName_useHoverEffectsChanged &sipStrings_QtGui[9002]
#define sipNameNr_cursorFlashTimeChanged 9025
#define sipName_cursorFlashTimeChanged &sipStrings_QtGui[9025]
#define sipNameNr_setFocusOnTouchRelease 9048
#define sipName_setFocusOnTouchRelease &sipStrings_QtGui[9048]
#define sipNameNr_keyboardAutoRepeatRate 9071
#define sipName_keyboardAutoRepeatRate &sipStrings_QtGui[9071]
#define sipNameNr_takeVerticalHeaderItem 9094
#define sipName_takeVerticalHeaderItem &sipStrings_QtGui[9094]
#define sipNameNr_virtualGeometryChanged 9117
#define sipName_virtualGeometryChanged &sipStrings_QtGui[9117]
#define sipNameNr_setDocumentXmpMetadata 9140
#define sipName_setDocumentXmpMetadata &sipStrings_QtGui[9140]
#define sipNameNr_PaintOutsidePaintEvent 9163
#define sipName_PaintOutsidePaintEvent &sipStrings_QtGui[9163]
#define sipNameNr_QTextItem__RenderFlags 9186
#define sipName_QTextItem__RenderFlags &sipStrings_QtGui[9186]
#define sipNameNr_devicePixelRatioFScale 9209
#define sipName_devicePixelRatioFScale &sipStrings_QtGui[9209]
#define sipNameNr_CompositionMode_Darken 9232
#define sipName_CompositionMode_Darken &sipStrings_QtGui[9232]
#define sipNameNr_CompositionMode_Screen 9255
#define sipName_CompositionMode_Screen &sipStrings_QtGui[9255]
#define sipNameNr_CompositionMode_Source 9278
#define sipName_CompositionMode_Source &sipStrings_QtGui[9278]
#define sipNameNr_LosslessImageRendering 9301
#define sipName_LosslessImageRendering &sipStrings_QtGui[9301]
#define sipNameNr_isFixedSamplePositions 9324
#define sipName_isFixedSamplePositions &sipStrings_QtGui[9324]
#define sipNameNr_setMagnificationFilter 9347
#define sipName_setMagnificationFilter &sipStrings_QtGui[9347]
#define sipNameNr_QOpenGLTexture__Filter 9370
#define sipName_QOpenGLTexture__Filter &sipStrings_QtGui[9370]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x8 9393
#define sipName_SRGB8_Alpha8_ASTC_10x8 &sipStrings_QtGui[9393]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x6 9416
#define sipName_SRGB8_Alpha8_ASTC_10x6 &sipStrings_QtGui[9416]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x5 9439
#define sipName_SRGB8_Alpha8_ASTC_10x5 &sipStrings_QtGui[9439]
#define sipNameNr_BindingTargetRectangle 9462
#define sipName_BindingTargetRectangle &sipStrings_QtGui[9462]
#define sipNameNr_QOpenGLTexture__Target 9485
#define sipName_QOpenGLTexture__Target &sipStrings_QtGui[9485]
#define sipNameNr_TessellationEvaluation 9508
#define sipName_TessellationEvaluation &sipStrings_QtGui[9508]
#define sipNameNr_DeprecatedBehaviorType 9531
#define sipName_DeprecatedBehaviorType &sipStrings_QtGui[9531]
#define sipNameNr_supportsThreadedOpenGL 9554
#define sipName_supportsThreadedOpenGL &sipStrings_QtGui[9554]
#define sipNameNr_anchorRectangleChanged 9577
#define sipName_anchorRectangleChanged &sipStrings_QtGui[9577]
#define sipNameNr_inputItemClipRectangle 9600
#define sipName_inputItemClipRectangle &sipStrings_QtGui[9600]
#define sipNameNr_cursorRectangleChanged 9623
#define sipName_cursorRectangleChanged &sipStrings_QtGui[9623]
#define sipNameNr_UnsupportedFormatError 9646
#define sipName_UnsupportedFormatError &sipStrings_QtGui[9646]
#define sipNameNr_TransformationRotate90 9669
#define sipName_TransformationRotate90 &sipStrings_QtGui[9669]
#define sipNameNr_AvailableSizesArgument 629
#define sipName_AvailableSizesArgument &sipStrings_QtGui[629]
#define sipNameNr_setFallbackSearchPaths 9692
#define sipName_setFallbackSearchPaths &sipStrings_QtGui[9692]
#define sipNameNr_layoutDirectionChanged 9715
#define sipName_layoutDirectionChanged &sipStrings_QtGui[9715]
#define sipNameNr_applicationDisplayName 9738
#define sipName_applicationDisplayName &sipStrings_QtGui[9738]
#define sipNameNr_quitOnLastWindowClosed 9761
#define sipName_quitOnLastWindowClosed &sipStrings_QtGui[9761]
#define sipNameNr_queryKeyboardModifiers 9784
#define sipName_queryKeyboardModifiers &sipStrings_QtGui[9784]
#define sipNameNr_QWhatsThisClickedEvent 9807
#define sipName_QWhatsThisClickedEvent &sipStrings_QtGui[9807]
#define sipNameNr_QInputMethodQueryEvent 9830
#define sipName_QInputMethodQueryEvent &sipStrings_QtGui[9830]
#define sipNameNr_QColorSpace__Primaries 9853
#define sipName_QColorSpace__Primaries &sipStrings_QtGui[9853]
#define sipNameNr_9876 9876
#define sipName_9876 &sipStrings_QtGui[9876]
#define sipNameNr_9898 9898
#define sipName_9898 &sipStrings_QtGui[9898]
#define sipNameNr_mouseDoubleClickEvent 9920
#define sipName_mouseDoubleClickEvent &sipStrings_QtGui[9920]
#define sipNameNr_QWindow__AncestorMode 9942
#define sipName_QWindow__AncestorMode &sipStrings_QtGui[9942]
#define sipNameNr_setMaximumTouchPoints 9964
#define sipName_setMaximumTouchPoints &sipStrings_QtGui[9964]
#define sipNameNr_IncludeTrailingSpaces 9986
#define sipName_IncludeTrailingSpaces &sipStrings_QtGui[9986]
#define sipNameNr_QTextOption__WrapMode 10008
#define sipName_QTextOption__WrapMode &sipStrings_QtGui[10008]
#define sipNameNr_isValidCursorPosition 10030
#define sipName_isValidCursorPosition &sipStrings_QtGui[10030]
#define sipNameNr_fontLetterSpacingType 10052
#define sipName_fontLetterSpacingType &sipStrings_QtGui[10052]
#define sipNameNr_fontHintingPreference 10074
#define sipName_fontHintingPreference &sipStrings_QtGui[10074]
#define sipNameNr_setFontCapitalization 10096
#define sipName_setFontCapitalization &sipStrings_QtGui[10096]
#define sipNameNr_TableCellBottomBorder 10118
#define sipName_TableCellBottomBorder &sipStrings_QtGui[10118]
#define sipNameNr_FontLetterSpacingType 6608
#define sipName_FontLetterSpacingType &sipStrings_QtGui[6608]
#define sipNameNr_FontHintingPreference 6633
#define sipName_FontHintingPreference &sipStrings_QtGui[6633]
#define sipNameNr_TableCellRightPadding 10140
#define sipName_TableCellRightPadding &sipStrings_QtGui[10140]
#define sipNameNr_TextVerticalAlignment 10162
#define sipName_TextVerticalAlignment &sipStrings_QtGui[10162]
#define sipNameNr_QTextFormat__Property 10184
#define sipName_QTextFormat__Property &sipStrings_QtGui[10184]
#define sipNameNr_PageBreak_AlwaysAfter 10206
#define sipName_PageBreak_AlwaysAfter &sipStrings_QtGui[10206]
#define sipNameNr_QTextDocumentFragment 10228
#define sipName_QTextDocumentFragment &sipStrings_QtGui[10228]
#define sipNameNr_MarkdownDialectGitHub 10250
#define sipName_MarkdownDialectGitHub &sipStrings_QtGui[10250]
#define sipNameNr_QTextDocument__Stacks 10272
#define sipName_QTextDocument__Stacks &sipStrings_QtGui[10272]
#define sipNameNr_documentLayoutChanged 10294
#define sipName_documentLayoutChanged &sipStrings_QtGui[10294]
#define sipNameNr_findBlockByLineNumber 10316
#define sipName_findBlockByLineNumber &sipStrings_QtGui[10316]
#define sipNameNr_cursorPositionChanged 10338
#define sipName_cursorPositionChanged &sipStrings_QtGui[10338]
#define sipNameNr_joinPreviousEditBlock 10360
#define sipName_joinPreviousEditBlock &sipStrings_QtGui[10360]
#define sipNameNr_QTextCursor__MoveMode 10382
#define sipName_QTextCursor__MoveMode &sipStrings_QtGui[10382]
#define sipNameNr_DefaultRenderableType 10404
#define sipName_DefaultRenderableType &sipStrings_QtGui[10404]
#define sipNameNr_QSurface__SurfaceType 10426
#define sipName_QSurface__SurfaceType &sipStrings_QtGui[10426]
#define sipNameNr_singleClickActivation 10448
#define sipName_singleClickActivation &sipStrings_QtGui[10448]
#define sipNameNr_passwordMaskCharacter 10470
#define sipName_passwordMaskCharacter &sipStrings_QtGui[10470]
#define sipNameNr_keyboardInputInterval 10492
#define sipName_keyboardInputInterval &sipStrings_QtGui[10492]
#define sipNameNr_accessibleDescription 10514
#define sipName_accessibleDescription &sipStrings_QtGui[10514]
#define sipNameNr_setVerticalHeaderItem 10536
#define sipName_setVerticalHeaderItem &sipStrings_QtGui[10536]
#define sipNameNr_orientationUpdateMask 10558
#define sipName_orientationUpdateMask &sipStrings_QtGui[10558]
#define sipNameNr_QRawFont__LayoutFlags 10580
#define sipName_QRawFont__LayoutFlags &sipStrings_QtGui[10580]
#define sipNameNr_glyphIndexesForString 10602
#define sipName_glyphIndexesForString &sipStrings_QtGui[10602]
#define sipNameNr_qPixelFormatGrayscale 10624
#define sipName_qPixelFormatGrayscale &sipStrings_QtGui[10624]
#define sipNameNr_QPainterPath__Element 10646
#define sipName_QPainterPath__Element &sipStrings_QtGui[10646]
#define sipNameNr_QTextItem__RenderFlag 10668
#define sipName_QTextItem__RenderFlag &sipStrings_QtGui[10668]
#define sipNameNr_setWorldMatrixEnabled 10690
#define sipName_setWorldMatrixEnabled &sipStrings_QtGui[10690]
#define sipNameNr_CompositionMode_Clear 10712
#define sipName_CompositionMode_Clear &sipStrings_QtGui[10712]
#define sipNameNr_QPainter__RenderHints 10734
#define sipName_QPainter__RenderHints &sipStrings_QtGui[10734]
#define sipNameNr_Qt4CompatiblePainting 10756
#define sipName_Qt4CompatiblePainting &sipStrings_QtGui[10756]
#define sipNameNr_NonCosmeticDefaultPen 10778
#define sipName_NonCosmeticDefaultPen &sipStrings_QtGui[10778]
#define sipNameNr_SmoothPixmapTransform 10800
#define sipName_SmoothPixmapTransform &sipStrings_QtGui[10800]
#define sipNameNr_FuzzyOrientationMatch 10822
#define sipName_FuzzyOrientationMatch &sipStrings_QtGui[10822]
#define sipNameNr_QPageSize__PageSizeId 10844
#define sipName_QPageSize__PageSizeId &sipStrings_QtGui[10844]
#define sipNameNr_QOpenGLTextureBlitter 10866
#define sipName_QOpenGLTextureBlitter &sipStrings_QtGui[10866]
#define sipNameNr_setComparisonFunction 10888
#define sipName_setComparisonFunction &sipStrings_QtGui[10888]
#define sipNameNr_setLevelOfDetailRange 10910
#define sipName_setLevelOfDetailRange &sipStrings_QtGui[10910]
#define sipNameNr_setMinificationFilter 10932
#define sipName_setMinificationFilter &sipStrings_QtGui[10932]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x8 10954
#define sipName_SRGB8_Alpha8_ASTC_8x8 &sipStrings_QtGui[10954]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x6 10976
#define sipName_SRGB8_Alpha8_ASTC_8x6 &sipStrings_QtGui[10976]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x5 10998
#define sipName_SRGB8_Alpha8_ASTC_8x5 &sipStrings_QtGui[10998]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x6 11020
#define sipName_SRGB8_Alpha8_ASTC_6x6 &sipStrings_QtGui[11020]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x5 11042
#define sipName_SRGB8_Alpha8_ASTC_6x5 &sipStrings_QtGui[11042]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x5 11064
#define sipName_SRGB8_Alpha8_ASTC_5x5 &sipStrings_QtGui[11064]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x4 11086
#define sipName_SRGB8_Alpha8_ASTC_5x4 &sipStrings_QtGui[11086]
#define sipNameNr_SRGB8_Alpha8_ASTC_4x4 11108
#define sipName_SRGB8_Alpha8_ASTC_4x4 &sipStrings_QtGui[11108]
#define sipNameNr_SRGB8_Alpha8_ETC2_EAC 11130
#define sipName_SRGB8_Alpha8_ETC2_EAC &sipStrings_QtGui[11130]
#define sipNameNr_RGB_BP_UNSIGNED_FLOAT 11152
#define sipName_RGB_BP_UNSIGNED_FLOAT &sipStrings_QtGui[11152]
#define sipNameNr_disableAttributeArray 11174
#define sipName_disableAttributeArray &sipStrings_QtGui[11174]
#define sipNameNr_bindAttributeLocation 11196
#define sipName_bindAttributeLocation &sipStrings_QtGui[11196]
#define sipNameNr_internalTextureFormat 11218
#define sipName_internalTextureFormat &sipStrings_QtGui[11218]
#define sipNameNr_UndefinedBehaviorType 11240
#define sipName_UndefinedBehaviorType &sipStrings_QtGui[11240]
#define sipNameNr_QOpenGLVersionProfile 11262
#define sipName_QOpenGLVersionProfile &sipStrings_QtGui[11262]
#define sipNameNr_RangeInvalidateBuffer 11284
#define sipName_RangeInvalidateBuffer &sipStrings_QtGui[11284]
#define sipNameNr_QOpenGLBuffer__Access 11306
#define sipName_QOpenGLBuffer__Access &sipStrings_QtGui[11306]
#define sipNameNr_SelectStartOfDocument 11328
#define sipName_SelectStartOfDocument &sipStrings_QtGui[11328]
#define sipNameNr_MoveToStartOfDocument 11350
#define sipName_MoveToStartOfDocument &sipStrings_QtGui[11350]
#define sipNameNr_inputDirectionChanged 11372
#define sipName_inputDirectionChanged &sipStrings_QtGui[11372]
#define sipNameNr_setInputItemRectangle 11394
#define sipName_setInputItemRectangle &sipStrings_QtGui[11394]
#define sipNameNr_setInputItemTransform 11416
#define sipName_setInputItemTransform &sipStrings_QtGui[11416]
#define sipNameNr_autoDetectImageFormat 11438
#define sipName_autoDetectImageFormat &sipStrings_QtGui[11438]
#define sipNameNr_supportedImageFormats 11460
#define sipName_supportedImageFormats &sipStrings_QtGui[11460]
#define sipNameNr_convertedToColorSpace 11482
#define sipName_convertedToColorSpace &sipStrings_QtGui[11482]
#define sipNameNr_restoreOverrideCursor 11504
#define sipName_restoreOverrideCursor &sipStrings_QtGui[11504]
#define sipNameNr_removeApplicationFont 11526
#define sipName_removeApplicationFont &sipStrings_QtGui[11526]
#define sipNameNr_PreferVerticalHinting 11548
#define sipName_PreferVerticalHinting &sipStrings_QtGui[11548]
#define sipNameNr_QFont__Capitalization 11570
#define sipName_QFont__Capitalization &sipStrings_QtGui[11570]
#define sipNameNr_QPlatformSurfaceEvent 11592
#define sipName_QPlatformSurfaceEvent &sipStrings_QtGui[11592]
#define sipNameNr_11614 11614
#define sipName_11614 &sipStrings_QtGui[11614]
#define sipNameNr_11635 11635
#define sipName_11635 &sipStrings_QtGui[11635]
#define sipNameNr_11656 11656
#define sipName_11656 &sipStrings_QtGui[11656]
#define sipNameNr_maximumHeightChanged 11677
#define sipName_maximumHeightChanged &sipStrings_QtGui[11677]
#define sipNameNr_minimumHeightChanged 11698
#define sipName_minimumHeightChanged &sipStrings_QtGui[11698]
#define sipNameNr_setRegularExpression 11719
#define sipName_setRegularExpression &sipStrings_QtGui[11719]
#define sipNameNr_tableCellFormatIndex 11740
#define sipName_tableCellFormatIndex &sipStrings_QtGui[11740]
#define sipNameNr_QTextOption__TabType 11761
#define sipName_QTextOption__TabType &sipStrings_QtGui[11761]
#define sipNameNr_QTextBlock__iterator 11782
#define sipName_QTextBlock__iterator &sipStrings_QtGui[11782]
#define sipNameNr_QTextFrame__iterator 11803
#define sipName_QTextFrame__iterator &sipStrings_QtGui[11803]
#define sipNameNr_setAdditionalFormats 11824
#define sipName_setAdditionalFormats &sipStrings_QtGui[11824]
#define sipNameNr_setBottomBorderBrush 11845
#define sipName_setBottomBorderBrush &sipStrings_QtGui[11845]
#define sipNameNr_setBottomBorderStyle 11866
#define sipName_setBottomBorderStyle &sipStrings_QtGui[11866]
#define sipNameNr_QTextTableCellFormat 11887
#define sipName_QTextTableCellFormat &sipStrings_QtGui[11887]
#define sipNameNr_setNonBreakableLines 11908
#define sipName_setNonBreakableLines &sipStrings_QtGui[11908]
#define sipNameNr_setFontStyleStrategy 11929
#define sipName_setFontStyleStrategy &sipStrings_QtGui[11929]
#define sipNameNr_setFontLetterSpacing 11950
#define sipName_setFontLetterSpacing &sipStrings_QtGui[11950]
#define sipNameNr_setVerticalAlignment 11971
#define sipName_setVerticalAlignment &sipStrings_QtGui[11971]
#define sipNameNr_lengthVectorProperty 11992
#define sipName_lengthVectorProperty &sipStrings_QtGui[11992]
#define sipNameNr_TableCellRightBorder 12013
#define sipName_TableCellRightBorder &sipStrings_QtGui[12013]
#define sipNameNr_TableCellLeftPadding 12034
#define sipName_TableCellLeftPadding &sipStrings_QtGui[12034]
#define sipNameNr_setDefaultTextOption 12055
#define sipName_setDefaultTextOption &sipStrings_QtGui[12055]
#define sipNameNr_setMaximumBlockCount 12076
#define sipName_setMaximumBlockCount &sipStrings_QtGui[12076]
#define sipNameNr_setDefaultStyleSheet 12097
#define sipName_setDefaultStyleSheet &sipStrings_QtGui[12097]
#define sipNameNr_convertFromPlainText 12118
#define sipName_convertFromPlainText &sipStrings_QtGui[12118]
#define sipNameNr_keepPositionOnInsert 12139
#define sipName_keepPositionOnInsert &sipStrings_QtGui[12139]
#define sipNameNr_setVerticalMovementX 12160
#define sipName_setVerticalMovementX &sipStrings_QtGui[12160]
#define sipNameNr_mergeBlockCharFormat 12181
#define sipName_mergeBlockCharFormat &sipStrings_QtGui[12181]
#define sipNameNr_currentBlockUserData 12202
#define sipName_currentBlockUserData &sipStrings_QtGui[12202]
#define sipNameNr_setCurrentBlockState 12223
#define sipName_setCurrentBlockState &sipStrings_QtGui[12223]
#define sipNameNr_setStencilBufferSize 12244
#define sipName_setStencilBufferSize &sipStrings_QtGui[12244]
#define sipNameNr_CompatibilityProfile 12265
#define sipName_CompatibilityProfile &sipStrings_QtGui[12265]
#define sipNameNr_OpenGLContextProfile 378
#define sipName_OpenGLContextProfile &sipStrings_QtGui[378]
#define sipNameNr_startDragTimeChanged 12286
#define sipName_startDragTimeChanged &sipStrings_QtGui[12286]
#define sipNameNr_horizontalHeaderItem 12307
#define sipName_horizontalHeaderItem &sipStrings_QtGui[12307]
#define sipNameNr_availableVirtualSize 12328
#define sipName_availableVirtualSize &sipStrings_QtGui[12328]
#define sipNameNr_physicalDotsPerInchY 12349
#define sipName_physicalDotsPerInchY &sipStrings_QtGui[12349]
#define sipNameNr_physicalDotsPerInchX 12370
#define sipName_physicalDotsPerInchX &sipStrings_QtGui[12370]
#define sipNameNr_QRawFont__LayoutFlag 12391
#define sipName_QRawFont__LayoutFlag &sipStrings_QtGui[12391]
#define sipNameNr_SubPixelAntialiasing 12412
#define sipName_SubPixelAntialiasing &sipStrings_QtGui[12412]
#define sipNameNr_setCurrentColorGroup 12433
#define sipName_setCurrentColorGroup &sipStrings_QtGui[12433]
#define sipNameNr_QPalette__ColorGroup 12454
#define sipName_QPalette__ColorGroup &sipStrings_QtGui[12454]
#define sipNameNr_setElementPositionAt 12475
#define sipName_setElementPositionAt &sipStrings_QtGui[12475]
#define sipNameNr_DirtyCompositionMode 12496
#define sipName_DirtyCompositionMode &sipStrings_QtGui[12496]
#define sipNameNr_PerspectiveTransform 12517
#define sipName_PerspectiveTransform &sipStrings_QtGui[12517]
#define sipNameNr_viewTransformEnabled 12538
#define sipName_viewTransformEnabled &sipStrings_QtGui[12538]
#define sipNameNr_CompositionMode_Plus 12559
#define sipName_CompositionMode_Plus &sipStrings_QtGui[12559]
#define sipNameNr_QPainter__RenderHint 12580
#define sipName_QPainter__RenderHint &sipStrings_QtGui[12580]
#define sipNameNr_setLevelofDetailBias 12601
#define sipName_setLevelofDetailBias &sipStrings_QtGui[12601]
#define sipNameNr_maximumLevelOfDetail 12622
#define sipName_maximumLevelOfDetail &sipStrings_QtGui[12622]
#define sipNameNr_minimumLevelOfDetail 12643
#define sipName_minimumLevelOfDetail &sipStrings_QtGui[12643]
#define sipNameNr_setMaximumAnisotropy 12664
#define sipName_setMaximumAnisotropy &sipStrings_QtGui[12664]
#define sipNameNr_NearestMipMapNearest 12685
#define sipName_NearestMipMapNearest &sipStrings_QtGui[12685]
#define sipNameNr_AnisotropicFiltering 12706
#define sipName_AnisotropicFiltering &sipStrings_QtGui[12706]
#define sipNameNr_TextureCubeMapArrays 12727
#define sipName_TextureCubeMapArrays &sipStrings_QtGui[12727]
#define sipNameNr_LuminanceAlphaFormat 12748
#define sipName_LuminanceAlphaFormat &sipStrings_QtGui[12748]
#define sipNameNr_DontResetTextureUnit 12769
#define sipName_DontResetTextureUnit &sipStrings_QtGui[12769]
#define sipNameNr_BindingTargetCubeMap 12790
#define sipName_BindingTargetCubeMap &sipStrings_QtGui[12790]
#define sipNameNr_BindingTarget2DArray 12811
#define sipName_BindingTarget2DArray &sipStrings_QtGui[12811]
#define sipNameNr_BindingTarget1DArray 12832
#define sipName_BindingTarget1DArray &sipStrings_QtGui[12832]
#define sipNameNr_setUniformValueArray 12853
#define sipName_setUniformValueArray &sipStrings_QtGui[12853]
#define sipNameNr_enableAttributeArray 12874
#define sipName_enableAttributeArray &sipStrings_QtGui[12874]
#define sipNameNr_QOpenGLShaderProgram 12895
#define sipName_QOpenGLShaderProgram &sipStrings_QtGui[12895]
#define sipNameNr_CombinedDepthStencil 12916
#define sipName_CombinedDepthStencil &sipStrings_QtGui[12916]
#define sipNameNr_maximumMessageLength 12937
#define sipName_maximumMessageLength &sipStrings_QtGui[12937]
#define sipNameNr_NotificationSeverity 12958
#define sipName_NotificationSeverity &sipStrings_QtGui[12958]
#define sipNameNr_ShaderCompilerSource 12979
#define sipName_ShaderCompilerSource &sipStrings_QtGui[12979]
#define sipNameNr_QInputMethod__Action 13000
#define sipName_QInputMethod__Action &sipStrings_QtGui[13000]
#define sipNameNr_progressiveScanWrite 13021
#define sipName_progressiveScanWrite &sipStrings_QtGui[13021]
#define sipNameNr_TransformationMirror 13042
#define sipName_TransformationMirror &sipStrings_QtGui[13042]
#define sipNameNr_TransformedByDefault 13063
#define sipName_TransformedByDefault &sipStrings_QtGui[13063]
#define sipNameNr_ProgressiveScanWrite 8372
#define sipName_ProgressiveScanWrite &sipStrings_QtGui[8372]
#define sipNameNr_ScaledPixmapArgument 1115
#define sipName_ScaledPixmapArgument &sipStrings_QtGui[1115]
#define sipNameNr_setFallbackThemeName 13084
#define sipName_setFallbackThemeName &sipStrings_QtGui[13084]
#define sipNameNr_primaryScreenChanged 13105
#define sipName_primaryScreenChanged &sipStrings_QtGui[13105]
#define sipNameNr_desktopSettingsAware 13126
#define sipName_desktopSettingsAware &sipStrings_QtGui[13126]
#define sipNameNr_changeOverrideCursor 13147
#define sipName_changeOverrideCursor &sipStrings_QtGui[13147]
#define sipNameNr_SmallestReadableFont 13168
#define sipName_SmallestReadableFont &sipStrings_QtGui[13168]
#define sipNameNr_setHintingPreference 13189
#define sipName_setHintingPreference &sipStrings_QtGui[13189]
#define sipNameNr_PreferDefaultHinting 13210
#define sipName_PreferDefaultHinting &sipStrings_QtGui[13210]
#define sipNameNr_QFont__StyleStrategy 13231
#define sipName_QFont__StyleStrategy &sipStrings_QtGui[13231]
#define sipNameNr_acceptProposedAction 13252
#define sipName_acceptProposedAction &sipStrings_QtGui[13252]
#define sipNameNr_withTransferFunction 13273
#define sipName_withTransferFunction &sipStrings_QtGui[13273]
#define sipNameNr_lightgoldenrodyellow 13294
#define sipName_lightgoldenrodyellow &sipStrings_QtGui[13294]
#define sipNameNr_QColorConstants__Svg 13315
#define sipName_QColorConstants__Svg &sipStrings_QtGui[13315]
#define sipNameNr_QTextObjectInterface 13336
#define sipName_QTextObjectInterface &sipStrings_QtGui[13336]
#define sipNameNr_positionInlineObject 13357
#define sipName_positionInlineObject &sipStrings_QtGui[13357]
#define sipNameNr_supportedDragActions 13378
#define sipName_supportedDragActions &sipStrings_QtGui[13378]
#define sipNameNr_supportedDropActions 13399
#define sipName_supportedDropActions &sipStrings_QtGui[13399]
#define sipNameNr_13420 13420
#define sipName_13420 &sipStrings_QtGui[13420]
#define sipNameNr_AutomaticVisibility 13440
#define sipName_AutomaticVisibility &sipStrings_QtGui[13440]
#define sipNameNr_QWindow__Visibility 13460
#define sipName_QWindow__Visibility &sipStrings_QtGui[13460]
#define sipNameNr_maximumWidthChanged 13480
#define sipName_maximumWidthChanged &sipStrings_QtGui[13480]
#define sipNameNr_minimumWidthChanged 13500
#define sipName_minimumWidthChanged &sipStrings_QtGui[13500]
#define sipNameNr_setMouseGrabEnabled 13520
#define sipName_setMouseGrabEnabled &sipStrings_QtGui[13520]
#define sipNameNr_firstCursorPosition 13540
#define sipName_firstCursorPosition &sipStrings_QtGui[13540]
#define sipNameNr_rightCursorPosition 13560
#define sipName_rightCursorPosition &sipStrings_QtGui[13560]
#define sipNameNr_lineForTextPosition 13580
#define sipName_lineForTextPosition &sipStrings_QtGui[13580]
#define sipNameNr_preeditAreaPosition 13600
#define sipName_preeditAreaPosition &sipStrings_QtGui[13600]
#define sipNameNr_setRightBorderBrush 13620
#define sipName_setRightBorderBrush &sipStrings_QtGui[13620]
#define sipNameNr_setRightBorderStyle 13640
#define sipName_setRightBorderStyle &sipStrings_QtGui[13640]
#define sipNameNr_BorderStyle_DotDash 13660
#define sipName_BorderStyle_DotDash &sipStrings_QtGui[13660]
#define sipNameNr_SpellCheckUnderline 13680
#define sipName_SpellCheckUnderline &sipStrings_QtGui[13680]
#define sipNameNr_setTableCellRowSpan 13700
#define sipName_setTableCellRowSpan &sipStrings_QtGui[13700]
#define sipNameNr_tableCellColumnSpan 13720
#define sipName_tableCellColumnSpan &sipStrings_QtGui[13720]
#define sipNameNr_TableCellLeftBorder 13740
#define sipName_TableCellLeftBorder &sipStrings_QtGui[13740]
#define sipNameNr_TableBorderCollapse 13760
#define sipName_TableBorderCollapse &sipStrings_QtGui[13760]
#define sipNameNr_TableCellTopPadding 13780
#define sipName_TableCellTopPadding &sipStrings_QtGui[13780]
#define sipNameNr_TableHeaderRowCount 13800
#define sipName_TableHeaderRowCount &sipStrings_QtGui[13800]
#define sipNameNr_TableCellColumnSpan 8844
#define sipName_TableCellColumnSpan &sipStrings_QtGui[8844]
#define sipNameNr_QTextDocumentWriter 13820
#define sipName_QTextDocumentWriter &sipStrings_QtGui[13820]
#define sipNameNr_clearUndoRedoStacks 13840
#define sipName_clearUndoRedoStacks &sipStrings_QtGui[13840]
#define sipNameNr_modificationChanged 13860
#define sipName_modificationChanged &sipStrings_QtGui[13860]
#define sipNameNr_setUseDesignMetrics 13880
#define sipName_setUseDesignMetrics &sipStrings_QtGui[13880]
#define sipNameNr_FindCaseSensitively 13900
#define sipName_FindCaseSensitively &sipStrings_QtGui[13900]
#define sipNameNr_setVisualNavigation 13920
#define sipName_setVisualNavigation &sipStrings_QtGui[13920]
#define sipNameNr_hasComplexSelection 13940
#define sipName_hasComplexSelection &sipStrings_QtGui[13940]
#define sipNameNr_DefaultSwapBehavior 13960
#define sipName_DefaultSwapBehavior &sipStrings_QtGui[13960]
#define sipNameNr_DeprecatedFunctions 13980
#define sipName_DeprecatedFunctions &sipStrings_QtGui[13980]
#define sipNameNr_physicalSizeChanged 14000
#define sipName_physicalSizeChanged &sipStrings_QtGui[14000]
#define sipNameNr_logicalDotsPerInchY 14020
#define sipName_logicalDotsPerInchY &sipStrings_QtGui[14020]
#define sipNameNr_logicalDotsPerInchX 14040
#define sipName_logicalDotsPerInchX &sipStrings_QtGui[14040]
#define sipNameNr_physicalDotsPerInch 14060
#define sipName_physicalDotsPerInch &sipStrings_QtGui[14060]
#define sipNameNr_QRegion__RegionType 14080
#define sipName_QRegion__RegionType &sipStrings_QtGui[14080]
#define sipNameNr_CurrentSystemEndian 14100
#define sipName_CurrentSystemEndian &sipStrings_QtGui[14100]
#define sipNameNr_documentXmpMetadata 14120
#define sipName_documentXmpMetadata &sipStrings_QtGui[14120]
#define sipNameNr_QPalette__ColorRole 14140
#define sipName_QPalette__ColorRole &sipStrings_QtGui[14140]
#define sipNameNr_QPainterPathStroker 14160
#define sipName_QPainterPathStroker &sipStrings_QtGui[14160]
#define sipNameNr_brushNeedsResolving 14180
#define sipName_brushNeedsResolving &sipStrings_QtGui[14180]
#define sipNameNr_DirtyBackgroundMode 14200
#define sipName_DirtyBackgroundMode &sipStrings_QtGui[14200]
#define sipNameNr_PaintEngineFeatures 1014
#define sipName_PaintEngineFeatures &sipStrings_QtGui[1014]
#define sipNameNr_ConicalGradientFill 14220
#define sipName_ConicalGradientFill &sipStrings_QtGui[14220]
#define sipNameNr_PdmDevicePixelRatio 14240
#define sipName_PdmDevicePixelRatio &sipStrings_QtGui[14240]
#define sipNameNr_drawPixmapFragments 14260
#define sipName_drawPixmapFragments &sipStrings_QtGui[14260]
#define sipNameNr_PixmapFragmentHints 2932
#define sipName_PixmapFragmentHints &sipStrings_QtGui[2932]
#define sipNameNr_beginNativePainting 14280
#define sipName_beginNativePainting &sipStrings_QtGui[14280]
#define sipNameNr_CompositionMode_Xor 14300
#define sipName_CompositionMode_Xor &sipStrings_QtGui[14300]
#define sipNameNr_CompareRefToTexture 14320
#define sipName_CompareRefToTexture &sipStrings_QtGui[14320]
#define sipNameNr_CompareGreaterEqual 14340
#define sipName_CompareGreaterEqual &sipStrings_QtGui[14340]
#define sipNameNr_CoordinateDirection 596
#define sipName_CoordinateDirection &sipStrings_QtGui[596]
#define sipNameNr_magnificationFilter 14360
#define sipName_magnificationFilter &sipStrings_QtGui[14360]
#define sipNameNr_LinearMipMapNearest 14380
#define sipName_LinearMipMapNearest &sipStrings_QtGui[14380]
#define sipNameNr_NearestMipMapLinear 14400
#define sipName_NearestMipMapLinear &sipStrings_QtGui[14400]
#define sipNameNr_setDepthStencilMode 14420
#define sipName_setDepthStencilMode &sipStrings_QtGui[14420]
#define sipNameNr_RGB_BP_SIGNED_FLOAT 14440
#define sipName_RGB_BP_SIGNED_FLOAT &sipStrings_QtGui[14440]
#define sipNameNr_DontGenerateMipMaps 14460
#define sipName_DontGenerateMipMaps &sipStrings_QtGui[14460]
#define sipNameNr_BindingTargetBuffer 14480
#define sipName_BindingTargetBuffer &sipStrings_QtGui[14480]
#define sipNameNr_Target2DMultisample 5385
#define sipName_Target2DMultisample &sipStrings_QtGui[5385]
#define sipNameNr_setPatchVertexCount 14500
#define sipName_setPatchVertexCount &sipStrings_QtGui[14500]
#define sipNameNr_TessellationControl 14520
#define sipName_TessellationControl &sipStrings_QtGui[14520]
#define sipNameNr_setSwapBytesEnabled 14540
#define sipName_setSwapBytesEnabled &sipStrings_QtGui[14540]
#define sipNameNr_AsynchronousLogging 14560
#define sipName_AsynchronousLogging &sipStrings_QtGui[14560]
#define sipNameNr_QOpenGLDebugMessage 14580
#define sipName_QOpenGLDebugMessage &sipStrings_QtGui[14580]
#define sipNameNr_currentContextGroup 14600
#define sipName_currentContextGroup &sipStrings_QtGui[14600]
#define sipNameNr_QOpenGLContextGroup 14620
#define sipName_QOpenGLContextGroup &sipStrings_QtGui[14620]
#define sipNameNr_RangeUnsynchronized 14640
#define sipName_RangeUnsynchronized &sipStrings_QtGui[14640]
#define sipNameNr_QOpenGLBuffer__Type 14660
#define sipName_QOpenGLBuffer__Type &sipStrings_QtGui[14660]
#define sipNameNr_InsertLineSeparator 14680
#define sipName_InsertLineSeparator &sipStrings_QtGui[14680]
#define sipNameNr_SelectEndOfDocument 14700
#define sipName_SelectEndOfDocument &sipStrings_QtGui[14700]
#define sipNameNr_MoveToEndOfDocument 14720
#define sipName_MoveToEndOfDocument &sipStrings_QtGui[14720]
#define sipNameNr_ImageTransformation 14740
#define sipName_ImageTransformation &sipStrings_QtGui[14740]
#define sipNameNr_applyColorTransform 14760
#define sipName_applyColorTransform &sipStrings_QtGui[14760]
#define sipNameNr_convertToColorSpace 14780
#define sipName_convertToColorSpace &sipStrings_QtGui[14780]
#define sipNameNr_reinterpretAsFormat 14800
#define sipName_reinterpretAsFormat &sipStrings_QtGui[14800]
#define sipNameNr_setDevicePixelRatio 14820
#define sipName_setDevicePixelRatio &sipStrings_QtGui[14820]
#define sipNameNr_createMaskFromColor 14840
#define sipName_createMaskFromColor &sipStrings_QtGui[14840]
#define sipNameNr_createHeuristicMask 14860
#define sipName_createHeuristicMask &sipStrings_QtGui[14860]
#define sipNameNr_fallbackSearchPaths 14880
#define sipName_fallbackSearchPaths &sipStrings_QtGui[14880]
#define sipNameNr_setThemeSearchPaths 14900
#define sipName_setThemeSearchPaths &sipStrings_QtGui[14900]
#define sipNameNr_fontDatabaseChanged 14920
#define sipName_fontDatabaseChanged &sipStrings_QtGui[14920]
#define sipNameNr_writingSystemSample 14940
#define sipName_writingSystemSample &sipStrings_QtGui[14940]
#define sipNameNr_removeSubstitutions 14960
#define sipName_removeSubstitutions &sipStrings_QtGui[14960]
#define sipNameNr_insertSubstitutions 14980
#define sipName_insertSubstitutions &sipStrings_QtGui[14980]
#define sipNameNr_ForceIntegerMetrics 15000
#define sipName_ForceIntegerMetrics &sipStrings_QtGui[15000]
#define sipNameNr_NoSubpixelAntialias 15020
#define sipName_NoSubpixelAntialias &sipStrings_QtGui[15020]
#define sipNameNr_QNativeGestureEvent 15040
#define sipName_QNativeGestureEvent &sipStrings_QtGui[15040]
#define sipNameNr_QScrollPrepareEvent 15060
#define sipName_QScrollPrepareEvent &sipStrings_QtGui[15060]
#define sipNameNr_setTransferFunction 15080
#define sipName_setTransferFunction &sipStrings_QtGui[15080]
#define sipNameNr_StretchToDeviceMode 15100
#define sipName_StretchToDeviceMode &sipStrings_QtGui[15100]
#define sipNameNr_documentSizeChanged 15120
#define sipName_documentSizeChanged &sipStrings_QtGui[15120]
#define sipNameNr_15140 15140
#define sipName_15140 &sipStrings_QtGui[15140]
#define sipNameNr_15159 15159
#define sipName_15159 &sipStrings_QtGui[15159]
#define sipNameNr_windowTitleChanged 15178
#define sipName_windowTitleChanged &sipStrings_QtGui[15178]
#define sipNameNr_windowStateChanged 15197
#define sipName_windowStateChanged &sipStrings_QtGui[15197]
#define sipNameNr_setTransientParent 15216
#define sipName_setTransientParent &sipStrings_QtGui[15216]
#define sipNameNr_contentOrientation 15235
#define sipName_contentOrientation &sipStrings_QtGui[15235]
#define sipNameNr_TransformationType 2318
#define sipName_TransformationType &sipStrings_QtGui[2318]
#define sipNameNr_maximumTouchPoints 15254
#define sipName_maximumTouchPoints &sipStrings_QtGui[15254]
#define sipNameNr_NormalizedPosition 15273
#define sipName_NormalizedPosition &sipStrings_QtGui[15273]
#define sipNameNr_setTabStopDistance 15292
#define sipName_setTabStopDistance &sipStrings_QtGui[15292]
#define sipNameNr_QTextOption__Flags 15311
#define sipName_QTextOption__Flags &sipStrings_QtGui[15311]
#define sipNameNr_QTextBlockUserData 15330
#define sipName_QTextBlockUserData &sipStrings_QtGui[15330]
#define sipNameNr_lastCursorPosition 15349
#define sipName_lastCursorPosition &sipStrings_QtGui[15349]
#define sipNameNr_blockFormatChanged 15368
#define sipName_blockFormatChanged &sipStrings_QtGui[15368]
#define sipNameNr_setLeadingIncluded 15387
#define sipName_setLeadingIncluded &sipStrings_QtGui[15387]
#define sipNameNr_leftCursorPosition 15406
#define sipName_leftCursorPosition &sipStrings_QtGui[15406]
#define sipNameNr_setCursorMoveStyle 15425
#define sipName_setCursorMoveStyle &sipStrings_QtGui[15425]
#define sipNameNr_nextCursorPosition 15444
#define sipName_nextCursorPosition &sipStrings_QtGui[15444]
#define sipNameNr_setLeftBorderBrush 15463
#define sipName_setLeftBorderBrush &sipStrings_QtGui[15463]
#define sipNameNr_setLeftBorderStyle 15482
#define sipName_setLeftBorderStyle &sipStrings_QtGui[15482]
#define sipNameNr_BorderStyle_Outset 15501
#define sipName_BorderStyle_Outset &sipStrings_QtGui[15501]
#define sipNameNr_BorderStyle_Groove 15520
#define sipName_BorderStyle_Groove &sipStrings_QtGui[15520]
#define sipNameNr_BorderStyle_Double 15539
#define sipName_BorderStyle_Double &sipStrings_QtGui[15539]
#define sipNameNr_BorderStyle_Dashed 15558
#define sipName_BorderStyle_Dashed &sipStrings_QtGui[15558]
#define sipNameNr_BorderStyle_Dotted 15577
#define sipName_BorderStyle_Dotted &sipStrings_QtGui[15577]
#define sipNameNr_LineDistanceHeight 15596
#define sipName_LineDistanceHeight &sipStrings_QtGui[15596]
#define sipNameNr_ProportionalHeight 15615
#define sipName_ProportionalHeight &sipStrings_QtGui[15615]
#define sipNameNr_setPageBreakPolicy 15634
#define sipName_setPageBreakPolicy &sipStrings_QtGui[15634]
#define sipNameNr_setFontWordSpacing 15653
#define sipName_setFontWordSpacing &sipStrings_QtGui[15653]
#define sipNameNr_fontCapitalization 15672
#define sipName_fontCapitalization &sipStrings_QtGui[15672]
#define sipNameNr_TableCellTopBorder 15691
#define sipName_TableCellTopBorder &sipStrings_QtGui[15691]
#define sipNameNr_FontCapitalization 10099
#define sipName_FontCapitalization &sipStrings_QtGui[10099]
#define sipNameNr_BackgroundImageUrl 15710
#define sipName_BackgroundImageUrl &sipStrings_QtGui[15710]
#define sipNameNr_FullWidthSelection 15729
#define sipName_FullWidthSelection &sipStrings_QtGui[15729]
#define sipNameNr_TextUnderlineStyle 15748
#define sipName_TextUnderlineStyle &sipStrings_QtGui[15748]
#define sipNameNr_TextUnderlineColor 15767
#define sipName_TextUnderlineColor &sipStrings_QtGui[15767]
#define sipNameNr_FontSizeAdjustment 15786
#define sipName_FontSizeAdjustment &sipStrings_QtGui[15786]
#define sipNameNr_availableRedoSteps 15805
#define sipName_availableRedoSteps &sipStrings_QtGui[15805]
#define sipNameNr_availableUndoSteps 15824
#define sipName_availableUndoSteps &sipStrings_QtGui[15824]
#define sipNameNr_StyleSheetResource 15843
#define sipName_StyleSheetResource &sipStrings_QtGui[15843]
#define sipNameNr_setMetaInformation 15862
#define sipName_setMetaInformation &sipStrings_QtGui[15862]
#define sipNameNr_setUndoRedoEnabled 15881
#define sipName_setUndoRedoEnabled &sipStrings_QtGui[15881]
#define sipNameNr_setBlockCharFormat 15900
#define sipName_setBlockCharFormat &sipStrings_QtGui[15900]
#define sipNameNr_selectedTableCells 15919
#define sipName_selectedTableCells &sipStrings_QtGui[15919]
#define sipNameNr_removeSelectedText 15938
#define sipName_removeSelectedText &sipStrings_QtGui[15938]
#define sipNameNr_deletePreviousChar 15957
#define sipName_deletePreviousChar &sipStrings_QtGui[15957]
#define sipNameNr_previousBlockState 15976
#define sipName_previousBlockState &sipStrings_QtGui[15976]
#define sipNameNr_QSyntaxHighlighter 15995
#define sipName_QSyntaxHighlighter &sipStrings_QtGui[15995]
#define sipNameNr_setAlphaBufferSize 16014
#define sipName_setAlphaBufferSize &sipStrings_QtGui[16014]
#define sipNameNr_setGreenBufferSize 16033
#define sipName_setGreenBufferSize &sipStrings_QtGui[16033]
#define sipNameNr_setDepthBufferSize 16052
#define sipName_setDepthBufferSize &sipStrings_QtGui[16052]
#define sipNameNr_setUseHoverEffects 16071
#define sipName_setUseHoverEffects &sipStrings_QtGui[16071]
#define sipNameNr_fontSmoothingGamma 16090
#define sipName_fontSmoothingGamma &sipStrings_QtGui[16090]
#define sipNameNr_setPerformanceHint 16109
#define sipName_setPerformanceHint &sipStrings_QtGui[16109]
#define sipNameNr_verticalHeaderItem 16128
#define sipName_verticalHeaderItem &sipStrings_QtGui[16128]
#define sipNameNr_QStandardItemModel 16147
#define sipName_QStandardItemModel &sipStrings_QtGui[16147]
#define sipNameNr_refreshRateChanged 16166
#define sipName_refreshRateChanged &sipStrings_QtGui[16166]
#define sipNameNr_orientationChanged 16185
#define sipName_orientationChanged &sipStrings_QtGui[16185]
#define sipNameNr_primaryOrientation 16204
#define sipName_primaryOrientation &sipStrings_QtGui[16204]
#define sipNameNr_logicalDotsPerInch 16223
#define sipName_logicalDotsPerInch &sipStrings_QtGui[16223]
#define sipNameNr_fromRotationMatrix 16242
#define sipName_fromRotationMatrix &sipStrings_QtGui[16242]
#define sipNameNr_typeInterpretation 16261
#define sipName_typeInterpretation &sipStrings_QtGui[16261]
#define sipNameNr_TypeInterpretation 1217
#define sipName_TypeInterpretation &sipStrings_QtGui[1217]
#define sipNameNr_AlphaPremultiplied 1250
#define sipName_AlphaPremultiplied &sipStrings_QtGui[1250]
#define sipNameNr_CurveToDataElement 16280
#define sipName_CurveToDataElement &sipStrings_QtGui[16280]
#define sipNameNr_QPaintEngine__Type 16299
#define sipName_QPaintEngine__Type &sipStrings_QtGui[16299]
#define sipNameNr_RadialGradientFill 16318
#define sipName_RadialGradientFill &sipStrings_QtGui[16318]
#define sipNameNr_LinearGradientFill 16337
#define sipName_LinearGradientFill &sipStrings_QtGui[16337]
#define sipNameNr_PrimitiveTransform 16356
#define sipName_PrimitiveTransform &sipStrings_QtGui[16356]
#define sipNameNr_PaintEngineFeature 1283
#define sipName_PaintEngineFeature &sipStrings_QtGui[1283]
#define sipNameNr_PixmapFragmentHint 3854
#define sipName_PixmapFragmentHint &sipStrings_QtGui[3854]
#define sipNameNr_worldMatrixEnabled 16375
#define sipName_worldMatrixEnabled &sipStrings_QtGui[16375]
#define sipNameNr_setCompositionMode 16394
#define sipName_setCompositionMode &sipStrings_QtGui[16394]
#define sipNameNr_RasterOp_NotSource 16413
#define sipName_RasterOp_NotSource &sipStrings_QtGui[16413]
#define sipNameNr_setPageOrientation 16432
#define sipName_setPageOrientation &sipStrings_QtGui[16432]
#define sipNameNr_FanFoldGermanLegal 16451
#define sipName_FanFoldGermanLegal &sipStrings_QtGui[16451]
#define sipNameNr_PartialUpdateBlend 16470
#define sipName_PartialUpdateBlend &sipStrings_QtGui[16470]
#define sipNameNr_QPaintDeviceWindow 16489
#define sipName_QPaintDeviceWindow &sipStrings_QtGui[16489]
#define sipNameNr_comparisonFunction 16508
#define sipName_comparisonFunction &sipStrings_QtGui[16508]
#define sipNameNr_ComparisonFunction 809
#define sipName_ComparisonFunction &sipStrings_QtGui[809]
#define sipNameNr_levelOfDetailRange 16527
#define sipName_levelOfDetailRange &sipStrings_QtGui[16527]
#define sipNameNr_minificationFilter 16546
#define sipName_minificationFilter &sipStrings_QtGui[16546]
#define sipNameNr_LinearMipMapLinear 16565
#define sipName_LinearMipMapLinear &sipStrings_QtGui[16565]
#define sipNameNr_TextureMipMapLevel 16584
#define sipName_TextureMipMapLevel &sipStrings_QtGui[16584]
#define sipNameNr_TextureMultisample 16603
#define sipName_TextureMultisample &sipStrings_QtGui[16603]
#define sipNameNr_UInt32_RGB10A2_Rev 16622
#define sipName_UInt32_RGB10A2_Rev &sipStrings_QtGui[16622]
#define sipNameNr_isStorageAllocated 16641
#define sipName_isStorageAllocated &sipStrings_QtGui[16641]
#define sipNameNr_TargetCubeMapArray 6172
#define sipName_TargetCubeMapArray &sipStrings_QtGui[6172]
#define sipNameNr_setAttributeBuffer 16660
#define sipName_setAttributeBuffer &sipStrings_QtGui[16660]
#define sipNameNr_isSwapBytesEnabled 16679
#define sipName_isSwapBytesEnabled &sipStrings_QtGui[16679]
#define sipNameNr_ensureActiveTarget 16698
#define sipName_ensureActiveTarget &sipStrings_QtGui[16698]
#define sipNameNr_QOpenGLPaintDevice 16717
#define sipName_QOpenGLPaintDevice &sipStrings_QtGui[16717]
#define sipNameNr_addColorAttachment 16736
#define sipName_addColorAttachment &sipStrings_QtGui[16736]
#define sipNameNr_SynchronousLogging 16755
#define sipName_SynchronousLogging &sipStrings_QtGui[16755]
#define sipNameNr_QOpenGLDebugLogger 16774
#define sipName_QOpenGLDebugLogger &sipStrings_QtGui[16774]
#define sipNameNr_WindowSystemSource 16793
#define sipName_WindowSystemSource &sipStrings_QtGui[16793]
#define sipNameNr_globalShareContext 16812
#define sipName_globalShareContext &sipStrings_QtGui[16812]
#define sipNameNr_openGLModuleHandle 16831
#define sipName_openGLModuleHandle &sipStrings_QtGui[16831]
#define sipNameNr_aboutToBeDestroyed 16850
#define sipName_aboutToBeDestroyed &sipStrings_QtGui[16850]
#define sipNameNr_RangeFlushExplicit 16869
#define sipName_RangeFlushExplicit &sipStrings_QtGui[16869]
#define sipNameNr_currentFrameNumber 16888
#define sipName_currentFrameNumber &sipStrings_QtGui[16888]
#define sipNameNr_QMovie__MovieState 16907
#define sipName_QMovie__MovieState &sipStrings_QtGui[16907]
#define sipNameNr_DeleteCompleteLine 16926
#define sipName_DeleteCompleteLine &sipStrings_QtGui[16926]
#define sipNameNr_SelectStartOfBlock 16945
#define sipName_SelectStartOfBlock &sipStrings_QtGui[16945]
#define sipNameNr_SelectPreviousPage 16964
#define sipName_SelectPreviousPage &sipStrings_QtGui[16964]
#define sipNameNr_SelectPreviousLine 16983
#define sipName_SelectPreviousLine &sipStrings_QtGui[16983]
#define sipNameNr_SelectPreviousWord 17002
#define sipName_SelectPreviousWord &sipStrings_QtGui[17002]
#define sipNameNr_SelectPreviousChar 17021
#define sipName_SelectPreviousChar &sipStrings_QtGui[17021]
#define sipNameNr_MoveToStartOfBlock 17040
#define sipName_MoveToStartOfBlock &sipStrings_QtGui[17040]
#define sipNameNr_MoveToPreviousPage 17059
#define sipName_MoveToPreviousPage &sipStrings_QtGui[17059]
#define sipNameNr_MoveToPreviousLine 17078
#define sipName_MoveToPreviousLine &sipStrings_QtGui[17078]
#define sipNameNr_MoveToPreviousWord 17097
#define sipName_MoveToPreviousWord &sipStrings_QtGui[17097]
#define sipNameNr_MoveToPreviousChar 17116
#define sipName_MoveToPreviousChar &sipStrings_QtGui[17116]
#define sipNameNr_inputItemRectangle 17135
#define sipName_inputItemRectangle &sipStrings_QtGui[17135]
#define sipNameNr_inputItemTransform 17154
#define sipName_inputItemTransform &sipStrings_QtGui[17154]
#define sipNameNr_supportedMimeTypes 17173
#define sipName_supportedMimeTypes &sipStrings_QtGui[17173]
#define sipNameNr_setBackgroundColor 17192
#define sipName_setBackgroundColor &sipStrings_QtGui[17192]
#define sipNameNr_TransformationFlip 17211
#define sipName_TransformationFlip &sipStrings_QtGui[17211]
#define sipNameNr_TransformationNone 17230
#define sipName_TransformationNone &sipStrings_QtGui[17230]
#define sipNameNr_currentImageNumber 17249
#define sipName_currentImageNumber &sipStrings_QtGui[17249]
#define sipNameNr_IncrementalReading 17268
#define sipName_IncrementalReading &sipStrings_QtGui[17268]
#define sipNameNr_Format_Grayscale16 17287
#define sipName_Format_Grayscale16 &sipStrings_QtGui[17287]
#define sipNameNr_QImage__InvertMode 17306
#define sipName_QImage__InvertMode &sipStrings_QtGui[17306]
#define sipNameNr_AvailableSizesHook 17325
#define sipName_AvailableSizesHook &sipStrings_QtGui[17325]
#define sipNameNr_setDesktopFileName 17344
#define sipName_setDesktopFileName &sipStrings_QtGui[17344]
#define sipNameNr_focusWindowChanged 17363
#define sipName_focusWindowChanged &sipStrings_QtGui[17363]
#define sipNameNr_focusObjectChanged 17382
#define sipName_focusObjectChanged &sipStrings_QtGui[17382]
#define sipNameNr_setLayoutDirection 17401
#define sipName_setLayoutDirection &sipStrings_QtGui[17401]
#define sipNameNr_addApplicationFont 17420
#define sipName_addApplicationFont &sipStrings_QtGui[17420]
#define sipNameNr_isSmoothlyScalable 17439
#define sipName_isSmoothlyScalable &sipStrings_QtGui[17439]
#define sipNameNr_TraditionalChinese 17458
#define sipName_TraditionalChinese &sipStrings_QtGui[17458]
#define sipNameNr_QFont__SpacingType 17477
#define sipName_QFont__SpacingType &sipStrings_QtGui[17477]
#define sipNameNr_insertSubstitution 17496
#define sipName_insertSubstitution &sipStrings_QtGui[17496]
#define sipNameNr_setContentPosRange 17515
#define sipName_setContentPosRange &sipStrings_QtGui[17515]
#define sipNameNr_rawScreenPositions 17534
#define sipName_rawScreenPositions &sipStrings_QtGui[17534]
#define sipNameNr_startNormalizedPos 17553
#define sipName_startNormalizedPos &sipStrings_QtGui[17553]
#define sipNameNr_tangentialPressure 17572
#define sipName_tangentialPressure &sipStrings_QtGui[17572]
#define sipNameNr_supportsFindBuffer 17591
#define sipName_supportsFindBuffer &sipStrings_QtGui[17591]
#define sipNameNr_ObjectBoundingMode 17610
#define sipName_ObjectBoundingMode &sipStrings_QtGui[17610]
#define sipNameNr_QColor__NameFormat 17629
#define sipName_QColor__NameFormat &sipStrings_QtGui[17629]
#define sipNameNr_resizeInlineObject 17648
#define sipName_resizeInlineObject &sipStrings_QtGui[17648]
#define sipNameNr_ScientificNotation 17667
#define sipName_ScientificNotation &sipStrings_QtGui[17667]
#define sipNameNr_17686 17686
#define sipName_17686 &sipStrings_QtGui[17686]
#define sipNameNr_startSystemResize 17704
#define sipName_startSystemResize &sipStrings_QtGui[17704]
#define sipNameNr_visibilityChanged 17722
#define sipName_visibilityChanged &sipStrings_QtGui[17722]
#define sipNameNr_mouseReleaseEvent 17740
#define sipName_mouseReleaseEvent &sipStrings_QtGui[17740]
#define sipNameNr_IncludeTransients 17758
#define sipName_IncludeTransients &sipStrings_QtGui[17758]
#define sipNameNr_ExcludeTransients 17776
#define sipName_ExcludeTransients &sipStrings_QtGui[17776]
#define sipNameNr_QValidator__State 17794
#define sipName_QValidator__State &sipStrings_QtGui[17794]
#define sipNameNr_ShowTabsAndSpaces 17812
#define sipName_ShowTabsAndSpaces &sipStrings_QtGui[17812]
#define sipNameNr_QTextOption__Flag 17830
#define sipName_QTextOption__Flag &sipStrings_QtGui[17830]
#define sipNameNr_CursorOnCharacter 17848
#define sipName_CursorOnCharacter &sipStrings_QtGui[17848]
#define sipNameNr_additionalFormats 17866
#define sipName_additionalFormats &sipStrings_QtGui[17866]
#define sipNameNr_QTextInlineObject 17884
#define sipName_QTextInlineObject &sipStrings_QtGui[17884]
#define sipNameNr_bottomBorderBrush 17902
#define sipName_bottomBorderBrush &sipStrings_QtGui[17902]
#define sipNameNr_setTopBorderBrush 17920
#define sipName_setTopBorderBrush &sipStrings_QtGui[17920]
#define sipNameNr_bottomBorderStyle 17938
#define sipName_bottomBorderStyle &sipStrings_QtGui[17938]
#define sipNameNr_setTopBorderStyle 17956
#define sipName_setTopBorderStyle &sipStrings_QtGui[17956]
#define sipNameNr_setBorderCollapse 17974
#define sipName_setBorderCollapse &sipStrings_QtGui[17974]
#define sipNameNr_setHeaderRowCount 17992
#define sipName_setHeaderRowCount &sipStrings_QtGui[17992]
#define sipNameNr_BorderStyle_Inset 18010
#define sipName_BorderStyle_Inset &sipStrings_QtGui[18010]
#define sipNameNr_BorderStyle_Ridge 18028
#define sipName_BorderStyle_Ridge &sipStrings_QtGui[18028]
#define sipNameNr_BorderStyle_Solid 18046
#define sipName_BorderStyle_Solid &sipStrings_QtGui[18046]
#define sipNameNr_nonBreakableLines 18064
#define sipName_nonBreakableLines &sipStrings_QtGui[18064]
#define sipNameNr_FontPropertiesAll 18082
#define sipName_FontPropertiesAll &sipStrings_QtGui[18082]
#define sipNameNr_fontStyleStrategy 18100
#define sipName_fontStyleStrategy &sipStrings_QtGui[18100]
#define sipNameNr_fontLetterSpacing 18118
#define sipName_fontLetterSpacing &sipStrings_QtGui[18118]
#define sipNameNr_setUnderlineStyle 18136
#define sipName_setUnderlineStyle &sipStrings_QtGui[18136]
#define sipNameNr_verticalAlignment 18154
#define sipName_verticalAlignment &sipStrings_QtGui[18154]
#define sipNameNr_setFontFixedPitch 18172
#define sipName_setFontFixedPitch &sipStrings_QtGui[18172]
#define sipNameNr_setUnderlineColor 18190
#define sipName_setUnderlineColor &sipStrings_QtGui[18190]
#define sipNameNr_VerticalAlignment 705
#define sipName_VerticalAlignment &sipStrings_QtGui[705]
#define sipNameNr_toTableCellFormat 18208
#define sipName_toTableCellFormat &sipStrings_QtGui[18208]
#define sipNameNr_isTableCellFormat 18226
#define sipName_isTableCellFormat &sipStrings_QtGui[18226]
#define sipNameNr_BlockCodeLanguage 18244
#define sipName_BlockCodeLanguage &sipStrings_QtGui[18244]
#define sipNameNr_FontStyleStrategy 11932
#define sipName_FontStyleStrategy &sipStrings_QtGui[11932]
#define sipNameNr_FontLetterSpacing 11953
#define sipName_FontLetterSpacing &sipStrings_QtGui[11953]
#define sipNameNr_FirstFontProperty 18262
#define sipName_FirstFontProperty &sipStrings_QtGui[18262]
#define sipNameNr_FrameBottomMargin 18280
#define sipName_FrameBottomMargin &sipStrings_QtGui[18280]
#define sipNameNr_FontSizeIncrement 18298
#define sipName_FontSizeIncrement &sipStrings_QtGui[18298]
#define sipNameNr_BlockBottomMargin 18316
#define sipName_BlockBottomMargin &sipStrings_QtGui[18316]
#define sipNameNr_QTextLength__Type 18334
#define sipName_QTextLength__Type &sipStrings_QtGui[18334]
#define sipNameNr_UndoAndRedoStacks 18352
#define sipName_UndoAndRedoStacks &sipStrings_QtGui[18352]
#define sipNameNr_setDocumentMargin 18370
#define sipName_setDocumentMargin &sipStrings_QtGui[18370]
#define sipNameNr_findBlockByNumber 18388
#define sipName_findBlockByNumber &sipStrings_QtGui[18388]
#define sipNameNr_defaultTextOption 18406
#define sipName_defaultTextOption &sipStrings_QtGui[18406]
#define sipNameNr_maximumBlockCount 18424
#define sipName_maximumBlockCount &sipStrings_QtGui[18424]
#define sipNameNr_defaultStyleSheet 18442
#define sipName_defaultStyleSheet &sipStrings_QtGui[18442]
#define sipNameNr_blockCountChanged 18460
#define sipName_blockCountChanged &sipStrings_QtGui[18460]
#define sipNameNr_markContentsDirty 18478
#define sipName_markContentsDirty &sipStrings_QtGui[18478]
#define sipNameNr_setDocumentLayout 18496
#define sipName_setDocumentLayout &sipStrings_QtGui[18496]
#define sipNameNr_isUndoRedoEnabled 18514
#define sipName_isUndoRedoEnabled &sipStrings_QtGui[18514]
#define sipNameNr_verticalMovementX 18532
#define sipName_verticalMovementX &sipStrings_QtGui[18532]
#define sipNameNr_PreviousCharacter 18550
#define sipName_PreviousCharacter &sipStrings_QtGui[18550]
#define sipNameNr_currentBlockState 18568
#define sipName_currentBlockState &sipStrings_QtGui[18568]
#define sipNameNr_DefaultColorSpace 18586
#define sipName_DefaultColorSpace &sipStrings_QtGui[18586]
#define sipNameNr_setRenderableType 18604
#define sipName_setRenderableType &sipStrings_QtGui[18604]
#define sipNameNr_setBlueBufferSize 18622
#define sipName_setBlueBufferSize &sipStrings_QtGui[18622]
#define sipNameNr_stencilBufferSize 18640
#define sipName_stencilBufferSize &sipStrings_QtGui[18640]
#define sipNameNr_ResetNotification 18658
#define sipName_ResetNotification &sipStrings_QtGui[18658]
#define sipNameNr_passwordMaskDelay 18676
#define sipName_passwordMaskDelay &sipStrings_QtGui[18676]
#define sipNameNr_startDragVelocity 18694
#define sipName_startDragVelocity &sipStrings_QtGui[18694]
#define sipNameNr_startDragDistance 18712
#define sipName_startDragDistance &sipStrings_QtGui[18712]
#define sipNameNr_AggressiveCaching 18730
#define sipName_AggressiveCaching &sipStrings_QtGui[18730]
#define sipNameNr_setAccessibleText 18748
#define sipName_setAccessibleText &sipStrings_QtGui[18748]
#define sipNameNr_invisibleRootItem 18766
#define sipName_invisibleRootItem &sipStrings_QtGui[18766]
#define sipNameNr_nativeOrientation 18784
#define sipName_nativeOrientation &sipStrings_QtGui[18784]
#define sipNameNr_availableGeometry 18802
#define sipName_availableGeometry &sipStrings_QtGui[18802]
#define sipNameNr_underlinePosition 18820
#define sipName_underlinePosition &sipStrings_QtGui[18820]
#define sipNameNr_supportsCharacter 18838
#define sipName_supportsCharacter &sipStrings_QtGui[18838]
#define sipNameNr_PixelAntialiasing 12415
#define sipName_PixelAntialiasing &sipStrings_QtGui[12415]
#define sipNameNr_QPixmapCache__Key 18856
#define sipName_QPixmapCache__Key &sipStrings_QtGui[18856]
#define sipNameNr_qPixelFormatAlpha 18874
#define sipName_qPixelFormatAlpha &sipStrings_QtGui[18874]
#define sipNameNr_addFileAttachment 18892
#define sipName_addFileAttachment &sipStrings_QtGui[18892]
#define sipNameNr_currentColorGroup 18910
#define sipName_currentColorGroup &sipStrings_QtGui[18910]
#define sipNameNr_setCurveThreshold 18928
#define sipName_setCurveThreshold &sipStrings_QtGui[18928]
#define sipNameNr_toSubpathPolygons 18946
#define sipName_toSubpathPolygons &sipStrings_QtGui[18946]
#define sipNameNr_penNeedsResolving 18964
#define sipName_penNeedsResolving &sipStrings_QtGui[18964]
#define sipNameNr_QPaintEngineState 18982
#define sipName_QPaintEngineState &sipStrings_QtGui[18982]
#define sipNameNr_devicePixelRatioF 19000
#define sipName_devicePixelRatioF &sipStrings_QtGui[19000]
#define sipNameNr_PaintDeviceMetric 1906
#define sipName_PaintDeviceMetric &sipStrings_QtGui[1906]
#define sipNameNr_endNativePainting 19018
#define sipName_endNativePainting &sipStrings_QtGui[19018]
#define sipNameNr_combinedTransform 19036
#define sipName_combinedTransform &sipStrings_QtGui[19036]
#define sipNameNr_setWorldTransform 19054
#define sipName_setWorldTransform &sipStrings_QtGui[19054]
#define sipNameNr_drawConvexPolygon 19072
#define sipName_drawConvexPolygon &sipStrings_QtGui[19072]
#define sipNameNr_setBackgroundMode 19090
#define sipName_setBackgroundMode &sipStrings_QtGui[19090]
#define sipNameNr_setMinimumMargins 19108
#define sipName_setMinimumMargins &sipStrings_QtGui[19108]
#define sipNameNr_QPageLayout__Mode 19126
#define sipName_QPageLayout__Mode &sipStrings_QtGui[19126]
#define sipNameNr_QPageLayout__Unit 19144
#define sipName_QPageLayout__Unit &sipStrings_QtGui[19144]
#define sipNameNr_ExecutiveStandard 19162
#define sipName_ExecutiveStandard &sipStrings_QtGui[19162]
#define sipNameNr_QPagedPaintDevice 19180
#define sipName_QPagedPaintDevice &sipStrings_QtGui[19180]
#define sipNameNr_PartialUpdateBlit 19198
#define sipName_PartialUpdateBlit &sipStrings_QtGui[19198]
#define sipNameNr_setRedBlueSwizzle 19216
#define sipName_setRedBlueSwizzle &sipStrings_QtGui[19216]
#define sipNameNr_setComparisonMode 19234
#define sipName_setComparisonMode &sipStrings_QtGui[19234]
#define sipNameNr_levelofDetailBias 19252
#define sipName_levelofDetailBias &sipStrings_QtGui[19252]
#define sipNameNr_maximumAnisotropy 19270
#define sipName_maximumAnisotropy &sipStrings_QtGui[19270]
#define sipNameNr_NPOTTextureRepeat 19288
#define sipName_NPOTTextureRepeat &sipStrings_QtGui[19288]
#define sipNameNr_setCompressedData 19306
#define sipName_setCompressedData &sipStrings_QtGui[19306]
#define sipNameNr_UInt16_R5G6B5_Rev 19324
#define sipName_UInt16_R5G6B5_Rev &sipStrings_QtGui[19324]
#define sipNameNr_UInt16_RGB5A1_Rev 19342
#define sipName_UInt16_RGB5A1_Rev &sipStrings_QtGui[19342]
#define sipNameNr_createTextureView 19360
#define sipName_createTextureView &sipStrings_QtGui[19360]
#define sipNameNr_setAttributeArray 19378
#define sipName_setAttributeArray &sipStrings_QtGui[19378]
#define sipNameNr_setAttributeValue 19396
#define sipName_setAttributeValue &sipStrings_QtGui[19396]
#define sipNameNr_attributeLocation 19414
#define sipName_attributeLocation &sipStrings_QtGui[19414]
#define sipNameNr_compileSourceFile 19432
#define sipName_compileSourceFile &sipStrings_QtGui[19432]
#define sipNameNr_compileSourceCode 19450
#define sipName_compileSourceCode &sipStrings_QtGui[19450]
#define sipNameNr_ApplicationSource 19468
#define sipName_ApplicationSource &sipStrings_QtGui[19468]
#define sipNameNr_PixelUnpackBuffer 19486
#define sipName_PixelUnpackBuffer &sipStrings_QtGui[19486]
#define sipNameNr_QOffscreenSurface 19504
#define sipName_QOffscreenSurface &sipStrings_QtGui[19504]
#define sipNameNr_QMovie__CacheMode 19522
#define sipName_QMovie__CacheMode &sipStrings_QtGui[19522]
#define sipNameNr_DeleteStartOfWord 19540
#define sipName_DeleteStartOfWord &sipStrings_QtGui[19540]
#define sipNameNr_SelectStartOfLine 19558
#define sipName_SelectStartOfLine &sipStrings_QtGui[19558]
#define sipNameNr_MoveToStartOfLine 19576
#define sipName_MoveToStartOfLine &sipStrings_QtGui[19576]
#define sipNameNr_keyboardRectangle 19594
#define sipName_keyboardRectangle &sipStrings_QtGui[19594]
#define sipNameNr_setTransformation 19612
#define sipName_setTransformation &sipStrings_QtGui[19612]
#define sipNameNr_setOptimizedWrite 19630
#define sipName_setOptimizedWrite &sipStrings_QtGui[19630]
#define sipNameNr_InvalidImageError 19648
#define sipName_InvalidImageError &sipStrings_QtGui[19648]
#define sipNameNr_supportedSubTypes 19666
#define sipName_supportedSubTypes &sipStrings_QtGui[19666]
#define sipNameNr_supportsAnimation 19684
#define sipName_supportsAnimation &sipStrings_QtGui[19684]
#define sipNameNr_setScaledClipRect 19702
#define sipName_setScaledClipRect &sipStrings_QtGui[19702]
#define sipNameNr_FileNotFoundError 19720
#define sipName_FileNotFoundError &sipStrings_QtGui[19720]
#define sipNameNr_SupportedSubTypes 19738
#define sipName_SupportedSubTypes &sipStrings_QtGui[19738]
#define sipNameNr_Format_Grayscale8 19756
#define sipName_Format_Grayscale8 &sipStrings_QtGui[19756]
#define sipNameNr_fallbackThemeName 19774
#define sipName_fallbackThemeName &sipStrings_QtGui[19774]
#define sipNameNr_setOverrideCursor 19792
#define sipName_setOverrideCursor &sipStrings_QtGui[19792]
#define sipNameNr_horizontalAdvance 19810
#define sipName_horizontalAdvance &sipStrings_QtGui[19810]
#define sipNameNr_tightBoundingRect 19828
#define sipName_tightBoundingRect &sipStrings_QtGui[19828]
#define sipNameNr_writingSystemName 19846
#define sipName_writingSystemName &sipStrings_QtGui[19846]
#define sipNameNr_SimplifiedChinese 19864
#define sipName_SimplifiedChinese &sipStrings_QtGui[19864]
#define sipNameNr_hintingPreference 19882
#define sipName_hintingPreference &sipStrings_QtGui[19882]
#define sipNameNr_PreferFullHinting 19900
#define sipName_PreferFullHinting &sipStrings_QtGui[19900]
#define sipNameNr_HintingPreference 6637
#define sipName_HintingPreference &sipStrings_QtGui[6637]
#define sipNameNr_setCapitalization 19918
#define sipName_setCapitalization &sipStrings_QtGui[19918]
#define sipNameNr_letterSpacingType 19936
#define sipName_letterSpacingType &sipStrings_QtGui[19936]
#define sipNameNr_PercentageSpacing 19954
#define sipName_PercentageSpacing &sipStrings_QtGui[19954]
#define sipNameNr_overshootDistance 19972
#define sipName_overshootDistance &sipStrings_QtGui[19972]
#define sipNameNr_lastNormalizedPos 19990
#define sipName_lastNormalizedPos &sipStrings_QtGui[19990]
#define sipNameNr_keyboardModifiers 20008
#define sipName_keyboardModifiers &sipStrings_QtGui[20008]
#define sipNameNr_replacementLength 20026
#define sipName_replacementLength &sipStrings_QtGui[20026]
#define sipNameNr_QInputMethodEvent 20044
#define sipName_QInputMethodEvent &sipStrings_QtGui[20044]
#define sipNameNr_QContextMenuEvent 20062
#define sipName_QContextMenuEvent &sipStrings_QtGui[20062]
#define sipNameNr_findBufferChanged 20080
#define sipName_findBufferChanged &sipStrings_QtGui[20080]
#define sipNameNr_supportsSelection 20098
#define sipName_supportsSelection &sipStrings_QtGui[20098]
#define sipNameNr_setCoordinateMode 20116
#define sipName_setCoordinateMode &sipStrings_QtGui[20116]
#define sipNameNr_QGradient__Preset 20134
#define sipName_QGradient__Preset &sipStrings_QtGui[20134]
#define sipNameNr_QGradient__Spread 20152
#define sipName_QGradient__Spread &sipStrings_QtGui[20152]
#define sipNameNr_mediumspringgreen 20170
#define sipName_mediumspringgreen &sipStrings_QtGui[20170]
#define sipNameNr_hasStaticContents 20188
#define sipName_hasStaticContents &sipStrings_QtGui[20188]
#define sipNameNr_setStaticContents 20206
#define sipName_setStaticContents &sipStrings_QtGui[20206]
#define sipNameNr_blockWithMarkerAt 20224
#define sipName_blockWithMarkerAt &sipStrings_QtGui[20224]
#define sipNameNr_unregisterHandler 20242
#define sipName_unregisterHandler &sipStrings_QtGui[20242]
#define sipNameNr_blockBoundingRect 20260
#define sipName_blockBoundingRect &sipStrings_QtGui[20260]
#define sipNameNr_frameBoundingRect 20278
#define sipName_frameBoundingRect &sipStrings_QtGui[20278]
#define sipNameNr_regularExpression 20296
#define sipName_regularExpression &sipStrings_QtGui[20296]
#define sipNameNr_sip_simplewrapper 20314
#define sipName_sip_simplewrapper &sipStrings_QtGui[20314]
#define sipNameNr_20332 20332
#define sipName_20332 &sipStrings_QtGui[20332]
#define sipNameNr_20349 20349
#define sipName_20349 &sipStrings_QtGui[20349]
#define sipNameNr_20366 20366
#define sipName_20366 &sipStrings_QtGui[20366]
#define sipNameNr_setMaximumHeight 20383
#define sipName_setMaximumHeight &sipStrings_QtGui[20383]
#define sipNameNr_setMinimumHeight 20400
#define sipName_setMinimumHeight &sipStrings_QtGui[20400]
#define sipNameNr_setFramePosition 20417
#define sipName_setFramePosition &sipStrings_QtGui[20417]
#define sipNameNr_setSizeIncrement 20434
#define sipName_setSizeIncrement &sipStrings_QtGui[20434]
#define sipNameNr_toVector3DAffine 20451
#define sipName_toVector3DAffine &sipStrings_QtGui[20451]
#define sipNameNr_toVector2DAffine 20468
#define sipName_toVector2DAffine &sipStrings_QtGui[20468]
#define sipNameNr_QRegExpValidator 20485
#define sipName_QRegExpValidator &sipStrings_QtGui[20485]
#define sipNameNr_StandardNotation 20502
#define sipName_StandardNotation &sipStrings_QtGui[20502]
#define sipNameNr_QDoubleValidator 20519
#define sipName_QDoubleValidator &sipStrings_QtGui[20519]
#define sipNameNr_QTextOption__Tab 20536
#define sipName_QTextOption__Tab &sipStrings_QtGui[20536]
#define sipNameNr_setTextDirection 20553
#define sipName_setTextDirection &sipStrings_QtGui[20553]
#define sipNameNr_blockFormatIndex 20570
#define sipName_blockFormatIndex &sipStrings_QtGui[20570]
#define sipNameNr_naturalTextWidth 20587
#define sipName_naturalTextWidth &sipStrings_QtGui[20587]
#define sipNameNr_rightBorderBrush 20604
#define sipName_rightBorderBrush &sipStrings_QtGui[20604]
#define sipNameNr_rightBorderStyle 20621
#define sipName_rightBorderStyle &sipStrings_QtGui[20621]
#define sipNameNr_setBottomPadding 20638
#define sipName_setBottomPadding &sipStrings_QtGui[20638]
#define sipNameNr_QTextTableFormat 20655
#define sipName_QTextTableFormat &sipStrings_QtGui[20655]
#define sipNameNr_BorderStyle_None 20672
#define sipName_BorderStyle_None &sipStrings_QtGui[20672]
#define sipNameNr_QTextFrameFormat 20689
#define sipName_QTextFrameFormat &sipStrings_QtGui[20689]
#define sipNameNr_QTextImageFormat 20706
#define sipName_QTextImageFormat &sipStrings_QtGui[20706]
#define sipNameNr_QTextBlockFormat 20723
#define sipName_QTextBlockFormat &sipStrings_QtGui[20723]
#define sipNameNr_setFontStyleName 20740
#define sipName_setFontStyleName &sipStrings_QtGui[20740]
#define sipNameNr_setFontStyleHint 20757
#define sipName_setFontStyleHint &sipStrings_QtGui[20757]
#define sipNameNr_tableCellRowSpan 20774
#define sipName_tableCellRowSpan &sipStrings_QtGui[20774]
#define sipNameNr_setFontStrikeOut 20791
#define sipName_setFontStrikeOut &sipStrings_QtGui[20791]
#define sipNameNr_setFontUnderline 20808
#define sipName_setFontUnderline &sipStrings_QtGui[20808]
#define sipNameNr_setFontPointSize 20825
#define sipName_setFontPointSize &sipStrings_QtGui[20825]
#define sipNameNr_AlignSuperScript 20842
#define sipName_AlignSuperScript &sipStrings_QtGui[20842]
#define sipNameNr_ListNumberSuffix 20859
#define sipName_ListNumberSuffix &sipStrings_QtGui[20859]
#define sipNameNr_ListNumberPrefix 20876
#define sipName_ListNumberPrefix &sipStrings_QtGui[20876]
#define sipNameNr_LastFontProperty 20893
#define sipName_LastFontProperty &sipStrings_QtGui[20893]
#define sipNameNr_FrameBorderStyle 20910
#define sipName_FrameBorderStyle &sipStrings_QtGui[20910]
#define sipNameNr_FrameBorderBrush 20927
#define sipName_FrameBorderBrush &sipStrings_QtGui[20927]
#define sipNameNr_FrameRightMargin 20944
#define sipName_FrameRightMargin &sipStrings_QtGui[20944]
#define sipNameNr_TableCellRowSpan 13703
#define sipName_TableCellRowSpan &sipStrings_QtGui[13703]
#define sipNameNr_TableCellPadding 20961
#define sipName_TableCellPadding &sipStrings_QtGui[20961]
#define sipNameNr_TableCellSpacing 20978
#define sipName_TableCellSpacing &sipStrings_QtGui[20978]
#define sipNameNr_BlockRightMargin 20995
#define sipName_BlockRightMargin &sipStrings_QtGui[20995]
#define sipNameNr_PercentageLength 21012
#define sipName_PercentageLength &sipStrings_QtGui[21012]
#define sipNameNr_MarkdownFeatures 1843
#define sipName_MarkdownFeatures &sipStrings_QtGui[1843]
#define sipNameNr_undoCommandAdded 21029
#define sipName_undoCommandAdded &sipStrings_QtGui[21029]
#define sipNameNr_useDesignMetrics 21046
#define sipName_useDesignMetrics &sipStrings_QtGui[21046]
#define sipNameNr_MarkdownResource 21063
#define sipName_MarkdownResource &sipStrings_QtGui[21063]
#define sipNameNr_visualNavigation 21080
#define sipName_visualNavigation &sipStrings_QtGui[21080]
#define sipNameNr_mergeBlockFormat 21097
#define sipName_mergeBlockFormat &sipStrings_QtGui[21097]
#define sipNameNr_BlockUnderCursor 21114
#define sipName_BlockUnderCursor &sipStrings_QtGui[21114]
#define sipNameNr_rehighlightBlock 21131
#define sipName_rehighlightBlock &sipStrings_QtGui[21131]
#define sipNameNr_setRedBufferSize 21148
#define sipName_setRedBufferSize &sipStrings_QtGui[21148]
#define sipNameNr_wheelScrollLines 21165
#define sipName_wheelScrollLines &sipStrings_QtGui[21165]
#define sipNameNr_tabFocusBehavior 21182
#define sipName_tabFocusBehavior &sipStrings_QtGui[21182]
#define sipNameNr_useRtlExtensions 21199
#define sipName_useRtlExtensions &sipStrings_QtGui[21199]
#define sipNameNr_showIsFullScreen 21216
#define sipName_showIsFullScreen &sipStrings_QtGui[21216]
#define sipNameNr_setTextAlignment 21233
#define sipName_setTextAlignment &sipStrings_QtGui[21233]
#define sipNameNr_setItemRoleNames 21250
#define sipName_setItemRoleNames &sipStrings_QtGui[21250]
#define sipNameNr_setItemPrototype 21267
#define sipName_setItemPrototype &sipStrings_QtGui[21267]
#define sipNameNr_virtualSiblingAt 21284
#define sipName_virtualSiblingAt &sipStrings_QtGui[21284]
#define sipNameNr_transformBetween 21301
#define sipName_transformBetween &sipStrings_QtGui[21301]
#define sipNameNr_UseDesignMetrics 13883
#define sipName_UseDesignMetrics &sipStrings_QtGui[13883]
#define sipNameNr_SeparateAdvances 21318
#define sipName_SeparateAdvances &sipStrings_QtGui[21318]
#define sipNameNr_alphaMapForGlyph 21335
#define sipName_alphaMapForGlyph &sipStrings_QtGui[21335]
#define sipNameNr_antialiasingType 21352
#define sipName_antialiasingType &sipStrings_QtGui[21352]
#define sipNameNr_AntialiasingType 5172
#define sipName_AntialiasingType &sipStrings_QtGui[5172]
#define sipNameNr_toRotationMatrix 21369
#define sipName_toRotationMatrix &sipStrings_QtGui[21369]
#define sipNameNr_fromAxisAndAngle 21386
#define sipName_fromAxisAndAngle &sipStrings_QtGui[21386]
#define sipNameNr_convertFromImage 21403
#define sipName_convertFromImage &sipStrings_QtGui[21403]
#define sipNameNr_qPixelFormatCmyk 21420
#define sipName_qPixelFormatCmyk &sipStrings_QtGui[21420]
#define sipNameNr_qPixelFormatRgba 21437
#define sipName_qPixelFormatRgba &sipStrings_QtGui[21437]
#define sipNameNr_NotPremultiplied 21454
#define sipName_NotPremultiplied &sipStrings_QtGui[21454]
#define sipNameNr_controlPointRect 21471
#define sipName_controlPointRect &sipStrings_QtGui[21471]
#define sipNameNr_DirtyClipEnabled 21488
#define sipName_DirtyClipEnabled &sipStrings_QtGui[21488]
#define sipNameNr_DirtyBrushOrigin 21505
#define sipName_DirtyBrushOrigin &sipStrings_QtGui[21505]
#define sipNameNr_PatternTransform 21522
#define sipName_PatternTransform &sipStrings_QtGui[21522]
#define sipNameNr_clipBoundingRect 21539
#define sipName_clipBoundingRect &sipStrings_QtGui[21539]
#define sipNameNr_TextAntialiasing 21556
#define sipName_TextAntialiasing &sipStrings_QtGui[21556]
#define sipNameNr_EnvelopePersonal 21573
#define sipName_EnvelopePersonal &sipStrings_QtGui[21573]
#define sipNameNr_OriginBottomLeft 21590
#define sipName_OriginBottomLeft &sipStrings_QtGui[21590]
#define sipNameNr_CommpareNotEqual 21607
#define sipName_CommpareNotEqual &sipStrings_QtGui[21607]
#define sipNameNr_CompareLessEqual 21624
#define sipName_CompareLessEqual &sipStrings_QtGui[21624]
#define sipNameNr_setMinMagFilters 21641
#define sipName_setMinMagFilters &sipStrings_QtGui[21641]
#define sipNameNr_depthStencilMode 21658
#define sipName_depthStencilMode &sipStrings_QtGui[21658]
#define sipNameNr_DepthStencilMode 1450
#define sipName_DepthStencilMode &sipStrings_QtGui[1450]
#define sipNameNr_SwizzleComponent 1483
#define sipName_SwizzleComponent &sipStrings_QtGui[1483]
#define sipNameNr_setMipLevelRange 21675
#define sipName_setMipLevelRange &sipStrings_QtGui[21675]
#define sipNameNr_StencilTexturing 21692
#define sipName_StencilTexturing &sipStrings_QtGui[21692]
#define sipNameNr_TextureRectangle 21709
#define sipName_TextureRectangle &sipStrings_QtGui[21709]
#define sipNameNr_ImmutableStorage 21726
#define sipName_ImmutableStorage &sipStrings_QtGui[21726]
#define sipNameNr_UInt32_RGBA8_Rev 21743
#define sipName_UInt32_RGBA8_Rev &sipStrings_QtGui[21743]
#define sipNameNr_UInt16_RGBA4_Rev 21760
#define sipName_UInt16_RGBA4_Rev &sipStrings_QtGui[21760]
#define sipNameNr_CubeMapNegativeZ 21777
#define sipName_CubeMapNegativeZ &sipStrings_QtGui[21777]
#define sipNameNr_CubeMapPositiveZ 21794
#define sipName_CubeMapPositiveZ &sipStrings_QtGui[21794]
#define sipNameNr_CubeMapNegativeY 21811
#define sipName_CubeMapNegativeY &sipStrings_QtGui[21811]
#define sipNameNr_CubeMapPositiveY 21828
#define sipName_CubeMapPositiveY &sipStrings_QtGui[21828]
#define sipNameNr_CubeMapNegativeX 21845
#define sipName_CubeMapNegativeX &sipStrings_QtGui[21845]
#define sipNameNr_CubeMapPositiveX 21862
#define sipName_CubeMapPositiveX &sipStrings_QtGui[21862]
#define sipNameNr_maximumMipLevels 21879
#define sipName_maximumMipLevels &sipStrings_QtGui[21879]
#define sipNameNr_ResetTextureUnit 12773
#define sipName_ResetTextureUnit &sipStrings_QtGui[12773]
#define sipNameNr_TextureUnitReset 1516
#define sipName_TextureUnitReset &sipStrings_QtGui[1516]
#define sipNameNr_MipMapGeneration 1549
#define sipName_MipMapGeneration &sipStrings_QtGui[1549]
#define sipNameNr_patchVertexCount 21896
#define sipName_patchVertexCount &sipStrings_QtGui[21896]
#define sipNameNr_removeAllShaders 21913
#define sipName_removeAllShaders &sipStrings_QtGui[21913]
#define sipNameNr_hasOpenGLShaders 21930
#define sipName_hasOpenGLShaders &sipStrings_QtGui[21930]
#define sipNameNr_setTextureTarget 21947
#define sipName_setTextureTarget &sipStrings_QtGui[21947]
#define sipNameNr_ThirdPartySource 21964
#define sipName_ThirdPartySource &sipStrings_QtGui[21964]
#define sipNameNr_openGLModuleType 21981
#define sipName_openGLModuleType &sipStrings_QtGui[21981]
#define sipNameNr_OpenGLModuleType 1648
#define sipName_OpenGLModuleType &sipStrings_QtGui[1648]
#define sipNameNr_versionFunctions 21998
#define sipName_versionFunctions &sipStrings_QtGui[21998]
#define sipNameNr_RangeAccessFlags 2163
#define sipName_RangeAccessFlags &sipStrings_QtGui[2163]
#define sipNameNr_supportedFormats 22015
#define sipName_supportedFormats &sipStrings_QtGui[22015]
#define sipNameNr_SelectEndOfBlock 22032
#define sipName_SelectEndOfBlock &sipStrings_QtGui[22032]
#define sipNameNr_MoveToEndOfBlock 22049
#define sipName_MoveToEndOfBlock &sipStrings_QtGui[22049]
#define sipNameNr_animatingChanged 22066
#define sipName_animatingChanged &sipStrings_QtGui[22066]
#define sipNameNr_queryFocusObject 22083
#define sipName_queryFocusObject &sipStrings_QtGui[22083]
#define sipNameNr_ImageWriterError 2754
#define sipName_ImageWriterError &sipStrings_QtGui[2754]
#define sipNameNr_setAutoTransform 22100
#define sipName_setAutoTransform &sipStrings_QtGui[22100]
#define sipNameNr_InvalidDataError 22117
#define sipName_InvalidDataError &sipStrings_QtGui[22117]
#define sipNameNr_ImageReaderError 2785
#define sipName_ImageReaderError &sipStrings_QtGui[2785]
#define sipNameNr_currentImageRect 22134
#define sipName_currentImageRect &sipStrings_QtGui[22134]
#define sipNameNr_CompressionRatio 22151
#define sipName_CompressionRatio &sipStrings_QtGui[22151]
#define sipNameNr_setDotsPerMeterY 22168
#define sipName_setDotsPerMeterY &sipStrings_QtGui[22168]
#define sipNameNr_setDotsPerMeterX 22185
#define sipName_setDotsPerMeterX &sipStrings_QtGui[22185]
#define sipNameNr_ScaledPixmapHook 22202
#define sipName_ScaledPixmapHook &sipStrings_QtGui[22202]
#define sipNameNr_themeSearchPaths 22219
#define sipName_themeSearchPaths &sipStrings_QtGui[22219]
#define sipNameNr_applicationState 22236
#define sipName_applicationState &sipStrings_QtGui[22236]
#define sipNameNr_devicePixelRatio 22253
#define sipName_devicePixelRatio &sipStrings_QtGui[22253]
#define sipNameNr_lastWindowClosed 22270
#define sipName_lastWindowClosed &sipStrings_QtGui[22270]
#define sipNameNr_averageCharWidth 22287
#define sipName_averageCharWidth &sipStrings_QtGui[22287]
#define sipNameNr_boundingRectChar 22304
#define sipName_boundingRectChar &sipStrings_QtGui[22304]
#define sipNameNr_isBitmapScalable 22321
#define sipName_isBitmapScalable &sipStrings_QtGui[22321]
#define sipNameNr_setLetterSpacing 22338
#define sipName_setLetterSpacing &sipStrings_QtGui[22338]
#define sipNameNr_lastResortFamily 22355
#define sipName_lastResortFamily &sipStrings_QtGui[22355]
#define sipNameNr_setStyleStrategy 22372
#define sipName_setStyleStrategy &sipStrings_QtGui[22372]
#define sipNameNr_OpenGLCompatible 22389
#define sipName_OpenGLCompatible &sipStrings_QtGui[22389]
#define sipNameNr_QFont__StyleHint 22406
#define sipName_QFont__StyleHint &sipStrings_QtGui[22406]
#define sipNameNr_surfaceEventType 22423
#define sipName_surfaceEventType &sipStrings_QtGui[22423]
#define sipNameNr_SurfaceEventType 268
#define sipName_SurfaceEventType &sipStrings_QtGui[268]
#define sipNameNr_touchPointStates 22440
#define sipName_touchPointStates &sipStrings_QtGui[22440]
#define sipNameNr_ellipseDiameters 22457
#define sipName_ellipseDiameters &sipStrings_QtGui[22457]
#define sipNameNr_replacementStart 22474
#define sipName_replacementStart &sipStrings_QtGui[22474]
#define sipNameNr_nativeVirtualKey 22491
#define sipName_nativeVirtualKey &sipStrings_QtGui[22491]
#define sipNameNr_supportedActions 22508
#define sipName_supportedActions &sipStrings_QtGui[22508]
#define sipNameNr_QDesktopServices 22525
#define sipName_QDesktopServices &sipStrings_QtGui[22525]
#define sipNameNr_transferFunction 22542
#define sipName_transferFunction &sipStrings_QtGui[22542]
#define sipNameNr_TransferFunction 3595
#define sipName_TransferFunction &sipStrings_QtGui[3595]
#define sipNameNr_QClipboard__Mode 22559
#define sipName_QClipboard__Mode &sipStrings_QtGui[22559]
#define sipNameNr_QConicalGradient 22576
#define sipName_QConicalGradient &sipStrings_QtGui[22576]
#define sipNameNr_EternalConstance 22593
#define sipName_EternalConstance &sipStrings_QtGui[22593]
#define sipNameNr_mediumaquamarine 22610
#define sipName_mediumaquamarine &sipStrings_QtGui[22610]
#define sipNameNr_drawInlineObject 22627
#define sipName_drawInlineObject &sipStrings_QtGui[22627]
#define sipNameNr_pageCountChanged 22644
#define sipName_pageCountChanged &sipStrings_QtGui[22644]
#define sipNameNr_handlerForObject 22661
#define sipName_handlerForObject &sipStrings_QtGui[22661]
#define sipNameNr_setDefaultFormat 22678
#define sipName_setDefaultFormat &sipStrings_QtGui[22678]
#define sipNameNr_selectionChanged 22695
#define sipName_selectionChanged &sipStrings_QtGui[22695]
#define sipNameNr_disconnectNotify 22712
#define sipName_disconnectNotify &sipStrings_QtGui[22712]
#define sipNameNr_22729 22729
#define sipName_22729 &sipStrings_QtGui[22729]
#define sipNameNr_22745 22745
#define sipName_22745 &sipStrings_QtGui[22745]
#define sipNameNr_22761 22761
#define sipName_22761 &sipStrings_QtGui[22761]
#define sipNameNr_22777 22777
#define sipName_22777 &sipStrings_QtGui[22777]
#define sipNameNr_22793 22793
#define sipName_22793 &sipStrings_QtGui[22793]
#define sipNameNr_startSystemMove 22809
#define sipName_startSystemMove &sipStrings_QtGui[22809]
#define sipNameNr_setWindowStates 22825
#define sipName_setWindowStates &sipStrings_QtGui[22825]
#define sipNameNr_mousePressEvent 22841
#define sipName_mousePressEvent &sipStrings_QtGui[22841]
#define sipNameNr_keyReleaseEvent 22857
#define sipName_keyReleaseEvent &sipStrings_QtGui[22857]
#define sipNameNr_modalityChanged 22873
#define sipName_modalityChanged &sipStrings_QtGui[22873]
#define sipNameNr_setMaximumWidth 22889
#define sipName_setMaximumWidth &sipStrings_QtGui[22889]
#define sipNameNr_setMinimumWidth 22905
#define sipName_setMinimumWidth &sipStrings_QtGui[22905]
#define sipNameNr_transientParent 22921
#define sipName_transientParent &sipStrings_QtGui[22921]
#define sipNameNr_requestActivate 22937
#define sipName_requestActivate &sipStrings_QtGui[22937]
#define sipNameNr_distanceToPoint 22953
#define sipName_distanceToPoint &sipStrings_QtGui[22953]
#define sipNameNr_setCapabilities 22969
#define sipName_setCapabilities &sipStrings_QtGui[22969]
#define sipNameNr_tabStopDistance 22985
#define sipName_tabStopDistance &sipStrings_QtGui[22985]
#define sipNameNr_firstLineNumber 23001
#define sipName_firstLineNumber &sipStrings_QtGui[23001]
#define sipNameNr_charFormatIndex 23017
#define sipName_charFormatIndex &sipStrings_QtGui[23017]
#define sipNameNr_QTextBlockGroup 23033
#define sipName_QTextBlockGroup &sipStrings_QtGui[23033]
#define sipNameNr_leadingIncluded 23049
#define sipName_leadingIncluded &sipStrings_QtGui[23049]
#define sipNameNr_QTextLine__Edge 23065
#define sipName_QTextLine__Edge &sipStrings_QtGui[23065]
#define sipNameNr_naturalTextRect 23081
#define sipName_naturalTextRect &sipStrings_QtGui[23081]
#define sipNameNr_cursorMoveStyle 23097
#define sipName_cursorMoveStyle &sipStrings_QtGui[23097]
#define sipNameNr_setCacheEnabled 23113
#define sipName_setCacheEnabled &sipStrings_QtGui[23113]
#define sipNameNr_preeditAreaText 23129
#define sipName_preeditAreaText &sipStrings_QtGui[23129]
#define sipNameNr_leftBorderBrush 23145
#define sipName_leftBorderBrush &sipStrings_QtGui[23145]
#define sipNameNr_leftBorderStyle 23161
#define sipName_leftBorderStyle &sipStrings_QtGui[23161]
#define sipNameNr_setBottomBorder 23177
#define sipName_setBottomBorder &sipStrings_QtGui[23177]
#define sipNameNr_setRightPadding 23193
#define sipName_setRightPadding &sipStrings_QtGui[23193]
#define sipNameNr_setNumberSuffix 23209
#define sipName_setNumberSuffix &sipStrings_QtGui[23209]
#define sipNameNr_setNumberPrefix 23225
#define sipName_setNumberPrefix &sipStrings_QtGui[23225]
#define sipNameNr_QTextListFormat 23241
#define sipName_QTextListFormat &sipStrings_QtGui[23241]
#define sipNameNr_setHeadingLevel 23257
#define sipName_setHeadingLevel &sipStrings_QtGui[23257]
#define sipNameNr_LineHeightTypes 950
#define sipName_LineHeightTypes &sipStrings_QtGui[950]
#define sipNameNr_setTabPositions 23273
#define sipName_setTabPositions &sipStrings_QtGui[23273]
#define sipNameNr_pageBreakPolicy 23289
#define sipName_pageBreakPolicy &sipStrings_QtGui[23289]
#define sipNameNr_setFontFamilies 23305
#define sipName_setFontFamilies &sipStrings_QtGui[23305]
#define sipNameNr_fontWordSpacing 23321
#define sipName_fontWordSpacing &sipStrings_QtGui[23321]
#define sipNameNr_SingleUnderline 23337
#define sipName_SingleUnderline &sipStrings_QtGui[23337]
#define sipNameNr_setFontOverline 23353
#define sipName_setFontOverline &sipStrings_QtGui[23353]
#define sipNameNr_QTextCharFormat 23369
#define sipName_QTextCharFormat &sipStrings_QtGui[23369]
#define sipNameNr_clearForeground 23385
#define sipName_clearForeground &sipStrings_QtGui[23385]
#define sipNameNr_clearBackground 23401
#define sipName_clearBackground &sipStrings_QtGui[23401]
#define sipNameNr_BlockQuoteLevel 23417
#define sipName_BlockQuoteLevel &sipStrings_QtGui[23417]
#define sipNameNr_FontWordSpacing 15656
#define sipName_FontWordSpacing &sipStrings_QtGui[15656]
#define sipNameNr_FrameLeftMargin 23433
#define sipName_FrameLeftMargin &sipStrings_QtGui[23433]
#define sipNameNr_PageBreakPolicy 15637
#define sipName_PageBreakPolicy &sipStrings_QtGui[15637]
#define sipNameNr_BlockLeftMargin 23449
#define sipName_BlockLeftMargin &sipStrings_QtGui[23449]
#define sipNameNr_ForegroundBrush 23465
#define sipName_ForegroundBrush &sipStrings_QtGui[23465]
#define sipNameNr_BackgroundBrush 23481
#define sipName_BackgroundBrush &sipStrings_QtGui[23481]
#define sipNameNr_TableCellObject 23497
#define sipName_TableCellObject &sipStrings_QtGui[23497]
#define sipNameNr_MarkdownFeature 2383
#define sipName_MarkdownFeature &sipStrings_QtGui[2383]
#define sipNameNr_contentsChanged 23513
#define sipName_contentsChanged &sipStrings_QtGui[23513]
#define sipNameNr_UnknownResource 23529
#define sipName_UnknownResource &sipStrings_QtGui[23529]
#define sipNameNr_objectForFormat 23545
#define sipName_objectForFormat &sipStrings_QtGui[23545]
#define sipNameNr_metaInformation 23561
#define sipName_metaInformation &sipStrings_QtGui[23561]
#define sipNameNr_MetaInformation 2414
#define sipName_MetaInformation &sipStrings_QtGui[2414]
#define sipNameNr_isRedoAvailable 23577
#define sipName_isRedoAvailable &sipStrings_QtGui[23577]
#define sipNameNr_isUndoAvailable 23593
#define sipName_isUndoAvailable &sipStrings_QtGui[23593]
#define sipNameNr_mightBeRichText 23609
#define sipName_mightBeRichText &sipStrings_QtGui[23609]
#define sipNameNr_positionInBlock 23625
#define sipName_positionInBlock &sipStrings_QtGui[23625]
#define sipNameNr_blockCharFormat 23641
#define sipName_blockCharFormat &sipStrings_QtGui[23641]
#define sipNameNr_mergeCharFormat 23657
#define sipName_mergeCharFormat &sipStrings_QtGui[23657]
#define sipNameNr_LineUnderCursor 23673
#define sipName_LineUnderCursor &sipStrings_QtGui[23673]
#define sipNameNr_WordUnderCursor 23689
#define sipName_WordUnderCursor &sipStrings_QtGui[23689]
#define sipNameNr_setSwapInterval 23705
#define sipName_setSwapInterval &sipStrings_QtGui[23705]
#define sipNameNr_setMinorVersion 23721
#define sipName_setMinorVersion &sipStrings_QtGui[23721]
#define sipNameNr_setMajorVersion 23737
#define sipName_setMajorVersion &sipStrings_QtGui[23737]
#define sipNameNr_setSwapBehavior 23753
#define sipName_setSwapBehavior &sipStrings_QtGui[23753]
#define sipNameNr_alphaBufferSize 23769
#define sipName_alphaBufferSize &sipStrings_QtGui[23769]
#define sipNameNr_greenBufferSize 23785
#define sipName_greenBufferSize &sipStrings_QtGui[23785]
#define sipNameNr_depthBufferSize 23801
#define sipName_depthBufferSize &sipStrings_QtGui[23801]
#define sipNameNr_RasterGLSurface 23817
#define sipName_RasterGLSurface &sipStrings_QtGui[23817]
#define sipNameNr_useHoverEffects 23833
#define sipName_useHoverEffects &sipStrings_QtGui[23833]
#define sipNameNr_showIsMaximized 23849
#define sipName_showIsMaximized &sipStrings_QtGui[23849]
#define sipNameNr_cursorFlashTime 23865
#define sipName_cursorFlashTime &sipStrings_QtGui[23865]
#define sipNameNr_performanceHint 23881
#define sipName_performanceHint &sipStrings_QtGui[23881]
#define sipNameNr_ModerateCaching 23897
#define sipName_ModerateCaching &sipStrings_QtGui[23897]
#define sipNameNr_PerformanceHint 3828
#define sipName_PerformanceHint &sipStrings_QtGui[3828]
#define sipNameNr_setUserTristate 23913
#define sipName_setUserTristate &sipStrings_QtGui[23913]
#define sipNameNr_setAutoTristate 23929
#define sipName_setAutoTristate &sipStrings_QtGui[23929]
#define sipNameNr_emitDataChanged 23945
#define sipName_emitDataChanged &sipStrings_QtGui[23945]
#define sipNameNr_geometryChanged 23961
#define sipName_geometryChanged &sipStrings_QtGui[23961]
#define sipNameNr_virtualGeometry 23977
#define sipName_virtualGeometry &sipStrings_QtGui[23977]
#define sipNameNr_virtualSiblings 23993
#define sipName_virtualSiblings &sipStrings_QtGui[23993]
#define sipNameNr_unpremultiplied 24009
#define sipName_unpremultiplied &sipStrings_QtGui[24009]
#define sipNameNr_fromEulerAngles 24025
#define sipName_fromEulerAngles &sipStrings_QtGui[24025]
#define sipNameNr_getAxisAndAngle 24041
#define sipName_getAxisAndAngle &sipStrings_QtGui[24041]
#define sipNameNr_fromImageReader 24057
#define sipName_fromImageReader &sipStrings_QtGui[24057]
#define sipNameNr_qPixelFormatYuv 24073
#define sipName_qPixelFormatYuv &sipStrings_QtGui[24073]
#define sipNameNr_qPixelFormatHsv 24089
#define sipName_qPixelFormatHsv &sipStrings_QtGui[24089]
#define sipNameNr_qPixelFormatHsl 24105
#define sipName_qPixelFormatHsl &sipStrings_QtGui[24105]
#define sipNameNr_defineIOHandler 24121
#define sipName_defineIOHandler &sipStrings_QtGui[24121]
#define sipNameNr_placeholderText 24137
#define sipName_placeholderText &sipStrings_QtGui[24137]
#define sipNameNr_highlightedText 24153
#define sipName_highlightedText &sipStrings_QtGui[24153]
#define sipNameNr_PlaceholderText 24169
#define sipName_PlaceholderText &sipStrings_QtGui[24169]
#define sipNameNr_HighlightedText 24185
#define sipName_HighlightedText &sipStrings_QtGui[24185]
#define sipNameNr_percentAtLength 24201
#define sipName_percentAtLength &sipStrings_QtGui[24201]
#define sipNameNr_currentPosition 24217
#define sipName_currentPosition &sipStrings_QtGui[24217]
#define sipNameNr_backgroundBrush 24233
#define sipName_backgroundBrush &sipStrings_QtGui[24233]
#define sipNameNr_PolygonDrawMode 2906
#define sipName_PolygonDrawMode &sipStrings_QtGui[2906]
#define sipNameNr_DirtyClipRegion 24249
#define sipName_DirtyClipRegion &sipStrings_QtGui[24249]
#define sipNameNr_DirtyBackground 24265
#define sipName_DirtyBackground &sipStrings_QtGui[24265]
#define sipNameNr_ConstantOpacity 24281
#define sipName_ConstantOpacity &sipStrings_QtGui[24281]
#define sipNameNr_PixmapTransform 10806
#define sipName_PixmapTransform &sipStrings_QtGui[10806]
#define sipNameNr_PdmPhysicalDpiY 24297
#define sipName_PdmPhysicalDpiY &sipStrings_QtGui[24297]
#define sipNameNr_PdmPhysicalDpiX 24313
#define sipName_PdmPhysicalDpiX &sipStrings_QtGui[24313]
#define sipNameNr_drawRoundedRect 24329
#define sipName_drawRoundedRect &sipStrings_QtGui[24329]
#define sipNameNr_deviceTransform 24345
#define sipName_deviceTransform &sipStrings_QtGui[24345]
#define sipNameNr_drawTiledPixmap 24361
#define sipName_drawTiledPixmap &sipStrings_QtGui[24361]
#define sipNameNr_compositionMode 24377
#define sipName_compositionMode &sipStrings_QtGui[24377]
#define sipNameNr_CompositionMode 6071
#define sipName_CompositionMode &sipStrings_QtGui[6071]
#define sipNameNr_definitionUnits 24393
#define sipName_definitionUnits &sipStrings_QtGui[24393]
#define sipNameNr_SizeMatchPolicy 5308
#define sipName_SizeMatchPolicy &sipStrings_QtGui[5308]
#define sipNameNr_QPageSize__Unit 24409
#define sipName_QPageSize__Unit &sipStrings_QtGui[24409]
#define sipNameNr_paintRectPixels 24425
#define sipName_paintRectPixels &sipStrings_QtGui[24425]
#define sipNameNr_paintRectPoints 24441
#define sipName_paintRectPoints &sipStrings_QtGui[24441]
#define sipNameNr_setBottomMargin 24457
#define sipName_setBottomMargin &sipStrings_QtGui[24457]
#define sipNameNr_EnvelopeItalian 24473
#define sipName_EnvelopeItalian &sipStrings_QtGui[24473]
#define sipNameNr_EnvelopeMonarch 24489
#define sipName_EnvelopeMonarch &sipStrings_QtGui[24489]
#define sipNameNr_grabFramebuffer 24505
#define sipName_grabFramebuffer &sipStrings_QtGui[24505]
#define sipNameNr_NoPartialUpdate 24521
#define sipName_NoPartialUpdate &sipStrings_QtGui[24521]
#define sipNameNr_sourceTransform 24537
#define sipName_sourceTransform &sipStrings_QtGui[24537]
#define sipNameNr_targetTransform 24553
#define sipName_targetTransform &sipStrings_QtGui[24553]
#define sipNameNr_generateMipMaps 24569
#define sipName_generateMipMaps &sipStrings_QtGui[24569]
#define sipNameNr_setMipBaseLevel 24585
#define sipName_setMipBaseLevel &sipStrings_QtGui[24585]
#define sipNameNr_UInt8_RG3B2_Rev 24601
#define sipName_UInt8_RG3B2_Rev &sipStrings_QtGui[24601]
#define sipNameNr_UInt32_RG11B10F 24617
#define sipName_UInt32_RG11B10F &sipStrings_QtGui[24617]
#define sipNameNr_allocateStorage 24633
#define sipName_allocateStorage &sipStrings_QtGui[24633]
#define sipNameNr_RGBA_ASTC_12x12 24649
#define sipName_RGBA_ASTC_12x12 &sipStrings_QtGui[24649]
#define sipNameNr_RGBA_ASTC_12x10 24665
#define sipName_RGBA_ASTC_12x10 &sipStrings_QtGui[24665]
#define sipNameNr_RGBA_ASTC_10x10 24681
#define sipName_RGBA_ASTC_10x10 &sipStrings_QtGui[24681]
#define sipNameNr_LuminanceFormat 24697
#define sipName_LuminanceFormat &sipStrings_QtGui[24697]
#define sipNameNr_SRGB_Alpha_DXT5 24713
#define sipName_SRGB_Alpha_DXT5 &sipStrings_QtGui[24713]
#define sipNameNr_SRGB_Alpha_DXT3 24729
#define sipName_SRGB_Alpha_DXT3 &sipStrings_QtGui[24729]
#define sipNameNr_SRGB_Alpha_DXT1 24745
#define sipName_SRGB_Alpha_DXT1 &sipStrings_QtGui[24745]
#define sipNameNr_GenerateMipMaps 14464
#define sipName_GenerateMipMaps &sipStrings_QtGui[14464]
#define sipNameNr_BindingTarget3D 24761
#define sipName_BindingTarget3D &sipStrings_QtGui[24761]
#define sipNameNr_BindingTarget2D 24777
#define sipName_BindingTarget2D &sipStrings_QtGui[24777]
#define sipNameNr_BindingTarget1D 24793
#define sipName_BindingTarget1D &sipStrings_QtGui[24793]
#define sipNameNr_TargetRectangle 9469
#define sipName_TargetRectangle &sipStrings_QtGui[9469]
#define sipNameNr_setUniformValue 24809
#define sipName_setUniformValue &sipStrings_QtGui[24809]
#define sipNameNr_uniformLocation 24825
#define sipName_uniformLocation &sipStrings_QtGui[24825]
#define sipNameNr_setPaintFlipped 24841
#define sipName_setPaintFlipped &sipStrings_QtGui[24841]
#define sipNameNr_blitFramebuffer 24857
#define sipName_blitFramebuffer &sipStrings_QtGui[24857]
#define sipNameNr_internal_format 24873
#define sipName_internal_format &sipStrings_QtGui[24873]
#define sipNameNr_disableMessages 24889
#define sipName_disableMessages &sipStrings_QtGui[24889]
#define sipNameNr_InvalidSeverity 24905
#define sipName_InvalidSeverity &sipStrings_QtGui[24905]
#define sipNameNr_PerformanceType 24921
#define sipName_PerformanceType &sipStrings_QtGui[24921]
#define sipNameNr_PortabilityType 24937
#define sipName_PortabilityType &sipStrings_QtGui[24937]
#define sipNameNr_isLegacyVersion 24953
#define sipName_isLegacyVersion &sipStrings_QtGui[24953]
#define sipNameNr_setShareContext 24969
#define sipName_setShareContext &sipStrings_QtGui[24969]
#define sipNameNr_RangeInvalidate 24985
#define sipName_RangeInvalidate &sipStrings_QtGui[24985]
#define sipNameNr_RangeAccessFlag 2724
#define sipName_RangeAccessFlag &sipStrings_QtGui[2724]
#define sipNameNr_setUsagePattern 25001
#define sipName_setUsagePattern &sipStrings_QtGui[25001]
#define sipNameNr_PixelPackBuffer 25017
#define sipName_PixelPackBuffer &sipStrings_QtGui[25017]
#define sipNameNr_setNativeHandle 25033
#define sipName_setNativeHandle &sipStrings_QtGui[25033]
#define sipNameNr_requestedFormat 25049
#define sipName_requestedFormat &sipStrings_QtGui[25049]
#define sipNameNr_lastErrorString 25065
#define sipName_lastErrorString &sipStrings_QtGui[25065]
#define sipNameNr_jumpToNextFrame 25081
#define sipName_jumpToNextFrame &sipStrings_QtGui[25081]
#define sipNameNr_distanceToPlane 25097
#define sipName_distanceToPlane &sipStrings_QtGui[25097]
#define sipNameNr_DeleteEndOfLine 25113
#define sipName_DeleteEndOfLine &sipStrings_QtGui[25113]
#define sipNameNr_DeleteEndOfWord 25129
#define sipName_DeleteEndOfWord &sipStrings_QtGui[25129]
#define sipNameNr_SelectEndOfLine 25145
#define sipName_SelectEndOfLine &sipStrings_QtGui[25145]
#define sipNameNr_MoveToEndOfLine 25161
#define sipName_MoveToEndOfLine &sipStrings_QtGui[25161]
#define sipNameNr_anchorRectangle 25177
#define sipName_anchorRectangle &sipStrings_QtGui[25177]
#define sipNameNr_cursorRectangle 25193
#define sipName_cursorRectangle &sipStrings_QtGui[25193]
#define sipNameNr_backgroundColor 25209
#define sipName_backgroundColor &sipStrings_QtGui[25209]
#define sipNameNr_Transformations 1682
#define sipName_Transformations &sipStrings_QtGui[1682]
#define sipNameNr_jumpToNextImage 25225
#define sipName_jumpToNextImage &sipStrings_QtGui[25225]
#define sipNameNr_BackgroundColor 17195
#define sipName_BackgroundColor &sipStrings_QtGui[17195]
#define sipNameNr_QImageIOHandler 25241
#define sipName_QImageIOHandler &sipStrings_QtGui[25241]
#define sipNameNr_aspectRatioMode 25257
#define sipName_aspectRatioMode &sipStrings_QtGui[25257]
#define sipNameNr_createAlphaMask 25273
#define sipName_createAlphaMask &sipStrings_QtGui[25273]
#define sipNameNr_hasAlphaChannel 25289
#define sipName_hasAlphaChannel &sipStrings_QtGui[25289]
#define sipNameNr_convertToFormat 25305
#define sipName_convertToFormat &sipStrings_QtGui[25305]
#define sipNameNr_Format_RGBA8888 25321
#define sipName_Format_RGBA8888 &sipStrings_QtGui[25321]
#define sipNameNr_Format_RGBX8888 25337
#define sipName_Format_RGBX8888 &sipStrings_QtGui[25337]
#define sipNameNr_Format_Indexed8 25353
#define sipName_Format_Indexed8 &sipStrings_QtGui[25353]
#define sipNameNr_desktopFileName 25369
#define sipName_desktopFileName &sipStrings_QtGui[25369]
#define sipNameNr_layoutDirection 25385
#define sipName_layoutDirection &sipStrings_QtGui[25385]
#define sipNameNr_topLevelWindows 25401
#define sipName_topLevelWindows &sipStrings_QtGui[25401]
#define sipNameNr_QGuiApplication 25417
#define sipName_QGuiApplication &sipStrings_QtGui[25417]
#define sipNameNr_setBoundingRect 25433
#define sipName_setBoundingRect &sipStrings_QtGui[25433]
#define sipNameNr_setGlyphIndexes 25449
#define sipName_setGlyphIndexes &sipStrings_QtGui[25449]
#define sipNameNr_minRightBearing 25465
#define sipName_minRightBearing &sipStrings_QtGui[25465]
#define sipNameNr_isPrivateFamily 25481
#define sipName_isPrivateFamily &sipStrings_QtGui[25481]
#define sipNameNr_PreferNoHinting 25497
#define sipName_PreferNoHinting &sipStrings_QtGui[25497]
#define sipNameNr_AbsoluteSpacing 25513
#define sipName_AbsoluteSpacing &sipStrings_QtGui[25513]
#define sipNameNr_cacheStatistics 25529
#define sipName_cacheStatistics &sipStrings_QtGui[25529]
#define sipNameNr_PreferNoShaping 25545
#define sipName_PreferNoShaping &sipStrings_QtGui[25545]
#define sipNameNr_PreferAntialias 25561
#define sipName_PreferAntialias &sipStrings_QtGui[25561]
#define sipNameNr_setViewportSize 25577
#define sipName_setViewportSize &sipStrings_QtGui[25577]
#define sipNameNr_contentPosRange 25593
#define sipName_contentPosRange &sipStrings_QtGui[25593]
#define sipNameNr_QStatusTipEvent 25609
#define sipName_QStatusTipEvent &sipStrings_QtGui[25609]
#define sipNameNr_QDragLeaveEvent 25625
#define sipName_QDragLeaveEvent &sipStrings_QtGui[25625]
#define sipNameNr_QDragEnterEvent 25641
#define sipName_QDragEnterEvent &sipStrings_QtGui[25641]
#define sipNameNr_possibleActions 25657
#define sipName_possibleActions &sipStrings_QtGui[25657]
#define sipNameNr_setCommitString 25673
#define sipName_setCommitString &sipStrings_QtGui[25673]
#define sipNameNr_nativeModifiers 25689
#define sipName_nativeModifiers &sipStrings_QtGui[25689]
#define sipNameNr_unsetUrlHandler 25705
#define sipName_unsetUrlHandler &sipStrings_QtGui[25705]
#define sipNameNr_QColorTransform 25721
#define sipName_QColorTransform &sipStrings_QtGui[25721]
#define sipNameNr_NamedColorSpace 4205
#define sipName_NamedColorSpace &sipStrings_QtGui[4205]
#define sipNameNr_setCenterRadius 25737
#define sipName_setCenterRadius &sipStrings_QtGui[25737]
#define sipNameNr_QRadialGradient 25753
#define sipName_QRadialGradient &sipStrings_QtGui[25753]
#define sipNameNr_QLinearGradient 25769
#define sipName_QLinearGradient &sipStrings_QtGui[25769]
#define sipNameNr_LandingAircraft 25785
#define sipName_LandingAircraft &sipStrings_QtGui[25785]
#define sipNameNr_CheerfulCaramel 25801
#define sipName_CheerfulCaramel &sipStrings_QtGui[25801]
#define sipNameNr_SaintPetersburg 25817
#define sipName_SaintPetersburg &sipStrings_QtGui[25817]
#define sipNameNr_CloudyKnoxville 25833
#define sipName_CloudyKnoxville &sipStrings_QtGui[25833]
#define sipNameNr_ConicalGradient 22577
#define sipName_ConicalGradient &sipStrings_QtGui[22577]
#define sipNameNr_QGradient__Type 25849
#define sipName_QGradient__Type &sipStrings_QtGui[25849]
#define sipNameNr_setTextureImage 25865
#define sipName_setTextureImage &sipStrings_QtGui[25865]
#define sipNameNr_mediumvioletred 25881
#define sipName_mediumvioletred &sipStrings_QtGui[25881]
#define sipNameNr_mediumturquoise 25897
#define sipName_mediumturquoise &sipStrings_QtGui[25897]
#define sipNameNr_mediumslateblue 25913
#define sipName_mediumslateblue &sipStrings_QtGui[25913]
#define sipNameNr_QColorConstants 25929
#define sipName_QColorConstants &sipStrings_QtGui[25929]
#define sipNameNr_documentChanged 25945
#define sipName_documentChanged &sipStrings_QtGui[25945]
#define sipNameNr_registerHandler 20244
#define sipName_registerHandler &sipStrings_QtGui[20244]
#define sipNameNr_UnsignedInteger 25961
#define sipName_UnsignedInteger &sipStrings_QtGui[25961]
#define sipNameNr_canDropMimeData 25977
#define sipName_canDropMimeData &sipStrings_QtGui[25977]
#define sipNameNr_LayoutDirection 17404
#define sipName_LayoutDirection &sipStrings_QtGui[17404]
#define sipNameNr_25993 25993
#define sipName_25993 &sipStrings_QtGui[25993]
#define sipNameNr_26008 26008
#define sipName_26008 &sipStrings_QtGui[26008]
#define sipNameNr_26023 26023
#define sipName_26023 &sipStrings_QtGui[26023]
#define sipNameNr_26038 26038
#define sipName_26038 &sipStrings_QtGui[26038]
#define sipNameNr_26053 26053
#define sipName_26053 &sipStrings_QtGui[26053]
#define sipNameNr_opacityChanged 26068
#define sipName_opacityChanged &sipStrings_QtGui[26068]
#define sipNameNr_mouseMoveEvent 26083
#define sipName_mouseMoveEvent &sipStrings_QtGui[26083]
#define sipNameNr_showFullScreen 26098
#define sipName_showFullScreen &sipStrings_QtGui[26098]
#define sipNameNr_setMaximumSize 26113
#define sipName_setMaximumSize &sipStrings_QtGui[26113]
#define sipNameNr_setMinimumSize 26128
#define sipName_setMinimumSize &sipStrings_QtGui[26128]
#define sipNameNr_setWindowState 26143
#define sipName_setWindowState &sipStrings_QtGui[26143]
#define sipNameNr_setSurfaceType 26158
#define sipName_setSurfaceType &sipStrings_QtGui[26158]
#define sipNameNr_distanceToLine 26173
#define sipName_distanceToLine &sipStrings_QtGui[26173]
#define sipNameNr_MouseEmulation 26188
#define sipName_MouseEmulation &sipStrings_QtGui[26188]
#define sipNameNr_CapabilityFlag 3626
#define sipName_CapabilityFlag &sipStrings_QtGui[3626]
#define sipNameNr_QTextTableCell 26203
#define sipName_QTextTableCell &sipStrings_QtGui[26203]
#define sipNameNr_SuppressColors 26218
#define sipName_SuppressColors &sipStrings_QtGui[26218]
#define sipNameNr_setFrameFormat 26233
#define sipName_setFrameFormat &sipStrings_QtGui[26233]
#define sipNameNr_CursorPosition 5604
#define sipName_CursorPosition &sipStrings_QtGui[5604]
#define sipNameNr_SkipCharacters 26248
#define sipName_SkipCharacters &sipStrings_QtGui[26248]
#define sipNameNr_setPreeditArea 26263
#define sipName_setPreeditArea &sipStrings_QtGui[26263]
#define sipNameNr_topBorderBrush 26278
#define sipName_topBorderBrush &sipStrings_QtGui[26278]
#define sipNameNr_topBorderStyle 26293
#define sipName_topBorderStyle &sipStrings_QtGui[26293]
#define sipNameNr_setRightBorder 26308
#define sipName_setRightBorder &sipStrings_QtGui[26308]
#define sipNameNr_setLeftPadding 26323
#define sipName_setLeftPadding &sipStrings_QtGui[26323]
#define sipNameNr_borderCollapse 26338
#define sipName_borderCollapse &sipStrings_QtGui[26338]
#define sipNameNr_headerRowCount 26353
#define sipName_headerRowCount &sipStrings_QtGui[26353]
#define sipNameNr_setCellPadding 26368
#define sipName_setCellPadding &sipStrings_QtGui[26368]
#define sipNameNr_setCellSpacing 26383
#define sipName_setCellSpacing &sipStrings_QtGui[26383]
#define sipNameNr_setBorderStyle 26398
#define sipName_setBorderStyle &sipStrings_QtGui[26398]
#define sipNameNr_setBorderBrush 26413
#define sipName_setBorderBrush &sipStrings_QtGui[26413]
#define sipNameNr_ListUpperRoman 26428
#define sipName_ListUpperRoman &sipStrings_QtGui[26428]
#define sipNameNr_ListLowerRoman 26443
#define sipName_ListLowerRoman &sipStrings_QtGui[26443]
#define sipNameNr_ListUpperAlpha 26458
#define sipName_ListUpperAlpha &sipStrings_QtGui[26458]
#define sipNameNr_ListLowerAlpha 26473
#define sipName_ListLowerAlpha &sipStrings_QtGui[26473]
#define sipNameNr_lineHeightType 26488
#define sipName_lineHeightType &sipStrings_QtGui[26488]
#define sipNameNr_setFontStretch 26503
#define sipName_setFontStretch &sipStrings_QtGui[26503]
#define sipNameNr_setFontKerning 26518
#define sipName_setFontKerning &sipStrings_QtGui[26518]
#define sipNameNr_setAnchorNames 26533
#define sipName_setAnchorNames &sipStrings_QtGui[26533]
#define sipNameNr_underlineStyle 26548
#define sipName_underlineStyle &sipStrings_QtGui[26548]
#define sipNameNr_UnderlineStyle 1813
#define sipName_UnderlineStyle &sipStrings_QtGui[1813]
#define sipNameNr_setTextOutline 26563
#define sipName_setTextOutline &sipStrings_QtGui[26563]
#define sipNameNr_fontFixedPitch 26578
#define sipName_fontFixedPitch &sipStrings_QtGui[26578]
#define sipNameNr_underlineColor 26593
#define sipName_underlineColor &sipStrings_QtGui[26593]
#define sipNameNr_AlignSubScript 26608
#define sipName_AlignSubScript &sipStrings_QtGui[26608]
#define sipNameNr_lengthProperty 26623
#define sipName_lengthProperty &sipStrings_QtGui[26623]
#define sipNameNr_stringProperty 26638
#define sipName_stringProperty &sipStrings_QtGui[26638]
#define sipNameNr_doubleProperty 26653
#define sipName_doubleProperty &sipStrings_QtGui[26653]
#define sipNameNr_setObjectIndex 26668
#define sipName_setObjectIndex &sipStrings_QtGui[26668]
#define sipNameNr_BlockCodeFence 26683
#define sipName_BlockCodeFence &sipStrings_QtGui[26683]
#define sipNameNr_LineHeightType 26698
#define sipName_LineHeightType &sipStrings_QtGui[26698]
#define sipNameNr_FrameTopMargin 26713
#define sipName_FrameTopMargin &sipStrings_QtGui[26713]
#define sipNameNr_FontFixedPitch 18175
#define sipName_FontFixedPitch &sipStrings_QtGui[18175]
#define sipNameNr_BlockTopMargin 26728
#define sipName_BlockTopMargin &sipStrings_QtGui[26728]
#define sipNameNr_BlockAlignment 26743
#define sipName_BlockAlignment &sipStrings_QtGui[26743]
#define sipNameNr_PageBreakFlags 4346
#define sipName_PageBreakFlags &sipStrings_QtGui[4346]
#define sipNameNr_PageBreak_Auto 26758
#define sipName_PageBreak_Auto &sipStrings_QtGui[26758]
#define sipNameNr_VariableLength 26773
#define sipName_VariableLength &sipStrings_QtGui[26773]
#define sipNameNr_MarkdownNoHTML 26788
#define sipName_MarkdownNoHTML &sipStrings_QtGui[26788]
#define sipNameNr_baseUrlChanged 26803
#define sipName_baseUrlChanged &sipStrings_QtGui[26803]
#define sipNameNr_characterCount 26818
#define sipName_characterCount &sipStrings_QtGui[26818]
#define sipNameNr_documentMargin 26833
#define sipName_documentMargin &sipStrings_QtGui[26833]
#define sipNameNr_setIndentWidth 26848
#define sipName_setIndentWidth &sipStrings_QtGui[26848]
#define sipNameNr_contentsChange 26863
#define sipName_contentsChange &sipStrings_QtGui[26863]
#define sipNameNr_setDefaultFont 26878
#define sipName_setDefaultFont &sipStrings_QtGui[26878]
#define sipNameNr_FindWholeWords 26893
#define sipName_FindWholeWords &sipStrings_QtGui[26893]
#define sipNameNr_documentLayout 26908
#define sipName_documentLayout &sipStrings_QtGui[26908]
#define sipNameNr_beginEditBlock 26923
#define sipName_beginEditBlock &sipStrings_QtGui[26923]
#define sipNameNr_insertFragment 26938
#define sipName_insertFragment &sipStrings_QtGui[26938]
#define sipNameNr_setBlockFormat 26953
#define sipName_setBlockFormat &sipStrings_QtGui[26953]
#define sipNameNr_selectionStart 26968
#define sipName_selectionStart &sipStrings_QtGui[26968]
#define sipNameNr_highlightBlock 21133
#define sipName_highlightBlock &sipStrings_QtGui[21133]
#define sipNameNr_sRGBColorSpace 26983
#define sipName_sRGBColorSpace &sipStrings_QtGui[26983]
#define sipNameNr_renderableType 26998
#define sipName_renderableType &sipStrings_QtGui[26998]
#define sipNameNr_blueBufferSize 27013
#define sipName_blueBufferSize &sipStrings_QtGui[27013]
#define sipNameNr_RenderableType 2446
#define sipName_RenderableType &sipStrings_QtGui[2446]
#define sipNameNr_QSurfaceFormat 27028
#define sipName_QSurfaceFormat &sipStrings_QtGui[27028]
#define sipNameNr_supportsOpenGL 27043
#define sipName_supportsOpenGL &sipStrings_QtGui[27043]
#define sipNameNr_isUserTristate 27058
#define sipName_isUserTristate &sipStrings_QtGui[27058]
#define sipNameNr_isAutoTristate 27073
#define sipName_isAutoTristate &sipStrings_QtGui[27073]
#define sipNameNr_setDropEnabled 27088
#define sipName_setDropEnabled &sipStrings_QtGui[27088]
#define sipNameNr_setDragEnabled 27103
#define sipName_setDragEnabled &sipStrings_QtGui[27103]
#define sipNameNr_accessibleText 27118
#define sipName_accessibleText &sipStrings_QtGui[27118]
#define sipNameNr_setColumnCount 27133
#define sipName_setColumnCount &sipStrings_QtGui[27133]
#define sipNameNr_qUnpremultiply 27148
#define sipName_qUnpremultiply &sipStrings_QtGui[27148]
#define sipNameNr_KernedAdvances 27163
#define sipName_KernedAdvances &sipStrings_QtGui[27163]
#define sipNameNr_getEulerAngles 27178
#define sipName_getEulerAngles &sipStrings_QtGui[27178]
#define sipNameNr_brightnessSize 27193
#define sipName_brightnessSize &sipStrings_QtGui[27193]
#define sipNameNr_saturationSize 27208
#define sipName_saturationSize &sipStrings_QtGui[27208]
#define sipNameNr_setDashPattern 27223
#define sipName_setDashPattern &sipStrings_QtGui[27223]
#define sipNameNr_curveThreshold 27238
#define sipName_curveThreshold &sipStrings_QtGui[27238]
#define sipNameNr_addRoundedRect 27253
#define sipName_addRoundedRect &sipStrings_QtGui[27253]
#define sipNameNr_slopeAtPercent 27268
#define sipName_slopeAtPercent &sipStrings_QtGui[27268]
#define sipNameNr_angleAtPercent 27283
#define sipName_angleAtPercent &sipStrings_QtGui[27283]
#define sipNameNr_pointAtPercent 27298
#define sipName_pointAtPercent &sipStrings_QtGui[27298]
#define sipNameNr_toFillPolygons 27313
#define sipName_toFillPolygons &sipStrings_QtGui[27313]
#define sipNameNr_CurveToElement 27328
#define sipName_CurveToElement &sipStrings_QtGui[27328]
#define sipNameNr_DirtyTransform 27343
#define sipName_DirtyTransform &sipStrings_QtGui[27343]
#define sipNameNr_paintingActive 27358
#define sipName_paintingActive &sipStrings_QtGui[27358]
#define sipNameNr_drawStaticText 27373
#define sipName_drawStaticText &sipStrings_QtGui[27373]
#define sipNameNr_PixmapFragment 7065
#define sipName_PixmapFragment &sipStrings_QtGui[7065]
#define sipNameNr_testRenderHint 27388
#define sipName_testRenderHint &sipStrings_QtGui[27388]
#define sipNameNr_worldTransform 27403
#define sipName_worldTransform &sipStrings_QtGui[27403]
#define sipNameNr_resetTransform 27418
#define sipName_resetTransform &sipStrings_QtGui[27418]
#define sipNameNr_setRenderHints 27433
#define sipName_setRenderHints &sipStrings_QtGui[27433]
#define sipNameNr_setBrushOrigin 27448
#define sipName_setBrushOrigin &sipStrings_QtGui[27448]
#define sipNameNr_backgroundMode 27463
#define sipName_backgroundMode &sipStrings_QtGui[27463]
#define sipNameNr_definitionSize 27478
#define sipName_definitionSize &sipStrings_QtGui[27478]
#define sipNameNr_fullRectPixels 27493
#define sipName_fullRectPixels &sipStrings_QtGui[27493]
#define sipNameNr_fullRectPoints 27508
#define sipName_fullRectPoints &sipStrings_QtGui[27508]
#define sipNameNr_maximumMargins 27523
#define sipName_maximumMargins &sipStrings_QtGui[27523]
#define sipNameNr_minimumMargins 27538
#define sipName_minimumMargins &sipStrings_QtGui[27538]
#define sipNameNr_setRightMargin 27553
#define sipName_setRightMargin &sipStrings_QtGui[27553]
#define sipNameNr_setOrientation 27568
#define sipName_setOrientation &sipStrings_QtGui[27568]
#define sipNameNr_isEquivalentTo 27583
#define sipName_isEquivalentTo &sipStrings_QtGui[27583]
#define sipNameNr_setPageMargins 27598
#define sipName_setPageMargins &sipStrings_QtGui[27598]
#define sipNameNr_PdfVersion_1_6 27613
#define sipName_PdfVersion_1_6 &sipStrings_QtGui[27613]
#define sipNameNr_PdfVersion_A1b 27628
#define sipName_PdfVersion_A1b &sipStrings_QtGui[27628]
#define sipNameNr_PdfVersion_1_4 27643
#define sipName_PdfVersion_1_4 &sipStrings_QtGui[27643]
#define sipNameNr_EnvelopeInvite 27658
#define sipName_EnvelopeInvite &sipStrings_QtGui[27658]
#define sipNameNr_DoublePostcard 27673
#define sipName_DoublePostcard &sipStrings_QtGui[27673]
#define sipNameNr_updateBehavior 27688
#define sipName_updateBehavior &sipStrings_QtGui[27688]
#define sipNameNr_UpdateBehavior 3087
#define sipName_UpdateBehavior &sipStrings_QtGui[3087]
#define sipNameNr_comparisonMode 27703
#define sipName_comparisonMode &sipStrings_QtGui[27703]
#define sipNameNr_ComparisonMode 2539
#define sipName_ComparisonMode &sipStrings_QtGui[2539]
#define sipNameNr_CompareGreater 27718
#define sipName_CompareGreater &sipStrings_QtGui[27718]
#define sipNameNr_setBorderColor 27733
#define sipName_setBorderColor &sipStrings_QtGui[27733]
#define sipNameNr_MirroredRepeat 27748
#define sipName_MirroredRepeat &sipStrings_QtGui[27748]
#define sipNameNr_setSwizzleMask 27763
#define sipName_setSwizzleMask &sipStrings_QtGui[27763]
#define sipNameNr_resetBaseLevel 27778
#define sipName_resetBaseLevel &sipStrings_QtGui[27778]
#define sipNameNr_setMipMaxLevel 27793
#define sipName_setMipMaxLevel &sipStrings_QtGui[27793]
#define sipNameNr_UInt32_RGB10A2 27808
#define sipName_UInt32_RGB10A2 &sipStrings_QtGui[27808]
#define sipNameNr_UInt32_RGB9_E5 27823
#define sipName_UInt32_RGB9_E5 &sipStrings_QtGui[27823]
#define sipNameNr_LuminanceAlpha 27838
#define sipName_LuminanceAlpha &sipStrings_QtGui[27838]
#define sipNameNr_NoSourceFormat 27853
#define sipName_NoSourceFormat &sipStrings_QtGui[27853]
#define sipNameNr_RGBA_ASTC_10x8 27868
#define sipName_RGBA_ASTC_10x8 &sipStrings_QtGui[27868]
#define sipNameNr_RGBA_ASTC_10x6 27883
#define sipName_RGBA_ASTC_10x6 &sipStrings_QtGui[27883]
#define sipNameNr_RGBA_ASTC_10x5 27898
#define sipName_RGBA_ASTC_10x5 &sipStrings_QtGui[27898]
#define sipNameNr_RGBA8_ETC2_EAC 27913
#define sipName_RGBA8_ETC2_EAC &sipStrings_QtGui[27913]
#define sipNameNr_RG11_EAC_SNorm 27928
#define sipName_RG11_EAC_SNorm &sipStrings_QtGui[27928]
#define sipNameNr_RG11_EAC_UNorm 27943
#define sipName_RG11_EAC_UNorm &sipStrings_QtGui[27943]
#define sipNameNr_RG_ATI2N_SNorm 27958
#define sipName_RG_ATI2N_SNorm &sipStrings_QtGui[27958]
#define sipNameNr_RG_ATI2N_UNorm 27973
#define sipName_RG_ATI2N_UNorm &sipStrings_QtGui[27973]
#define sipNameNr_boundTextureId 27988
#define sipName_boundTextureId &sipStrings_QtGui[27988]
#define sipNameNr_QOpenGLTexture 28003
#define sipName_QOpenGLTexture &sipStrings_QtGui[28003]
#define sipNameNr_setImageHeight 28018
#define sipName_setImageHeight &sipStrings_QtGui[28018]
#define sipNameNr_loggedMessages 28033
#define sipName_loggedMessages &sipStrings_QtGui[28033]
#define sipNameNr_enableMessages 28048
#define sipName_enableMessages &sipStrings_QtGui[28048]
#define sipNameNr_MediumSeverity 28063
#define sipName_MediumSeverity &sipStrings_QtGui[28063]
#define sipNameNr_versionProfile 28078
#define sipName_versionProfile &sipStrings_QtGui[28078]
#define sipNameNr_currentContext 28093
#define sipName_currentContext &sipStrings_QtGui[28093]
#define sipNameNr_getProcAddress 28108
#define sipName_getProcAddress &sipStrings_QtGui[28108]
#define sipNameNr_QOpenGLContext 28123
#define sipName_QOpenGLContext &sipStrings_QtGui[28123]
#define sipNameNr_nextFrameDelay 28138
#define sipName_nextFrameDelay &sipStrings_QtGui[28138]
#define sipNameNr_listFromString 28153
#define sipName_listFromString &sipStrings_QtGui[28153]
#define sipNameNr_SelectNextPage 28168
#define sipName_SelectNextPage &sipStrings_QtGui[28168]
#define sipNameNr_SelectNextLine 28183
#define sipName_SelectNextLine &sipStrings_QtGui[28183]
#define sipNameNr_SelectNextWord 28198
#define sipName_SelectNextWord &sipStrings_QtGui[28198]
#define sipNameNr_SelectNextChar 28213
#define sipName_SelectNextChar &sipStrings_QtGui[28213]
#define sipNameNr_MoveToNextPage 28228
#define sipName_MoveToNextPage &sipStrings_QtGui[28228]
#define sipNameNr_MoveToNextLine 28243
#define sipName_MoveToNextLine &sipStrings_QtGui[28243]
#define sipNameNr_MoveToNextWord 28258
#define sipName_MoveToNextWord &sipStrings_QtGui[28258]
#define sipNameNr_MoveToNextChar 28273
#define sipName_MoveToNextChar &sipStrings_QtGui[28273]
#define sipNameNr_SequenceFormat 4032
#define sipName_SequenceFormat &sipStrings_QtGui[4032]
#define sipNameNr_visibleChanged 28288
#define sipName_visibleChanged &sipStrings_QtGui[28288]
#define sipNameNr_inputDirection 28303
#define sipName_inputDirection &sipStrings_QtGui[28303]
#define sipNameNr_optimizedWrite 28318
#define sipName_optimizedWrite &sipStrings_QtGui[28318]
#define sipNameNr_setCompression 28333
#define sipName_setCompression &sipStrings_QtGui[28333]
#define sipNameNr_transformation 28348
#define sipName_transformation &sipStrings_QtGui[28348]
#define sipNameNr_scaledClipRect 28363
#define sipName_scaledClipRect &sipStrings_QtGui[28363]
#define sipNameNr_Transformation 2229
#define sipName_Transformation &sipStrings_QtGui[2229]
#define sipNameNr_nextImageDelay 28378
#define sipName_nextImageDelay &sipStrings_QtGui[28378]
#define sipNameNr_supportsOption 28393
#define sipName_supportsOption &sipStrings_QtGui[28393]
#define sipNameNr_OptimizedWrite 19633
#define sipName_OptimizedWrite &sipStrings_QtGui[19633]
#define sipNameNr_ScaledClipRect 19705
#define sipName_ScaledClipRect &sipStrings_QtGui[19705]
#define sipNameNr_scaledToHeight 28408
#define sipName_scaledToHeight &sipStrings_QtGui[28408]
#define sipNameNr_Format_MonoLSB 28423
#define sipName_Format_MonoLSB &sipStrings_QtGui[28423]
#define sipNameNr_Format_Invalid 28438
#define sipName_Format_Invalid &sipStrings_QtGui[28438]
#define sipNameNr_QImage__Format 28453
#define sipName_QImage__Format &sipStrings_QtGui[28453]
#define sipNameNr_IconEngineHook 4822
#define sipName_IconEngineHook &sipStrings_QtGui[4822]
#define sipNameNr_availableSizes 28468
#define sipName_availableSizes &sipStrings_QtGui[28468]
#define sipNameNr_paletteChanged 28483
#define sipName_paletteChanged &sipStrings_QtGui[28483]
#define sipNameNr_overrideCursor 28498
#define sipName_overrideCursor &sipStrings_QtGui[28498]
#define sipNameNr_setRightToLeft 28513
#define sipName_setRightToLeft &sipStrings_QtGui[28513]
#define sipNameNr_minLeftBearing 28528
#define sipName_minLeftBearing &sipStrings_QtGui[28528]
#define sipNameNr_writingSystems 28543
#define sipName_writingSystems &sipStrings_QtGui[28543]
#define sipNameNr_capitalization 28558
#define sipName_capitalization &sipStrings_QtGui[28558]
#define sipNameNr_setWordSpacing 28573
#define sipName_setWordSpacing &sipStrings_QtGui[28573]
#define sipNameNr_Capitalization 10103
#define sipName_Capitalization &sipStrings_QtGui[10103]
#define sipNameNr_lastResortFont 28588
#define sipName_lastResortFont &sipStrings_QtGui[28588]
#define sipNameNr_ExtraCondensed 28603
#define sipName_ExtraCondensed &sipStrings_QtGui[28603]
#define sipNameNr_UltraCondensed 28618
#define sipName_UltraCondensed &sipStrings_QtGui[28618]
#define sipNameNr_QFont__Stretch 28633
#define sipName_QFont__Stretch &sipStrings_QtGui[28633]
#define sipNameNr_SurfaceCreated 28648
#define sipName_SurfaceCreated &sipStrings_QtGui[28648]
#define sipNameNr_ScrollFinished 28663
#define sipName_ScrollFinished &sipStrings_QtGui[28663]
#define sipNameNr_startScreenPos 28678
#define sipName_startScreenPos &sipStrings_QtGui[28678]
#define sipNameNr_QShortcutEvent 28693
#define sipName_QShortcutEvent &sipStrings_QtGui[28693]
#define sipNameNr_QFileOpenEvent 28708
#define sipName_QFileOpenEvent &sipStrings_QtGui[28708]
#define sipNameNr_QDragMoveEvent 28723
#define sipName_QDragMoveEvent &sipStrings_QtGui[28723]
#define sipNameNr_proposedAction 28738
#define sipName_proposedAction &sipStrings_QtGui[28738]
#define sipNameNr_QIconDragEvent 28753
#define sipName_QIconDragEvent &sipStrings_QtGui[28753]
#define sipNameNr_nativeScanCode 28768
#define sipName_nativeScanCode &sipStrings_QtGui[28768]
#define sipNameNr_UnknownPointer 28783
#define sipName_UnknownPointer &sipStrings_QtGui[28783]
#define sipNameNr_RotationStylus 28798
#define sipName_RotationStylus &sipStrings_QtGui[28798]
#define sipNameNr_globalPosition 28813
#define sipName_globalPosition &sipStrings_QtGui[28813]
#define sipNameNr_fromIccProfile 28828
#define sipName_fromIccProfile &sipStrings_QtGui[28828]
#define sipNameNr_ownsFindBuffer 28843
#define sipName_ownsFindBuffer &sipStrings_QtGui[28843]
#define sipNameNr_setFocalRadius 28858
#define sipName_setFocalRadius &sipStrings_QtGui[28858]
#define sipNameNr_coordinateMode 28873
#define sipName_coordinateMode &sipStrings_QtGui[28873]
#define sipNameNr_StrictNovember 28888
#define sipName_StrictNovember &sipStrings_QtGui[28888]
#define sipNameNr_SleeplessNight 28903
#define sipName_SleeplessNight &sipStrings_QtGui[28903]
#define sipNameNr_MillenniumPine 28918
#define sipName_MillenniumPine &sipStrings_QtGui[28918]
#define sipNameNr_ConfidentCloud 28933
#define sipName_ConfidentCloud &sipStrings_QtGui[28933]
#define sipNameNr_OctoberSilence 28948
#define sipName_OctoberSilence &sipStrings_QtGui[28948]
#define sipNameNr_PurpleDivision 28963
#define sipName_PurpleDivision &sipStrings_QtGui[28963]
#define sipNameNr_EverlastingSky 28978
#define sipName_EverlastingSky &sipStrings_QtGui[28978]
#define sipNameNr_RadialGradient 25754
#define sipName_RadialGradient &sipStrings_QtGui[25754]
#define sipNameNr_LinearGradient 25770
#define sipName_LinearGradient &sipStrings_QtGui[25770]
#define sipNameNr_CoordinateMode 6540
#define sipName_CoordinateMode &sipStrings_QtGui[6540]
#define sipNameNr_mediumseagreen 28993
#define sipName_mediumseagreen &sipStrings_QtGui[28993]
#define sipNameNr_lightsteelblue 29008
#define sipName_lightsteelblue &sipStrings_QtGui[29008]
#define sipNameNr_lightslategrey 29023
#define sipName_lightslategrey &sipStrings_QtGui[29023]
#define sipNameNr_lightslategray 29038
#define sipName_lightslategray &sipStrings_QtGui[29038]
#define sipNameNr_darkolivegreen 29053
#define sipName_darkolivegreen &sipStrings_QtGui[29053]
#define sipNameNr_cornflowerblue 29068
#define sipName_cornflowerblue &sipStrings_QtGui[29068]
#define sipNameNr_blanchedalmond 29083
#define sipName_blanchedalmond &sipStrings_QtGui[29083]
#define sipNameNr_hslSaturationF 29098
#define sipName_hslSaturationF &sipStrings_QtGui[29098]
#define sipNameNr_hsvSaturationF 29113
#define sipName_hsvSaturationF &sipStrings_QtGui[29113]
#define sipNameNr_staticContents 29128
#define sipName_staticContents &sipStrings_QtGui[29128]
#define sipNameNr_setPaintDevice 29143
#define sipName_setPaintDevice &sipStrings_QtGui[29143]
#define sipNameNr_cursorPosition 29158
#define sipName_cursorPosition &sipStrings_QtGui[29158]
#define sipNameNr_clearSelection 29173
#define sipName_clearSelection &sipStrings_QtGui[29173]
#define sipNameNr_setDescription 29188
#define sipName_setDescription &sipStrings_QtGui[29188]
#define sipNameNr_DashDotDotLine 29203
#define sipName_DashDotDotLine &sipStrings_QtGui[29203]
#define sipNameNr_29218 29218
#define sipName_29218 &sipStrings_QtGui[29218]
#define sipNameNr_setVisibility 29232
#define sipName_setVisibility &sipStrings_QtGui[29232]
#define sipNameNr_keyPressEvent 29246
#define sipName_keyPressEvent &sipStrings_QtGui[29246]
#define sipNameNr_focusOutEvent 29260
#define sipName_focusOutEvent &sipStrings_QtGui[29260]
#define sipNameNr_heightChanged 29274
#define sipName_heightChanged &sipStrings_QtGui[29274]
#define sipNameNr_requestUpdate 29288
#define sipName_requestUpdate &sipStrings_QtGui[29288]
#define sipNameNr_showMaximized 29302
#define sipName_showMaximized &sipStrings_QtGui[29302]
#define sipNameNr_showMinimized 29316
#define sipName_showMinimized &sipStrings_QtGui[29316]
#define sipNameNr_mapFromGlobal 29330
#define sipName_mapFromGlobal &sipStrings_QtGui[29330]
#define sipNameNr_framePosition 29344
#define sipName_framePosition &sipStrings_QtGui[29344]
#define sipNameNr_frameGeometry 29358
#define sipName_frameGeometry &sipStrings_QtGui[29358]
#define sipNameNr_sizeIncrement 29372
#define sipName_sizeIncrement &sipStrings_QtGui[29372]
#define sipNameNr_maximumHeight 29386
#define sipName_maximumHeight &sipStrings_QtGui[29386]
#define sipNameNr_minimumHeight 29400
#define sipName_minimumHeight &sipStrings_QtGui[29400]
#define sipNameNr_QIntValidator 29414
#define sipName_QIntValidator &sipStrings_QtGui[29414]
#define sipNameNr_fromTranslate 29428
#define sipName_fromTranslate &sipStrings_QtGui[29428]
#define sipNameNr_isTranslating 29442
#define sipName_isTranslating &sipStrings_QtGui[29442]
#define sipNameNr_rotateRadians 29456
#define sipName_rotateRadians &sipStrings_QtGui[29456]
#define sipNameNr_appendColumns 29470
#define sipName_appendColumns &sipStrings_QtGui[29470]
#define sipNameNr_QTextFragment 29484
#define sipName_QTextFragment &sipStrings_QtGui[29484]
#define sipNameNr_firstPosition 29498
#define sipName_firstPosition &sipStrings_QtGui[29498]
#define sipNameNr_blockInserted 29512
#define sipName_blockInserted &sipStrings_QtGui[29512]
#define sipNameNr_setNumColumns 29526
#define sipName_setNumColumns &sipStrings_QtGui[29526]
#define sipNameNr_setLeftBorder 29540
#define sipName_setLeftBorder &sipStrings_QtGui[29540]
#define sipNameNr_bottomPadding 29554
#define sipName_bottomPadding &sipStrings_QtGui[29554]
#define sipNameNr_setTopPadding 29568
#define sipName_setTopPadding &sipStrings_QtGui[29568]
#define sipNameNr_setLineHeight 29582
#define sipName_setLineHeight &sipStrings_QtGui[29582]
#define sipNameNr_MinimumHeight 20403
#define sipName_MinimumHeight &sipStrings_QtGui[20403]
#define sipNameNr_setTextIndent 29596
#define sipName_setTextIndent &sipStrings_QtGui[29596]
#define sipNameNr_fontStyleName 29610
#define sipName_fontStyleName &sipStrings_QtGui[29610]
#define sipNameNr_fontStyleHint 29624
#define sipName_fontStyleHint &sipStrings_QtGui[29624]
#define sipNameNr_WaveUnderline 29638
#define sipName_WaveUnderline &sipStrings_QtGui[29638]
#define sipNameNr_DashUnderline 29652
#define sipName_DashUnderline &sipStrings_QtGui[29652]
#define sipNameNr_setAnchorHref 29666
#define sipName_setAnchorHref &sipStrings_QtGui[29666]
#define sipNameNr_fontStrikeOut 29680
#define sipName_fontStrikeOut &sipStrings_QtGui[29680]
#define sipNameNr_fontUnderline 29694
#define sipName_fontUnderline &sipStrings_QtGui[29694]
#define sipNameNr_setFontItalic 29708
#define sipName_setFontItalic &sipStrings_QtGui[29708]
#define sipNameNr_setFontWeight 29722
#define sipName_setFontWeight &sipStrings_QtGui[29722]
#define sipNameNr_fontPointSize 29736
#define sipName_fontPointSize &sipStrings_QtGui[29736]
#define sipNameNr_setFontFamily 29750
#define sipName_setFontFamily &sipStrings_QtGui[29750]
#define sipNameNr_setObjectType 29764
#define sipName_setObjectType &sipStrings_QtGui[29764]
#define sipNameNr_toFrameFormat 29778
#define sipName_toFrameFormat &sipStrings_QtGui[29778]
#define sipNameNr_toTableFormat 29792
#define sipName_toTableFormat &sipStrings_QtGui[29792]
#define sipNameNr_toBlockFormat 29806
#define sipName_toBlockFormat &sipStrings_QtGui[29806]
#define sipNameNr_isTableFormat 29820
#define sipName_isTableFormat &sipStrings_QtGui[29820]
#define sipNameNr_isImageFormat 29834
#define sipName_isImageFormat &sipStrings_QtGui[29834]
#define sipNameNr_isFrameFormat 29848
#define sipName_isFrameFormat &sipStrings_QtGui[29848]
#define sipNameNr_isBlockFormat 29862
#define sipName_isBlockFormat &sipStrings_QtGui[29862]
#define sipNameNr_brushProperty 29876
#define sipName_brushProperty &sipStrings_QtGui[29876]
#define sipNameNr_colorProperty 29890
#define sipName_colorProperty &sipStrings_QtGui[29890]
#define sipNameNr_clearProperty 29904
#define sipName_clearProperty &sipStrings_QtGui[29904]
#define sipNameNr_FontStyleName 20743
#define sipName_FontStyleName &sipStrings_QtGui[20743]
#define sipNameNr_FontStyleHint 20760
#define sipName_FontStyleHint &sipStrings_QtGui[20760]
#define sipNameNr_FontPixelSize 29918
#define sipName_FontPixelSize &sipStrings_QtGui[29918]
#define sipNameNr_FontStrikeOut 20794
#define sipName_FontStrikeOut &sipStrings_QtGui[20794]
#define sipNameNr_FontUnderline 20811
#define sipName_FontUnderline &sipStrings_QtGui[20811]
#define sipNameNr_FontPointSize 20828
#define sipName_FontPointSize &sipStrings_QtGui[20828]
#define sipNameNr_PageBreakFlag 5040
#define sipName_PageBreakFlag &sipStrings_QtGui[5040]
#define sipNameNr_fromPlainText 29932
#define sipName_fromPlainText &sipStrings_QtGui[29932]
#define sipNameNr_undoAvailable 29946
#define sipName_undoAvailable &sipStrings_QtGui[29946]
#define sipNameNr_redoAvailable 29960
#define sipName_redoAvailable &sipStrings_QtGui[29960]
#define sipNameNr_ImageResource 29974
#define sipName_ImageResource &sipStrings_QtGui[29974]
#define sipNameNr_DocumentTitle 29988
#define sipName_DocumentTitle &sipStrings_QtGui[29988]
#define sipNameNr_QTextDocument 30002
#define sipName_QTextDocument &sipStrings_QtGui[30002]
#define sipNameNr_setCharFormat 30016
#define sipName_setCharFormat &sipStrings_QtGui[30016]
#define sipNameNr_SelectionType 5067
#define sipName_SelectionType &sipStrings_QtGui[5067]
#define sipNameNr_NextCharacter 30030
#define sipName_NextCharacter &sipStrings_QtGui[30030]
#define sipNameNr_PreviousBlock 30044
#define sipName_PreviousBlock &sipStrings_QtGui[30044]
#define sipNameNr_MoveOperation 5094
#define sipName_MoveOperation &sipStrings_QtGui[5094]
#define sipNameNr_redBufferSize 30058
#define sipName_redBufferSize &sipStrings_QtGui[30058]
#define sipNameNr_FormatOptions 2878
#define sipName_FormatOptions &sipStrings_QtGui[2878]
#define sipNameNr_StereoBuffers 30072
#define sipName_StereoBuffers &sipStrings_QtGui[30072]
#define sipNameNr_VulkanSurface 30086
#define sipName_VulkanSurface &sipStrings_QtGui[30086]
#define sipNameNr_OpenVGSurface 30100
#define sipName_OpenVGSurface &sipStrings_QtGui[30100]
#define sipNameNr_OpenGLSurface 30114
#define sipName_OpenGLSurface &sipStrings_QtGui[30114]
#define sipNameNr_RasterSurface 30128
#define sipName_RasterSurface &sipStrings_QtGui[30128]
#define sipNameNr_startDragTime 30142
#define sipName_startDragTime &sipStrings_QtGui[30142]
#define sipNameNr_setTextOption 30156
#define sipName_setTextOption &sipStrings_QtGui[30156]
#define sipNameNr_setTextFormat 30170
#define sipName_setTextFormat &sipStrings_QtGui[30170]
#define sipNameNr_setCheckState 30184
#define sipName_setCheckState &sipStrings_QtGui[30184]
#define sipNameNr_setForeground 30198
#define sipName_setForeground &sipStrings_QtGui[30198]
#define sipNameNr_isDropEnabled 30212
#define sipName_isDropEnabled &sipStrings_QtGui[30212]
#define sipNameNr_isDragEnabled 30226
#define sipName_isDragEnabled &sipStrings_QtGui[30226]
#define sipNameNr_setSelectable 30240
#define sipName_setSelectable &sipStrings_QtGui[30240]
#define sipNameNr_textAlignment 30254
#define sipName_textAlignment &sipStrings_QtGui[30254]
#define sipNameNr_QStandardItem 30268
#define sipName_QStandardItem &sipStrings_QtGui[30268]
#define sipNameNr_clearItemData 30282
#define sipName_clearItemData &sipStrings_QtGui[30282]
#define sipNameNr_itemPrototype 30296
#define sipName_itemPrototype &sipStrings_QtGui[30296]
#define sipNameNr_indexFromItem 30310
#define sipName_indexFromItem &sipStrings_QtGui[30310]
#define sipNameNr_itemFromIndex 30324
#define sipName_itemFromIndex &sipStrings_QtGui[30324]
#define sipNameNr_availableSize 30338
#define sipName_availableSize &sipStrings_QtGui[30338]
#define sipNameNr_isTransparent 30352
#define sipName_isTransparent &sipStrings_QtGui[30352]
#define sipNameNr_lineThickness 30366
#define sipName_lineThickness &sipStrings_QtGui[30366]
#define sipNameNr_QRasterWindow 30380
#define sipName_QRasterWindow &sipStrings_QtGui[30380]
#define sipNameNr_toEulerAngles 30394
#define sipName_toEulerAngles &sipStrings_QtGui[30394]
#define sipNameNr_fromDirection 30408
#define sipName_fromDirection &sipStrings_QtGui[30408]
#define sipNameNr_rotatedVector 30422
#define sipName_rotatedVector &sipStrings_QtGui[30422]
#define sipNameNr_lengthSquared 30436
#define sipName_lengthSquared &sipStrings_QtGui[30436]
#define sipNameNr_containsPoint 30450
#define sipName_containsPoint &sipStrings_QtGui[30450]
#define sipNameNr_setCacheLimit 30464
#define sipName_setCacheLimit &sipStrings_QtGui[30464]
#define sipNameNr_premultiplied 24011
#define sipName_premultiplied &sipStrings_QtGui[24011]
#define sipNameNr_alphaPosition 30478
#define sipName_alphaPosition &sipStrings_QtGui[30478]
#define sipNameNr_lightnessSize 30492
#define sipName_lightnessSize &sipStrings_QtGui[30492]
#define sipNameNr_FloatingPoint 30506
#define sipName_FloatingPoint &sipStrings_QtGui[30506]
#define sipNameNr_UnsignedShort 30520
#define sipName_UnsignedShort &sipStrings_QtGui[30520]
#define sipNameNr_Premultiplied 1255
#define sipName_Premultiplied &sipStrings_QtGui[1255]
#define sipNameNr_AlphaPosition 4431
#define sipName_AlphaPosition &sipStrings_QtGui[4431]
#define sipNameNr_outputFormats 30534
#define sipName_outputFormats &sipStrings_QtGui[30534]
#define sipNameNr_pictureFormat 30548
#define sipName_pictureFormat &sipStrings_QtGui[30548]
#define sipNameNr_setParameters 30562
#define sipName_setParameters &sipStrings_QtGui[30562]
#define sipNameNr_formatVersion 30576
#define sipName_formatVersion &sipStrings_QtGui[30576]
#define sipNameNr_setPdfVersion 30590
#define sipName_setPdfVersion &sipStrings_QtGui[30590]
#define sipNameNr_setResolution 30604
#define sipName_setResolution &sipStrings_QtGui[30604]
#define sipNameNr_alternateBase 30618
#define sipName_alternateBase &sipStrings_QtGui[30618]
#define sipNameNr_setColorGroup 30632
#define sipName_setColorGroup &sipStrings_QtGui[30632]
#define sipNameNr_AlternateBase 30646
#define sipName_AlternateBase &sipStrings_QtGui[30646]
#define sipNameNr_setDashOffset 30660
#define sipName_setDashOffset &sipStrings_QtGui[30660]
#define sipNameNr_setMiterLimit 30674
#define sipName_setMiterLimit &sipStrings_QtGui[30674]
#define sipNameNr_toFillPolygon 30688
#define sipName_toFillPolygon &sipStrings_QtGui[30688]
#define sipNameNr_LineToElement 30702
#define sipName_LineToElement &sipStrings_QtGui[30702]
#define sipNameNr_MoveToElement 30716
#define sipName_MoveToElement &sipStrings_QtGui[30716]
#define sipNameNr_isClipEnabled 30730
#define sipName_isClipEnabled &sipStrings_QtGui[30730]
#define sipNameNr_clipOperation 30744
#define sipName_clipOperation &sipStrings_QtGui[30744]
#define sipNameNr_QWindowSystem 30758
#define sipName_QWindowSystem &sipStrings_QtGui[30758]
#define sipNameNr_DirtyClipPath 30772
#define sipName_DirtyClipPath &sipStrings_QtGui[30772]
#define sipNameNr_RasterOpModes 30786
#define sipName_RasterOpModes &sipStrings_QtGui[30786]
#define sipNameNr_setRenderHint 30800
#define sipName_setRenderHint &sipStrings_QtGui[30800]
#define sipNameNr_setClipRegion 30814
#define sipName_setClipRegion &sipStrings_QtGui[30814]
#define sipNameNr_setBackground 30828
#define sipName_setBackground &sipStrings_QtGui[30828]
#define sipNameNr_marginsPixels 30842
#define sipName_marginsPixels &sipStrings_QtGui[30842]
#define sipNameNr_marginsPoints 30856
#define sipName_marginsPoints &sipStrings_QtGui[30856]
#define sipNameNr_setLeftMargin 30870
#define sipName_setLeftMargin &sipStrings_QtGui[30870]
#define sipNameNr_setPageLayout 30884
#define sipName_setPageLayout &sipStrings_QtGui[30884]
#define sipNameNr_setPageSizeMM 30898
#define sipName_setPageSizeMM &sipStrings_QtGui[30898]
#define sipNameNr_EnvelopePrc10 30912
#define sipName_EnvelopePrc10 &sipStrings_QtGui[30912]
#define sipNameNr_EnvelopeKaku3 30926
#define sipName_EnvelopeKaku3 &sipStrings_QtGui[30926]
#define sipNameNr_EnvelopeKaku2 30940
#define sipName_EnvelopeKaku2 &sipStrings_QtGui[30940]
#define sipNameNr_EnvelopeChou4 30954
#define sipName_EnvelopeChou4 &sipStrings_QtGui[30954]
#define sipNameNr_EnvelopeChou3 30968
#define sipName_EnvelopeChou3 &sipStrings_QtGui[30968]
#define sipNameNr_FanFoldGerman 30982
#define sipName_FanFoldGerman &sipStrings_QtGui[30982]
#define sipNameNr_Imperial15x11 30996
#define sipName_Imperial15x11 &sipStrings_QtGui[30996]
#define sipNameNr_Imperial12x11 31010
#define sipName_Imperial12x11 &sipStrings_QtGui[31010]
#define sipNameNr_Imperial10x14 31024
#define sipName_Imperial10x14 &sipStrings_QtGui[31024]
#define sipNameNr_Imperial10x13 31038
#define sipName_Imperial10x13 &sipStrings_QtGui[31038]
#define sipNameNr_Imperial10x11 31052
#define sipName_Imperial10x11 &sipStrings_QtGui[31052]
#define sipNameNr_QOpenGLWindow 31066
#define sipName_QOpenGLWindow &sipStrings_QtGui[31066]
#define sipNameNr_OriginTopLeft 31080
#define sipName_OriginTopLeft &sipStrings_QtGui[31080]
#define sipNameNr_CompareAlways 31094
#define sipName_CompareAlways &sipStrings_QtGui[31094]
#define sipNameNr_ClampToBorder 31108
#define sipName_ClampToBorder &sipStrings_QtGui[31108]
#define sipNameNr_minMagFilters 31122
#define sipName_minMagFilters &sipStrings_QtGui[31122]
#define sipNameNr_mipLevelRange 31136
#define sipName_mipLevelRange &sipStrings_QtGui[31136]
#define sipNameNr_TextureBuffer 31150
#define sipName_TextureBuffer &sipStrings_QtGui[31150]
#define sipNameNr_TextureArrays 31164
#define sipName_TextureArrays &sipStrings_QtGui[31164]
#define sipNameNr_UInt16_R5G6B5 31178
#define sipName_UInt16_R5G6B5 &sipStrings_QtGui[31178]
#define sipNameNr_UInt16_RGB5A1 31192
#define sipName_UInt16_RGB5A1 &sipStrings_QtGui[31192]
#define sipNameNr_isTextureView 31206
#define sipName_isTextureView &sipStrings_QtGui[31206]
#define sipNameNr_RGBA_ASTC_8x8 31220
#define sipName_RGBA_ASTC_8x8 &sipStrings_QtGui[31220]
#define sipNameNr_RGBA_ASTC_8x6 31234
#define sipName_RGBA_ASTC_8x6 &sipStrings_QtGui[31234]
#define sipNameNr_RGBA_ASTC_8x5 31248
#define sipName_RGBA_ASTC_8x5 &sipStrings_QtGui[31248]
#define sipNameNr_RGBA_ASTC_6x6 31262
#define sipName_RGBA_ASTC_6x6 &sipStrings_QtGui[31262]
#define sipNameNr_RGBA_ASTC_6x5 31276
#define sipName_RGBA_ASTC_6x5 &sipStrings_QtGui[31276]
#define sipNameNr_RGBA_ASTC_5x5 31290
#define sipName_RGBA_ASTC_5x5 &sipStrings_QtGui[31290]
#define sipNameNr_RGBA_ASTC_5x4 31304
#define sipName_RGBA_ASTC_5x4 &sipStrings_QtGui[31304]
#define sipNameNr_RGBA_ASTC_4x4 31318
#define sipName_RGBA_ASTC_4x4 &sipStrings_QtGui[31318]
#define sipNameNr_R11_EAC_SNorm 31332
#define sipName_R11_EAC_SNorm &sipStrings_QtGui[31332]
#define sipNameNr_R11_EAC_UNorm 31346
#define sipName_R11_EAC_UNorm &sipStrings_QtGui[31346]
#define sipNameNr_SRGB_BP_UNorm 31360
#define sipName_SRGB_BP_UNorm &sipStrings_QtGui[31360]
#define sipNameNr_R_ATI1N_SNorm 31374
#define sipName_R_ATI1N_SNorm &sipStrings_QtGui[31374]
#define sipNameNr_R_ATI1N_UNorm 31388
#define sipName_R_ATI1N_UNorm &sipStrings_QtGui[31388]
#define sipNameNr_TextureFormat 3178
#define sipName_TextureFormat &sipStrings_QtGui[3178]
#define sipNameNr_BindingTarget 3208
#define sipName_BindingTarget &sipStrings_QtGui[3208]
#define sipNameNr_TargetCubeMap 12797
#define sipName_TargetCubeMap &sipStrings_QtGui[12797]
#define sipNameNr_Target2DArray 12818
#define sipName_Target2DArray &sipStrings_QtGui[12818]
#define sipNameNr_Target1DArray 12839
#define sipName_Target1DArray &sipStrings_QtGui[12839]
#define sipNameNr_ShaderTypeBit 3946
#define sipName_ShaderTypeBit &sipStrings_QtGui[3946]
#define sipNameNr_QOpenGLShader 31402
#define sipName_QOpenGLShader &sipStrings_QtGui[31402]
#define sipNameNr_setSkipPixels 31416
#define sipName_setSkipPixels &sipStrings_QtGui[31416]
#define sipNameNr_setSkipImages 31430
#define sipName_setSkipImages &sipStrings_QtGui[31430]
#define sipNameNr_textureTarget 31444
#define sipName_textureTarget &sipStrings_QtGui[31444]
#define sipNameNr_setAttachment 31458
#define sipName_setAttachment &sipStrings_QtGui[31458]
#define sipNameNr_messageLogged 31472
#define sipName_messageLogged &sipStrings_QtGui[31472]
#define sipNameNr_GroupPushType 31486
#define sipName_GroupPushType &sipStrings_QtGui[31486]
#define sipNameNr_InvalidSource 31500
#define sipName_InvalidSource &sipStrings_QtGui[31500]
#define sipNameNr_QOpenGLBuffer 31514
#define sipName_QOpenGLBuffer &sipStrings_QtGui[31514]
#define sipNameNr_screenChanged 31528
#define sipName_screenChanged &sipStrings_QtGui[31528]
#define sipNameNr_currentPixmap 31542
#define sipName_currentPixmap &sipStrings_QtGui[31542]
#define sipNameNr_PreviousChild 31556
#define sipName_PreviousChild &sipStrings_QtGui[31556]
#define sipNameNr_SequenceMatch 4739
#define sipName_SequenceMatch &sipStrings_QtGui[4739]
#define sipNameNr_localeChanged 31570
#define sipName_localeChanged &sipStrings_QtGui[31570]
#define sipNameNr_autoTransform 31584
#define sipName_autoTransform &sipStrings_QtGui[31584]
#define sipNameNr_setScaledSize 31598
#define sipName_setScaledSize &sipStrings_QtGui[31598]
#define sipNameNr_setColorSpace 31612
#define sipName_setColorSpace &sipStrings_QtGui[31612]
#define sipNameNr_setPixelColor 31626
#define sipName_setPixelColor &sipStrings_QtGui[31626]
#define sipNameNr_toImageFormat 31640
#define sipName_toImageFormat &sipStrings_QtGui[31640]
#define sipNameNr_toPixelFormat 31654
#define sipName_toPixelFormat &sipStrings_QtGui[31654]
#define sipNameNr_bitPlaneCount 31668
#define sipName_bitPlaneCount &sipStrings_QtGui[31668]
#define sipNameNr_setColorCount 31682
#define sipName_setColorCount &sipStrings_QtGui[31682]
#define sipNameNr_dotsPerMeterY 31696
#define sipName_dotsPerMeterY &sipStrings_QtGui[31696]
#define sipNameNr_dotsPerMeterX 31710
#define sipName_dotsPerMeterX &sipStrings_QtGui[31710]
#define sipNameNr_scaledToWidth 31724
#define sipName_scaledToWidth &sipStrings_QtGui[31724]
#define sipNameNr_transformMode 31738
#define sipName_transformMode &sipStrings_QtGui[31738]
#define sipNameNr_setColorTable 31752
#define sipName_setColorTable &sipStrings_QtGui[31752]
#define sipNameNr_constScanLine 31766
#define sipName_constScanLine &sipStrings_QtGui[31766]
#define sipNameNr_Format_BGR888 31780
#define sipName_Format_BGR888 &sipStrings_QtGui[31780]
#define sipNameNr_Format_RGBA64 31794
#define sipName_Format_RGBA64 &sipStrings_QtGui[31794]
#define sipNameNr_Format_RGBX64 31808
#define sipName_Format_RGBX64 &sipStrings_QtGui[31808]
#define sipNameNr_Format_Alpha8 31822
#define sipName_Format_Alpha8 &sipStrings_QtGui[31822]
#define sipNameNr_Format_RGB444 31836
#define sipName_Format_RGB444 &sipStrings_QtGui[31836]
#define sipNameNr_Format_RGB888 31850
#define sipName_Format_RGB888 &sipStrings_QtGui[31850]
#define sipNameNr_Format_RGB555 31864
#define sipName_Format_RGB555 &sipStrings_QtGui[31864]
#define sipNameNr_Format_RGB666 31878
#define sipName_Format_RGB666 &sipStrings_QtGui[31878]
#define sipNameNr_Format_ARGB32 31892
#define sipName_Format_ARGB32 &sipStrings_QtGui[31892]
#define sipNameNr_screenRemoved 31906
#define sipName_screenRemoved &sipStrings_QtGui[31906]
#define sipNameNr_setWindowIcon 31920
#define sipName_setWindowIcon &sipStrings_QtGui[31920]
#define sipNameNr_isLeftToRight 31934
#define sipName_isLeftToRight &sipStrings_QtGui[31934]
#define sipNameNr_primaryScreen 31948
#define sipName_primaryScreen &sipStrings_QtGui[31948]
#define sipNameNr_isRightToLeft 31962
#define sipName_isRightToLeft &sipStrings_QtGui[31962]
#define sipNameNr_GlyphRunFlags 7466
#define sipName_GlyphRunFlags &sipStrings_QtGui[7466]
#define sipNameNr_SplitLigature 31976
#define sipName_SplitLigature &sipStrings_QtGui[31976]
#define sipNameNr_setToIdentity 31990
#define sipName_setToIdentity &sipStrings_QtGui[31990]
#define sipNameNr_QFontMetricsF 32004
#define sipName_QFontMetricsF &sipStrings_QtGui[32004]
#define sipNameNr_writingSystem 32018
#define sipName_writingSystem &sipStrings_QtGui[32018]
#define sipNameNr_standardSizes 32032
#define sipName_standardSizes &sipStrings_QtGui[32032]
#define sipNameNr_WritingSystem 4149
#define sipName_WritingSystem &sipStrings_QtGui[4149]
#define sipNameNr_QFontDatabase 32046
#define sipName_QFontDatabase &sipStrings_QtGui[32046]
#define sipNameNr_letterSpacing 32060
#define sipName_letterSpacing &sipStrings_QtGui[32060]
#define sipNameNr_defaultFamily 32074
#define sipName_defaultFamily &sipStrings_QtGui[32074]
#define sipNameNr_substitutions 32088
#define sipName_substitutions &sipStrings_QtGui[32088]
#define sipNameNr_styleStrategy 32102
#define sipName_styleStrategy &sipStrings_QtGui[32102]
#define sipNameNr_setFixedPitch 32116
#define sipName_setFixedPitch &sipStrings_QtGui[32116]
#define sipNameNr_setPointSizeF 32130
#define sipName_setPointSizeF &sipStrings_QtGui[32130]
#define sipNameNr_UltraExpanded 32144
#define sipName_UltraExpanded &sipStrings_QtGui[32144]
#define sipNameNr_ExtraExpanded 32158
#define sipName_ExtraExpanded &sipStrings_QtGui[32158]
#define sipNameNr_SemiCondensed 32172
#define sipName_SemiCondensed &sipStrings_QtGui[32172]
#define sipNameNr_QFont__Weight 32186
#define sipName_QFont__Weight &sipStrings_QtGui[32186]
#define sipNameNr_NoFontMerging 32200
#define sipName_NoFontMerging &sipStrings_QtGui[32200]
#define sipNameNr_PreferQuality 32214
#define sipName_PreferQuality &sipStrings_QtGui[32214]
#define sipNameNr_PreferOutline 32228
#define sipName_PreferOutline &sipStrings_QtGui[32228]
#define sipNameNr_PreferDefault 32242
#define sipName_PreferDefault &sipStrings_QtGui[32242]
#define sipNameNr_StyleStrategy 11936
#define sipName_StyleStrategy &sipStrings_QtGui[11936]
#define sipNameNr_fromNumericId 32256
#define sipName_fromNumericId &sipStrings_QtGui[32256]
#define sipNameNr_ScrollUpdated 32270
#define sipName_ScrollUpdated &sipStrings_QtGui[32270]
#define sipNameNr_ScrollStarted 32284
#define sipName_ScrollStarted &sipStrings_QtGui[32284]
#define sipNameNr_setContentPos 32298
#define sipName_setContentPos &sipStrings_QtGui[32298]
#define sipNameNr_normalizedPos 32312
#define sipName_normalizedPos &sipStrings_QtGui[32312]
#define sipNameNr_lastScreenPos 32326
#define sipName_lastScreenPos &sipStrings_QtGui[32326]
#define sipNameNr_startScenePos 32340
#define sipName_startScenePos &sipStrings_QtGui[32340]
#define sipNameNr_setDropAction 32354
#define sipName_setDropAction &sipStrings_QtGui[32354]
#define sipNameNr_preeditString 32368
#define sipName_preeditString &sipStrings_QtGui[32368]
#define sipNameNr_AttributeType 1750
#define sipName_AttributeType &sipStrings_QtGui[1750]
#define sipNameNr_defaultAction 32382
#define sipName_defaultAction &sipStrings_QtGui[32382]
#define sipNameNr_targetChanged 32396
#define sipName_targetChanged &sipStrings_QtGui[32396]
#define sipNameNr_actionChanged 32410
#define sipName_actionChanged &sipStrings_QtGui[32410]
#define sipNameNr_setDragCursor 32424
#define sipName_setDragCursor &sipStrings_QtGui[32424]
#define sipNameNr_setUrlHandler 25707
#define sipName_setUrlHandler &sipStrings_QtGui[25707]
#define sipNameNr_ownsSelection 32438
#define sipName_ownsSelection &sipStrings_QtGui[32438]
#define sipNameNr_ownsClipboard 32452
#define sipName_ownsClipboard &sipStrings_QtGui[32452]
#define sipNameNr_setFocalPoint 32466
#define sipName_setFocalPoint &sipStrings_QtGui[32466]
#define sipNameNr_SugarLollipop 32480
#define sipName_SugarLollipop &sipStrings_QtGui[32480]
#define sipNameNr_ColorfulPeach 32494
#define sipName_ColorfulPeach &sipStrings_QtGui[32494]
#define sipNameNr_MidnightBloom 32508
#define sipName_MidnightBloom &sipStrings_QtGui[32508]
#define sipNameNr_HappyMemories 32522
#define sipName_HappyMemories &sipStrings_QtGui[32522]
#define sipNameNr_ViciousStance 32536
#define sipName_ViciousStance &sipStrings_QtGui[32536]
#define sipNameNr_RiskyConcrete 32550
#define sipName_RiskyConcrete &sipStrings_QtGui[32550]
#define sipNameNr_PassionateBed 32564
#define sipName_PassionateBed &sipStrings_QtGui[32564]
#define sipNameNr_BurningSpring 32578
#define sipName_BurningSpring &sipStrings_QtGui[32578]
#define sipNameNr_ItmeoBranding 32592
#define sipName_ItmeoBranding &sipStrings_QtGui[32592]
#define sipNameNr_SharpeyeEagle 32606
#define sipName_SharpeyeEagle &sipStrings_QtGui[32606]
#define sipNameNr_TemptingAzure 32620
#define sipName_TemptingAzure &sipStrings_QtGui[32620]
#define sipNameNr_RainyAshville 32634
#define sipName_RainyAshville &sipStrings_QtGui[32634]
#define sipNameNr_ReflectSpread 32648
#define sipName_ReflectSpread &sipStrings_QtGui[32648]
#define sipNameNr_palevioletred 32662
#define sipName_palevioletred &sipStrings_QtGui[32662]
#define sipNameNr_paleturquoise 32676
#define sipName_paleturquoise &sipStrings_QtGui[32676]
#define sipNameNr_palegoldenrod 32690
#define sipName_palegoldenrod &sipStrings_QtGui[32690]
#define sipNameNr_lightseagreen 32704
#define sipName_lightseagreen &sipStrings_QtGui[32704]
#define sipNameNr_lavenderblush 32718
#define sipName_lavenderblush &sipStrings_QtGui[32718]
#define sipNameNr_darkturquoise 32732
#define sipName_darkturquoise &sipStrings_QtGui[32732]
#define sipNameNr_darkslategrey 32746
#define sipName_darkslategrey &sipStrings_QtGui[32746]
#define sipNameNr_darkslategray 32760
#define sipName_darkslategray &sipStrings_QtGui[32760]
#define sipNameNr_darkslateblue 32774
#define sipName_darkslateblue &sipStrings_QtGui[32774]
#define sipNameNr_darkgoldenrod 32788
#define sipName_darkgoldenrod &sipStrings_QtGui[32788]
#define sipNameNr_toExtendedRgb 32802
#define sipName_toExtendedRgb &sipStrings_QtGui[32802]
#define sipNameNr_hslSaturation 32816
#define sipName_hslSaturation &sipStrings_QtGui[32816]
#define sipNameNr_hsvSaturation 32830
#define sipName_hsvSaturation &sipStrings_QtGui[32830]
#define sipNameNr_setNamedColor 32844
#define sipName_setNamedColor &sipStrings_QtGui[32844]
#define sipNameNr_QBackingStore 32858
#define sipName_QBackingStore &sipStrings_QtGui[32858]
#define sipNameNr_intrinsicSize 32872
#define sipName_intrinsicSize &sipStrings_QtGui[32872]
#define sipNameNr_defaultFormat 32886
#define sipName_defaultFormat &sipStrings_QtGui[32886]
#define sipNameNr_InvalidFormat 32900
#define sipName_InvalidFormat &sipStrings_QtGui[32900]
#define sipNameNr_propertyCount 32914
#define sipName_propertyCount &sipStrings_QtGui[32914]
#define sipNameNr_textDirection 32928
#define sipName_textDirection &sipStrings_QtGui[32928]
#define sipNameNr_connectNotify 22715
#define sipName_connectNotify &sipStrings_QtGui[22715]
#define sipNameNr_activeChanged 32942
#define sipName_activeChanged &sipStrings_QtGui[32942]
#define sipNameNr_removeColumns 32956
#define sipName_removeColumns &sipStrings_QtGui[32956]
#define sipNameNr_insertColumns 32970
#define sipName_insertColumns &sipStrings_QtGui[32970]
#define sipNameNr_setHeaderData 32984
#define sipName_setHeaderData &sipStrings_QtGui[32984]
#define sipNameNr_AlignBaseline 32998
#define sipName_AlignBaseline &sipStrings_QtGui[32998]
#define sipNameNr_qFuzzyCompare 33012
#define sipName_qFuzzyCompare &sipStrings_QtGui[33012]
#define sipNameNr_33026 33026
#define sipName_33026 &sipStrings_QtGui[33026]
#define sipNameNr_windowStates 33039
#define sipName_windowStates &sipStrings_QtGui[33039]
#define sipNameNr_focusInEvent 33052
#define sipName_focusInEvent &sipStrings_QtGui[33052]
#define sipNameNr_widthChanged 33065
#define sipName_widthChanged &sipStrings_QtGui[33065]
#define sipNameNr_frameMargins 33078
#define sipName_frameMargins &sipStrings_QtGui[33078]
#define sipNameNr_isAncestorOf 33091
#define sipName_isAncestorOf &sipStrings_QtGui[33091]
#define sipNameNr_AncestorMode 9951
#define sipName_AncestorMode &sipStrings_QtGui[9951]
#define sipNameNr_crossProduct 33104
#define sipName_crossProduct &sipStrings_QtGui[33104]
#define sipNameNr_Intermediate 33117
#define sipName_Intermediate &sipStrings_QtGui[33117]
#define sipNameNr_isInvertible 33130
#define sipName_isInvertible &sipStrings_QtGui[33130]
#define sipNameNr_mapToPolygon 33143
#define sipName_mapToPolygon &sipStrings_QtGui[33143]
#define sipNameNr_quadToSquare 33156
#define sipName_quadToSquare &sipStrings_QtGui[33156]
#define sipNameNr_squareToQuad 33169
#define sipName_squareToQuad &sipStrings_QtGui[33169]
#define sipNameNr_capabilities 33182
#define sipName_capabilities &sipStrings_QtGui[33182]
#define sipNameNr_Capabilities 4933
#define sipName_Capabilities &sipStrings_QtGui[4933]
#define sipNameNr_RawPositions 33195
#define sipName_RawPositions &sipStrings_QtGui[33195]
#define sipNameNr_QTouchDevice 33208
#define sipName_QTouchDevice &sipStrings_QtGui[33208]
#define sipNameNr_DelimiterTab 33221
#define sipName_DelimiterTab &sipStrings_QtGui[33221]
#define sipNameNr_WrapAnywhere 33234
#define sipName_WrapAnywhere &sipStrings_QtGui[33234]
#define sipNameNr_setLineCount 33247
#define sipName_setLineCount &sipStrings_QtGui[33247]
#define sipNameNr_setUserState 33260
#define sipName_setUserState &sipStrings_QtGui[33260]
#define sipNameNr_lastPosition 33273
#define sipName_lastPosition &sipStrings_QtGui[33273]
#define sipNameNr_blockRemoved 33286
#define sipName_blockRemoved &sipStrings_QtGui[33286]
#define sipNameNr_setLineWidth 33299
#define sipName_setLineWidth &sipStrings_QtGui[33299]
#define sipNameNr_clearFormats 33312
#define sipName_clearFormats &sipStrings_QtGui[33312]
#define sipNameNr_maximumWidth 33325
#define sipName_maximumWidth &sipStrings_QtGui[33325]
#define sipNameNr_minimumWidth 33338
#define sipName_minimumWidth &sipStrings_QtGui[33338]
#define sipNameNr_cacheEnabled 33351
#define sipName_cacheEnabled &sipStrings_QtGui[33351]
#define sipNameNr_textPosition 33364
#define sipName_textPosition &sipStrings_QtGui[33364]
#define sipNameNr_bottomBorder 33377
#define sipName_bottomBorder &sipStrings_QtGui[33377]
#define sipNameNr_setTopBorder 33390
#define sipName_setTopBorder &sipStrings_QtGui[33390]
#define sipNameNr_rightPadding 33403
#define sipName_rightPadding &sipStrings_QtGui[33403]
#define sipNameNr_numberSuffix 33416
#define sipName_numberSuffix &sipStrings_QtGui[33416]
#define sipNameNr_numberPrefix 33429
#define sipName_numberPrefix &sipStrings_QtGui[33429]
#define sipNameNr_headingLevel 33442
#define sipName_headingLevel &sipStrings_QtGui[33442]
#define sipNameNr_SingleHeight 33455
#define sipName_SingleHeight &sipStrings_QtGui[33455]
#define sipNameNr_tabPositions 33468
#define sipName_tabPositions &sipStrings_QtGui[33468]
#define sipNameNr_fontFamilies 33481
#define sipName_fontFamilies &sipStrings_QtGui[33481]
#define sipNameNr_fontOverline 33494
#define sipName_fontOverline &sipStrings_QtGui[33494]
#define sipNameNr_toListFormat 33507
#define sipName_toListFormat &sipStrings_QtGui[33507]
#define sipNameNr_toCharFormat 33520
#define sipName_toCharFormat &sipStrings_QtGui[33520]
#define sipNameNr_isListFormat 33533
#define sipName_isListFormat &sipStrings_QtGui[33533]
#define sipNameNr_isCharFormat 33546
#define sipName_isCharFormat &sipStrings_QtGui[33546]
#define sipNameNr_boolProperty 33559
#define sipName_boolProperty &sipStrings_QtGui[33559]
#define sipNameNr_UserProperty 33572
#define sipName_UserProperty &sipStrings_QtGui[33572]
#define sipNameNr_ImageAltText 33585
#define sipName_ImageAltText &sipStrings_QtGui[33585]
#define sipNameNr_FontFamilies 8572
#define sipName_FontFamilies &sipStrings_QtGui[8572]
#define sipNameNr_ImageQuality 33598
#define sipName_ImageQuality &sipStrings_QtGui[33598]
#define sipNameNr_HeadingLevel 23260
#define sipName_HeadingLevel &sipStrings_QtGui[23260]
#define sipNameNr_TabPositions 23276
#define sipName_TabPositions &sipStrings_QtGui[23276]
#define sipNameNr_TableColumns 33611
#define sipName_TableColumns &sipStrings_QtGui[33611]
#define sipNameNr_FramePadding 33624
#define sipName_FramePadding &sipStrings_QtGui[33624]
#define sipNameNr_FontOverline 23356
#define sipName_FontOverline &sipStrings_QtGui[23356]
#define sipNameNr_drawContents 33637
#define sipName_drawContents &sipStrings_QtGui[33637]
#define sipNameNr_loadResource 33650
#define sipName_loadResource &sipStrings_QtGui[33650]
#define sipNameNr_createObject 33663
#define sipName_createObject &sipStrings_QtGui[33663]
#define sipNameNr_UserResource 33676
#define sipName_UserResource &sipStrings_QtGui[33676]
#define sipNameNr_HtmlResource 33689
#define sipName_HtmlResource &sipStrings_QtGui[33689]
#define sipNameNr_ResourceType 4376
#define sipName_ResourceType &sipStrings_QtGui[4376]
#define sipNameNr_FindBackward 33702
#define sipName_FindBackward &sipStrings_QtGui[33702]
#define sipNameNr_setPlainText 33715
#define sipName_setPlainText &sipStrings_QtGui[33715]
#define sipNameNr_endEditBlock 33728
#define sipName_endEditBlock &sipStrings_QtGui[33728]
#define sipNameNr_currentTable 33741
#define sipName_currentTable &sipStrings_QtGui[33741]
#define sipNameNr_atBlockStart 33754
#define sipName_atBlockStart &sipStrings_QtGui[33754]
#define sipNameNr_selectedText 33767
#define sipName_selectedText &sipStrings_QtGui[33767]
#define sipNameNr_selectionEnd 33780
#define sipName_selectionEnd &sipStrings_QtGui[33780]
#define sipNameNr_movePosition 33793
#define sipName_movePosition &sipStrings_QtGui[33793]
#define sipNameNr_PreviousCell 33806
#define sipName_PreviousCell &sipStrings_QtGui[33806]
#define sipNameNr_PreviousWord 17008
#define sipName_PreviousWord &sipStrings_QtGui[17008]
#define sipNameNr_StartOfBlock 16951
#define sipName_StartOfBlock &sipStrings_QtGui[16951]
#define sipNameNr_currentBlock 33819
#define sipName_currentBlock &sipStrings_QtGui[33819]
#define sipNameNr_swapInterval 33832
#define sipName_swapInterval &sipStrings_QtGui[33832]
#define sipNameNr_swapBehavior 33845
#define sipName_swapBehavior &sipStrings_QtGui[33845]
#define sipNameNr_TripleBuffer 33858
#define sipName_TripleBuffer &sipStrings_QtGui[33858]
#define sipNameNr_DoubleBuffer 33871
#define sipName_DoubleBuffer &sipStrings_QtGui[33871]
#define sipNameNr_SingleBuffer 33884
#define sipName_SingleBuffer &sipStrings_QtGui[33884]
#define sipNameNr_SwapBehavior 3715
#define sipName_SwapBehavior &sipStrings_QtGui[3715]
#define sipNameNr_DebugContext 33897
#define sipName_DebugContext &sipStrings_QtGui[33897]
#define sipNameNr_FormatOption 3744
#define sipName_FormatOption &sipStrings_QtGui[3744]
#define sipNameNr_surfaceClass 33910
#define sipName_surfaceClass &sipStrings_QtGui[33910]
#define sipNameNr_MetalSurface 33923
#define sipName_MetalSurface &sipStrings_QtGui[33923]
#define sipNameNr_SurfaceClass 8966
#define sipName_SurfaceClass &sipStrings_QtGui[8966]
#define sipNameNr_setTextWidth 33936
#define sipName_setTextWidth &sipStrings_QtGui[33936]
#define sipNameNr_setWhatsThis 33949
#define sipName_setWhatsThis &sipStrings_QtGui[33949]
#define sipNameNr_setStatusTip 33962
#define sipName_setStatusTip &sipStrings_QtGui[33962]
#define sipNameNr_sortChildren 33975
#define sipName_sortChildren &sipStrings_QtGui[33975]
#define sipNameNr_setCheckable 33988
#define sipName_setCheckable &sipStrings_QtGui[33988]
#define sipNameNr_isSelectable 34001
#define sipName_isSelectable &sipStrings_QtGui[34001]
#define sipNameNr_appendColumn 34014
#define sipName_appendColumn &sipStrings_QtGui[34014]
#define sipNameNr_serialNumber 34027
#define sipName_serialNumber &sipStrings_QtGui[34027]
#define sipNameNr_manufacturer 34040
#define sipName_manufacturer &sipStrings_QtGui[34040]
#define sipNameNr_angleBetween 34053
#define sipName_angleBetween &sipStrings_QtGui[34053]
#define sipNameNr_physicalSize 34066
#define sipName_physicalSize &sipStrings_QtGui[34066]
#define sipNameNr_qPremultiply 34079
#define sipName_qPremultiply &sipStrings_QtGui[34079]
#define sipNameNr_loadFromFile 34092
#define sipName_loadFromFile &sipStrings_QtGui[34092]
#define sipNameNr_maxCharWidth 34105
#define sipName_maxCharWidth &sipStrings_QtGui[34105]
#define sipNameNr_pathForGlyph 34118
#define sipName_pathForGlyph &sipStrings_QtGui[34118]
#define sipNameNr_QPixmapCache 34131
#define sipName_QPixmapCache &sipStrings_QtGui[34131]
#define sipNameNr_defaultDepth 34144
#define sipName_defaultDepth &sipStrings_QtGui[34144]
#define sipNameNr_bitsPerPixel 34157
#define sipName_bitsPerPixel &sipStrings_QtGui[34157]
#define sipNameNr_channelCount 34170
#define sipName_channelCount &sipStrings_QtGui[34170]
#define sipNameNr_UnsignedByte 34183
#define sipName_UnsignedByte &sipStrings_QtGui[34183]
#define sipNameNr_IgnoresAlpha 34196
#define sipName_IgnoresAlpha &sipStrings_QtGui[34196]
#define sipNameNr_QPixelFormat 34209
#define sipName_QPixelFormat &sipStrings_QtGui[34209]
#define sipNameNr_inputFormats 34222
#define sipName_inputFormats &sipStrings_QtGui[34222]
#define sipNameNr_NColorGroups 34235
#define sipName_NColorGroups &sipStrings_QtGui[34235]
#define sipNameNr_createStroke 34248
#define sipName_createStroke &sipStrings_QtGui[34248]
#define sipNameNr_setJoinStyle 34261
#define sipName_setJoinStyle &sipStrings_QtGui[34261]
#define sipNameNr_elementCount 34274
#define sipName_elementCount &sipStrings_QtGui[34274]
#define sipNameNr_closeSubpath 34287
#define sipName_closeSubpath &sipStrings_QtGui[34287]
#define sipNameNr_QPainterPath 34300
#define sipName_QPainterPath &sipStrings_QtGui[34300]
#define sipNameNr_CoreGraphics 34313
#define sipName_CoreGraphics &sipStrings_QtGui[34313]
#define sipNameNr_drawTextItem 34326
#define sipName_drawTextItem &sipStrings_QtGui[34326]
#define sipNameNr_PolylineMode 34339
#define sipName_PolylineMode &sipStrings_QtGui[34339]
#define sipNameNr_DirtyOpacity 34352
#define sipName_DirtyOpacity &sipStrings_QtGui[34352]
#define sipNameNr_PainterPaths 34365
#define sipName_PainterPaths &sipStrings_QtGui[34365]
#define sipNameNr_PatternBrush 34378
#define sipName_PatternBrush &sipStrings_QtGui[34378]
#define sipNameNr_QPaintEngine 34391
#define sipName_QPaintEngine &sipStrings_QtGui[34391]
#define sipNameNr_physicalDpiY 34404
#define sipName_physicalDpiY &sipStrings_QtGui[34404]
#define sipNameNr_physicalDpiX 34417
#define sipName_physicalDpiX &sipStrings_QtGui[34417]
#define sipNameNr_PdmNumColors 34430
#define sipName_PdmNumColors &sipStrings_QtGui[34430]
#define sipNameNr_drawGlyphRun 34443
#define sipName_drawGlyphRun &sipStrings_QtGui[34443]
#define sipNameNr_drawPolyline 34456
#define sipName_drawPolyline &sipStrings_QtGui[34456]
#define sipNameNr_Antialiasing 8092
#define sipName_Antialiasing &sipStrings_QtGui[8092]
#define sipNameNr_bottomMargin 34469
#define sipName_bottomMargin &sipStrings_QtGui[34469]
#define sipNameNr_setTopMargin 34482
#define sipName_setTopMargin &sipStrings_QtGui[34482]
#define sipNameNr_FullPageMode 34495
#define sipName_FullPageMode &sipStrings_QtGui[34495]
#define sipNameNr_StandardMode 34508
#define sipName_StandardMode &sipStrings_QtGui[34508]
#define sipNameNr_LastPageSize 34521
#define sipName_LastPageSize &sipStrings_QtGui[34521]
#define sipNameNr_EnvelopeYou4 34534
#define sipName_EnvelopeYou4 &sipStrings_QtGui[34534]
#define sipNameNr_EnvelopePrc9 34547
#define sipName_EnvelopePrc9 &sipStrings_QtGui[34547]
#define sipNameNr_EnvelopePrc8 34560
#define sipName_EnvelopePrc8 &sipStrings_QtGui[34560]
#define sipNameNr_EnvelopePrc7 34573
#define sipName_EnvelopePrc7 &sipStrings_QtGui[34573]
#define sipNameNr_EnvelopePrc6 34586
#define sipName_EnvelopePrc6 &sipStrings_QtGui[34586]
#define sipNameNr_EnvelopePrc5 34599
#define sipName_EnvelopePrc5 &sipStrings_QtGui[34599]
#define sipNameNr_EnvelopePrc4 34612
#define sipName_EnvelopePrc4 &sipStrings_QtGui[34612]
#define sipNameNr_EnvelopePrc3 34625
#define sipName_EnvelopePrc3 &sipStrings_QtGui[34625]
#define sipNameNr_EnvelopePrc2 34638
#define sipName_EnvelopePrc2 &sipStrings_QtGui[34638]
#define sipNameNr_EnvelopePrc1 34651
#define sipName_EnvelopePrc1 &sipStrings_QtGui[34651]
#define sipNameNr_Imperial9x12 34664
#define sipName_Imperial9x12 &sipStrings_QtGui[34664]
#define sipNameNr_Imperial9x11 34677
#define sipName_Imperial9x11 &sipStrings_QtGui[34677]
#define sipNameNr_Imperial8x10 34690
#define sipName_Imperial8x10 &sipStrings_QtGui[34690]
#define sipNameNr_TabloidExtra 34703
#define sipName_TabloidExtra &sipStrings_QtGui[34703]
#define sipNameNr_paintUnderGL 34716
#define sipName_paintUnderGL &sipStrings_QtGui[34716]
#define sipNameNr_initializeGL 34729
#define sipName_initializeGL &sipStrings_QtGui[34729]
#define sipNameNr_frameSwapped 34742
#define sipName_frameSwapped &sipStrings_QtGui[34742]
#define sipNameNr_CompareNever 34755
#define sipName_CompareNever &sipStrings_QtGui[34755]
#define sipNameNr_CompareEqual 34768
#define sipName_CompareEqual &sipStrings_QtGui[34768]
#define sipNameNr_SwizzleValue 3918
#define sipName_SwizzleValue &sipStrings_QtGui[3918]
#define sipNameNr_SwizzleAlpha 34781
#define sipName_SwizzleAlpha &sipStrings_QtGui[34781]
#define sipNameNr_SwizzleGreen 34794
#define sipName_SwizzleGreen &sipStrings_QtGui[34794]
#define sipNameNr_mipBaseLevel 34807
#define sipName_mipBaseLevel &sipStrings_QtGui[34807]
#define sipNameNr_NPOTTextures 34820
#define sipName_NPOTTextures &sipStrings_QtGui[34820]
#define sipNameNr_UInt32_D24S8 34833
#define sipName_UInt32_D24S8 &sipStrings_QtGui[34833]
#define sipNameNr_UInt32_RGBA8 34846
#define sipName_UInt32_RGBA8 &sipStrings_QtGui[34846]
#define sipNameNr_UInt16_RGBA4 34859
#define sipName_UInt16_RGBA4 &sipStrings_QtGui[34859]
#define sipNameNr_DepthStencil 12924
#define sipName_DepthStencil &sipStrings_QtGui[12924]
#define sipNameNr_BGRA_Integer 34872
#define sipName_BGRA_Integer &sipStrings_QtGui[34872]
#define sipNameNr_RGBA_Integer 34885
#define sipName_RGBA_Integer &sipStrings_QtGui[34885]
#define sipNameNr_setMipLevels 34898
#define sipName_setMipLevels &sipStrings_QtGui[34898]
#define sipNameNr_SRGB8_Alpha8 34911
#define sipName_SRGB8_Alpha8 &sipStrings_QtGui[34911]
#define sipNameNr_RGB_BP_UNorm 31361
#define sipName_RGB_BP_UNorm &sipStrings_QtGui[31361]
#define sipNameNr_RGBA16_SNorm 34924
#define sipName_RGBA16_SNorm &sipStrings_QtGui[34924]
#define sipNameNr_RGBA16_UNorm 34937
#define sipName_RGBA16_UNorm &sipStrings_QtGui[34937]
#define sipNameNr_TargetBuffer 14487
#define sipName_TargetBuffer &sipStrings_QtGui[14487]
#define sipNameNr_removeShader 34950
#define sipName_removeShader &sipStrings_QtGui[34950]
#define sipNameNr_setRowLength 34963
#define sipName_setRowLength &sipStrings_QtGui[34963]
#define sipNameNr_setAlignment 34976
#define sipName_setAlignment &sipStrings_QtGui[34976]
#define sipNameNr_paintFlipped 34989
#define sipName_paintFlipped &sipStrings_QtGui[34989]
#define sipNameNr_NoAttachment 35002
#define sipName_NoAttachment &sipStrings_QtGui[35002]
#define sipNameNr_startLogging 35015
#define sipName_startLogging &sipStrings_QtGui[35015]
#define sipNameNr_HighSeverity 35028
#define sipName_HighSeverity &sipStrings_QtGui[35028]
#define sipNameNr_GroupPopType 35041
#define sipName_GroupPopType &sipStrings_QtGui[35041]
#define sipNameNr_hasExtension 35054
#define sipName_hasExtension &sipStrings_QtGui[35054]
#define sipNameNr_shareContext 35067
#define sipName_shareContext &sipStrings_QtGui[35067]
#define sipNameNr_usagePattern 35080
#define sipName_usagePattern &sipStrings_QtGui[35080]
#define sipNameNr_UsagePattern 4712
#define sipName_UsagePattern &sipStrings_QtGui[4712]
#define sipNameNr_VertexBuffer 35093
#define sipName_VertexBuffer &sipStrings_QtGui[35093]
#define sipNameNr_nativeHandle 35106
#define sipName_nativeHandle &sipStrings_QtGui[35106]
#define sipNameNr_setCacheMode 35119
#define sipName_setCacheMode &sipStrings_QtGui[35119]
#define sipNameNr_currentImage 35132
#define sipName_currentImage &sipStrings_QtGui[35132]
#define sipNameNr_normalMatrix 35145
#define sipName_normalMatrix &sipStrings_QtGui[35145]
#define sipNameNr_listToString 35158
#define sipName_listToString &sipStrings_QtGui[35158]
#define sipNameNr_FindPrevious 35171
#define sipName_FindPrevious &sipStrings_QtGui[35171]
#define sipNameNr_HelpContents 35184
#define sipName_HelpContents &sipStrings_QtGui[35184]
#define sipNameNr_PartialMatch 35197
#define sipName_PartialMatch &sipStrings_QtGui[35197]
#define sipNameNr_PortableText 35210
#define sipName_PortableText &sipStrings_QtGui[35210]
#define sipNameNr_invokeAction 35223
#define sipName_invokeAction &sipStrings_QtGui[35223]
#define sipNameNr_QInputMethod 35236
#define sipName_QInputMethod &sipStrings_QtGui[35236]
#define sipNameNr_QImageWriter 35249
#define sipName_QImageWriter &sipStrings_QtGui[35249]
#define sipNameNr_QImageReader 35262
#define sipName_QImageReader &sipStrings_QtGui[35262]
#define sipNameNr_smoothScaled 35275
#define sipName_smoothScaled &sipStrings_QtGui[35275]
#define sipNameNr_invertPixels 35288
#define sipName_invertPixels &sipStrings_QtGui[35288]
#define sipNameNr_bytesPerLine 35301
#define sipName_bytesPerLine &sipStrings_QtGui[35301]
#define sipNameNr_Format_RGB30 35314
#define sipName_Format_RGB30 &sipStrings_QtGui[35314]
#define sipNameNr_Format_BGR30 35327
#define sipName_Format_BGR30 &sipStrings_QtGui[35327]
#define sipNameNr_Format_RGB16 35340
#define sipName_Format_RGB16 &sipStrings_QtGui[35340]
#define sipNameNr_Format_RGB32 35353
#define sipName_Format_RGB32 &sipStrings_QtGui[35353]
#define sipNameNr_QPaintDevice 35366
#define sipName_QPaintDevice &sipStrings_QtGui[35366]
#define sipNameNr_scaledPixmap 35379
#define sipName_scaledPixmap &sipStrings_QtGui[35379]
#define sipNameNr_IconNameHook 35392
#define sipName_IconNameHook &sipStrings_QtGui[35392]
#define sipNameNr_setThemeName 35405
#define sipName_setThemeName &sipStrings_QtGui[35405]
#define sipNameNr_hasThemeIcon 35418
#define sipName_hasThemeIcon &sipStrings_QtGui[35418]
#define sipNameNr_QIcon__State 35431
#define sipName_QIcon__State &sipStrings_QtGui[35431]
#define sipNameNr_platformName 35444
#define sipName_platformName &sipStrings_QtGui[35444]
#define sipNameNr_GlyphRunFlag 8548
#define sipName_GlyphRunFlag &sipStrings_QtGui[8548]
#define sipNameNr_setPositions 35457
#define sipName_setPositions &sipStrings_QtGui[35457]
#define sipNameNr_glyphIndexes 35470
#define sipName_glyphIndexes &sipStrings_QtGui[35470]
#define sipNameNr_strikeOutPos 35483
#define sipName_strikeOutPos &sipStrings_QtGui[35483]
#define sipNameNr_underlinePos 35496
#define sipName_underlinePos &sipStrings_QtGui[35496]
#define sipNameNr_boundingRect 35509
#define sipName_boundingRect &sipStrings_QtGui[35509]
#define sipNameNr_rightBearing 35522
#define sipName_rightBearing &sipStrings_QtGui[35522]
#define sipNameNr_QFontMetrics 35535
#define sipName_QFontMetrics &sipStrings_QtGui[35535]
#define sipNameNr_isFixedPitch 35548
#define sipName_isFixedPitch &sipStrings_QtGui[35548]
#define sipNameNr_setStyleName 35561
#define sipName_setStyleName &sipStrings_QtGui[35561]
#define sipNameNr_AllLowercase 35574
#define sipName_AllLowercase &sipStrings_QtGui[35574]
#define sipNameNr_AllUppercase 35587
#define sipName_AllUppercase &sipStrings_QtGui[35587]
#define sipNameNr_setStyleHint 35600
#define sipName_setStyleHint &sipStrings_QtGui[35600]
#define sipNameNr_setStrikeOut 35613
#define sipName_setStrikeOut &sipStrings_QtGui[35613]
#define sipNameNr_setUnderline 35626
#define sipName_setUnderline &sipStrings_QtGui[35626]
#define sipNameNr_setPixelSize 35639
#define sipName_setPixelSize &sipStrings_QtGui[35639]
#define sipNameNr_setPointSize 35652
#define sipName_setPointSize &sipStrings_QtGui[35652]
#define sipNameNr_SemiExpanded 35665
#define sipName_SemiExpanded &sipStrings_QtGui[35665]
#define sipNameNr_StyleOblique 35678
#define sipName_StyleOblique &sipStrings_QtGui[35678]
#define sipNameNr_QFont__Style 35691
#define sipName_QFont__Style &sipStrings_QtGui[35691]
#define sipNameNr_ForceOutline 35704
#define sipName_ForceOutline &sipStrings_QtGui[35704]
#define sipNameNr_PreferDevice 35717
#define sipName_PreferDevice &sipStrings_QtGui[35717]
#define sipNameNr_PreferBitmap 35730
#define sipName_PreferBitmap &sipStrings_QtGui[35730]
#define sipNameNr_QScrollEvent 35743
#define sipName_QScrollEvent &sipStrings_QtGui[35743]
#define sipNameNr_viewportSize 35756
#define sipName_viewportSize &sipStrings_QtGui[35756]
#define sipNameNr_QExposeEvent 35769
#define sipName_QExposeEvent &sipStrings_QtGui[35769]
#define sipNameNr_lastScenePos 35782
#define sipName_lastScenePos &sipStrings_QtGui[35782]
#define sipNameNr_QActionEvent 35795
#define sipName_QActionEvent &sipStrings_QtGui[35795]
#define sipNameNr_mouseButtons 35808
#define sipName_mouseButtons &sipStrings_QtGui[35808]
#define sipNameNr_commitString 35821
#define sipName_commitString &sipStrings_QtGui[35821]
#define sipNameNr_QResizeEvent 35834
#define sipName_QResizeEvent &sipStrings_QtGui[35834]
#define sipNameNr_isAutoRepeat 35847
#define sipName_isAutoRepeat &sipStrings_QtGui[35847]
#define sipNameNr_hiResGlobalY 35860
#define sipName_hiResGlobalY &sipStrings_QtGui[35860]
#define sipNameNr_hiResGlobalX 35873
#define sipName_hiResGlobalX &sipStrings_QtGui[35873]
#define sipNameNr_TabletDevice 5527
#define sipName_TabletDevice &sipStrings_QtGui[5527]
#define sipNameNr_QTabletEvent 35886
#define sipName_QTabletEvent &sipStrings_QtGui[35886]
#define sipNameNr_setTimestamp 35899
#define sipName_setTimestamp &sipStrings_QtGui[35899]
#define sipNameNr_setPrimaries 35912
#define sipName_setPrimaries &sipStrings_QtGui[35912]
#define sipNameNr_centerRadius 35925
#define sipName_centerRadius &sipStrings_QtGui[35925]
#define sipNameNr_setFinalStop 35938
#define sipName_setFinalStop &sipStrings_QtGui[35938]
#define sipNameNr_FabledSunset 35951
#define sipName_FabledSunset &sipStrings_QtGui[35951]
#define sipNameNr_SweetDessert 35964
#define sipName_SweetDessert &sipStrings_QtGui[35964]
#define sipNameNr_MorningSalad 35977
#define sipName_MorningSalad &sipStrings_QtGui[35977]
#define sipNameNr_PerfectWhite 35990
#define sipName_PerfectWhite &sipStrings_QtGui[35990]
#define sipNameNr_SaltMountain 36003
#define sipName_SaltMountain &sipStrings_QtGui[36003]
#define sipNameNr_SoftLipstick 36016
#define sipName_SoftLipstick &sipStrings_QtGui[36016]
#define sipNameNr_CrystalRiver 36029
#define sipName_CrystalRiver &sipStrings_QtGui[36029]
#define sipNameNr_GrassShampoo 36042
#define sipName_GrassShampoo &sipStrings_QtGui[36042]
#define sipNameNr_AquaGuidance 36055
#define sipName_AquaGuidance &sipStrings_QtGui[36055]
#define sipNameNr_NorthMiracle 36068
#define sipName_NorthMiracle &sipStrings_QtGui[36068]
#define sipNameNr_AfricanField 36081
#define sipName_AfricanField &sipStrings_QtGui[36081]
#define sipNameNr_HappyUnicorn 36094
#define sipName_HappyUnicorn &sipStrings_QtGui[36094]
#define sipNameNr_HiddenJaguar 36107
#define sipName_HiddenJaguar &sipStrings_QtGui[36107]
#define sipNameNr_NewRetrowave 36120
#define sipName_NewRetrowave &sipStrings_QtGui[36120]
#define sipNameNr_HealthyWater 36133
#define sipName_HealthyWater &sipStrings_QtGui[36133]
#define sipNameNr_PremiumWhite 36146
#define sipName_PremiumWhite &sipStrings_QtGui[36146]
#define sipNameNr_AlchemistLab 36159
#define sipName_AlchemistLab &sipStrings_QtGui[36159]
#define sipNameNr_FarawayRiver 36172
#define sipName_FarawayRiver &sipStrings_QtGui[36172]
#define sipNameNr_PhoenixStart 36185
#define sipName_PhoenixStart &sipStrings_QtGui[36185]
#define sipNameNr_MountainRock 36198
#define sipName_MountainRock &sipStrings_QtGui[36198]
#define sipNameNr_RedSalvation 36211
#define sipName_RedSalvation &sipStrings_QtGui[36211]
#define sipNameNr_PoliteRumors 36224
#define sipName_PoliteRumors &sipStrings_QtGui[36224]
#define sipNameNr_TeenNotebook 36237
#define sipName_TeenNotebook &sipStrings_QtGui[36237]
#define sipNameNr_LadogaBottom 36250
#define sipName_LadogaBottom &sipStrings_QtGui[36250]
#define sipNameNr_FrozenDreams 36263
#define sipName_FrozenDreams &sipStrings_QtGui[36263]
#define sipNameNr_SunnyMorning 36276
#define sipName_SunnyMorning &sipStrings_QtGui[36276]
#define sipNameNr_YoungPassion 36289
#define sipName_YoungPassion &sipStrings_QtGui[36289]
#define sipNameNr_SpringWarmth 36302
#define sipName_SpringWarmth &sipStrings_QtGui[36302]
#define sipNameNr_RepeatSpread 36315
#define sipName_RepeatSpread &sipStrings_QtGui[36315]
#define sipNameNr_setTransform 27420
#define sipName_setTransform &sipStrings_QtGui[27420]
#define sipNameNr_textureImage 36328
#define sipName_textureImage &sipStrings_QtGui[36328]
#define sipNameNr_midnightblue 36341
#define sipName_midnightblue &sipStrings_QtGui[36341]
#define sipNameNr_mediumpurple 36354
#define sipName_mediumpurple &sipStrings_QtGui[36354]
#define sipNameNr_mediumorchid 36367
#define sipName_mediumorchid &sipStrings_QtGui[36367]
#define sipNameNr_lightskyblue 36380
#define sipName_lightskyblue &sipStrings_QtGui[36380]
#define sipNameNr_lemonchiffon 36393
#define sipName_lemonchiffon &sipStrings_QtGui[36393]
#define sipNameNr_darkseagreen 36406
#define sipName_darkseagreen &sipStrings_QtGui[36406]
#define sipNameNr_antiquewhite 36419
#define sipName_antiquewhite &sipStrings_QtGui[36419]
#define sipNameNr_isValidColor 36432
#define sipName_isValidColor &sipStrings_QtGui[36432]
#define sipNameNr_QColor__Spec 36445
#define sipName_QColor__Spec &sipStrings_QtGui[36445]
#define sipNameNr_documentSize 36458
#define sipName_documentSize &sipStrings_QtGui[36458]
#define sipNameNr_PaintContext 232
#define sipName_PaintContext &sipStrings_QtGui[232]
#define sipNameNr_columnNumber 36471
#define sipName_columnNumber &sipStrings_QtGui[36471]
#define sipNameNr_loadFromData 36484
#define sipName_loadFromData &sipStrings_QtGui[36484]
#define sipNameNr_frameChanged 36497
#define sipName_frameChanged &sipStrings_QtGui[36497]
#define sipNameNr_currentFrame 36510
#define sipName_currentFrame &sipStrings_QtGui[36510]
#define sipNameNr_minorVersion 36523
#define sipName_minorVersion &sipStrings_QtGui[36523]
#define sipNameNr_majorVersion 36536
#define sipName_majorVersion &sipStrings_QtGui[36536]
#define sipNameNr_QKeySequence 36549
#define sipName_QKeySequence &sipStrings_QtGui[36549]
#define sipNameNr_hasSelection 36562
#define sipName_hasSelection &sipStrings_QtGui[36562]
#define sipNameNr_LittleEndian 36575
#define sipName_LittleEndian &sipStrings_QtGui[36575]
#define sipNameNr_UnknownError 36588
#define sipName_UnknownError &sipStrings_QtGui[36588]
#define sipNameNr___contains__ 36601
#define sipName___contains__ &sipStrings_QtGui[36601]
#define sipNameNr_removeColumn 36614
#define sipName_removeColumn &sipStrings_QtGui[36614]
#define sipNameNr_insertColumn 36627
#define sipName_insertColumn &sipStrings_QtGui[36627]
#define sipNameNr_canFetchMore 36640
#define sipName_canFetchMore &sipStrings_QtGui[36640]
#define sipNameNr_dropMimeData 36653
#define sipName_dropMimeData &sipStrings_QtGui[36653]
#define sipNameNr_stateChanged 36666
#define sipName_stateChanged &sipStrings_QtGui[36666]
#define sipNameNr_tabletEvent 36679
#define sipName_tabletEvent &sipStrings_QtGui[36679]
#define sipNameNr_unsetCursor 36691
#define sipName_unsetCursor &sipStrings_QtGui[36691]
#define sipNameNr_mapToGlobal 36703
#define sipName_mapToGlobal &sipStrings_QtGui[36703]
#define sipNameNr_setFilePath 36715
#define sipName_setFilePath &sipStrings_QtGui[36715]
#define sipNameNr_setGeometry 36727
#define sipName_setGeometry &sipStrings_QtGui[36727]
#define sipNameNr_setBaseSize 36739
#define sipName_setBaseSize &sipStrings_QtGui[36739]
#define sipNameNr_maximumSize 36751
#define sipName_maximumSize &sipStrings_QtGui[36751]
#define sipNameNr_minimumSize 36763
#define sipName_minimumSize &sipStrings_QtGui[36763]
#define sipNameNr_windowState 36775
#define sipName_windowState &sipStrings_QtGui[36775]
#define sipNameNr_setModality 36787
#define sipName_setModality &sipStrings_QtGui[36787]
#define sipNameNr_setNotation 36799
#define sipName_setNotation &sipStrings_QtGui[36799]
#define sipNameNr_setDecimals 36811
#define sipName_setDecimals &sipStrings_QtGui[36811]
#define sipNameNr_TxTranslate 36823
#define sipName_TxTranslate &sipStrings_QtGui[36823]
#define sipNameNr_TouchScreen 36835
#define sipName_TouchScreen &sipStrings_QtGui[36835]
#define sipNameNr_setTabArray 36847
#define sipName_setTabArray &sipStrings_QtGui[36847]
#define sipNameNr_QTextOption 36859
#define sipName_QTextOption &sipStrings_QtGui[36859]
#define sipNameNr_textFormats 36871
#define sipName_textFormats &sipStrings_QtGui[36871]
#define sipNameNr_setRevision 36883
#define sipName_setRevision &sipStrings_QtGui[36883]
#define sipNameNr_setUserData 36895
#define sipName_setUserData &sipStrings_QtGui[36895]
#define sipNameNr_parentFrame 36907
#define sipName_parentFrame &sipStrings_QtGui[36907]
#define sipNameNr_childFrames 36919
#define sipName_childFrames &sipStrings_QtGui[36919]
#define sipNameNr_frameFormat 36931
#define sipName_frameFormat &sipStrings_QtGui[36931]
#define sipNameNr_QTextObject 36943
#define sipName_QTextObject &sipStrings_QtGui[36943]
#define sipNameNr_clearLayout 36955
#define sipName_clearLayout &sipStrings_QtGui[36955]
#define sipNameNr_beginLayout 36967
#define sipName_beginLayout &sipStrings_QtGui[36967]
#define sipNameNr_FormatRange 6593
#define sipName_FormatRange &sipStrings_QtGui[6593]
#define sipNameNr_QTextLayout 36979
#define sipName_QTextLayout &sipStrings_QtGui[36979]
#define sipNameNr_formatIndex 36991
#define sipName_formatIndex &sipStrings_QtGui[36991]
#define sipNameNr_rightBorder 37003
#define sipName_rightBorder &sipStrings_QtGui[37003]
#define sipNameNr_leftPadding 37015
#define sipName_leftPadding &sipStrings_QtGui[37015]
#define sipNameNr_cellPadding 37027
#define sipName_cellPadding &sipStrings_QtGui[37027]
#define sipNameNr_cellSpacing 37039
#define sipName_cellSpacing &sipStrings_QtGui[37039]
#define sipNameNr_borderStyle 37051
#define sipName_borderStyle &sipStrings_QtGui[37051]
#define sipNameNr_borderBrush 37063
#define sipName_borderBrush &sipStrings_QtGui[37063]
#define sipNameNr_BorderStyle 2850
#define sipName_BorderStyle &sipStrings_QtGui[2850]
#define sipNameNr_ListDecimal 37075
#define sipName_ListDecimal &sipStrings_QtGui[37075]
#define sipNameNr_FixedHeight 37087
#define sipName_FixedHeight &sipStrings_QtGui[37087]
#define sipNameNr_fontStretch 37099
#define sipName_fontStretch &sipStrings_QtGui[37099]
#define sipNameNr_fontKerning 37111
#define sipName_fontKerning &sipStrings_QtGui[37111]
#define sipNameNr_anchorNames 37123
#define sipName_anchorNames &sipStrings_QtGui[37123]
#define sipNameNr_NoUnderline 37135
#define sipName_NoUnderline &sipStrings_QtGui[37135]
#define sipNameNr_textOutline 37147
#define sipName_textOutline &sipStrings_QtGui[37147]
#define sipNameNr_AlignMiddle 37159
#define sipName_AlignMiddle &sipStrings_QtGui[37159]
#define sipNameNr_AlignNormal 37171
#define sipName_AlignNormal &sipStrings_QtGui[37171]
#define sipNameNr_penProperty 37183
#define sipName_penProperty &sipStrings_QtGui[37183]
#define sipNameNr_intProperty 37195
#define sipName_intProperty &sipStrings_QtGui[37195]
#define sipNameNr_hasProperty 37207
#define sipName_hasProperty &sipStrings_QtGui[37207]
#define sipNameNr_BlockMarker 37219
#define sipName_BlockMarker &sipStrings_QtGui[37219]
#define sipNameNr_FontStretch 26506
#define sipName_FontStretch &sipStrings_QtGui[26506]
#define sipNameNr_FontKerning 26521
#define sipName_FontKerning &sipStrings_QtGui[26521]
#define sipNameNr_TextToolTip 37231
#define sipName_TextToolTip &sipStrings_QtGui[37231]
#define sipNameNr_ImageHeight 28021
#define sipName_ImageHeight &sipStrings_QtGui[28021]
#define sipNameNr_FrameHeight 37243
#define sipName_FrameHeight &sipStrings_QtGui[37243]
#define sipNameNr_FrameMargin 37255
#define sipName_FrameMargin &sipStrings_QtGui[37255]
#define sipNameNr_FrameBorder 37267
#define sipName_FrameBorder &sipStrings_QtGui[37267]
#define sipNameNr_TextOutline 26566
#define sipName_TextOutline &sipStrings_QtGui[26566]
#define sipNameNr_BlockIndent 37279
#define sipName_BlockIndent &sipStrings_QtGui[37279]
#define sipNameNr_ObjectIndex 26671
#define sipName_ObjectIndex &sipStrings_QtGui[26671]
#define sipNameNr_TableObject 37291
#define sipName_TableObject &sipStrings_QtGui[37291]
#define sipNameNr_ImageObject 37303
#define sipName_ImageObject &sipStrings_QtGui[37303]
#define sipNameNr_ObjectTypes 6718
#define sipName_ObjectTypes &sipStrings_QtGui[6718]
#define sipNameNr_FrameFormat 20694
#define sipName_FrameFormat &sipStrings_QtGui[20694]
#define sipNameNr_TableFormat 20660
#define sipName_TableFormat &sipStrings_QtGui[20660]
#define sipNameNr_BlockFormat 20728
#define sipName_BlockFormat &sipStrings_QtGui[20728]
#define sipNameNr_FixedLength 37315
#define sipName_FixedLength &sipStrings_QtGui[37315]
#define sipNameNr_setMarkdown 37327
#define sipName_setMarkdown &sipStrings_QtGui[37327]
#define sipNameNr_characterAt 37339
#define sipName_characterAt &sipStrings_QtGui[37339]
#define sipNameNr_indentWidth 37351
#define sipName_indentWidth &sipStrings_QtGui[37351]
#define sipNameNr_setModified 37363
#define sipName_setModified &sipStrings_QtGui[37363]
#define sipNameNr_addResource 37375
#define sipName_addResource &sipStrings_QtGui[37375]
#define sipNameNr_defaultFont 37387
#define sipName_defaultFont &sipStrings_QtGui[37387]
#define sipNameNr_objectIndex 37399
#define sipName_objectIndex &sipStrings_QtGui[37399]
#define sipNameNr_toPlainText 37411
#define sipName_toPlainText &sipStrings_QtGui[37411]
#define sipNameNr_DocumentUrl 37423
#define sipName_DocumentUrl &sipStrings_QtGui[37423]
#define sipNameNr_blockNumber 37435
#define sipName_blockNumber &sipStrings_QtGui[37435]
#define sipNameNr_insertImage 37447
#define sipName_insertImage &sipStrings_QtGui[37447]
#define sipNameNr_insertFrame 37459
#define sipName_insertFrame &sipStrings_QtGui[37459]
#define sipNameNr_insertTable 37471
#define sipName_insertTable &sipStrings_QtGui[37471]
#define sipNameNr_currentList 37483
#define sipName_currentList &sipStrings_QtGui[37483]
#define sipNameNr_insertBlock 37495
#define sipName_insertBlock &sipStrings_QtGui[37495]
#define sipNameNr_blockFormat 37507
#define sipName_blockFormat &sipStrings_QtGui[37507]
#define sipNameNr_PreviousRow 37519
#define sipName_PreviousRow &sipStrings_QtGui[37519]
#define sipNameNr_StartOfWord 19546
#define sipName_StartOfWord &sipStrings_QtGui[19546]
#define sipNameNr_StartOfLine 19564
#define sipName_StartOfLine &sipStrings_QtGui[19564]
#define sipNameNr_QTextCursor 37531
#define sipName_QTextCursor &sipStrings_QtGui[37531]
#define sipNameNr_rehighlight 37543
#define sipName_rehighlight &sipStrings_QtGui[37543]
#define sipNameNr_setDocument 37555
#define sipName_setDocument &sipStrings_QtGui[37555]
#define sipNameNr_CoreProfile 37567
#define sipName_CoreProfile &sipStrings_QtGui[37567]
#define sipNameNr_SurfaceType 10436
#define sipName_SurfaceType &sipStrings_QtGui[10436]
#define sipNameNr_QStyleHints 37579
#define sipName_QStyleHints &sipStrings_QtGui[37579]
#define sipNameNr_QStaticText 37591
#define sipName_QStaticText &sipStrings_QtGui[37591]
#define sipNameNr_setSizeHint 37603
#define sipName_setSizeHint &sipStrings_QtGui[37603]
#define sipNameNr_setTristate 37615
#define sipName_setTristate &sipStrings_QtGui[37615]
#define sipNameNr_isCheckable 37627
#define sipName_isCheckable &sipStrings_QtGui[37627]
#define sipNameNr_setEditable 37639
#define sipName_setEditable &sipStrings_QtGui[37639]
#define sipNameNr_itemChanged 37651
#define sipName_itemChanged &sipStrings_QtGui[37651]
#define sipNameNr_setRowCount 37663
#define sipName_setRowCount &sipStrings_QtGui[37663]
#define sipNameNr_refreshRate 37675
#define sipName_refreshRate &sipStrings_QtGui[37675]
#define sipNameNr_isLandscape 37687
#define sipName_isLandscape &sipStrings_QtGui[37687]
#define sipNameNr_virtualSize 37699
#define sipName_virtualSize &sipStrings_QtGui[37699]
#define sipNameNr_LayoutFlags 10590
#define sipName_LayoutFlags &sipStrings_QtGui[10590]
#define sipNameNr_magentaSize 37711
#define sipName_magentaSize &sipStrings_QtGui[37711]
#define sipNameNr_AtBeginning 37723
#define sipName_AtBeginning &sipStrings_QtGui[37723]
#define sipNameNr_setIODevice 37735
#define sipName_setIODevice &sipStrings_QtGui[37735]
#define sipNameNr_setCosmetic 37747
#define sipName_setCosmetic &sipStrings_QtGui[37747]
#define sipNameNr_toolTipText 37759
#define sipName_toolTipText &sipStrings_QtGui[37759]
#define sipNameNr_toolTipBase 37771
#define sipName_toolTipBase &sipStrings_QtGui[37771]
#define sipNameNr_linkVisited 37783
#define sipName_linkVisited &sipStrings_QtGui[37783]
#define sipNameNr_NColorRoles 37795
#define sipName_NColorRoles &sipStrings_QtGui[37795]
#define sipNameNr_ToolTipText 37807
#define sipName_ToolTipText &sipStrings_QtGui[37807]
#define sipNameNr_ToolTipBase 37819
#define sipName_ToolTipBase &sipStrings_QtGui[37819]
#define sipNameNr_LinkVisited 37831
#define sipName_LinkVisited &sipStrings_QtGui[37831]
#define sipNameNr_dashPattern 37843
#define sipName_dashPattern &sipStrings_QtGui[37843]
#define sipNameNr_setCapStyle 37855
#define sipName_setCapStyle &sipStrings_QtGui[37855]
#define sipNameNr_setFillRule 37867
#define sipName_setFillRule &sipStrings_QtGui[37867]
#define sipNameNr_connectPath 37879
#define sipName_connectPath &sipStrings_QtGui[37879]
#define sipNameNr_ElementType 5867
#define sipName_ElementType &sipStrings_QtGui[5867]
#define sipNameNr_PaintBuffer 37891
#define sipName_PaintBuffer &sipStrings_QtGui[37891]
#define sipNameNr_WindingMode 37903
#define sipName_WindingMode &sipStrings_QtGui[37903]
#define sipNameNr_OddEvenMode 37915
#define sipName_OddEvenMode &sipStrings_QtGui[37915]
#define sipNameNr_AllFeatures 37927
#define sipName_AllFeatures &sipStrings_QtGui[37927]
#define sipNameNr_MaskedBrush 37939
#define sipName_MaskedBrush &sipStrings_QtGui[37939]
#define sipNameNr_BrushStroke 37951
#define sipName_BrushStroke &sipStrings_QtGui[37951]
#define sipNameNr_renderFlags 37963
#define sipName_renderFlags &sipStrings_QtGui[37963]
#define sipNameNr_RenderFlags 9197
#define sipName_RenderFlags &sipStrings_QtGui[9197]
#define sipNameNr_exposeEvent 37975
#define sipName_exposeEvent &sipStrings_QtGui[37975]
#define sipNameNr_logicalDpiY 37987
#define sipName_logicalDpiY &sipStrings_QtGui[37987]
#define sipNameNr_logicalDpiX 37999
#define sipName_logicalDpiX &sipStrings_QtGui[37999]
#define sipNameNr_PdmHeightMM 38011
#define sipName_PdmHeightMM &sipStrings_QtGui[38011]
#define sipNameNr_renderHints 38023
#define sipName_renderHints &sipStrings_QtGui[38023]
#define sipNameNr_drawPicture 38035
#define sipName_drawPicture &sipStrings_QtGui[38035]
#define sipNameNr_drawPolygon 38047
#define sipName_drawPolygon &sipStrings_QtGui[38047]
#define sipNameNr_drawEllipse 38059
#define sipName_drawEllipse &sipStrings_QtGui[38059]
#define sipNameNr_setViewport 38071
#define sipName_setViewport &sipStrings_QtGui[38071]
#define sipNameNr_hasClipping 38083
#define sipName_hasClipping &sipStrings_QtGui[38083]
#define sipNameNr_setClipping 38095
#define sipName_setClipping &sipStrings_QtGui[38095]
#define sipNameNr_setClipPath 38107
#define sipName_setClipPath &sipStrings_QtGui[38107]
#define sipNameNr_brushOrigin 38119
#define sipName_brushOrigin &sipStrings_QtGui[38119]
#define sipNameNr_fontMetrics 38131
#define sipName_fontMetrics &sipStrings_QtGui[38131]
#define sipNameNr_RenderHints 10744
#define sipName_RenderHints &sipStrings_QtGui[10744]
#define sipNameNr_matchPolicy 38143
#define sipName_matchPolicy &sipStrings_QtGui[38143]
#define sipNameNr_rightMargin 38155
#define sipName_rightMargin &sipStrings_QtGui[38155]
#define sipNameNr_QPageLayout 38167
#define sipName_QPageLayout &sipStrings_QtGui[38167]
#define sipNameNr_setPageSize 38179
#define sipName_setPageSize &sipStrings_QtGui[38179]
#define sipNameNr_EnvelopeC65 38191
#define sipName_EnvelopeC65 &sipStrings_QtGui[38191]
#define sipNameNr_Imperial7x9 38203
#define sipName_Imperial7x9 &sipStrings_QtGui[38203]
#define sipNameNr_LetterSmall 38215
#define sipName_LetterSmall &sipStrings_QtGui[38215]
#define sipNameNr_LetterExtra 38227
#define sipName_LetterExtra &sipStrings_QtGui[38227]
#define sipNameNr_resizeEvent 38239
#define sipName_resizeEvent &sipStrings_QtGui[38239]
#define sipNameNr_paintOverGL 38251
#define sipName_paintOverGL &sipStrings_QtGui[38251]
#define sipNameNr_CompareNone 38263
#define sipName_CompareNone &sipStrings_QtGui[38263]
#define sipNameNr_CompareLess 38275
#define sipName_CompareLess &sipStrings_QtGui[38275]
#define sipNameNr_borderColor 38287
#define sipName_borderColor &sipStrings_QtGui[38287]
#define sipNameNr_setWrapMode 38299
#define sipName_setWrapMode &sipStrings_QtGui[38299]
#define sipNameNr_ClampToEdge 38311
#define sipName_ClampToEdge &sipStrings_QtGui[38311]
#define sipNameNr_StencilMode 1455
#define sipName_StencilMode &sipStrings_QtGui[1455]
#define sipNameNr_swizzleMask 38323
#define sipName_swizzleMask &sipStrings_QtGui[38323]
#define sipNameNr_SwizzleBlue 38335
#define sipName_SwizzleBlue &sipStrings_QtGui[38335]
#define sipNameNr_mipMaxLevel 38347
#define sipName_mipMaxLevel &sipStrings_QtGui[38347]
#define sipNameNr_UInt8_RG3B2 38359
#define sipName_UInt8_RG3B2 &sipStrings_QtGui[38359]
#define sipNameNr_NoPixelType 38371
#define sipName_NoPixelType &sipStrings_QtGui[38371]
#define sipNameNr_BGR_Integer 38383
#define sipName_BGR_Integer &sipStrings_QtGui[38383]
#define sipNameNr_RGB_Integer 38395
#define sipName_RGB_Integer &sipStrings_QtGui[38395]
#define sipNameNr_Red_Integer 38407
#define sipName_Red_Integer &sipStrings_QtGui[38407]
#define sipNameNr_PixelFormat 4573
#define sipName_PixelFormat &sipStrings_QtGui[4573]
#define sipNameNr_CubeMapFace 4601
#define sipName_CubeMapFace &sipStrings_QtGui[4601]
#define sipNameNr_AlphaFormat 12757
#define sipName_AlphaFormat &sipStrings_QtGui[12757]
#define sipNameNr_DepthFormat 38419
#define sipName_DepthFormat &sipStrings_QtGui[38419]
#define sipNameNr_RGB16_SNorm 38431
#define sipName_RGB16_SNorm &sipStrings_QtGui[38431]
#define sipNameNr_RGBA8_SNorm 38443
#define sipName_RGBA8_SNorm &sipStrings_QtGui[38443]
#define sipNameNr_RGB16_UNorm 38455
#define sipName_RGB16_UNorm &sipStrings_QtGui[38455]
#define sipNameNr_RGBA8_UNorm 38467
#define sipName_RGBA8_UNorm &sipStrings_QtGui[38467]
#define sipNameNr_imageHeight 38479
#define sipName_imageHeight &sipStrings_QtGui[38479]
#define sipNameNr_setSkipRows 38491
#define sipName_setSkipRows &sipStrings_QtGui[38491]
#define sipNameNr_takeTexture 38503
#define sipName_takeTexture &sipStrings_QtGui[38503]
#define sipNameNr_bindDefault 38515
#define sipName_bindDefault &sipStrings_QtGui[38515]
#define sipNameNr_stopLogging 38527
#define sipName_stopLogging &sipStrings_QtGui[38527]
#define sipNameNr_loggingMode 38539
#define sipName_loggingMode &sipStrings_QtGui[38539]
#define sipNameNr_LoggingMode 2104
#define sipName_LoggingMode &sipStrings_QtGui[2104]
#define sipNameNr_AnySeverity 38551
#define sipName_AnySeverity &sipStrings_QtGui[38551]
#define sipNameNr_LowSeverity 38563
#define sipName_LowSeverity &sipStrings_QtGui[38563]
#define sipNameNr_InvalidType 38575
#define sipName_InvalidType &sipStrings_QtGui[38575]
#define sipNameNr_OtherSource 38587
#define sipName_OtherSource &sipStrings_QtGui[38587]
#define sipNameNr_hasProfiles 38599
#define sipName_hasProfiles &sipStrings_QtGui[38599]
#define sipNameNr_swapBuffers 38611
#define sipName_swapBuffers &sipStrings_QtGui[38611]
#define sipNameNr_doneCurrent 38623
#define sipName_doneCurrent &sipStrings_QtGui[38623]
#define sipNameNr_makeCurrent 38635
#define sipName_makeCurrent &sipStrings_QtGui[38635]
#define sipNameNr_DynamicCopy 38647
#define sipName_DynamicCopy &sipStrings_QtGui[38647]
#define sipNameNr_DynamicRead 38659
#define sipName_DynamicRead &sipStrings_QtGui[38659]
#define sipNameNr_DynamicDraw 38671
#define sipName_DynamicDraw &sipStrings_QtGui[38671]
#define sipNameNr_IndexBuffer 38683
#define sipName_IndexBuffer &sipStrings_QtGui[38683]
#define sipNameNr_surfaceType 38695
#define sipName_surfaceType &sipStrings_QtGui[38695]
#define sipNameNr_jumpToFrame 38707
#define sipName_jumpToFrame &sipStrings_QtGui[38707]
#define sipNameNr___imatmul__ 38719
#define sipName___imatmul__ &sipStrings_QtGui[38719]
#define sipNameNr_toTransform 22105
#define sipName_toTransform &sipStrings_QtGui[22105]
#define sipNameNr_perspective 38731
#define sipName_perspective &sipStrings_QtGui[38731]
#define sipNameNr_determinant 38743
#define sipName_determinant &sipStrings_QtGui[38743]
#define sipNameNr_keyBindings 38755
#define sipName_keyBindings &sipStrings_QtGui[38755]
#define sipNameNr_Preferences 38767
#define sipName_Preferences &sipStrings_QtGui[38767]
#define sipNameNr_StandardKey 6309
#define sipName_StandardKey &sipStrings_QtGui[6309]
#define sipNameNr_isAnimating 38779
#define sipName_isAnimating &sipStrings_QtGui[38779]
#define sipNameNr_compression 38791
#define sipName_compression &sipStrings_QtGui[38791]
#define sipNameNr_imageFormat 38803
#define sipName_imageFormat &sipStrings_QtGui[38803]
#define sipNameNr_setClipRect 38815
#define sipName_setClipRect &sipStrings_QtGui[38815]
#define sipNameNr_DeviceError 38827
#define sipName_DeviceError &sipStrings_QtGui[38827]
#define sipNameNr_jumpToImage 38839
#define sipName_jumpToImage &sipStrings_QtGui[38839]
#define sipNameNr_Description 6868
#define sipName_Description &sipStrings_QtGui[6868]
#define sipNameNr_ImageOption 4064
#define sipName_ImageOption &sipStrings_QtGui[4064]
#define sipNameNr_sizeInBytes 38851
#define sipName_sizeInBytes &sipStrings_QtGui[38851]
#define sipNameNr_pixelFormat 38863
#define sipName_pixelFormat &sipStrings_QtGui[38863]
#define sipNameNr_paintEngine 38875
#define sipName_paintEngine &sipStrings_QtGui[38875]
#define sipNameNr_isGrayscale 38887
#define sipName_isGrayscale &sipStrings_QtGui[38887]
#define sipNameNr_Format_Mono 38899
#define sipName_Format_Mono &sipStrings_QtGui[38899]
#define sipNameNr_QIconEngine 38911
#define sipName_QIconEngine &sipStrings_QtGui[38911]
#define sipNameNr_QIcon__Mode 38923
#define sipName_QIcon__Mode &sipStrings_QtGui[38923]
#define sipNameNr_fontChanged 38935
#define sipName_fontChanged &sipStrings_QtGui[38935]
#define sipNameNr_inputMethod 38947
#define sipName_inputMethod &sipStrings_QtGui[38947]
#define sipNameNr_modalWindow 38959
#define sipName_modalWindow &sipStrings_QtGui[38959]
#define sipNameNr_screenAdded 38971
#define sipName_screenAdded &sipStrings_QtGui[38971]
#define sipNameNr_focusObject 38983
#define sipName_focusObject &sipStrings_QtGui[38983]
#define sipNameNr_focusWindow 38995
#define sipName_focusWindow &sipStrings_QtGui[38995]
#define sipNameNr_overlinePos 39007
#define sipName_overlinePos &sipStrings_QtGui[39007]
#define sipNameNr_leftBearing 39019
#define sipName_leftBearing &sipStrings_QtGui[39019]
#define sipNameNr_lineSpacing 39031
#define sipName_lineSpacing &sipStrings_QtGui[39031]
#define sipNameNr_GeneralFont 39043
#define sipName_GeneralFont &sipStrings_QtGui[39043]
#define sipNameNr_styleString 39055
#define sipName_styleString &sipStrings_QtGui[39055]
#define sipNameNr_smoothSizes 39067
#define sipName_smoothSizes &sipStrings_QtGui[39067]
#define sipNameNr_setFamilies 39079
#define sipName_setFamilies &sipStrings_QtGui[39079]
#define sipNameNr_wordSpacing 39091
#define sipName_wordSpacing &sipStrings_QtGui[39091]
#define sipNameNr_SpacingType 6618
#define sipName_SpacingType &sipStrings_QtGui[6618]
#define sipNameNr_substitutes 39103
#define sipName_substitutes &sipStrings_QtGui[39103]
#define sipNameNr_setOverline 39115
#define sipName_setOverline &sipStrings_QtGui[39115]
#define sipNameNr_Unstretched 39127
#define sipName_Unstretched &sipStrings_QtGui[39127]
#define sipNameNr_StyleItalic 39139
#define sipName_StyleItalic &sipStrings_QtGui[39139]
#define sipNameNr_StyleNormal 39151
#define sipName_StyleNormal &sipStrings_QtGui[39151]
#define sipNameNr_NoAntialias 39163
#define sipName_NoAntialias &sipStrings_QtGui[39163]
#define sipNameNr_PreferMatch 39175
#define sipName_PreferMatch &sipStrings_QtGui[39175]
#define sipNameNr_gestureType 39187
#define sipName_gestureType &sipStrings_QtGui[39187]
#define sipNameNr_QEnterEvent 39199
#define sipName_QEnterEvent &sipStrings_QtGui[39199]
#define sipNameNr_scrollState 39211
#define sipName_scrollState &sipStrings_QtGui[39211]
#define sipNameNr_ScrollState 6465
#define sipName_ScrollState &sipStrings_QtGui[6465]
#define sipNameNr_touchPoints 39223
#define sipName_touchPoints &sipStrings_QtGui[39223]
#define sipNameNr_QTouchEvent 39235
#define sipName_QTouchEvent &sipStrings_QtGui[39235]
#define sipNameNr_isAmbiguous 39247
#define sipName_isAmbiguous &sipStrings_QtGui[39247]
#define sipNameNr_QCloseEvent 39259
#define sipName_QCloseEvent &sipStrings_QtGui[39259]
#define sipNameNr_QPaintEvent 39271
#define sipName_QPaintEvent &sipStrings_QtGui[39271]
#define sipNameNr_QFocusEvent 39283
#define sipName_QFocusEvent &sipStrings_QtGui[39283]
#define sipNameNr_pointerType 39295
#define sipName_pointerType &sipStrings_QtGui[39295]
#define sipNameNr_PointerType 6517
#define sipName_PointerType &sipStrings_QtGui[6517]
#define sipNameNr_XFreeEraser 39307
#define sipName_XFreeEraser &sipStrings_QtGui[39307]
#define sipNameNr_QWheelEvent 39319
#define sipName_QWheelEvent &sipStrings_QtGui[39319]
#define sipNameNr_QHoverEvent 39331
#define sipName_QHoverEvent &sipStrings_QtGui[39331]
#define sipNameNr_QMouseEvent 39343
#define sipName_QMouseEvent &sipStrings_QtGui[39343]
#define sipNameNr_QInputEvent 39355
#define sipName_QInputEvent &sipStrings_QtGui[39355]
#define sipNameNr_ProPhotoRgb 39367
#define sipName_ProPhotoRgb &sipStrings_QtGui[39367]
#define sipNameNr_setMimeData 39379
#define sipName_setMimeData &sipStrings_QtGui[39379]
#define sipNameNr_focalRadius 39391
#define sipName_focalRadius &sipStrings_QtGui[39391]
#define sipNameNr_PerfectBlue 39403
#define sipName_PerfectBlue &sipStrings_QtGui[39403]
#define sipNameNr_GagarinView 39415
#define sipName_GagarinView &sipStrings_QtGui[39415]
#define sipNameNr_NorseBeauty 39427
#define sipName_NorseBeauty &sipStrings_QtGui[39427]
#define sipNameNr_SmartIndigo 39439
#define sipName_SmartIndigo &sipStrings_QtGui[39439]
#define sipNameNr_RoyalGarden 39451
#define sipName_RoyalGarden &sipStrings_QtGui[39451]
#define sipNameNr_OrangeJuice 39463
#define sipName_OrangeJuice &sipStrings_QtGui[39463]
#define sipNameNr_AboveTheSky 39475
#define sipName_AboveTheSky &sipStrings_QtGui[39475]
#define sipNameNr_FlyingLemon 39487
#define sipName_FlyingLemon &sipStrings_QtGui[39487]
#define sipNameNr_FrozenBerry 39499
#define sipName_FrozenBerry &sipStrings_QtGui[39499]
#define sipNameNr_Crystalline 39511
#define sipName_Crystalline &sipStrings_QtGui[39511]
#define sipNameNr_StrongStick 39523
#define sipName_StrongStick &sipStrings_QtGui[39523]
#define sipNameNr_CloudyApple 39535
#define sipName_CloudyApple &sipStrings_QtGui[39535]
#define sipNameNr_SmilingRain 39547
#define sipName_SmilingRain &sipStrings_QtGui[39547]
#define sipNameNr_SummerGames 39559
#define sipName_SummerGames &sipStrings_QtGui[39559]
#define sipNameNr_CochitiLake 39571
#define sipName_CochitiLake &sipStrings_QtGui[39571]
#define sipNameNr_ColdEvening 39583
#define sipName_ColdEvening &sipStrings_QtGui[39583]
#define sipNameNr_PremiumDark 39595
#define sipName_PremiumDark &sipStrings_QtGui[39595]
#define sipNameNr_CleanMirror 39607
#define sipName_CleanMirror &sipStrings_QtGui[39607]
#define sipNameNr_HeavenPeach 39619
#define sipName_HeavenPeach &sipStrings_QtGui[39619]
#define sipNameNr_SoftCherish 39631
#define sipName_SoftCherish &sipStrings_QtGui[39631]
#define sipNameNr_SweetPeriod 39643
#define sipName_SweetPeriod &sipStrings_QtGui[39643]
#define sipNameNr_DirtyBeauty 39655
#define sipName_DirtyBeauty &sipStrings_QtGui[39655]
#define sipNameNr_FebruaryInk 39667
#define sipName_FebruaryInk &sipStrings_QtGui[39667]
#define sipNameNr_StrongBliss 39679
#define sipName_StrongBliss &sipStrings_QtGui[39679]
#define sipNameNr_AwesomePine 39691
#define sipName_AwesomePine &sipStrings_QtGui[39691]
#define sipNameNr_ZeusMiracle 39703
#define sipName_ZeusMiracle &sipStrings_QtGui[39703]
#define sipNameNr_HappyFisher 39715
#define sipName_HappyFisher &sipStrings_QtGui[39715]
#define sipNameNr_MorpheusDen 39727
#define sipName_MorpheusDen &sipStrings_QtGui[39727]
#define sipNameNr_MalibuBeach 39739
#define sipName_MalibuBeach &sipStrings_QtGui[39739]
#define sipNameNr_RipeMalinka 39751
#define sipName_RipeMalinka &sipStrings_QtGui[39751]
#define sipNameNr_LogicalMode 39763
#define sipName_LogicalMode &sipStrings_QtGui[39763]
#define sipNameNr_yellowgreen 39775
#define sipName_yellowgreen &sipStrings_QtGui[39775]
#define sipNameNr_springgreen 20176
#define sipName_springgreen &sipStrings_QtGui[20176]
#define sipNameNr_saddlebrown 39787
#define sipName_saddlebrown &sipStrings_QtGui[39787]
#define sipNameNr_navajowhite 39799
#define sipName_navajowhite &sipStrings_QtGui[39799]
#define sipNameNr_lightyellow 39811
#define sipName_lightyellow &sipStrings_QtGui[39811]
#define sipNameNr_lightsalmon 39823
#define sipName_lightsalmon &sipStrings_QtGui[39823]
#define sipNameNr_greenyellow 39835
#define sipName_greenyellow &sipStrings_QtGui[39835]
#define sipNameNr_forestgreen 39847
#define sipName_forestgreen &sipStrings_QtGui[39847]
#define sipNameNr_floralwhite 39859
#define sipName_floralwhite &sipStrings_QtGui[39859]
#define sipNameNr_deepskyblue 39871
#define sipName_deepskyblue &sipStrings_QtGui[39871]
#define sipNameNr_darkmagenta 39883
#define sipName_darkmagenta &sipStrings_QtGui[39883]
#define sipNameNr_Transparent 30354
#define sipName_Transparent &sipStrings_QtGui[30354]
#define sipNameNr_DarkMagenta 39895
#define sipName_DarkMagenta &sipStrings_QtGui[39895]
#define sipNameNr_saturationF 39907
#define sipName_saturationF &sipStrings_QtGui[39907]
#define sipNameNr_ExtendedRgb 32804
#define sipName_ExtendedRgb &sipStrings_QtGui[32804]
#define sipNameNr_transformed 39919
#define sipName_transformed &sipStrings_QtGui[39919]
#define sipNameNr_updateBlock 39931
#define sipName_updateBlock &sipStrings_QtGui[39931]
#define sipNameNr_paintDevice 39943
#define sipName_paintDevice &sipStrings_QtGui[39943]
#define sipNameNr_setPosition 39955
#define sipName_setPosition &sipStrings_QtGui[39955]
#define sipNameNr_setSortRole 39967
#define sipName_setSortRole &sipStrings_QtGui[39967]
#define sipNameNr_customEvent 39979
#define sipName_customEvent &sipStrings_QtGui[39979]
#define sipNameNr_setProperty 39991
#define sipName_setProperty &sipStrings_QtGui[39991]
#define sipNameNr_eventFilter 40003
#define sipName_eventFilter &sipStrings_QtGui[40003]
#define sipNameNr_QColorSpace 40015
#define sipName_QColorSpace &sipStrings_QtGui[40015]
#define sipNameNr_QQuaternion 40027
#define sipName_QQuaternion &sipStrings_QtGui[40027]
#define sipNameNr_QTextFormat 40039
#define sipName_QTextFormat &sipStrings_QtGui[40039]
#define sipNameNr_QTextLength 40051
#define sipName_QTextLength &sipStrings_QtGui[40051]
#define sipNameNr___delitem__ 40063
#define sipName___delitem__ &sipStrings_QtGui[40063]
#define sipNameNr___setitem__ 40075
#define sipName___setitem__ &sipStrings_QtGui[40075]
#define sipNameNr_intersected 40087
#define sipName_intersected &sipStrings_QtGui[40087]
#define sipNameNr_errorString 40099
#define sipName_errorString &sipStrings_QtGui[40099]
#define sipNameNr_setFileName 40111
#define sipName_setFileName &sipStrings_QtGui[40111]
#define sipNameNr_ContextMenu 40123
#define sipName_ContextMenu &sipStrings_QtGui[40123]
#define sipNameNr_description 40135
#define sipName_description &sipStrings_QtGui[40135]
#define sipNameNr_lastIndexOf 40147
#define sipName_lastIndexOf &sipStrings_QtGui[40147]
#define sipNameNr___getitem__ 40159
#define sipName___getitem__ &sipStrings_QtGui[40159]
#define sipNameNr_moveColumns 32958
#define sipName_moveColumns &sipStrings_QtGui[32958]
#define sipNameNr_dataChanged 40171
#define sipName_dataChanged &sipStrings_QtGui[40171]
#define sipNameNr_setItemData 40183
#define sipName_setItemData &sipStrings_QtGui[40183]
#define sipNameNr_orientation 40195
#define sipName_orientation &sipStrings_QtGui[40195]
#define sipNameNr_hasChildren 40207
#define sipName_hasChildren &sipStrings_QtGui[40207]
#define sipNameNr_columnCount 40219
#define sipName_columnCount &sipStrings_QtGui[40219]
#define sipNameNr_updateState 40231
#define sipName_updateState &sipStrings_QtGui[40231]
#define sipNameNr_RightToLeft 28516
#define sipName_RightToLeft &sipStrings_QtGui[28516]
#define sipNameNr_DashDotLine 40243
#define sipName_DashDotLine &sipStrings_QtGui[40243]
#define sipNameNr_AlignBottom 40255
#define sipName_AlignBottom &sipStrings_QtGui[40255]
#define sipNameNr_Orientation 7143
#define sipName_Orientation &sipStrings_QtGui[7143]
#define sipNameNr_PyQt5_QtGui 40267
#define sipName_PyQt5_QtGui &sipStrings_QtGui[40267]
#define sipNameNr_visibility 40279
#define sipName_visibility &sipStrings_QtGui[40279]
#define sipNameNr_Visibility 13449
#define sipName_Visibility &sipStrings_QtGui[13449]
#define sipNameNr_touchEvent 40290
#define sipName_touchEvent &sipStrings_QtGui[40290]
#define sipNameNr_wheelEvent 40301
#define sipName_wheelEvent &sipStrings_QtGui[40301]
#define sipNameNr_showNormal 40312
#define sipName_showNormal &sipStrings_QtGui[40312]
#define sipNameNr_isTopLevel 40323
#define sipName_isTopLevel &sipStrings_QtGui[40323]
#define sipNameNr_toVector2D 40334
#define sipName_toVector2D &sipStrings_QtGui[40334]
#define sipNameNr_toVector3D 40345
#define sipName_toVector3D &sipStrings_QtGui[40345]
#define sipNameNr_Acceptable 40356
#define sipName_Acceptable &sipStrings_QtGui[40356]
#define sipNameNr_QValidator 40367
#define sipName_QValidator &sipStrings_QtGui[40367]
#define sipNameNr_isRotating 40378
#define sipName_isRotating &sipStrings_QtGui[40378]
#define sipNameNr_quadToQuad 40389
#define sipName_quadToQuad &sipStrings_QtGui[40389]
#define sipNameNr_DeviceType 6569
#define sipName_DeviceType &sipStrings_QtGui[6569]
#define sipNameNr_mergeCells 40400
#define sipName_mergeCells &sipStrings_QtGui[40400]
#define sipNameNr_QTextTable 40411
#define sipName_QTextTable &sipStrings_QtGui[40411]
#define sipNameNr_columnSpan 40422
#define sipName_columnSpan &sipStrings_QtGui[40422]
#define sipNameNr_setTabStop 40433
#define sipName_setTabStop &sipStrings_QtGui[40433]
#define sipNameNr_ManualWrap 40444
#define sipName_ManualWrap &sipStrings_QtGui[40444]
#define sipNameNr_QTextBlock 40455
#define sipName_QTextBlock &sipStrings_QtGui[40455]
#define sipNameNr_QTextFrame 40466
#define sipName_QTextFrame &sipStrings_QtGui[40466]
#define sipNameNr_removeItem 40477
#define sipName_removeItem &sipStrings_QtGui[40477]
#define sipNameNr_itemNumber 40488
#define sipName_itemNumber &sipStrings_QtGui[40488]
#define sipNameNr_textLength 40499
#define sipName_textLength &sipStrings_QtGui[40499]
#define sipNameNr_setFormats 40510
#define sipName_setFormats &sipStrings_QtGui[40510]
#define sipNameNr_drawCursor 40521
#define sipName_drawCursor &sipStrings_QtGui[40521]
#define sipNameNr_CursorMode 7566
#define sipName_CursorMode &sipStrings_QtGui[7566]
#define sipNameNr_createLine 40532
#define sipName_createLine &sipStrings_QtGui[40532]
#define sipNameNr_setDescent 40543
#define sipName_setDescent &sipStrings_QtGui[40543]
#define sipNameNr_leftBorder 40554
#define sipName_leftBorder &sipStrings_QtGui[40554]
#define sipNameNr_topPadding 40565
#define sipName_topPadding &sipStrings_QtGui[40565]
#define sipNameNr_setColumns 40576
#define sipName_setColumns &sipStrings_QtGui[40576]
#define sipNameNr_setPadding 40587
#define sipName_setPadding &sipStrings_QtGui[40587]
#define sipNameNr_FloatRight 40598
#define sipName_FloatRight &sipStrings_QtGui[40598]
#define sipNameNr_ListSquare 40609
#define sipName_ListSquare &sipStrings_QtGui[40609]
#define sipNameNr_ListCircle 40620
#define sipName_ListCircle &sipStrings_QtGui[40620]
#define sipNameNr_lineHeight 40631
#define sipName_lineHeight &sipStrings_QtGui[40631]
#define sipNameNr_textIndent 40642
#define sipName_textIndent &sipStrings_QtGui[40642]
#define sipNameNr_anchorHref 40653
#define sipName_anchorHref &sipStrings_QtGui[40653]
#define sipNameNr_fontItalic 40664
#define sipName_fontItalic &sipStrings_QtGui[40664]
#define sipNameNr_fontWeight 40675
#define sipName_fontWeight &sipStrings_QtGui[40675]
#define sipNameNr_fontFamily 40686
#define sipName_fontFamily &sipStrings_QtGui[40686]
#define sipNameNr_properties 40697
#define sipName_properties &sipStrings_QtGui[40697]
#define sipNameNr_ImageTitle 40708
#define sipName_ImageTitle &sipStrings_QtGui[40708]
#define sipNameNr_LineHeight 29585
#define sipName_LineHeight &sipStrings_QtGui[29585]
#define sipNameNr_ImageWidth 40719
#define sipName_ImageWidth &sipStrings_QtGui[40719]
#define sipNameNr_FrameWidth 40730
#define sipName_FrameWidth &sipStrings_QtGui[40730]
#define sipNameNr_ListIndent 40741
#define sipName_ListIndent &sipStrings_QtGui[40741]
#define sipNameNr_ObjectType 29767
#define sipName_ObjectType &sipStrings_QtGui[29767]
#define sipNameNr_AnchorName 40752
#define sipName_AnchorName &sipStrings_QtGui[40752]
#define sipNameNr_AnchorHref 29669
#define sipName_AnchorHref &sipStrings_QtGui[29669]
#define sipNameNr_FontItalic 29711
#define sipName_FontItalic &sipStrings_QtGui[29711]
#define sipNameNr_FontWeight 29725
#define sipName_FontWeight &sipStrings_QtGui[29725]
#define sipNameNr_FontFamily 29753
#define sipName_FontFamily &sipStrings_QtGui[29753]
#define sipNameNr_TextIndent 29599
#define sipName_TextIndent &sipStrings_QtGui[29599]
#define sipNameNr_OutlinePen 40763
#define sipName_OutlinePen &sipStrings_QtGui[40763]
#define sipNameNr_UserObject 40774
#define sipName_UserObject &sipStrings_QtGui[40774]
#define sipNameNr_UserFormat 40785
#define sipName_UserFormat &sipStrings_QtGui[40785]
#define sipNameNr_ListFormat 23246
#define sipName_ListFormat &sipStrings_QtGui[23246]
#define sipNameNr_CharFormat 12191
#define sipName_CharFormat &sipStrings_QtGui[12191]
#define sipNameNr_toMarkdown 40796
#define sipName_toMarkdown &sipStrings_QtGui[40796]
#define sipNameNr_setBaseUrl 40807
#define sipName_setBaseUrl &sipStrings_QtGui[40807]
#define sipNameNr_firstBlock 40818
#define sipName_firstBlock &sipStrings_QtGui[40818]
#define sipNameNr_blockCount 40829
#define sipName_blockCount &sipStrings_QtGui[40829]
#define sipNameNr_adjustSize 40840
#define sipName_adjustSize &sipStrings_QtGui[40840]
#define sipNameNr_idealWidth 40851
#define sipName_idealWidth &sipStrings_QtGui[40851]
#define sipNameNr_allFormats 40862
#define sipName_allFormats &sipStrings_QtGui[40862]
#define sipNameNr_isModified 40873
#define sipName_isModified &sipStrings_QtGui[40873]
#define sipNameNr_insertHtml 40884
#define sipName_insertHtml &sipStrings_QtGui[40884]
#define sipNameNr_createList 40895
#define sipName_createList &sipStrings_QtGui[40895]
#define sipNameNr_insertList 40906
#define sipName_insertList &sipStrings_QtGui[40906]
#define sipNameNr_atBlockEnd 40917
#define sipName_atBlockEnd &sipStrings_QtGui[40917]
#define sipNameNr_charFormat 40928
#define sipName_charFormat &sipStrings_QtGui[40928]
#define sipNameNr_deleteChar 40939
#define sipName_deleteChar &sipStrings_QtGui[40939]
#define sipNameNr_EndOfBlock 22038
#define sipName_EndOfBlock &sipStrings_QtGui[22038]
#define sipNameNr_insertText 40950
#define sipName_insertText &sipStrings_QtGui[40950]
#define sipNameNr_KeepAnchor 40961
#define sipName_KeepAnchor &sipStrings_QtGui[40961]
#define sipNameNr_MoveAnchor 40972
#define sipName_MoveAnchor &sipStrings_QtGui[40972]
#define sipNameNr_ColorSpace 4210
#define sipName_ColorSpace &sipStrings_QtGui[4210]
#define sipNameNr_setOptions 40983
#define sipName_setOptions &sipStrings_QtGui[40983]
#define sipNameNr_testOption 40994
#define sipName_testOption &sipStrings_QtGui[40994]
#define sipNameNr_textOption 41005
#define sipName_textOption &sipStrings_QtGui[41005]
#define sipNameNr_textFormat 41016
#define sipName_textFormat &sipStrings_QtGui[41016]
#define sipNameNr_appendRows 41027
#define sipName_appendRows &sipStrings_QtGui[41027]
#define sipNameNr_setToolTip 41038
#define sipName_setToolTip &sipStrings_QtGui[41038]
#define sipNameNr_isTristate 41049
#define sipName_isTristate &sipStrings_QtGui[41049]
#define sipNameNr_isEditable 41060
#define sipName_isEditable &sipStrings_QtGui[41060]
#define sipNameNr_checkState 41071
#define sipName_checkState &sipStrings_QtGui[41071]
#define sipNameNr_takeColumn 41082
#define sipName_takeColumn &sipStrings_QtGui[41082]
#define sipNameNr_grabWindow 41093
#define sipName_grabWindow &sipStrings_QtGui[41093]
#define sipNameNr_isPortrait 41104
#define sipName_isPortrait &sipStrings_QtGui[41104]
#define sipNameNr_mapBetween 41115
#define sipName_mapBetween &sipStrings_QtGui[41115]
#define sipNameNr_fromArgb32 41126
#define sipName_fromArgb32 &sipStrings_QtGui[41126]
#define sipNameNr_RegionType 14089
#define sipName_RegionType &sipStrings_QtGui[14089]
#define sipNameNr_LayoutFlag 12401
#define sipName_LayoutFlag &sipStrings_QtGui[12401]
#define sipNameNr_unitsPerEm 41137
#define sipName_unitsPerEm &sipStrings_QtGui[41137]
#define sipNameNr_familyName 41148
#define sipName_familyName &sipStrings_QtGui[41148]
#define sipNameNr_conjugated 41159
#define sipName_conjugated &sipStrings_QtGui[41159]
#define sipNameNr_rotationTo 41170
#define sipName_rotationTo &sipStrings_QtGui[41170]
#define sipNameNr_toVector4D 41181
#define sipName_toVector4D &sipStrings_QtGui[41181]
#define sipNameNr_cacheLimit 41192
#define sipName_cacheLimit &sipStrings_QtGui[41192]
#define sipNameNr_alphaUsage 41203
#define sipName_alphaUsage &sipStrings_QtGui[41203]
#define sipNameNr_yellowSize 41214
#define sipName_yellowSize &sipStrings_QtGui[41214]
#define sipNameNr_colorModel 41225
#define sipName_colorModel &sipStrings_QtGui[41225]
#define sipNameNr_AlphaUsage 6994
#define sipName_AlphaUsage &sipStrings_QtGui[6994]
#define sipNameNr_ColorModel 7019
#define sipName_ColorModel &sipStrings_QtGui[7019]
#define sipNameNr_setPicture 41236
#define sipName_setPicture &sipStrings_QtGui[41236]
#define sipNameNr_parameters 41247
#define sipName_parameters &sipStrings_QtGui[41247]
#define sipNameNr_QPictureIO 41258
#define sipName_QPictureIO &sipStrings_QtGui[41258]
#define sipNameNr_isCosmetic 41269
#define sipName_isCosmetic &sipStrings_QtGui[41269]
#define sipNameNr_pdfVersion 41280
#define sipName_pdfVersion &sipStrings_QtGui[41280]
#define sipNameNr_setCreator 41291
#define sipName_setCreator &sipStrings_QtGui[41291]
#define sipNameNr_QPdfWriter 41302
#define sipName_QPdfWriter &sipStrings_QtGui[41302]
#define sipNameNr_isBrushSet 41313
#define sipName_isBrushSet &sipStrings_QtGui[41313]
#define sipNameNr_buttonText 41324
#define sipName_buttonText &sipStrings_QtGui[41324]
#define sipNameNr_brightText 41335
#define sipName_brightText &sipStrings_QtGui[41335]
#define sipNameNr_windowText 41346
#define sipName_windowText &sipStrings_QtGui[41346]
#define sipNameNr_Background 23406
#define sipName_Background &sipStrings_QtGui[23406]
#define sipNameNr_ButtonText 41357
#define sipName_ButtonText &sipStrings_QtGui[41357]
#define sipNameNr_BrightText 41368
#define sipName_BrightText &sipStrings_QtGui[41368]
#define sipNameNr_Foreground 23390
#define sipName_Foreground &sipStrings_QtGui[23390]
#define sipNameNr_WindowText 41379
#define sipName_WindowText &sipStrings_QtGui[41379]
#define sipNameNr_ColorGroup 12443
#define sipName_ColorGroup &sipStrings_QtGui[12443]
#define sipNameNr_foreground 41390
#define sipName_foreground &sipStrings_QtGui[41390]
#define sipNameNr_dashOffset 41401
#define sipName_dashOffset &sipStrings_QtGui[41401]
#define sipNameNr_miterLimit 41412
#define sipName_miterLimit &sipStrings_QtGui[41412]
#define sipNameNr_subtracted 41423
#define sipName_subtracted &sipStrings_QtGui[41423]
#define sipNameNr_toReversed 41434
#define sipName_toReversed &sipStrings_QtGui[41434]
#define sipNameNr_addPolygon 41445
#define sipName_addPolygon &sipStrings_QtGui[41445]
#define sipNameNr_addEllipse 41456
#define sipName_addEllipse &sipStrings_QtGui[41456]
#define sipNameNr_PostScript 41467
#define sipName_PostScript &sipStrings_QtGui[41467]
#define sipNameNr_MacPrinter 41478
#define sipName_MacPrinter &sipStrings_QtGui[41478]
#define sipNameNr_ConvexMode 41489
#define sipName_ConvexMode &sipStrings_QtGui[41489]
#define sipNameNr_DirtyFlags 7044
#define sipName_DirtyFlags &sipStrings_QtGui[7044]
#define sipNameNr_DirtyHints 41500
#define sipName_DirtyHints &sipStrings_QtGui[41500]
#define sipNameNr_DirtyBrush 41511
#define sipName_DirtyBrush &sipStrings_QtGui[41511]
#define sipNameNr_BlendModes 41522
#define sipName_BlendModes &sipStrings_QtGui[41522]
#define sipNameNr_PorterDuff 41533
#define sipName_PorterDuff &sipStrings_QtGui[41533]
#define sipNameNr_AlphaBlend 41544
#define sipName_AlphaBlend &sipStrings_QtGui[41544]
#define sipNameNr_RenderFlag 10679
#define sipName_RenderFlag &sipStrings_QtGui[10679]
#define sipNameNr_PdmWidthMM 41555
#define sipName_PdmWidthMM &sipStrings_QtGui[41555]
#define sipNameNr_OpaqueHint 41566
#define sipName_OpaqueHint &sipStrings_QtGui[41566]
#define sipNameNr_sourceLeft 41577
#define sipName_sourceLeft &sipStrings_QtGui[41577]
#define sipNameNr_drawPixmap 41588
#define sipName_drawPixmap &sipStrings_QtGui[41588]
#define sipNameNr_drawPoints 41599
#define sipName_drawPoints &sipStrings_QtGui[41599]
#define sipNameNr_strokePath 41610
#define sipName_strokePath &sipStrings_QtGui[41610]
#define sipNameNr_clipRegion 41621
#define sipName_clipRegion &sipStrings_QtGui[41621]
#define sipNameNr_background 41632
#define sipName_background &sipStrings_QtGui[41632]
#define sipNameNr_RenderHint 12590
#define sipName_RenderHint &sipStrings_QtGui[12590]
#define sipNameNr_rectPixels 41643
#define sipName_rectPixels &sipStrings_QtGui[41643]
#define sipNameNr_rectPoints 41654
#define sipName_rectPoints &sipStrings_QtGui[41654]
#define sipNameNr_sizePixels 41665
#define sipName_sizePixels &sipStrings_QtGui[41665]
#define sipNameNr_sizePoints 41676
#define sipName_sizePoints &sipStrings_QtGui[41676]
#define sipNameNr_FuzzyMatch 41687
#define sipName_FuzzyMatch &sipStrings_QtGui[41687]
#define sipNameNr_PageSizeId 10855
#define sipName_PageSizeId &sipStrings_QtGui[10855]
#define sipNameNr_resolution 41698
#define sipName_resolution &sipStrings_QtGui[41698]
#define sipNameNr_leftMargin 41709
#define sipName_leftMargin &sipStrings_QtGui[41709]
#define sipNameNr_minMargins 41720
#define sipName_minMargins &sipStrings_QtGui[41720]
#define sipNameNr_Millimeter 41731
#define sipName_Millimeter &sipStrings_QtGui[41731]
#define sipNameNr_pageLayout 41742
#define sipName_pageLayout &sipStrings_QtGui[41742]
#define sipNameNr_setMargins 41753
#define sipName_setMargins &sipStrings_QtGui[41753]
#define sipNameNr_pageSizeMM 41764
#define sipName_pageSizeMM &sipStrings_QtGui[41764]
#define sipNameNr_PdfVersion 3061
#define sipName_PdfVersion &sipStrings_QtGui[3061]
#define sipNameNr_Envelope10 41775
#define sipName_Envelope10 &sipStrings_QtGui[41775]
#define sipNameNr_EnvelopeDL 41786
#define sipName_EnvelopeDL &sipStrings_QtGui[41786]
#define sipNameNr_EnvelopeC5 41797
#define sipName_EnvelopeC5 &sipStrings_QtGui[41797]
#define sipNameNr_NPaperSize 41808
#define sipName_NPaperSize &sipStrings_QtGui[41808]
#define sipNameNr_Envelope14 41819
#define sipName_Envelope14 &sipStrings_QtGui[41819]
#define sipNameNr_Envelope12 41830
#define sipName_Envelope12 &sipStrings_QtGui[41830]
#define sipNameNr_Envelope11 41841
#define sipName_Envelope11 &sipStrings_QtGui[41841]
#define sipNameNr_EnvelopeC7 41852
#define sipName_EnvelopeC7 &sipStrings_QtGui[41852]
#define sipNameNr_EnvelopeC6 41863
#define sipName_EnvelopeC6 &sipStrings_QtGui[41863]
#define sipNameNr_EnvelopeC4 41874
#define sipName_EnvelopeC4 &sipStrings_QtGui[41874]
#define sipNameNr_EnvelopeC3 41885
#define sipName_EnvelopeC3 &sipStrings_QtGui[41885]
#define sipNameNr_EnvelopeC2 41896
#define sipName_EnvelopeC2 &sipStrings_QtGui[41896]
#define sipNameNr_EnvelopeC1 41907
#define sipName_EnvelopeC1 &sipStrings_QtGui[41907]
#define sipNameNr_EnvelopeC0 41918
#define sipName_EnvelopeC0 &sipStrings_QtGui[41918]
#define sipNameNr_EnvelopeB6 41929
#define sipName_EnvelopeB6 &sipStrings_QtGui[41929]
#define sipNameNr_EnvelopeB5 41940
#define sipName_EnvelopeB5 &sipStrings_QtGui[41940]
#define sipNameNr_EnvelopeB4 41951
#define sipName_EnvelopeB4 &sipStrings_QtGui[41951]
#define sipNameNr_LetterPlus 41962
#define sipName_LetterPlus &sipStrings_QtGui[41962]
#define sipNameNr_LegalExtra 41973
#define sipName_LegalExtra &sipStrings_QtGui[41973]
#define sipNameNr_paintEvent 41984
#define sipName_paintEvent &sipStrings_QtGui[41984]
#define sipNameNr_setOpacity 41995
#define sipName_setOpacity &sipStrings_QtGui[41995]
#define sipNameNr_DirectionR 42006
#define sipName_DirectionR &sipStrings_QtGui[42006]
#define sipNameNr_DirectionT 42017
#define sipName_DirectionT &sipStrings_QtGui[42017]
#define sipNameNr_DirectionS 42028
#define sipName_DirectionS &sipStrings_QtGui[42028]
#define sipNameNr_AlphaValue 42039
#define sipName_AlphaValue &sipStrings_QtGui[42039]
#define sipNameNr_GreenValue 42050
#define sipName_GreenValue &sipStrings_QtGui[42050]
#define sipNameNr_SwizzleRed 42061
#define sipName_SwizzleRed &sipStrings_QtGui[42061]
#define sipNameNr_hasFeature 42072
#define sipName_hasFeature &sipStrings_QtGui[42072]
#define sipNameNr_Float16OES 42083
#define sipName_Float16OES &sipStrings_QtGui[42083]
#define sipNameNr_RG_Integer 42094
#define sipName_RG_Integer &sipStrings_QtGui[42094]
#define sipNameNr_SRGB8_ETC2 42105
#define sipName_SRGB8_ETC2 &sipStrings_QtGui[42105]
#define sipNameNr_RGBAFormat 42116
#define sipName_RGBAFormat &sipStrings_QtGui[42116]
#define sipNameNr_RG16_SNorm 42127
#define sipName_RG16_SNorm &sipStrings_QtGui[42127]
#define sipNameNr_RGB8_SNorm 42138
#define sipName_RGB8_SNorm &sipStrings_QtGui[42138]
#define sipNameNr_RG16_UNorm 42149
#define sipName_RG16_UNorm &sipStrings_QtGui[42149]
#define sipNameNr_RGB8_UNorm 42160
#define sipName_RGB8_UNorm &sipStrings_QtGui[42160]
#define sipNameNr_genMipMaps 42171
#define sipName_genMipMaps &sipStrings_QtGui[42171]
#define sipNameNr_isCompiled 42182
#define sipName_isCompiled &sipStrings_QtGui[42182]
#define sipNameNr_sourceCode 42193
#define sipName_sourceCode &sipStrings_QtGui[42193]
#define sipNameNr_shaderType 42204
#define sipName_shaderType &sipStrings_QtGui[42204]
#define sipNameNr_ShaderType 6232
#define sipName_ShaderType &sipStrings_QtGui[6232]
#define sipNameNr_skipPixels 42215
#define sipName_skipPixels &sipStrings_QtGui[42215]
#define sipNameNr_skipImages 42226
#define sipName_skipImages &sipStrings_QtGui[42226]
#define sipNameNr_setSamples 42237
#define sipName_setSamples &sipStrings_QtGui[42237]
#define sipNameNr_attachment 42248
#define sipName_attachment &sipStrings_QtGui[42248]
#define sipNameNr_Attachment 425
#define sipName_Attachment &sipStrings_QtGui[425]
#define sipNameNr_logMessage 42259
#define sipName_logMessage &sipStrings_QtGui[42259]
#define sipNameNr_severities 42270
#define sipName_severities &sipStrings_QtGui[42270]
#define sipNameNr_Severities 2137
#define sipName_Severities &sipStrings_QtGui[2137]
#define sipNameNr_MarkerType 3688
#define sipName_MarkerType &sipStrings_QtGui[3688]
#define sipNameNr_setProfile 42281
#define sipName_setProfile &sipStrings_QtGui[42281]
#define sipNameNr_isOpenGLES 42292
#define sipName_isOpenGLES &sipStrings_QtGui[42292]
#define sipNameNr_extensions 42303
#define sipName_extensions &sipStrings_QtGui[42303]
#define sipNameNr_areSharing 42314
#define sipName_areSharing &sipStrings_QtGui[42314]
#define sipNameNr_shareGroup 42325
#define sipName_shareGroup &sipStrings_QtGui[42325]
#define sipNameNr_RangeWrite 42336
#define sipName_RangeWrite &sipStrings_QtGui[42336]
#define sipNameNr_StaticCopy 42347
#define sipName_StaticCopy &sipStrings_QtGui[42347]
#define sipNameNr_StaticRead 42358
#define sipName_StaticRead &sipStrings_QtGui[42358]
#define sipNameNr_StaticDraw 42369
#define sipName_StaticDraw &sipStrings_QtGui[42369]
#define sipNameNr_StreamCopy 42380
#define sipName_StreamCopy &sipStrings_QtGui[42380]
#define sipNameNr_StreamRead 42391
#define sipName_StreamRead &sipStrings_QtGui[42391]
#define sipNameNr_StreamDraw 42402
#define sipName_StreamDraw &sipStrings_QtGui[42402]
#define sipNameNr_frameCount 42413
#define sipName_frameCount &sipStrings_QtGui[42413]
#define sipNameNr_MovieState 16915
#define sipName_MovieState &sipStrings_QtGui[16915]
#define sipNameNr___matmul__ 42424
#define sipName___matmul__ &sipStrings_QtGui[42424]
#define sipNameNr_invertible 42435
#define sipName_invertible &sipStrings_QtGui[42435]
#define sipNameNr_FullScreen 21222
#define sipName_FullScreen &sipStrings_QtGui[21222]
#define sipNameNr_UnknownKey 42446
#define sipName_UnknownKey &sipStrings_QtGui[42446]
#define sipNameNr_ExactMatch 42457
#define sipName_ExactMatch &sipStrings_QtGui[42457]
#define sipNameNr_NativeText 42468
#define sipName_NativeText &sipStrings_QtGui[42468]
#define sipNameNr_setVisible 42479
#define sipName_setVisible &sipStrings_QtGui[42479]
#define sipNameNr_setSubType 42490
#define sipName_setSubType &sipStrings_QtGui[42490]
#define sipNameNr_setQuality 42501
#define sipName_setQuality &sipStrings_QtGui[42501]
#define sipNameNr_scaledSize 42512
#define sipName_scaledSize &sipStrings_QtGui[42512]
#define sipNameNr_imageCount 42523
#define sipName_imageCount &sipStrings_QtGui[42523]
#define sipNameNr_Endianness 42534
#define sipName_Endianness &sipStrings_QtGui[42534]
#define sipNameNr_ScaledSize 31601
#define sipName_ScaledSize &sipStrings_QtGui[31601]
#define sipNameNr_pixelColor 42545
#define sipName_pixelColor &sipStrings_QtGui[42545]
#define sipNameNr_colorCount 42556
#define sipName_colorCount &sipStrings_QtGui[42556]
#define sipNameNr_trueMatrix 42567
#define sipName_trueMatrix &sipStrings_QtGui[42567]
#define sipNameNr_rgbSwapped 42578
#define sipName_rgbSwapped &sipStrings_QtGui[42578]
#define sipNameNr_horizontal 42589
#define sipName_horizontal &sipStrings_QtGui[42589]
#define sipNameNr_pixelIndex 42600
#define sipName_pixelIndex &sipStrings_QtGui[42600]
#define sipNameNr_colorTable 42611
#define sipName_colorTable &sipStrings_QtGui[42611]
#define sipNameNr_InvertRgba 42622
#define sipName_InvertRgba &sipStrings_QtGui[42622]
#define sipNameNr_InvertMode 17314
#define sipName_InvertMode &sipStrings_QtGui[17314]
#define sipNameNr_IsNullHook 42633
#define sipName_IsNullHook &sipStrings_QtGui[42633]
#define sipNameNr_actualSize 42644
#define sipName_actualSize &sipStrings_QtGui[42644]
#define sipNameNr_windowIcon 42655
#define sipName_windowIcon &sipStrings_QtGui[42655]
#define sipNameNr_styleHints 42666
#define sipName_styleHints &sipStrings_QtGui[42666]
#define sipNameNr_setPalette 42677
#define sipName_setPalette &sipStrings_QtGui[42677]
#define sipNameNr_topLevelAt 42688
#define sipName_topLevelAt &sipStrings_QtGui[42688]
#define sipNameNr_allWindows 42699
#define sipName_allWindows &sipStrings_QtGui[42699]
#define sipNameNr_setRawFont 42710
#define sipName_setRawFont &sipStrings_QtGui[42710]
#define sipNameNr_QMatrix2x2 42721
#define sipName_QMatrix2x2 &sipStrings_QtGui[42721]
#define sipNameNr_QMatrix2x3 42732
#define sipName_QMatrix2x3 &sipStrings_QtGui[42732]
#define sipNameNr_QMatrix2x4 42743
#define sipName_QMatrix2x4 &sipStrings_QtGui[42743]
#define sipNameNr_QMatrix3x2 42754
#define sipName_QMatrix3x2 &sipStrings_QtGui[42754]
#define sipNameNr_QMatrix3x3 42765
#define sipName_QMatrix3x3 &sipStrings_QtGui[42765]
#define sipNameNr_QMatrix3x4 42776
#define sipName_QMatrix3x4 &sipStrings_QtGui[42776]
#define sipNameNr_QMatrix4x2 42787
#define sipName_QMatrix4x2 &sipStrings_QtGui[42787]
#define sipNameNr_isIdentity 42798
#define sipName_isIdentity &sipStrings_QtGui[42798]
#define sipNameNr_copyDataTo 42809
#define sipName_copyDataTo &sipStrings_QtGui[42809]
#define sipNameNr_QMatrix4x3 42820
#define sipName_QMatrix4x3 &sipStrings_QtGui[42820]
#define sipNameNr_inFontUcs4 42831
#define sipName_inFontUcs4 &sipStrings_QtGui[42831]
#define sipNameNr_elidedText 42842
#define sipName_elidedText &sipStrings_QtGui[42842]
#define sipNameNr_systemFont 42853
#define sipName_systemFont &sipStrings_QtGui[42853]
#define sipNameNr_SystemFont 6388
#define sipName_SystemFont &sipStrings_QtGui[6388]
#define sipNameNr_isScalable 42864
#define sipName_isScalable &sipStrings_QtGui[42864]
#define sipNameNr_pointSizes 42875
#define sipName_pointSizes &sipStrings_QtGui[42875]
#define sipNameNr_Devanagari 42886
#define sipName_Devanagari &sipStrings_QtGui[42886]
#define sipNameNr_Capitalize 42897
#define sipName_Capitalize &sipStrings_QtGui[42897]
#define sipNameNr_initialize 42908
#define sipName_initialize &sipStrings_QtGui[42908]
#define sipNameNr_substitute 42919
#define sipName_substitute &sipStrings_QtGui[42919]
#define sipNameNr_setRawName 42930
#define sipName_setRawName &sipStrings_QtGui[42930]
#define sipNameNr_setRawMode 42941
#define sipName_setRawMode &sipStrings_QtGui[42941]
#define sipNameNr_setStretch 42952
#define sipName_setStretch &sipStrings_QtGui[42952]
#define sipNameNr_setKerning 42963
#define sipName_setKerning &sipStrings_QtGui[42963]
#define sipNameNr_fixedPitch 42974
#define sipName_fixedPitch &sipStrings_QtGui[42974]
#define sipNameNr_pointSizeF 42985
#define sipName_pointSizeF &sipStrings_QtGui[42985]
#define sipNameNr_AnyStretch 42996
#define sipName_AnyStretch &sipStrings_QtGui[42996]
#define sipNameNr_ExtraLight 43007
#define sipName_ExtraLight &sipStrings_QtGui[43007]
#define sipNameNr_Decorative 43018
#define sipName_Decorative &sipStrings_QtGui[43018]
#define sipNameNr_OldEnglish 43029
#define sipName_OldEnglish &sipStrings_QtGui[43029]
#define sipNameNr_TypeWriter 43040
#define sipName_TypeWriter &sipStrings_QtGui[43040]
#define sipNameNr_contentPos 43051
#define sipName_contentPos &sipStrings_QtGui[43051]
#define sipNameNr_screenRect 43062
#define sipName_screenRect &sipStrings_QtGui[43062]
#define sipNameNr_TouchPoint 8622
#define sipName_TouchPoint &sipStrings_QtGui[8622]
#define sipNameNr_shortcutId 43073
#define sipName_shortcutId &sipStrings_QtGui[43073]
#define sipNameNr_QHelpEvent 43084
#define sipName_QHelpEvent &sipStrings_QtGui[43084]
#define sipNameNr_answerRect 43095
#define sipName_answerRect &sipStrings_QtGui[43095]
#define sipNameNr_dropAction 43106
#define sipName_dropAction &sipStrings_QtGui[43106]
#define sipNameNr_QDropEvent 43117
#define sipName_QDropEvent &sipStrings_QtGui[43117]
#define sipNameNr_QHideEvent 43128
#define sipName_QHideEvent &sipStrings_QtGui[43128]
#define sipNameNr_QShowEvent 43139
#define sipName_QShowEvent &sipStrings_QtGui[43139]
#define sipNameNr_QMoveEvent 43150
#define sipName_QMoveEvent &sipStrings_QtGui[43150]
#define sipNameNr_deviceType 43161
#define sipName_deviceType &sipStrings_QtGui[43161]
#define sipNameNr_FourDMouse 43172
#define sipName_FourDMouse &sipStrings_QtGui[43172]
#define sipNameNr_globalPosF 43183
#define sipName_globalPosF &sipStrings_QtGui[43183]
#define sipNameNr_angleDelta 43194
#define sipName_angleDelta &sipStrings_QtGui[43194]
#define sipNameNr_pixelDelta 43205
#define sipName_pixelDelta &sipStrings_QtGui[43205]
#define sipNameNr_dragCursor 43216
#define sipName_dragCursor &sipStrings_QtGui[43216]
#define sipNameNr_setHotSpot 43227
#define sipName_setHotSpot &sipStrings_QtGui[43227]
#define sipNameNr_iccProfile 43238
#define sipName_iccProfile &sipStrings_QtGui[43238]
#define sipNameNr_colorSpace 43249
#define sipName_colorSpace &sipStrings_QtGui[43249]
#define sipNameNr_SRgbLinear 43260
#define sipName_SRgbLinear &sipStrings_QtGui[43260]
#define sipNameNr_FindBuffer 17599
#define sipName_FindBuffer &sipStrings_QtGui[17599]
#define sipNameNr_QClipboard 43271
#define sipName_QClipboard &sipStrings_QtGui[43271]
#define sipNameNr_focalPoint 43282
#define sipName_focalPoint &sipStrings_QtGui[43282]
#define sipNameNr_setColorAt 43293
#define sipName_setColorAt &sipStrings_QtGui[43293]
#define sipNameNr_NumPresets 43304
#define sipName_NumPresets &sipStrings_QtGui[43304]
#define sipNameNr_FrozenHeat 43315
#define sipName_FrozenHeat &sipStrings_QtGui[43315]
#define sipNameNr_LilyMeadow 43326
#define sipName_LilyMeadow &sipStrings_QtGui[43326]
#define sipNameNr_SupremeSky 43337
#define sipName_SupremeSky &sipStrings_QtGui[43337]
#define sipNameNr_DeepRelief 43348
#define sipName_DeepRelief &sipStrings_QtGui[43348]
#define sipNameNr_FreshOasis 43359
#define sipName_FreshOasis &sipStrings_QtGui[43359]
#define sipNameNr_WitchDance 43370
#define sipName_WitchDance &sipStrings_QtGui[43370]
#define sipNameNr_SandStrike 43381
#define sipName_SandStrike &sipStrings_QtGui[43381]
#define sipNameNr_ForestInei 43392
#define sipName_ForestInei &sipStrings_QtGui[43392]
#define sipNameNr_SpaceShift 43403
#define sipName_SpaceShift &sipStrings_QtGui[43403]
#define sipNameNr_HighFlight 43414
#define sipName_HighFlight &sipStrings_QtGui[43414]
#define sipNameNr_FruitBlend 43425
#define sipName_FruitBlend &sipStrings_QtGui[43425]
#define sipNameNr_GlassWater 43436
#define sipName_GlassWater &sipStrings_QtGui[43436]
#define sipNameNr_SolidStone 43447
#define sipName_SolidStone &sipStrings_QtGui[43447]
#define sipNameNr_GentleCare 43458
#define sipName_GentleCare &sipStrings_QtGui[43458]
#define sipNameNr_YoungGrass 43469
#define sipName_YoungGrass &sipStrings_QtGui[43469]
#define sipNameNr_MarbleWall 43480
#define sipName_MarbleWall &sipStrings_QtGui[43480]
#define sipNameNr_DenseWater 43491
#define sipName_DenseWater &sipStrings_QtGui[43491]
#define sipNameNr_LeCocktail 43502
#define sipName_LeCocktail &sipStrings_QtGui[43502]
#define sipNameNr_PartyBliss 43513
#define sipName_PartyBliss &sipStrings_QtGui[43513]
#define sipNameNr_AmourAmour 43524
#define sipName_AmourAmour &sipStrings_QtGui[43524]
#define sipNameNr_JapanBlush 43535
#define sipName_JapanBlush &sipStrings_QtGui[43535]
#define sipNameNr_DesertHump 43546
#define sipName_DesertHump &sipStrings_QtGui[43546]
#define sipNameNr_AquaSplash 43557
#define sipName_AquaSplash &sipStrings_QtGui[43557]
#define sipNameNr_NightParty 43568
#define sipName_NightParty &sipStrings_QtGui[43568]
#define sipNameNr_WideMatrix 43579
#define sipName_WideMatrix &sipStrings_QtGui[43579]
#define sipNameNr_GreatWhale 43590
#define sipName_GreatWhale &sipStrings_QtGui[43590]
#define sipNameNr_ShadyWater 43601
#define sipName_ShadyWater &sipStrings_QtGui[43601]
#define sipNameNr_SharpBlues 43612
#define sipName_SharpBlues &sipStrings_QtGui[43612]
#define sipNameNr_GrownEarly 43623
#define sipName_GrownEarly &sipStrings_QtGui[43623]
#define sipNameNr_MixedHopes 43634
#define sipName_MixedHopes &sipStrings_QtGui[43634]
#define sipNameNr_ShyRainbow 43645
#define sipName_ShyRainbow &sipStrings_QtGui[43645]
#define sipNameNr_TrueSunset 43656
#define sipName_TrueSunset &sipStrings_QtGui[43656]
#define sipNameNr_DustyGrass 43667
#define sipName_DustyGrass &sipStrings_QtGui[43667]
#define sipNameNr_WinterNeva 43678
#define sipName_WinterNeva &sipStrings_QtGui[43678]
#define sipNameNr_JuicyPeach 43689
#define sipName_JuicyPeach &sipStrings_QtGui[43689]
#define sipNameNr_NoGradient 43700
#define sipName_NoGradient &sipStrings_QtGui[43700]
#define sipNameNr_ObjectMode 43711
#define sipName_ObjectMode &sipStrings_QtGui[43711]
#define sipNameNr_setTexture 43722
#define sipName_setTexture &sipStrings_QtGui[43722]
#define sipNameNr_whitesmoke 43733
#define sipName_whitesmoke &sipStrings_QtGui[43733]
#define sipNameNr_sandybrown 43744
#define sipName_sandybrown &sipStrings_QtGui[43744]
#define sipNameNr_powderblue 43755
#define sipName_powderblue &sipStrings_QtGui[43755]
#define sipNameNr_papayawhip 43766
#define sipName_papayawhip &sipStrings_QtGui[43766]
#define sipNameNr_mediumblue 43777
#define sipName_mediumblue &sipStrings_QtGui[43777]
#define sipNameNr_lightgreen 43788
#define sipName_lightgreen &sipStrings_QtGui[43788]
#define sipNameNr_lightcoral 43799
#define sipName_lightcoral &sipStrings_QtGui[43799]
#define sipNameNr_ghostwhite 43810
#define sipName_ghostwhite &sipStrings_QtGui[43810]
#define sipNameNr_dodgerblue 43821
#define sipName_dodgerblue &sipStrings_QtGui[43821]
#define sipNameNr_darkviolet 43832
#define sipName_darkviolet &sipStrings_QtGui[43832]
#define sipNameNr_darksalmon 43843
#define sipName_darksalmon &sipStrings_QtGui[43843]
#define sipNameNr_darkorchid 43854
#define sipName_darkorchid &sipStrings_QtGui[43854]
#define sipNameNr_darkorange 43865
#define sipName_darkorange &sipStrings_QtGui[43865]
#define sipNameNr_chartreuse 43876
#define sipName_chartreuse &sipStrings_QtGui[43876]
#define sipNameNr_blueviolet 43887
#define sipName_blueviolet &sipStrings_QtGui[43887]
#define sipNameNr_aquamarine 22616
#define sipName_aquamarine &sipStrings_QtGui[22616]
#define sipNameNr_DarkYellow 43898
#define sipName_DarkYellow &sipStrings_QtGui[43898]
#define sipNameNr_fromRgba64 43909
#define sipName_fromRgba64 &sipStrings_QtGui[43909]
#define sipNameNr_NameFormat 17637
#define sipName_NameFormat &sipStrings_QtGui[17637]
#define sipNameNr_lightnessF 43920
#define sipName_lightnessF &sipStrings_QtGui[43920]
#define sipNameNr_saturation 43931
#define sipName_saturation &sipStrings_QtGui[43931]
#define sipNameNr_colorNames 43942
#define sipName_colorNames &sipStrings_QtGui[43942]
#define sipNameNr_beginPaint 43953
#define sipName_beginPaint &sipStrings_QtGui[43953]
#define sipNameNr_drawObject 43964
#define sipName_drawObject &sipStrings_QtGui[43964]
#define sipNameNr_objectType 43975
#define sipName_objectType &sipStrings_QtGui[43975]
#define sipNameNr_selections 43986
#define sipName_selections &sipStrings_QtGui[43986]
#define sipNameNr_attributes 43997
#define sipName_attributes &sipStrings_QtGui[43997]
#define sipNameNr_lineNumber 44008
#define sipName_lineNumber &sipStrings_QtGui[44008]
#define sipNameNr_exactMatch 44019
#define sipName_exactMatch &sipStrings_QtGui[44019]
#define sipNameNr_normalized 44030
#define sipName_normalized &sipStrings_QtGui[44030]
#define sipNameNr_NotRunning 44041
#define sipName_NotRunning &sipStrings_QtGui[44041]
#define sipNameNr_transposed 44052
#define sipName_transposed &sipStrings_QtGui[44052]
#define sipNameNr_dotProduct 44063
#define sipName_dotProduct &sipStrings_QtGui[44063]
#define sipNameNr_childEvent 44074
#define sipName_childEvent &sipStrings_QtGui[44074]
#define sipNameNr_timerEvent 44085
#define sipName_timerEvent &sipStrings_QtGui[44085]
#define sipNameNr_QMatrix4x4 44096
#define sipName_QMatrix4x4 &sipStrings_QtGui[44096]
#define sipNameNr_QTransform 44107
#define sipName_QTransform &sipStrings_QtGui[44107]
#define sipNameNr_setEnabled 44118
#define sipName_setEnabled &sipStrings_QtGui[44118]
#define sipNameNr_FormatType 7638
#define sipName_FormatType &sipStrings_QtGui[7638]
#define sipNameNr_Vietnamese 44129
#define sipName_Vietnamese &sipStrings_QtGui[44129]
#define sipNameNr_translated 44140
#define sipName_translated &sipStrings_QtGui[44140]
#define sipNameNr_intersects 44151
#define sipName_intersects &sipStrings_QtGui[44151]
#define sipNameNr_fromString 44162
#define sipName_fromString &sipStrings_QtGui[44162]
#define sipNameNr_setVersion 44173
#define sipName_setVersion &sipStrings_QtGui[44173]
#define sipNameNr_simplified 44184
#define sipName_simplified &sipStrings_QtGui[44184]
#define sipNameNr___rshift__ 44195
#define sipName___rshift__ &sipStrings_QtGui[44195]
#define sipNameNr___lshift__ 44206
#define sipName___lshift__ &sipStrings_QtGui[44206]
#define sipNameNr_isDetached 44217
#define sipName_isDetached &sipStrings_QtGui[44217]
#define sipNameNr_removeRows 44228
#define sipName_removeRows &sipStrings_QtGui[44228]
#define sipNameNr_insertRows 44239
#define sipName_insertRows &sipStrings_QtGui[44239]
#define sipNameNr_headerData 44250
#define sipName_headerData &sipStrings_QtGui[44250]
#define sipNameNr_TextFormat 30173
#define sipName_TextFormat &sipStrings_QtGui[30173]
#define sipNameNr___invert__ 44261
#define sipName___invert__ &sipStrings_QtGui[44261]
#define sipNameNr_fromWinId 44272
#define sipName_fromWinId &sipStrings_QtGui[44272]
#define sipNameNr_Maximized 23855
#define sipName_Maximized &sipStrings_QtGui[23855]
#define sipNameNr_Minimized 29320
#define sipName_Minimized &sipStrings_QtGui[29320]
#define sipNameNr_hideEvent 44282
#define sipName_hideEvent &sipStrings_QtGui[44282]
#define sipNameNr_showEvent 44292
#define sipName_showEvent &sipStrings_QtGui[44292]
#define sipNameNr_moveEvent 44302
#define sipName_moveEvent &sipStrings_QtGui[44302]
#define sipNameNr_setCursor 36693
#define sipName_setCursor &sipStrings_QtGui[36693]
#define sipNameNr_isExposed 44312
#define sipName_isExposed &sipStrings_QtGui[44312]
#define sipNameNr_unproject 44322
#define sipName_unproject &sipStrings_QtGui[44322]
#define sipNameNr_setRegExp 44332
#define sipName_setRegExp &sipStrings_QtGui[44332]
#define sipNameNr_fromScale 44342
#define sipName_fromScale &sipStrings_QtGui[44342]
#define sipNameNr_isScaling 44352
#define sipName_isScaling &sipStrings_QtGui[44352]
#define sipNameNr_setMatrix 44362
#define sipName_setMatrix &sipStrings_QtGui[44362]
#define sipNameNr_TxProject 44372
#define sipName_TxProject &sipStrings_QtGui[44372]
#define sipNameNr_splitCell 44382
#define sipName_splitCell &sipStrings_QtGui[44382]
#define sipNameNr_delimiter 44392
#define sipName_delimiter &sipStrings_QtGui[44392]
#define sipNameNr_CenterTab 44402
#define sipName_CenterTab &sipStrings_QtGui[44402]
#define sipNameNr_userState 44412
#define sipName_userState &sipStrings_QtGui[44412]
#define sipNameNr_blockList 44422
#define sipName_blockList &sipStrings_QtGui[44422]
#define sipNameNr_QTextList 44432
#define sipName_QTextList &sipStrings_QtGui[44432]
#define sipNameNr_textStart 44442
#define sipName_textStart &sipStrings_QtGui[44442]
#define sipNameNr_xToCursor 44452
#define sipName_xToCursor &sipStrings_QtGui[44452]
#define sipNameNr_cursorToX 44462
#define sipName_cursorToX &sipStrings_QtGui[44462]
#define sipNameNr_QTextLine 44472
#define sipName_QTextLine &sipStrings_QtGui[44472]
#define sipNameNr_glyphRuns 44482
#define sipName_glyphRuns &sipStrings_QtGui[44482]
#define sipNameNr_SkipWords 44492
#define sipName_SkipWords &sipStrings_QtGui[44492]
#define sipNameNr_endLayout 44502
#define sipName_endLayout &sipStrings_QtGui[44502]
#define sipNameNr_setAscent 44512
#define sipName_setAscent &sipStrings_QtGui[44512]
#define sipNameNr_topBorder 44522
#define sipName_topBorder &sipStrings_QtGui[44522]
#define sipNameNr_setMargin 44532
#define sipName_setMargin &sipStrings_QtGui[44532]
#define sipNameNr_setBorder 44542
#define sipName_setBorder &sipStrings_QtGui[44542]
#define sipNameNr_FloatLeft 44552
#define sipName_FloatLeft &sipStrings_QtGui[44552]
#define sipNameNr_setMarker 44562
#define sipName_setMarker &sipStrings_QtGui[44562]
#define sipNameNr_setIndent 44572
#define sipName_setIndent &sipStrings_QtGui[44572]
#define sipNameNr_setAnchor 44582
#define sipName_setAnchor &sipStrings_QtGui[44582]
#define sipNameNr_ImageName 44592
#define sipName_ImageName &sipStrings_QtGui[44592]
#define sipNameNr_ListStyle 44602
#define sipName_ListStyle &sipStrings_QtGui[44602]
#define sipNameNr_toRawText 44612
#define sipName_toRawText &sipStrings_QtGui[44612]
#define sipNameNr_RedoStack 44622
#define sipName_RedoStack &sipStrings_QtGui[44622]
#define sipNameNr_UndoStack 44632
#define sipName_UndoStack &sipStrings_QtGui[44632]
#define sipNameNr_lastBlock 44642
#define sipName_lastBlock &sipStrings_QtGui[44642]
#define sipNameNr_findBlock 44652
#define sipName_findBlock &sipStrings_QtGui[44652]
#define sipNameNr_rootFrame 44662
#define sipName_rootFrame &sipStrings_QtGui[44662]
#define sipNameNr_FindFlags 6770
#define sipName_FindFlags &sipStrings_QtGui[6770]
#define sipNameNr_WordRight 44672
#define sipName_WordRight &sipStrings_QtGui[44672]
#define sipNameNr_NextBlock 44682
#define sipName_NextBlock &sipStrings_QtGui[44682]
#define sipNameNr_EndOfWord 25135
#define sipName_EndOfWord &sipStrings_QtGui[25135]
#define sipNameNr_EndOfLine 25119
#define sipName_EndOfLine &sipStrings_QtGui[25119]
#define sipNameNr_setStereo 44692
#define sipName_setStereo &sipStrings_QtGui[44692]
#define sipNameNr_NoProfile 44702
#define sipName_NoProfile &sipStrings_QtGui[44702]
#define sipNameNr_Offscreen 44712
#define sipName_Offscreen &sipStrings_QtGui[44712]
#define sipNameNr_textWidth 44722
#define sipName_textWidth &sipStrings_QtGui[44722]
#define sipNameNr_clearData 44732
#define sipName_clearData &sipStrings_QtGui[44732]
#define sipNameNr_takeChild 44742
#define sipName_takeChild &sipStrings_QtGui[44742]
#define sipNameNr_whatsThis 44752
#define sipName_whatsThis &sipStrings_QtGui[44752]
#define sipNameNr_statusTip 44762
#define sipName_statusTip &sipStrings_QtGui[44762]
#define sipNameNr_findItems 44772
#define sipName_findItems &sipStrings_QtGui[44772]
#define sipNameNr_appendRow 44782
#define sipName_appendRow &sipStrings_QtGui[44782]
#define sipNameNr_Rectangle 9475
#define sipName_Rectangle &sipStrings_QtGui[9475]
#define sipNameNr_fontTable 44792
#define sipName_fontTable &sipStrings_QtGui[44792]
#define sipNameNr_setVector 44802
#define sipName_setVector &sipStrings_QtGui[44802]
#define sipNameNr_conjugate 44812
#define sipName_conjugate &sipStrings_QtGui[44812]
#define sipNameNr_setScalar 44822
#define sipName_setScalar &sipStrings_QtGui[44822]
#define sipNameNr_normalize 44832
#define sipName_normalize &sipStrings_QtGui[44832]
#define sipNameNr_toPolygon 44842
#define sipName_toPolygon &sipStrings_QtGui[44842]
#define sipNameNr_putPoints 44852
#define sipName_putPoints &sipStrings_QtGui[44852]
#define sipNameNr_isQBitmap 44862
#define sipName_isQBitmap &sipStrings_QtGui[44862]
#define sipNameNr_yuvLayout 44872
#define sipName_yuvLayout &sipStrings_QtGui[44872]
#define sipNameNr_alphaSize 44882
#define sipName_alphaSize &sipStrings_QtGui[44882]
#define sipNameNr_blackSize 44892
#define sipName_blackSize &sipStrings_QtGui[44892]
#define sipNameNr_greenSize 44902
#define sipName_greenSize &sipStrings_QtGui[44902]
#define sipNameNr_YUVLayout 7927
#define sipName_YUVLayout &sipStrings_QtGui[7927]
#define sipNameNr_UsesAlpha 44912
#define sipName_UsesAlpha &sipStrings_QtGui[44912]
#define sipNameNr_Grayscale 10636
#define sipName_Grayscale &sipStrings_QtGui[10636]
#define sipNameNr_setWidthF 44922
#define sipName_setWidthF &sipStrings_QtGui[44922]
#define sipNameNr_highlight 37545
#define sipName_highlight &sipStrings_QtGui[37545]
#define sipNameNr_Highlight 44932
#define sipName_Highlight &sipStrings_QtGui[44932]
#define sipNameNr_ColorRole 14150
#define sipName_ColorRole &sipStrings_QtGui[14150]
#define sipNameNr_joinStyle 44942
#define sipName_joinStyle &sipStrings_QtGui[44942]
#define sipNameNr_elementAt 44952
#define sipName_elementAt &sipStrings_QtGui[44952]
#define sipNameNr_arcMoveTo 44962
#define sipName_arcMoveTo &sipStrings_QtGui[44962]
#define sipNameNr_addRegion 44972
#define sipName_addRegion &sipStrings_QtGui[44972]
#define sipNameNr_isCurveTo 44982
#define sipName_isCurveTo &sipStrings_QtGui[44982]
#define sipNameNr_QuickDraw 44992
#define sipName_QuickDraw &sipStrings_QtGui[44992]
#define sipNameNr_lineCount 45002
#define sipName_lineCount &sipStrings_QtGui[45002]
#define sipNameNr_rectCount 45012
#define sipName_rectCount &sipStrings_QtGui[45012]
#define sipNameNr_setActive 45022
#define sipName_setActive &sipStrings_QtGui[45022]
#define sipNameNr_DirtyFont 45032
#define sipName_DirtyFont &sipStrings_QtGui[45032]
#define sipNameNr_DirtyFlag 7951
#define sipName_DirtyFlag &sipStrings_QtGui[7951]
#define sipNameNr_QTextItem 45042
#define sipName_QTextItem &sipStrings_QtGui[45042]
#define sipNameNr_PdmHeight 45052
#define sipName_PdmHeight &sipStrings_QtGui[45052]
#define sipNameNr_sourceTop 45062
#define sipName_sourceTop &sipStrings_QtGui[45062]
#define sipNameNr_drawImage 45072
#define sipName_drawImage &sipStrings_QtGui[45072]
#define sipNameNr_drawPoint 45082
#define sipName_drawPoint &sipStrings_QtGui[45082]
#define sipNameNr_eraseRect 45092
#define sipName_eraseRect &sipStrings_QtGui[45092]
#define sipNameNr_drawChord 45102
#define sipName_drawChord &sipStrings_QtGui[45102]
#define sipNameNr_drawRects 45112
#define sipName_drawRects &sipStrings_QtGui[45112]
#define sipNameNr_drawLines 45122
#define sipName_drawLines &sipStrings_QtGui[45122]
#define sipNameNr_setWindow 45132
#define sipName_setWindow &sipStrings_QtGui[45132]
#define sipNameNr_operation 45142
#define sipName_operation &sipStrings_QtGui[45142]
#define sipNameNr_NPageSize 45152
#define sipName_NPageSize &sipStrings_QtGui[45152]
#define sipNameNr_QPageSize 45162
#define sipName_QPageSize &sipStrings_QtGui[45162]
#define sipNameNr_topMargin 45172
#define sipName_topMargin &sipStrings_QtGui[45172]
#define sipNameNr_Landscape 37689
#define sipName_Landscape &sipStrings_QtGui[37689]
#define sipNameNr_Envelope9 45182
#define sipName_Envelope9 &sipStrings_QtGui[45182]
#define sipNameNr_FanFoldUS 45192
#define sipName_FanFoldUS &sipStrings_QtGui[45192]
#define sipNameNr_Prc32KBig 45202
#define sipName_Prc32KBig &sipStrings_QtGui[45202]
#define sipNameNr_Statement 45212
#define sipName_Statement &sipStrings_QtGui[45212]
#define sipNameNr_Executive 45222
#define sipName_Executive &sipStrings_QtGui[45222]
#define sipNameNr_DepthMode 45232
#define sipName_DepthMode &sipStrings_QtGui[45232]
#define sipNameNr_ZeroValue 45242
#define sipName_ZeroValue &sipStrings_QtGui[45242]
#define sipNameNr_BlueValue 45252
#define sipName_BlueValue &sipStrings_QtGui[45252]
#define sipNameNr_Texture1D 45262
#define sipName_Texture1D &sipStrings_QtGui[45262]
#define sipNameNr_Texture3D 45272
#define sipName_Texture3D &sipStrings_QtGui[45272]
#define sipNameNr_PixelType 6155
#define sipName_PixelType &sipStrings_QtGui[6155]
#define sipNameNr_Luminance 45282
#define sipName_Luminance &sipStrings_QtGui[45282]
#define sipNameNr_setLayers 45292
#define sipName_setLayers &sipStrings_QtGui[45292]
#define sipNameNr_mipLevels 45302
#define sipName_mipLevels &sipStrings_QtGui[45302]
#define sipNameNr_RGB8_ETC1 45312
#define sipName_RGB8_ETC1 &sipStrings_QtGui[45312]
#define sipNameNr_RGB8_ETC2 42106
#define sipName_RGB8_ETC2 &sipStrings_QtGui[42106]
#define sipNameNr_RGBFormat 45322
#define sipName_RGBFormat &sipStrings_QtGui[45322]
#define sipNameNr_SRGB_DXT1 45332
#define sipName_SRGB_DXT1 &sipStrings_QtGui[45332]
#define sipNameNr_RGBA_DXT5 45342
#define sipName_RGBA_DXT5 &sipStrings_QtGui[45342]
#define sipNameNr_RGBA_DXT3 45352
#define sipName_RGBA_DXT3 &sipStrings_QtGui[45352]
#define sipNameNr_RGBA_DXT1 45362
#define sipName_RGBA_DXT1 &sipStrings_QtGui[45362]
#define sipNameNr_D32FS8X24 45372
#define sipName_D32FS8X24 &sipStrings_QtGui[45372]
#define sipNameNr_R16_SNorm 45382
#define sipName_R16_SNorm &sipStrings_QtGui[45382]
#define sipNameNr_RG8_SNorm 45392
#define sipName_RG8_SNorm &sipStrings_QtGui[45392]
#define sipNameNr_R16_UNorm 45402
#define sipName_R16_UNorm &sipStrings_QtGui[45402]
#define sipNameNr_RG8_UNorm 45412
#define sipName_RG8_UNorm &sipStrings_QtGui[45412]
#define sipNameNr_textureId 45422
#define sipName_textureId &sipStrings_QtGui[45422]
#define sipNameNr_programId 45432
#define sipName_programId &sipStrings_QtGui[45432]
#define sipNameNr_addShader 45442
#define sipName_addShader &sipStrings_QtGui[45442]
#define sipNameNr_rowLength 45452
#define sipName_rowLength &sipStrings_QtGui[45452]
#define sipNameNr_setMipmap 45462
#define sipName_setMipmap &sipStrings_QtGui[45462]
#define sipNameNr_pushGroup 45472
#define sipName_pushGroup &sipStrings_QtGui[45472]
#define sipNameNr_isLogging 45482
#define sipName_isLogging &sipStrings_QtGui[45482]
#define sipNameNr_OtherType 45492
#define sipName_OtherType &sipStrings_QtGui[45492]
#define sipNameNr_ErrorType 45502
#define sipName_ErrorType &sipStrings_QtGui[45502]
#define sipNameNr_AnySource 45512
#define sipName_AnySource &sipStrings_QtGui[45512]
#define sipNameNr_APISource 45522
#define sipName_APISource &sipStrings_QtGui[45522]
#define sipNameNr_RangeRead 45532
#define sipName_RangeRead &sipStrings_QtGui[45532]
#define sipNameNr_isCreated 45542
#define sipName_isCreated &sipStrings_QtGui[45542]
#define sipNameNr_setScreen 45552
#define sipName_setScreen &sipStrings_QtGui[45552]
#define sipNameNr_cacheMode 45562
#define sipName_cacheMode &sipStrings_QtGui[45562]
#define sipNameNr_frameRect 45572
#define sipName_frameRect &sipStrings_QtGui[45572]
#define sipNameNr_CacheNone 45582
#define sipName_CacheNone &sipStrings_QtGui[45582]
#define sipNameNr_CacheMode 19530
#define sipName_CacheMode &sipStrings_QtGui[19530]
#define sipNameNr_mapVector 45592
#define sipName_mapVector &sipStrings_QtGui[45592]
#define sipNameNr_setColumn 45602
#define sipName_setColumn &sipStrings_QtGui[45602]
#define sipNameNr_nearPlane 45612
#define sipName_nearPlane &sipStrings_QtGui[45612]
#define sipNameNr_Backspace 45622
#define sipName_Backspace &sipStrings_QtGui[45622]
#define sipNameNr_SelectAll 45632
#define sipName_SelectAll &sipStrings_QtGui[45632]
#define sipNameNr_NextChild 45642
#define sipName_NextChild &sipStrings_QtGui[45642]
#define sipNameNr_isVisible 45652
#define sipName_isVisible &sipStrings_QtGui[45652]
#define sipNameNr_setOption 45662
#define sipName_setOption &sipStrings_QtGui[45662]
#define sipNameNr_setFormat 45672
#define sipName_setFormat &sipStrings_QtGui[45672]
#define sipNameNr_Animation 19692
#define sipName_Animation &sipStrings_QtGui[19692]
#define sipNameNr_byteCount 45682
#define sipName_byteCount &sipStrings_QtGui[45682]
#define sipNameNr_setOffset 45692
#define sipName_setOffset &sipStrings_QtGui[45692]
#define sipNameNr_clipTight 45702
#define sipName_clipTight &sipStrings_QtGui[45702]
#define sipNameNr_constBits 45712
#define sipName_constBits &sipStrings_QtGui[45712]
#define sipNameNr_InvertRgb 45722
#define sipName_InvertRgb &sipStrings_QtGui[45722]
#define sipNameNr_setIsMask 45732
#define sipName_setIsMask &sipStrings_QtGui[45732]
#define sipNameNr_themeName 45742
#define sipName_themeName &sipStrings_QtGui[45742]
#define sipNameNr_fromTheme 45752
#define sipName_fromTheme &sipStrings_QtGui[45752]
#define sipNameNr_addPixmap 45762
#define sipName_addPixmap &sipStrings_QtGui[45762]
#define sipNameNr_clipboard 45772
#define sipName_clipboard &sipStrings_QtGui[45772]
#define sipNameNr_StrikeOut 20798
#define sipName_StrikeOut &sipStrings_QtGui[20798]
#define sipNameNr_Underline 13690
#define sipName_Underline &sipStrings_QtGui[13690]
#define sipNameNr_positions 45782
#define sipName_positions &sipStrings_QtGui[45782]
#define sipNameNr_QGlyphRun 45792
#define sipName_QGlyphRun &sipStrings_QtGui[45792]
#define sipNameNr_capHeight 45802
#define sipName_capHeight &sipStrings_QtGui[45802]
#define sipNameNr_lineWidth 45812
#define sipName_lineWidth &sipStrings_QtGui[45812]
#define sipNameNr_widthChar 45822
#define sipName_widthChar &sipStrings_QtGui[45822]
#define sipNameNr_QFontInfo 45832
#define sipName_QFontInfo &sipStrings_QtGui[45832]
#define sipNameNr_TitleFont 45842
#define sipName_TitleFont &sipStrings_QtGui[45842]
#define sipNameNr_FixedFont 45852
#define sipName_FixedFont &sipStrings_QtGui[45852]
#define sipNameNr_styleName 45862
#define sipName_styleName &sipStrings_QtGui[45862]
#define sipNameNr_SmallCaps 45872
#define sipName_SmallCaps &sipStrings_QtGui[45872]
#define sipNameNr_MixedCase 45882
#define sipName_MixedCase &sipStrings_QtGui[45882]
#define sipNameNr_setItalic 45892
#define sipName_setItalic &sipStrings_QtGui[45892]
#define sipNameNr_styleHint 45902
#define sipName_styleHint &sipStrings_QtGui[45902]
#define sipNameNr_strikeOut 45912
#define sipName_strikeOut &sipStrings_QtGui[45912]
#define sipNameNr_underline 45922
#define sipName_underline &sipStrings_QtGui[45922]
#define sipNameNr_setWeight 45932
#define sipName_setWeight &sipStrings_QtGui[45932]
#define sipNameNr_pixelSize 45942
#define sipName_pixelSize &sipStrings_QtGui[45942]
#define sipNameNr_setFamily 45952
#define sipName_setFamily &sipStrings_QtGui[45952]
#define sipNameNr_pointSize 45962
#define sipName_pointSize &sipStrings_QtGui[45962]
#define sipNameNr_Condensed 28608
#define sipName_Condensed &sipStrings_QtGui[28608]
#define sipNameNr_ExtraBold 45972
#define sipName_ExtraBold &sipStrings_QtGui[45972]
#define sipNameNr_Monospace 45982
#define sipName_Monospace &sipStrings_QtGui[45982]
#define sipNameNr_SansSerif 45992
#define sipName_SansSerif &sipStrings_QtGui[45992]
#define sipNameNr_Helvetica 46002
#define sipName_Helvetica &sipStrings_QtGui[46002]
#define sipNameNr_StyleHint 20764
#define sipName_StyleHint &sipStrings_QtGui[20764]
#define sipNameNr_numericId 46012
#define sipName_numericId &sipStrings_QtGui[46012]
#define sipNameNr_InfoFlags 888
#define sipName_InfoFlags &sipStrings_QtGui[888]
#define sipNameNr_sceneRect 46022
#define sipName_sceneRect &sipStrings_QtGui[46022]
#define sipNameNr_ambiguous 46032
#define sipName_ambiguous &sipStrings_QtGui[46032]
#define sipNameNr_Attribute 4182
#define sipName_Attribute &sipStrings_QtGui[4182]
#define sipNameNr_paintRect 46042
#define sipName_paintRect &sipStrings_QtGui[46042]
#define sipNameNr_lostFocus 46052
#define sipName_lostFocus &sipStrings_QtGui[46052]
#define sipNameNr_QKeyEvent 46062
#define sipName_QKeyEvent &sipStrings_QtGui[46062]
#define sipNameNr_screenPos 46072
#define sipName_screenPos &sipStrings_QtGui[46072]
#define sipNameNr_windowPos 46082
#define sipName_windowPos &sipStrings_QtGui[46082]
#define sipNameNr_globalPos 46092
#define sipName_globalPos &sipStrings_QtGui[46092]
#define sipNameNr_timestamp 46102
#define sipName_timestamp &sipStrings_QtGui[46102]
#define sipNameNr_modifiers 46112
#define sipName_modifiers &sipStrings_QtGui[46112]
#define sipNameNr_primaries 46122
#define sipName_primaries &sipStrings_QtGui[46122]
#define sipNameNr_Primaries 9866
#define sipName_Primaries &sipStrings_QtGui[9866]
#define sipNameNr_DisplayP3 46132
#define sipName_DisplayP3 &sipStrings_QtGui[46132]
#define sipNameNr_setPixmap 46142
#define sipName_setPixmap &sipStrings_QtGui[46142]
#define sipNameNr_setRadius 46152
#define sipName_setRadius &sipStrings_QtGui[46152]
#define sipNameNr_setCenter 46162
#define sipName_setCenter &sipStrings_QtGui[46162]
#define sipNameNr_finalStop 46172
#define sipName_finalStop &sipStrings_QtGui[46172]
#define sipNameNr_setSpread 46182
#define sipName_setSpread &sipStrings_QtGui[46182]
#define sipNameNr_TeenParty 46192
#define sipName_TeenParty &sipStrings_QtGui[46192]
#define sipNameNr_MindCrawl 46202
#define sipName_MindCrawl &sipStrings_QtGui[46202]
#define sipNameNr_LightBlue 46212
#define sipName_LightBlue &sipStrings_QtGui[46212]
#define sipNameNr_NightCall 46222
#define sipName_NightCall &sipStrings_QtGui[46222]
#define sipNameNr_SeaStrike 46232
#define sipName_SeaStrike &sipStrings_QtGui[46232]
#define sipNameNr_AngelCare 46242
#define sipName_AngelCare &sipStrings_QtGui[46242]
#define sipNameNr_SunVeggie 46252
#define sipName_SunVeggie &sipStrings_QtGui[46252]
#define sipNameNr_JuicyCake 46262
#define sipName_JuicyCake &sipStrings_QtGui[46262]
#define sipNameNr_RichMetal 46272
#define sipName_RichMetal &sipStrings_QtGui[46272]
#define sipNameNr_MagicLake 46282
#define sipName_MagicLake &sipStrings_QtGui[46282]
#define sipNameNr_ChildCare 46292
#define sipName_ChildCare &sipStrings_QtGui[46292]
#define sipNameNr_RiverCity 46302
#define sipName_RiverCity &sipStrings_QtGui[46302]
#define sipNameNr_MarsParty 46312
#define sipName_MarsParty &sipStrings_QtGui[46312]
#define sipNameNr_JungleDay 46322
#define sipName_JungleDay &sipStrings_QtGui[46322]
#define sipNameNr_SpikyNaga 46332
#define sipName_SpikyNaga &sipStrings_QtGui[46332]
#define sipNameNr_SkyGlider 46342
#define sipName_SkyGlider &sipStrings_QtGui[46342]
#define sipNameNr_SoftGrass 46352
#define sipName_SoftGrass &sipStrings_QtGui[46352]
#define sipNameNr_KindSteel 46362
#define sipName_KindSteel &sipStrings_QtGui[46362]
#define sipNameNr_SnowAgain 46372
#define sipName_SnowAgain &sipStrings_QtGui[46372]
#define sipNameNr_FreshMilk 46382
#define sipName_FreshMilk &sipStrings_QtGui[46382]
#define sipNameNr_HappyAcid 46392
#define sipName_HappyAcid &sipStrings_QtGui[46392]
#define sipNameNr_LemonGate 46402
#define sipName_LemonGate &sipStrings_QtGui[46402]
#define sipNameNr_PlumPlate 46412
#define sipName_PlumPlate &sipStrings_QtGui[46412]
#define sipNameNr_WildApple 46422
#define sipName_WildApple &sipStrings_QtGui[46422]
#define sipNameNr_MeanFruit 46432
#define sipName_MeanFruit &sipStrings_QtGui[46432]
#define sipNameNr_HeavyRain 46442
#define sipName_HeavyRain &sipStrings_QtGui[46442]
#define sipNameNr_NightFade 46452
#define sipName_NightFade &sipStrings_QtGui[46452]
#define sipNameNr_WarmFlame 46462
#define sipName_WarmFlame &sipStrings_QtGui[46462]
#define sipNameNr_PadSpread 46472
#define sipName_PadSpread &sipStrings_QtGui[46472]
#define sipNameNr_QGradient 46482
#define sipName_QGradient &sipStrings_QtGui[46482]
#define sipNameNr_transform 46492
#define sipName_transform &sipStrings_QtGui[46492]
#define sipNameNr_turquoise 25903
#define sipName_turquoise &sipStrings_QtGui[25903]
#define sipNameNr_steelblue 29013
#define sipName_steelblue &sipStrings_QtGui[29013]
#define sipNameNr_slategrey 29028
#define sipName_slategrey &sipStrings_QtGui[29028]
#define sipNameNr_slategray 29043
#define sipName_slategray &sipStrings_QtGui[29043]
#define sipNameNr_slateblue 25919
#define sipName_slateblue &sipStrings_QtGui[25919]
#define sipNameNr_royalblue 46502
#define sipName_royalblue &sipStrings_QtGui[46502]
#define sipNameNr_rosybrown 46512
#define sipName_rosybrown &sipStrings_QtGui[46512]
#define sipNameNr_peachpuff 46522
#define sipName_peachpuff &sipStrings_QtGui[46522]
#define sipNameNr_palegreen 46532
#define sipName_palegreen &sipStrings_QtGui[46532]
#define sipNameNr_orangered 46542
#define sipName_orangered &sipStrings_QtGui[46542]
#define sipNameNr_olivedrab 46552
#define sipName_olivedrab &sipStrings_QtGui[46552]
#define sipNameNr_mistyrose 46562
#define sipName_mistyrose &sipStrings_QtGui[46562]
#define sipNameNr_mintcream 46572
#define sipName_mintcream &sipStrings_QtGui[46572]
#define sipNameNr_limegreen 46582
#define sipName_limegreen &sipStrings_QtGui[46582]
#define sipNameNr_lightpink 46592
#define sipName_lightpink &sipStrings_QtGui[46592]
#define sipNameNr_lightgrey 46602
#define sipName_lightgrey &sipStrings_QtGui[46602]
#define sipNameNr_lightgray 46612
#define sipName_lightgray &sipStrings_QtGui[46612]
#define sipNameNr_lightcyan 46622
#define sipName_lightcyan &sipStrings_QtGui[46622]
#define sipNameNr_lightblue 46632
#define sipName_lightblue &sipStrings_QtGui[46632]
#define sipNameNr_lawngreen 46642
#define sipName_lawngreen &sipStrings_QtGui[46642]
#define sipNameNr_indianred 46652
#define sipName_indianred &sipStrings_QtGui[46652]
#define sipNameNr_goldenrod 32694
#define sipName_goldenrod &sipStrings_QtGui[32694]
#define sipNameNr_gainsboro 46662
#define sipName_gainsboro &sipStrings_QtGui[46662]
#define sipNameNr_firebrick 46672
#define sipName_firebrick &sipStrings_QtGui[46672]
#define sipNameNr_darkkhaki 46682
#define sipName_darkkhaki &sipStrings_QtGui[46682]
#define sipNameNr_darkgreen 46692
#define sipName_darkgreen &sipStrings_QtGui[46692]
#define sipNameNr_chocolate 46702
#define sipName_chocolate &sipStrings_QtGui[46702]
#define sipNameNr_cadetblue 46712
#define sipName_cadetblue &sipStrings_QtGui[46712]
#define sipNameNr_burlywood 46722
#define sipName_burlywood &sipStrings_QtGui[46722]
#define sipNameNr_aliceblue 46732
#define sipName_aliceblue &sipStrings_QtGui[46732]
#define sipNameNr_DarkGreen 46742
#define sipName_DarkGreen &sipStrings_QtGui[46742]
#define sipNameNr_LightGray 46752
#define sipName_LightGray &sipStrings_QtGui[46752]
#define sipNameNr_setRgba64 46762
#define sipName_setRgba64 &sipStrings_QtGui[46762]
#define sipNameNr_lightness 46772
#define sipName_lightness &sipStrings_QtGui[46772]
#define sipNameNr_fromCmykF 46782
#define sipName_fromCmykF &sipStrings_QtGui[46782]
#define sipNameNr_convertTo 46792
#define sipName_convertTo &sipStrings_QtGui[46792]
#define sipNameNr_setGreenF 46802
#define sipName_setGreenF &sipStrings_QtGui[46802]
#define sipNameNr_setAlphaF 46812
#define sipName_setAlphaF &sipStrings_QtGui[46812]
#define sipNameNr_fromImage 46822
#define sipName_fromImage &sipStrings_QtGui[46822]
#define sipNameNr_component 46832
#define sipName_component &sipStrings_QtGui[46832]
#define sipNameNr_pageCount 46842
#define sipName_pageCount &sipStrings_QtGui[46842]
#define sipNameNr_Selection 314
#define sipName_Selection &sipStrings_QtGui[314]
#define sipNameNr_windowsId 46852
#define sipName_windowsId &sipStrings_QtGui[46852]
#define sipNameNr_alignment 46862
#define sipName_alignment &sipStrings_QtGui[46862]
#define sipNameNr_setHeight 46872
#define sipName_setHeight &sipStrings_QtGui[46872]
#define sipNameNr_setParent 46882
#define sipName_setParent &sipStrings_QtGui[46882]
#define sipNameNr_QPolygonF 46892
#define sipName_QPolygonF &sipStrings_QtGui[46892]
#define sipNameNr_QVector4D 46902
#define sipName_QVector4D &sipStrings_QtGui[46902]
#define sipNameNr_QVector3D 46912
#define sipName_QVector3D &sipStrings_QtGui[46912]
#define sipNameNr_QVector2D 46922
#define sipName_QVector2D &sipStrings_QtGui[46922]
#define sipNameNr_setBottom 46932
#define sipName_setBottom &sipStrings_QtGui[46932]
#define sipNameNr_isEnabled 46942
#define sipName_isEnabled &sipStrings_QtGui[46942]
#define sipNameNr_Malayalam 46952
#define sipName_Malayalam &sipStrings_QtGui[46952]
#define sipNameNr_setPoints 46962
#define sipName_setPoints &sipStrings_QtGui[46962]
#define sipNameNr_ReadWrite 46972
#define sipName_ReadWrite &sipStrings_QtGui[46972]
#define sipNameNr_WriteOnly 46982
#define sipName_WriteOnly &sipStrings_QtGui[46982]
#define sipNameNr_byteOrder 46992
#define sipName_byteOrder &sipStrings_QtGui[46992]
#define sipNameNr_setStatus 47002
#define sipName_setStatus &sipStrings_QtGui[47002]
#define sipNameNr_BigEndian 47012
#define sipName_BigEndian &sipStrings_QtGui[47012]
#define sipNameNr_ByteOrder 7903
#define sipName_ByteOrder &sipStrings_QtGui[7903]
#define sipNameNr_WhatsThis 33952
#define sipName_WhatsThis &sipStrings_QtGui[33952]
#define sipNameNr_Clipboard 32456
#define sipName_Clipboard &sipStrings_QtGui[32456]
#define sipNameNr___enter__ 47022
#define sipName___enter__ &sipStrings_QtGui[47022]
#define sipNameNr_translate 47032
#define sipName_translate &sipStrings_QtGui[47032]
#define sipNameNr_setLocale 47042
#define sipName_setLocale &sipStrings_QtGui[47042]
#define sipNameNr_lastError 47052
#define sipName_lastError &sipStrings_QtGui[47052]
#define sipNameNr_setDevice 47062
#define sipName_setDevice &sipStrings_QtGui[47062]
#define sipNameNr_selection 47072
#define sipName_selection &sipStrings_QtGui[47072]
#define sipNameNr_roleNames 47082
#define sipName_roleNames &sipStrings_QtGui[47082]
#define sipNameNr_removeRow 47092
#define sipName_removeRow &sipStrings_QtGui[47092]
#define sipNameNr_insertRow 47102
#define sipName_insertRow &sipStrings_QtGui[47102]
#define sipNameNr_fetchMore 47112
#define sipName_fetchMore &sipStrings_QtGui[47112]
#define sipNameNr_mimeTypes 47122
#define sipName_mimeTypes &sipStrings_QtGui[47122]
#define sipNameNr_setPaused 47132
#define sipName_setPaused &sipStrings_QtGui[47132]
#define sipNameNr_loopCount 47142
#define sipName_loopCount &sipStrings_QtGui[47142]
#define sipNameNr_Unchecked 47152
#define sipName_Unchecked &sipStrings_QtGui[47152]
#define sipNameNr___index__ 47162
#define sipName___index__ &sipStrings_QtGui[47162]
#define sipNameNr_Windowed 47172
#define sipName_Windowed &sipStrings_QtGui[47172]
#define sipNameNr_yChanged 6921
#define sipName_yChanged &sipStrings_QtGui[6921]
#define sipNameNr_xChanged 47181
#define sipName_xChanged &sipStrings_QtGui[47181]
#define sipNameNr_baseSize 47190
#define sipName_baseSize &sipStrings_QtGui[47190]
#define sipNameNr_modality 47199
#define sipName_modality &sipStrings_QtGui[47199]
#define sipNameNr_toPointF 47208
#define sipName_toPointF &sipStrings_QtGui[47208]
#define sipNameNr_Notation 4910
#define sipName_Notation &sipStrings_QtGui[4910]
#define sipNameNr_decimals 47217
#define sipName_decimals &sipStrings_QtGui[47217]
#define sipNameNr_setRange 47226
#define sipName_setRange &sipStrings_QtGui[47226]
#define sipNameNr_validate 24992
#define sipName_validate &sipStrings_QtGui[24992]
#define sipNameNr_TxRotate 47235
#define sipName_TxRotate &sipStrings_QtGui[47235]
#define sipNameNr_Velocity 18703
#define sipName_Velocity &sipStrings_QtGui[18703]
#define sipNameNr_Pressure 17582
#define sipName_Pressure &sipStrings_QtGui[17582]
#define sipNameNr_TouchPad 47244
#define sipName_TouchPad &sipStrings_QtGui[47244]
#define sipNameNr_rowStart 47253
#define sipName_rowStart &sipStrings_QtGui[47253]
#define sipNameNr_RightTab 47262
#define sipName_RightTab &sipStrings_QtGui[47262]
#define sipNameNr_WordWrap 47271
#define sipName_WordWrap &sipStrings_QtGui[47271]
#define sipNameNr_userData 47280
#define sipName_userData &sipStrings_QtGui[47280]
#define sipNameNr_textList 47289
#define sipName_textList &sipStrings_QtGui[47289]
#define sipNameNr_itemText 47298
#define sipName_itemText &sipStrings_QtGui[47298]
#define sipNameNr_Trailing 47307
#define sipName_Trailing &sipStrings_QtGui[47307]
#define sipNameNr_Position 4436
#define sipName_Position &sipStrings_QtGui[4436]
#define sipNameNr_ListDisc 47316
#define sipName_ListDisc &sipStrings_QtGui[47316]
#define sipNameNr_NoMarker 47325
#define sipName_NoMarker &sipStrings_QtGui[47325]
#define sipNameNr_isAnchor 47334
#define sipName_isAnchor &sipStrings_QtGui[47334]
#define sipNameNr_IsAnchor 47343
#define sipName_IsAnchor &sipStrings_QtGui[47343]
#define sipNameNr_CssFloat 47352
#define sipName_CssFloat &sipStrings_QtGui[47352]
#define sipNameNr_Property 10197
#define sipName_Property &sipStrings_QtGui[10197]
#define sipNameNr_NoObject 47361
#define sipName_NoObject &sipStrings_QtGui[47361]
#define sipNameNr_rawValue 47370
#define sipName_rawValue &sipStrings_QtGui[47370]
#define sipNameNr_fromHtml 47379
#define sipName_fromHtml &sipStrings_QtGui[47379]
#define sipNameNr_revision 47388
#define sipName_revision &sipStrings_QtGui[47388]
#define sipNameNr_resource 47397
#define sipName_resource &sipStrings_QtGui[47397]
#define sipNameNr_FindFlag 7664
#define sipName_FindFlag &sipStrings_QtGui[7664]
#define sipNameNr_encoding 47406
#define sipName_encoding &sipStrings_QtGui[47406]
#define sipNameNr_Document 11341
#define sipName_Document &sipStrings_QtGui[11341]
#define sipNameNr_NextCell 47415
#define sipName_NextCell &sipStrings_QtGui[47415]
#define sipNameNr_NextWord 28204
#define sipName_NextWord &sipStrings_QtGui[28204]
#define sipNameNr_WordLeft 47424
#define sipName_WordLeft &sipStrings_QtGui[47424]
#define sipNameNr_MoveMode 10395
#define sipName_MoveMode &sipStrings_QtGui[10395]
#define sipNameNr_OpenGLES 42294
#define sipName_OpenGLES &sipStrings_QtGui[42294]
#define sipNameNr_ItemType 7784
#define sipName_ItemType &sipStrings_QtGui[7784]
#define sipNameNr_setChild 47433
#define sipName_setChild &sipStrings_QtGui[47433]
#define sipNameNr_sizeHint 47442
#define sipName_sizeHint &sipStrings_QtGui[47442]
#define sipNameNr_takeItem 47451
#define sipName_takeItem &sipStrings_QtGui[47451]
#define sipNameNr_geometry 47460
#define sipName_geometry &sipStrings_QtGui[47460]
#define sipNameNr___long__ 47469
#define sipName___long__ &sipStrings_QtGui[47469]
#define sipNameNr_toArgb32 47478
#define sipName_toArgb32 &sipStrings_QtGui[47478]
#define sipNameNr_setRects 47487
#define sipName_setRects &sipStrings_QtGui[47487]
#define sipNameNr_fromFont 47496
#define sipName_fromFont &sipStrings_QtGui[47496]
#define sipNameNr_QRawFont 47505
#define sipName_QRawFont &sipStrings_QtGui[47505]
#define sipNameNr_fromAxes 47514
#define sipName_fromAxes &sipStrings_QtGui[47514]
#define sipNameNr_isClosed 47523
#define sipName_isClosed &sipStrings_QtGui[47523]
#define sipNameNr_setPoint 47532
#define sipName_setPoint &sipStrings_QtGui[47532]
#define sipNameNr_hasAlpha 47541
#define sipName_hasAlpha &sipStrings_QtGui[47541]
#define sipNameNr_cyanSize 47550
#define sipName_cyanSize &sipStrings_QtGui[47550]
#define sipNameNr_blueSize 47559
#define sipName_blueSize &sipStrings_QtGui[47559]
#define sipNameNr_YUV420SP 47568
#define sipName_YUV420SP &sipStrings_QtGui[47568]
#define sipNameNr_ioDevice 47577
#define sipName_ioDevice &sipStrings_QtGui[47577]
#define sipNameNr_QPicture 47586
#define sipName_QPicture &sipStrings_QtGui[47586]
#define sipNameNr_setTitle 47595
#define sipName_setTitle &sipStrings_QtGui[47595]
#define sipNameNr_midlight 47604
#define sipName_midlight &sipStrings_QtGui[47604]
#define sipNameNr_Midlight 47613
#define sipName_Midlight &sipStrings_QtGui[47613]
#define sipNameNr_Inactive 47622
#define sipName_Inactive &sipStrings_QtGui[47622]
#define sipNameNr_capStyle 47631
#define sipName_capStyle &sipStrings_QtGui[47631]
#define sipNameNr_isLineTo 47640
#define sipName_isLineTo &sipStrings_QtGui[47640]
#define sipNameNr_isMoveTo 47649
#define sipName_isMoveTo &sipStrings_QtGui[47649]
#define sipNameNr_Direct2D 47658
#define sipName_Direct2D &sipStrings_QtGui[47658]
#define sipNameNr_Direct3D 47667
#define sipName_Direct3D &sipStrings_QtGui[47667]
#define sipNameNr_features 47676
#define sipName_features &sipStrings_QtGui[47676]
#define sipNameNr_AllDirty 47685
#define sipName_AllDirty &sipStrings_QtGui[47685]
#define sipNameNr_DirtyPen 47694
#define sipName_DirtyPen &sipStrings_QtGui[47694]
#define sipNameNr_heightMM 47703
#define sipName_heightMM &sipStrings_QtGui[47703]
#define sipNameNr_PdmDepth 47712
#define sipName_PdmDepth &sipStrings_QtGui[47712]
#define sipNameNr_PdmWidth 47721
#define sipName_PdmWidth &sipStrings_QtGui[47721]
#define sipNameNr_drawRect 47730
#define sipName_drawRect &sipStrings_QtGui[47730]
#define sipNameNr_drawLine 47739
#define sipName_drawLine &sipStrings_QtGui[47739]
#define sipNameNr_fillRect 47748
#define sipName_fillRect &sipStrings_QtGui[47748]
#define sipNameNr_drawText 47757
#define sipName_drawText &sipStrings_QtGui[47757]
#define sipNameNr_fillRule 47766
#define sipName_fillRule &sipStrings_QtGui[47766]
#define sipNameNr_drawPath 47775
#define sipName_drawPath &sipStrings_QtGui[47775]
#define sipNameNr_fillPath 47784
#define sipName_fillPath &sipStrings_QtGui[47784]
#define sipNameNr_clipPath 47793
#define sipName_clipPath &sipStrings_QtGui[47793]
#define sipNameNr_setBrush 47802
#define sipName_setBrush &sipStrings_QtGui[47802]
#define sipNameNr_QPainter 47811
#define sipName_QPainter &sipStrings_QtGui[47811]
#define sipNameNr_fullRect 47820
#define sipName_fullRect &sipStrings_QtGui[47820]
#define sipNameNr_setUnits 47829
#define sipName_setUnits &sipStrings_QtGui[47829]
#define sipNameNr_Portrait 41106
#define sipName_Portrait &sipStrings_QtGui[41106]
#define sipNameNr_pageSize 47838
#define sipName_pageSize &sipStrings_QtGui[47838]
#define sipNameNr_Postcard 27679
#define sipName_Postcard &sipStrings_QtGui[27679]
#define sipNameNr_PageSize 4520
#define sipName_PageSize &sipStrings_QtGui[4520]
#define sipNameNr_resizeGL 47847
#define sipName_resizeGL &sipStrings_QtGui[47847]
#define sipNameNr_objectId 47856
#define sipName_objectId &sipStrings_QtGui[47856]
#define sipNameNr_wrapMode 47865
#define sipName_wrapMode &sipStrings_QtGui[47865]
#define sipNameNr_WrapMode 7221
#define sipName_WrapMode &sipStrings_QtGui[7221]
#define sipNameNr_OneValue 47874
#define sipName_OneValue &sipStrings_QtGui[47874]
#define sipNameNr_RedValue 47883
#define sipName_RedValue &sipStrings_QtGui[47883]
#define sipNameNr_Features 1025
#define sipName_Features &sipStrings_QtGui[1025]
#define sipNameNr_RGB_DXT1 45333
#define sipName_RGB_DXT1 &sipStrings_QtGui[45333]
#define sipNameNr_RG11B10F 24624
#define sipName_RG11B10F &sipStrings_QtGui[24624]
#define sipNameNr_R8_SNorm 47892
#define sipName_R8_SNorm &sipStrings_QtGui[47892]
#define sipNameNr_R8_UNorm 47901
#define sipName_R8_UNorm &sipStrings_QtGui[47901]
#define sipNameNr_NoFormat 47910
#define sipName_NoFormat &sipStrings_QtGui[47910]
#define sipNameNr_Target3D 24768
#define sipName_Target3D &sipStrings_QtGui[24768]
#define sipNameNr_Target2D 24784
#define sipName_Target2D &sipStrings_QtGui[24784]
#define sipNameNr_Target1D 24800
#define sipName_Target1D &sipStrings_QtGui[24800]
#define sipNameNr_isLinked 47919
#define sipName_isLinked &sipStrings_QtGui[47919]
#define sipNameNr_shaderId 47928
#define sipName_shaderId &sipStrings_QtGui[47928]
#define sipNameNr_Geometry 6971
#define sipName_Geometry &sipStrings_QtGui[6971]
#define sipNameNr_Fragment 7071
#define sipName_Fragment &sipStrings_QtGui[7071]
#define sipNameNr_skipRows 47937
#define sipName_skipRows &sipStrings_QtGui[47937]
#define sipNameNr_textures 47946
#define sipName_textures &sipStrings_QtGui[47946]
#define sipNameNr_popGroup 47955
#define sipName_popGroup &sipStrings_QtGui[47955]
#define sipNameNr_severity 47964
#define sipName_severity &sipStrings_QtGui[47964]
#define sipNameNr_Severity 3273
#define sipName_Severity &sipStrings_QtGui[3273]
#define sipNameNr_mapRange 47973
#define sipName_mapRange &sipStrings_QtGui[47973]
#define sipNameNr_allocate 47982
#define sipName_allocate &sipStrings_QtGui[47982]
#define sipNameNr_bufferId 47991
#define sipName_bufferId &sipStrings_QtGui[47991]
#define sipNameNr_QSurface 48000
#define sipName_QSurface &sipStrings_QtGui[48000]
#define sipNameNr_setSpeed 48009
#define sipName_setSpeed &sipStrings_QtGui[48009]
#define sipNameNr_CacheAll 48018
#define sipName_CacheAll &sipStrings_QtGui[48018]
#define sipNameNr_isAffine 48027
#define sipName_isAffine &sipStrings_QtGui[48027]
#define sipNameNr_viewport 48036
#define sipName_viewport &sipStrings_QtGui[48036]
#define sipNameNr_farPlane 48045
#define sipName_farPlane &sipStrings_QtGui[48045]
#define sipNameNr_mnemonic 3303
#define sipName_mnemonic &sipStrings_QtGui[3303]
#define sipNameNr_FindNext 48054
#define sipName_FindNext &sipStrings_QtGui[48054]
#define sipNameNr_canWrite 8384
#define sipName_canWrite &sipStrings_QtGui[8384]
#define sipNameNr_mimeType 48063
#define sipName_mimeType &sipStrings_QtGui[48063]
#define sipNameNr_setGamma 48072
#define sipName_setGamma &sipStrings_QtGui[48072]
#define sipNameNr_clipRect 48081
#define sipName_clipRect &sipStrings_QtGui[48081]
#define sipNameNr_ClipRect 19711
#define sipName_ClipRect &sipStrings_QtGui[19711]
#define sipNameNr_textKeys 48090
#define sipName_textKeys &sipStrings_QtGui[48090]
#define sipNameNr_mirrored 48099
#define sipName_mirrored &sipStrings_QtGui[48099]
#define sipNameNr_vertical 48108
#define sipName_vertical &sipStrings_QtGui[48108]
#define sipNameNr_setPixel 48117
#define sipName_setPixel &sipStrings_QtGui[48117]
#define sipNameNr_scanLine 48126
#define sipName_scanLine &sipStrings_QtGui[48126]
#define sipNameNr_cacheKey 48135
#define sipName_cacheKey &sipStrings_QtGui[48135]
#define sipNameNr_Selected 48144
#define sipName_Selected &sipStrings_QtGui[48144]
#define sipNameNr_Disabled 48153
#define sipName_Disabled &sipStrings_QtGui[48153]
#define sipNameNr_screenAt 48162
#define sipName_screenAt &sipStrings_QtGui[48162]
#define sipNameNr_Overline 23360
#define sipName_Overline &sipStrings_QtGui[23360]
#define sipNameNr_tabArray 48171
#define sipName_tabArray &sipStrings_QtGui[48171]
#define sipNameNr_tabStops 48180
#define sipName_tabStops &sipStrings_QtGui[48180]
#define sipNameNr_maxWidth 48189
#define sipName_maxWidth &sipStrings_QtGui[48189]
#define sipNameNr_fontInfo 48198
#define sipName_fontInfo &sipStrings_QtGui[48198]
#define sipNameNr_Gurmukhi 48207
#define sipName_Gurmukhi &sipStrings_QtGui[48207]
#define sipNameNr_Cyrillic 48216
#define sipName_Cyrillic &sipStrings_QtGui[48216]
#define sipNameNr_families 48225
#define sipName_families &sipStrings_QtGui[48225]
#define sipNameNr_isCopyOf 48234
#define sipName_isCopyOf &sipStrings_QtGui[48234]
#define sipNameNr_strategy 48243
#define sipName_strategy &sipStrings_QtGui[48243]
#define sipNameNr_overline 48252
#define sipName_overline &sipStrings_QtGui[48252]
#define sipNameNr_Expanded 32149
#define sipName_Expanded &sipStrings_QtGui[32149]
#define sipNameNr_DemiBold 48261
#define sipName_DemiBold &sipStrings_QtGui[48261]
#define sipNameNr_AnyStyle 48270
#define sipName_AnyStyle &sipStrings_QtGui[48270]
#define sipNameNr_velocity 48279
#define sipName_velocity &sipStrings_QtGui[48279]
#define sipNameNr_InfoFlag 1161
#define sipName_InfoFlag &sipStrings_QtGui[1161]
#define sipNameNr_scenePos 48288
#define sipName_scenePos &sipStrings_QtGui[48288]
#define sipNameNr_startPos 48297
#define sipName_startPos &sipStrings_QtGui[48297]
#define sipNameNr_openFile 48306
#define sipName_openFile &sipStrings_QtGui[48306]
#define sipNameNr_Keyboard 48315
#define sipName_Keyboard &sipStrings_QtGui[48315]
#define sipNameNr_gotFocus 48324
#define sipName_gotFocus &sipStrings_QtGui[48324]
#define sipNameNr_uniqueId 48333
#define sipName_uniqueId &sipStrings_QtGui[48333]
#define sipNameNr_rotation 48342
#define sipName_rotation &sipStrings_QtGui[48342]
#define sipNameNr_pressure 48351
#define sipName_pressure &sipStrings_QtGui[48351]
#define sipNameNr_Airbrush 48360
#define sipName_Airbrush &sipStrings_QtGui[48360]
#define sipNameNr_NoDevice 48369
#define sipName_NoDevice &sipStrings_QtGui[48369]
#define sipNameNr_inverted 48378
#define sipName_inverted &sipStrings_QtGui[48378]
#define sipNameNr_localPos 48387
#define sipName_localPos &sipStrings_QtGui[48387]
#define sipNameNr_setShape 48396
#define sipName_setShape &sipStrings_QtGui[48396]
#define sipNameNr_DciP3D65 48405
#define sipName_DciP3D65 &sipStrings_QtGui[48405]
#define sipNameNr_AdobeRgb 48414
#define sipName_AdobeRgb &sipStrings_QtGui[48414]
#define sipNameNr_setImage 48423
#define sipName_setImage &sipStrings_QtGui[48423]
#define sipNameNr_setStart 48432
#define sipName_setStart &sipStrings_QtGui[48432]
#define sipNameNr_setStops 48441
#define sipName_setStops &sipStrings_QtGui[48441]
#define sipNameNr_MagicRay 48450
#define sipName_MagicRay &sipStrings_QtGui[48450]
#define sipNameNr_BlackSea 48459
#define sipName_BlackSea &sipStrings_QtGui[48459]
#define sipNameNr_MoleHall 48468
#define sipName_MoleHall &sipStrings_QtGui[48468]
#define sipNameNr_PlumBath 48477
#define sipName_PlumBath &sipStrings_QtGui[48477]
#define sipNameNr_NightSky 48486
#define sipName_NightSky &sipStrings_QtGui[48486]
#define sipNameNr_Seashore 48495
#define sipName_Seashore &sipStrings_QtGui[48495]
#define sipNameNr_PaloAlto 48504
#define sipName_PaloAlto &sipStrings_QtGui[48504]
#define sipNameNr_BigMango 48513
#define sipName_BigMango &sipStrings_QtGui[48513]
#define sipNameNr_LoveKiss 48522
#define sipName_LoveKiss &sipStrings_QtGui[48522]
#define sipNameNr_StarWine 48531
#define sipName_StarWine &sipStrings_QtGui[48531]
#define sipNameNr_Blessing 48540
#define sipName_Blessing &sipStrings_QtGui[48540]
#define sipNameNr_NearMoon 48549
#define sipName_NearMoon &sipStrings_QtGui[48549]
#define sipNameNr_RareWind 48558
#define sipName_RareWind &sipStrings_QtGui[48558]
#define sipNameNr_DeepBlue 48567
#define sipName_DeepBlue &sipStrings_QtGui[48567]
#define sipNameNr_AmyCrisp 48576
#define sipName_AmyCrisp &sipStrings_QtGui[48576]
#define sipNameNr_LadyLips 48585
#define sipName_LadyLips &sipStrings_QtGui[48585]
#define sipNameNr_isOpaque 48594
#define sipName_isOpaque &sipStrings_QtGui[48594]
#define sipNameNr_gradient 48603
#define sipName_gradient &sipStrings_QtGui[48603]
#define sipNameNr_setColor 48612
#define sipName_setColor &sipStrings_QtGui[48612]
#define sipNameNr_setStyle 48621
#define sipName_setStyle &sipStrings_QtGui[48621]
#define sipNameNr_seashell 48630
#define sipName_seashell &sipStrings_QtGui[48630]
#define sipNameNr_seagreen 28999
#define sipName_seagreen &sipStrings_QtGui[28999]
#define sipNameNr_moccasin 48639
#define sipName_moccasin &sipStrings_QtGui[48639]
#define sipNameNr_lavender 48648
#define sipName_lavender &sipStrings_QtGui[48648]
#define sipNameNr_honeydew 48657
#define sipName_honeydew &sipStrings_QtGui[48657]
#define sipNameNr_deeppink 48666
#define sipName_deeppink &sipStrings_QtGui[48666]
#define sipNameNr_darkgrey 48675
#define sipName_darkgrey &sipStrings_QtGui[48675]
#define sipNameNr_darkgray 48684
#define sipName_darkgray &sipStrings_QtGui[48684]
#define sipNameNr_darkcyan 48693
#define sipName_darkcyan &sipStrings_QtGui[48693]
#define sipNameNr_darkblue 48702
#define sipName_darkblue &sipStrings_QtGui[48702]
#define sipNameNr_cornsilk 48711
#define sipName_cornsilk &sipStrings_QtGui[48711]
#define sipNameNr_DarkCyan 48720
#define sipName_DarkCyan &sipStrings_QtGui[48720]
#define sipNameNr_DarkBlue 48729
#define sipName_DarkBlue &sipStrings_QtGui[48729]
#define sipNameNr_DarkGray 48738
#define sipName_DarkGray &sipStrings_QtGui[48738]
#define sipNameNr_fromHslF 48747
#define sipName_fromHslF &sipStrings_QtGui[48747]
#define sipNameNr_fromCmyk 48756
#define sipName_fromCmyk &sipStrings_QtGui[48756]
#define sipNameNr_fromHsvF 48765
#define sipName_fromHsvF &sipStrings_QtGui[48765]
#define sipNameNr_fromRgbF 48774
#define sipName_fromRgbF &sipStrings_QtGui[48774]
#define sipNameNr_fromRgba 48783
#define sipName_fromRgba &sipStrings_QtGui[48783]
#define sipNameNr_setCmykF 48792
#define sipName_setCmykF &sipStrings_QtGui[48792]
#define sipNameNr_getCmykF 48801
#define sipName_getCmykF &sipStrings_QtGui[48801]
#define sipNameNr_magentaF 48810
#define sipName_magentaF &sipStrings_QtGui[48810]
#define sipNameNr_setBlueF 48819
#define sipName_setBlueF &sipStrings_QtGui[48819]
#define sipNameNr_setGreen 48828
#define sipName_setGreen &sipStrings_QtGui[48828]
#define sipNameNr_setAlpha 48837
#define sipName_setAlpha &sipStrings_QtGui[48837]
#define sipNameNr_fromData 48846
#define sipName_fromData &sipStrings_QtGui[48846]
#define sipNameNr_endPaint 48855
#define sipName_endPaint &sipStrings_QtGui[48855]
#define sipNameNr_formatAt 48864
#define sipName_formatAt &sipStrings_QtGui[48864]
#define sipNameNr_document 48873
#define sipName_document &sipStrings_QtGui[48873]
#define sipNameNr_anchorAt 48882
#define sipName_anchorAt &sipStrings_QtGui[48882]
#define sipNameNr_UserType 48891
#define sipName_UserType &sipStrings_QtGui[48891]
#define sipNameNr_fragment 48900
#define sipName_fragment &sipStrings_QtGui[48900]
#define sipNameNr_notation 48909
#define sipName_notation &sipStrings_QtGui[48909]
#define sipNameNr_setCodec 48918
#define sipName_setCodec &sipStrings_QtGui[48918]
#define sipNameNr_position 48927
#define sipName_position &sipStrings_QtGui[48927]
#define sipNameNr_sortRole 48936
#define sipName_sortRole &sipStrings_QtGui[48936]
#define sipNameNr_setValue 48945
#define sipName_setValue &sipStrings_QtGui[48945]
#define sipNameNr_iterator 11794
#define sipName_iterator &sipStrings_QtGui[11794]
#define sipNameNr_optimize 48954
#define sipName_optimize &sipStrings_QtGui[48954]
#define sipNameNr_setWidth 48963
#define sipName_setWidth &sipStrings_QtGui[48963]
#define sipNameNr_property 48972
#define sipName_property &sipStrings_QtGui[48972]
#define sipNameNr_iconName 48981
#define sipName_iconName &sipStrings_QtGui[48981]
#define sipNameNr_QPolygon 48990
#define sipName_QPolygon &sipStrings_QtGui[48990]
#define sipNameNr_QPalette 48999
#define sipName_QPalette &sipStrings_QtGui[48999]
#define sipNameNr___idiv__ 49008
#define sipName___idiv__ &sipStrings_QtGui[49008]
#define sipNameNr_Japanese 49017
#define sipName_Japanese &sipStrings_QtGui[49017]
#define sipNameNr_Gujarati 49026
#define sipName_Gujarati &sipStrings_QtGui[49026]
#define sipNameNr_Georgian 49035
#define sipName_Georgian &sipStrings_QtGui[49035]
#define sipNameNr_Armenian 49044
#define sipName_Armenian &sipStrings_QtGui[49044]
#define sipNameNr_Language 18253
#define sipName_Language &sipStrings_QtGui[18253]
#define sipNameNr_setAngle 49053
#define sipName_setAngle &sipStrings_QtGui[49053]
#define sipNameNr_previous 49062
#define sipName_previous &sipStrings_QtGui[49062]
#define sipNameNr_Deselect 49071
#define sipName_Deselect &sipStrings_QtGui[49071]
#define sipNameNr_ReadOnly 49080
#define sipName_ReadOnly &sipStrings_QtGui[49080]
#define sipNameNr_filePath 49089
#define sipName_filePath &sipStrings_QtGui[49089]
#define sipNameNr_fileName 49098
#define sipName_fileName &sipStrings_QtGui[49098]
#define sipNameNr___isub__ 49107
#define sipName___isub__ &sipStrings_QtGui[49107]
#define sipNameNr___exit__ 49116
#define sipName___exit__ &sipStrings_QtGui[49116]
#define sipNameNr_setFlags 49125
#define sipName_setFlags &sipStrings_QtGui[49125]
#define sipNameNr_toString 49134
#define sipName_toString &sipStrings_QtGui[49134]
#define sipNameNr_contains 49143
#define sipName_contains &sipStrings_QtGui[49143]
#define sipNameNr_capacity 49152
#define sipName_capacity &sipStrings_QtGui[49152]
#define sipNameNr___imul__ 49161
#define sipName___imul__ &sipStrings_QtGui[49161]
#define sipNameNr___repr__ 49170
#define sipName___repr__ &sipStrings_QtGui[49170]
#define sipNameNr___iadd__ 49179
#define sipName___iadd__ &sipStrings_QtGui[49179]
#define sipNameNr_isActive 49188
#define sipName_isActive &sipStrings_QtGui[49188]
#define sipNameNr_moveRows 44230
#define sipName_moveRows &sipStrings_QtGui[44230]
#define sipNameNr_mimeData 49197
#define sipName_mimeData &sipStrings_QtGui[49197]
#define sipNameNr_itemData 49206
#define sipName_itemData &sipStrings_QtGui[49206]
#define sipNameNr_rowCount 49215
#define sipName_rowCount &sipStrings_QtGui[49215]
#define sipNameNr_oldState 49224
#define sipName_oldState &sipStrings_QtGui[49224]
#define sipNameNr_finished 49233
#define sipName_finished &sipStrings_QtGui[49233]
#define sipNameNr_AlignTop 49242
#define sipName_AlignTop &sipStrings_QtGui[49242]
#define sipNameNr___hash__ 49251
#define sipName___hash__ &sipStrings_QtGui[49251]
#define sipNameNr___bool__ 49260
#define sipName___bool__ &sipStrings_QtGui[49260]
#define sipNameNr___ixor__ 49269
#define sipName___ixor__ &sipStrings_QtGui[49269]
#define sipNameNr___iand__ 49278
#define sipName___iand__ &sipStrings_QtGui[49278]
#define sipNameNr_isModal 49287
#define sipName_isModal &sipStrings_QtGui[49287]
#define sipNameNr_project 44324
#define sipName_project &sipStrings_QtGui[44324]
#define sipNameNr_adjoint 49295
#define sipName_adjoint &sipStrings_QtGui[49295]
#define sipNameNr_TxShear 49303
#define sipName_TxShear &sipStrings_QtGui[49303]
#define sipNameNr_TxScale 49311
#define sipName_TxScale &sipStrings_QtGui[49311]
#define sipNameNr_devices 49319
#define sipName_devices &sipStrings_QtGui[49319]
#define sipNameNr_rowSpan 49327
#define sipName_rowSpan &sipStrings_QtGui[49327]
#define sipNameNr_setTabs 49335
#define sipName_setTabs &sipStrings_QtGui[49335]
#define sipNameNr_LeftTab 49343
#define sipName_LeftTab &sipStrings_QtGui[49343]
#define sipNameNr_TabType 11774
#define sipName_TabType &sipStrings_QtGui[11774]
#define sipNameNr_tabStop 49351
#define sipName_tabStop &sipStrings_QtGui[49351]
#define sipNameNr_Leading 49359
#define sipName_Leading &sipStrings_QtGui[49359]
#define sipNameNr_padding 49367
#define sipName_padding &sipStrings_QtGui[49367]
#define sipNameNr_setName 49375
#define sipName_setName &sipStrings_QtGui[49375]
#define sipNameNr_scaling 49383
#define sipName_scaling &sipStrings_QtGui[49383]
#define sipNameNr_baseUrl 49391
#define sipName_baseUrl &sipStrings_QtGui[49391]
#define sipNameNr_atStart 49399
#define sipName_atStart &sipStrings_QtGui[49399]
#define sipNameNr_NextRow 49407
#define sipName_NextRow &sipStrings_QtGui[49407]
#define sipNameNr_prepare 49415
#define sipName_prepare &sipStrings_QtGui[49415]
#define sipNameNr_setIcon 49423
#define sipName_setIcon &sipStrings_QtGui[49423]
#define sipNameNr_toolTip 49431
#define sipName_toolTip &sipStrings_QtGui[49431]
#define sipNameNr_takeRow 49439
#define sipName_takeRow &sipStrings_QtGui[49439]
#define sipNameNr_setItem 49447
#define sipName_setItem &sipStrings_QtGui[49447]
#define sipNameNr_columns 49455
#define sipName_columns &sipStrings_QtGui[49455]
#define sipNameNr_QScreen 49463
#define sipName_QScreen &sipStrings_QtGui[49463]
#define sipNameNr_qIsGray 49471
#define sipName_qIsGray &sipStrings_QtGui[49471]
#define sipNameNr_qRgba64 49479
#define sipName_qRgba64 &sipStrings_QtGui[49479]
#define sipNameNr_toRgb16 49487
#define sipName_toRgb16 &sipStrings_QtGui[49487]
#define sipNameNr_QRgba64 49495
#define sipName_QRgba64 &sipStrings_QtGui[49495]
#define sipNameNr_Ellipse 38063
#define sipName_Ellipse &sipStrings_QtGui[38063]
#define sipNameNr_getAxes 49503
#define sipName_getAxes &sipStrings_QtGui[49503]
#define sipNameNr_exposed 49511
#define sipName_exposed &sipStrings_QtGui[49511]
#define sipNameNr_setMask 49519
#define sipName_setMask &sipStrings_QtGui[49519]
#define sipNameNr_hueSize 49527
#define sipName_hueSize &sipStrings_QtGui[49527]
#define sipNameNr_redSize 49535
#define sipName_redSize &sipStrings_QtGui[49535]
#define sipNameNr_subEnum 49543
#define sipName_subEnum &sipStrings_QtGui[49543]
#define sipNameNr_YUV420P 49551
#define sipName_YUV420P &sipStrings_QtGui[49551]
#define sipNameNr_Indexed 49559
#define sipName_Indexed &sipStrings_QtGui[49559]
#define sipNameNr_isSolid 49567
#define sipName_isSolid &sipStrings_QtGui[49567]
#define sipNameNr_creator 49575
#define sipName_creator &sipStrings_QtGui[49575]
#define sipNameNr_isEqual 49583
#define sipName_isEqual &sipStrings_QtGui[49583]
#define sipNameNr_addText 49591
#define sipName_addText &sipStrings_QtGui[49591]
#define sipNameNr_addRect 49599
#define sipName_addRect &sipStrings_QtGui[49599]
#define sipNameNr_cubicTo 49607
#define sipName_cubicTo &sipStrings_QtGui[49607]
#define sipNameNr_Element 10660
#define sipName_Element &sipStrings_QtGui[10660]
#define sipNameNr_Blitter 10880
#define sipName_Blitter &sipStrings_QtGui[10880]
#define sipNameNr_OpenGL2 49615
#define sipName_OpenGL2 &sipStrings_QtGui[49615]
#define sipNameNr_Picture 38039
#define sipName_Picture &sipStrings_QtGui[38039]
#define sipNameNr_QWindow 49623
#define sipName_QWindow &sipStrings_QtGui[49623]
#define sipNameNr_widthMM 49631
#define sipName_widthMM &sipStrings_QtGui[49631]
#define sipNameNr_PdmDpiY 49639
#define sipName_PdmDpiY &sipStrings_QtGui[49639]
#define sipNameNr_PdmDpiX 49647
#define sipName_PdmDpiX &sipStrings_QtGui[49647]
#define sipNameNr_combine 49655
#define sipName_combine &sipStrings_QtGui[49655]
#define sipNameNr_picture 49663
#define sipName_picture &sipStrings_QtGui[49663]
#define sipNameNr_drawPie 49671
#define sipName_drawPie &sipStrings_QtGui[49671]
#define sipNameNr_drawArc 49679
#define sipName_drawArc &sipStrings_QtGui[49679]
#define sipNameNr_restore 49687
#define sipName_restore &sipStrings_QtGui[49687]
#define sipNameNr_setMode 49695
#define sipName_setMode &sipStrings_QtGui[49695]
#define sipNameNr_Margins 5343
#define sipName_Margins &sipStrings_QtGui[5343]
#define sipNameNr_B5Extra 49703
#define sipName_B5Extra &sipStrings_QtGui[49703]
#define sipNameNr_A5Extra 49711
#define sipName_A5Extra &sipStrings_QtGui[49711]
#define sipNameNr_A4Small 49719
#define sipName_A4Small &sipStrings_QtGui[49719]
#define sipNameNr_A4Extra 49727
#define sipName_A4Extra &sipStrings_QtGui[49727]
#define sipNameNr_A3Extra 49735
#define sipName_A3Extra &sipStrings_QtGui[49735]
#define sipNameNr_Tabloid 49743
#define sipName_Tabloid &sipStrings_QtGui[49743]
#define sipNameNr_Comm10E 49751
#define sipName_Comm10E &sipStrings_QtGui[49751]
#define sipNameNr_newPage 49759
#define sipName_newPage &sipStrings_QtGui[49759]
#define sipNameNr_paintGL 49767
#define sipName_paintGL &sipStrings_QtGui[49767]
#define sipNameNr_opacity 49775
#define sipName_opacity &sipStrings_QtGui[49775]
#define sipNameNr_Nearest 12698
#define sipName_Nearest &sipStrings_QtGui[12698]
#define sipNameNr_Swizzle 19226
#define sipName_Swizzle &sipStrings_QtGui[19226]
#define sipNameNr_Feature 1294
#define sipName_Feature &sipStrings_QtGui[1294]
#define sipNameNr_Float32 49783
#define sipName_Float32 &sipStrings_QtGui[49783]
#define sipNameNr_Stencil 12929
#define sipName_Stencil &sipStrings_QtGui[12929]
#define sipNameNr_RGB10A2 27815
#define sipName_RGB10A2 &sipStrings_QtGui[27815]
#define sipNameNr_RGBA32F 49791
#define sipName_RGBA32F &sipStrings_QtGui[49791]
#define sipNameNr_RGBA16F 49799
#define sipName_RGBA16F &sipStrings_QtGui[49799]
#define sipNameNr_RGBA32I 49807
#define sipName_RGBA32I &sipStrings_QtGui[49807]
#define sipNameNr_RGBA16I 49815
#define sipName_RGBA16I &sipStrings_QtGui[49815]
#define sipNameNr_RGBA32U 49823
#define sipName_RGBA32U &sipStrings_QtGui[49823]
#define sipNameNr_RGBA16U 49831
#define sipName_RGBA16U &sipStrings_QtGui[49831]
#define sipNameNr_shaders 49839
#define sipName_shaders &sipStrings_QtGui[49839]
#define sipNameNr_Compute 49847
#define sipName_Compute &sipStrings_QtGui[49847]
#define sipNameNr_samples 49855
#define sipName_samples &sipStrings_QtGui[49855]
#define sipNameNr_buffers 49863
#define sipName_buffers &sipStrings_QtGui[49863]
#define sipNameNr_toImage 49871
#define sipName_toImage &sipStrings_QtGui[49871]
#define sipNameNr_isBound 49879
#define sipName_isBound &sipStrings_QtGui[49879]
#define sipNameNr_sources 49887
#define sipName_sources &sipStrings_QtGui[49887]
#define sipNameNr_AnyType 49895
#define sipName_AnyType &sipStrings_QtGui[49895]
#define sipNameNr_Sources 4010
#define sipName_Sources &sipStrings_QtGui[4010]
#define sipNameNr_profile 49903
#define sipName_profile &sipStrings_QtGui[49903]
#define sipNameNr_LibGLES 49911
#define sipName_LibGLES &sipStrings_QtGui[49911]
#define sipNameNr_surface 49919
#define sipName_surface &sipStrings_QtGui[49919]
#define sipNameNr_destroy 49927
#define sipName_destroy &sipStrings_QtGui[49927]
#define sipNameNr_updated 49935
#define sipName_updated &sipStrings_QtGui[49935]
#define sipNameNr_resized 49943
#define sipName_resized &sipStrings_QtGui[49943]
#define sipNameNr_mapRect 49951
#define sipName_mapRect &sipStrings_QtGui[49951]
#define sipNameNr_frustum 49959
#define sipName_frustum &sipStrings_QtGui[49959]
#define sipNameNr_Replace 49967
#define sipName_Replace &sipStrings_QtGui[49967]
#define sipNameNr_ZoomOut 49975
#define sipName_ZoomOut &sipStrings_QtGui[49975]
#define sipNameNr_Refresh 49983
#define sipName_Refresh &sipStrings_QtGui[49983]
#define sipNameNr_subType 49991
#define sipName_subType &sipStrings_QtGui[49991]
#define sipNameNr_canRead 49999
#define sipName_canRead &sipStrings_QtGui[49999]
#define sipNameNr_SubType 42493
#define sipName_SubType &sipStrings_QtGui[42493]
#define sipNameNr_Quality 32220
#define sipName_Quality &sipStrings_QtGui[32220]
#define sipNameNr_quality 50007
#define sipName_quality &sipStrings_QtGui[50007]
#define sipNameNr_allGray 50015
#define sipName_allGray &sipStrings_QtGui[50015]
#define sipNameNr_devType 50023
#define sipName_devType &sipStrings_QtGui[50023]
#define sipNameNr_addFile 50031
#define sipName_addFile &sipStrings_QtGui[50031]
#define sipNameNr_setFont 50039
#define sipName_setFont &sipStrings_QtGui[50039]
#define sipNameNr_screens 50047
#define sipName_screens &sipStrings_QtGui[50047]
#define sipNameNr_setFlag 50055
#define sipName_setFlag &sipStrings_QtGui[50055]
#define sipNameNr_rawFont 50063
#define sipName_rawFont &sipStrings_QtGui[50063]
#define sipNameNr_fontDpi 50071
#define sipName_fontDpi &sipStrings_QtGui[50071]
#define sipNameNr_xHeight 50079
#define sipName_xHeight &sipStrings_QtGui[50079]
#define sipNameNr_leading 50087
#define sipName_leading &sipStrings_QtGui[50087]
#define sipNameNr_descent 50095
#define sipName_descent &sipStrings_QtGui[50095]
#define sipNameNr_setBold 50103
#define sipName_setBold &sipStrings_QtGui[50103]
#define sipNameNr_cleanup 50111
#define sipName_cleanup &sipStrings_QtGui[50111]
#define sipNameNr_rawName 50119
#define sipName_rawName &sipStrings_QtGui[50119]
#define sipNameNr_rawMode 2914
#define sipName_rawMode &sipStrings_QtGui[2914]
#define sipNameNr_stretch 50127
#define sipName_stretch &sipStrings_QtGui[50127]
#define sipNameNr_kerning 50135
#define sipName_kerning &sipStrings_QtGui[50135]
#define sipNameNr_Stretch 26510
#define sipName_Stretch &sipStrings_QtGui[26510]
#define sipNameNr_Fantasy 50143
#define sipName_Fantasy &sipStrings_QtGui[50143]
#define sipNameNr_Cursive 50151
#define sipName_Cursive &sipStrings_QtGui[50151]
#define sipNameNr_Courier 50159
#define sipName_Courier &sipStrings_QtGui[50159]
#define sipNameNr_QAction 50167
#define sipName_QAction &sipStrings_QtGui[50167]
#define sipNameNr_lastPos 50175
#define sipName_lastPos &sipStrings_QtGui[50175]
#define sipNameNr_queries 50183
#define sipName_queries &sipStrings_QtGui[50183]
#define sipNameNr_oldSize 50191
#define sipName_oldSize &sipStrings_QtGui[50191]
#define sipNameNr_autorep 50199
#define sipName_autorep &sipStrings_QtGui[50199]
#define sipNameNr_oldPosF 50207
#define sipName_oldPosF &sipStrings_QtGui[50207]
#define sipNameNr_globalY 50215
#define sipName_globalY &sipStrings_QtGui[50215]
#define sipNameNr_globalX 50223
#define sipName_globalX &sipStrings_QtGui[50223]
#define sipNameNr_buttons 50231
#define sipName_buttons &sipStrings_QtGui[50231]
#define sipNameNr_openUrl 50239
#define sipName_openUrl &sipStrings_QtGui[50239]
#define sipNameNr_hotSpot 50247
#define sipName_hotSpot &sipStrings_QtGui[50247]
#define sipNameNr_changed 50255
#define sipName_changed &sipStrings_QtGui[50255]
#define sipNameNr_SeaLord 50263
#define sipName_SeaLord &sipStrings_QtGui[50263]
#define sipNameNr_OverSun 50271
#define sipName_OverSun &sipStrings_QtGui[50271]
#define sipNameNr_FlyHigh 50279
#define sipName_FlyHigh &sipStrings_QtGui[50279]
#define sipNameNr_NewYork 50287
#define sipName_NewYork &sipStrings_QtGui[50287]
#define sipNameNr_NewLife 50295
#define sipName_NewLife &sipStrings_QtGui[50295]
#define sipNameNr_texture 50303
#define sipName_texture &sipStrings_QtGui[50303]
#define sipNameNr_thistle 50311
#define sipName_thistle &sipStrings_QtGui[50311]
#define sipNameNr_skyblue 36385
#define sipName_skyblue &sipStrings_QtGui[36385]
#define sipNameNr_oldlace 50319
#define sipName_oldlace &sipStrings_QtGui[50319]
#define sipNameNr_hotpink 50327
#define sipName_hotpink &sipStrings_QtGui[50327]
#define sipNameNr_fuchsia 50335
#define sipName_fuchsia &sipStrings_QtGui[50335]
#define sipNameNr_dimgrey 50343
#define sipName_dimgrey &sipStrings_QtGui[50343]
#define sipNameNr_dimgray 50351
#define sipName_dimgray &sipStrings_QtGui[50351]
#define sipNameNr_darkred 50359
#define sipName_darkred &sipStrings_QtGui[50359]
#define sipNameNr_crimson 50367
#define sipName_crimson &sipStrings_QtGui[50367]
#define sipNameNr_DarkRed 50375
#define sipName_DarkRed &sipStrings_QtGui[50375]
#define sipNameNr_Magenta 39899
#define sipName_Magenta &sipStrings_QtGui[39899]
#define sipNameNr_HexArgb 50383
#define sipName_HexArgb &sipStrings_QtGui[50383]
#define sipNameNr_fromHsl 50391
#define sipName_fromHsl &sipStrings_QtGui[50391]
#define sipNameNr_setHslF 50399
#define sipName_setHslF &sipStrings_QtGui[50399]
#define sipNameNr_getHslF 50407
#define sipName_getHslF &sipStrings_QtGui[50407]
#define sipNameNr_hslHueF 50415
#define sipName_hslHueF &sipStrings_QtGui[50415]
#define sipNameNr_hsvHueF 50423
#define sipName_hsvHueF &sipStrings_QtGui[50423]
#define sipNameNr_lighter 16006
#define sipName_lighter &sipStrings_QtGui[16006]
#define sipNameNr_fromHsv 50431
#define sipName_fromHsv &sipStrings_QtGui[50431]
#define sipNameNr_fromRgb 50439
#define sipName_fromRgb &sipStrings_QtGui[50439]
#define sipNameNr_setCmyk 50447
#define sipName_setCmyk &sipStrings_QtGui[50447]
#define sipNameNr_getCmyk 50455
#define sipName_getCmyk &sipStrings_QtGui[50455]
#define sipNameNr_yellowF 50463
#define sipName_yellowF &sipStrings_QtGui[50463]
#define sipNameNr_setHsvF 50471
#define sipName_setHsvF &sipStrings_QtGui[50471]
#define sipNameNr_getHsvF 50479
#define sipName_getHsvF &sipStrings_QtGui[50479]
#define sipNameNr_setRgba 50487
#define sipName_setRgba &sipStrings_QtGui[50487]
#define sipNameNr_setRgbF 50495
#define sipName_setRgbF &sipStrings_QtGui[50495]
#define sipNameNr_getRgbF 50503
#define sipName_getRgbF &sipStrings_QtGui[50503]
#define sipNameNr_setRedF 50511
#define sipName_setRedF &sipStrings_QtGui[50511]
#define sipNameNr_setBlue 50519
#define sipName_setBlue &sipStrings_QtGui[50519]
#define sipNameNr_imageAt 50527
#define sipName_imageAt &sipStrings_QtGui[50527]
#define sipNameNr_hitTest 50535
#define sipName_hitTest &sipStrings_QtGui[50535]
#define sipNameNr_painter 50543
#define sipName_painter &sipStrings_QtGui[50543]
#define sipNameNr_palette 50551
#define sipName_palette &sipStrings_QtGui[50551]
#define sipNameNr_matches 50559
#define sipName_matches &sipStrings_QtGui[50559]
#define sipNameNr_release 50567
#define sipName_release &sipStrings_QtGui[50567]
#define sipNameNr_NoMatch 50575
#define sipName_NoMatch &sipStrings_QtGui[50575]
#define sipNameNr_setSize 50583
#define sipName_setSize &sipStrings_QtGui[50583]
#define sipNameNr_started 50591
#define sipName_started &sipStrings_QtGui[50591]
#define sipNameNr_toPoint 50599
#define sipName_toPoint &sipStrings_QtGui[50599]
#define sipNameNr_Windows 25409
#define sipName_Windows &sipStrings_QtGui[25409]
#define sipNameNr_formats 50607
#define sipName_formats &sipStrings_QtGui[50607]
#define sipNameNr_setHtml 50615
#define sipName_setHtml &sipStrings_QtGui[50615]
#define sipNameNr_setText 50623
#define sipName_setText &sipStrings_QtGui[50623]
#define sipNameNr_QCursor 50631
#define sipName_QCursor &sipStrings_QtGui[50631]
#define sipNameNr_QBitmap 44864
#define sipName_QBitmap &sipStrings_QtGui[44864]
#define sipNameNr_QRegion 50639
#define sipName_QRegion &sipStrings_QtGui[50639]
#define sipNameNr_QPixmap 50647
#define sipName_QPixmap &sipStrings_QtGui[50647]
#define sipNameNr___neg__ 50655
#define sipName___neg__ &sipStrings_QtGui[50655]
#define sipNameNr___div__ 50663
#define sipName___div__ &sipStrings_QtGui[50663]
#define sipNameNr_margins 50671
#define sipName_margins &sipStrings_QtGui[50671]
#define sipNameNr_Myanmar 50679
#define sipName_Myanmar &sipStrings_QtGui[50679]
#define sipNameNr_Sinhala 50687
#define sipName_Sinhala &sipStrings_QtGui[50687]
#define sipNameNr_Tibetan 50695
#define sipName_Tibetan &sipStrings_QtGui[50695]
#define sipNameNr_Kannada 50703
#define sipName_Kannada &sipStrings_QtGui[50703]
#define sipNameNr_Bengali 50711
#define sipName_Bengali &sipStrings_QtGui[50711]
#define sipNameNr_resolve 50719
#define sipName_resolve &sipStrings_QtGui[50719]
#define sipNameNr_Current 38627
#define sipName_Current &sipStrings_QtGui[38627]
#define sipNameNr_addPath 50727
#define sipName_addPath &sipStrings_QtGui[50727]
#define sipNameNr_setType 50735
#define sipName_setType &sipStrings_QtGui[50735]
#define sipNameNr___sub__ 50743
#define sipName___sub__ &sipStrings_QtGui[50743]
#define sipNameNr_MaxUser 50751
#define sipName_MaxUser &sipStrings_QtGui[50751]
#define sipNameNr_enabled 50759
#define sipName_enabled &sipStrings_QtGui[50759]
#define sipNameNr_version 50767
#define sipName_version &sipStrings_QtGui[50767]
#define sipNameNr_context 50775
#define sipName_context &sipStrings_QtGui[50775]
#define sipNameNr_Invalid 28445
#define sipName_Invalid &sipStrings_QtGui[28445]
#define sipNameNr_Float16 50783
#define sipName_Float16 &sipStrings_QtGui[50783]
#define sipNameNr___add__ 50791
#define sipName___add__ &sipStrings_QtGui[50791]
#define sipNameNr_reserve 50799
#define sipName_reserve &sipStrings_QtGui[50799]
#define sipNameNr___mul__ 50807
#define sipName___mul__ &sipStrings_QtGui[50807]
#define sipNameNr_replace 50815
#define sipName_replace &sipStrings_QtGui[50815]
#define sipNameNr_prepend 50823
#define sipName_prepend &sipStrings_QtGui[50823]
#define sipNameNr_indexOf 50831
#define sipName_indexOf &sipStrings_QtGui[50831]
#define sipNameNr_isEmpty 50839
#define sipName_isEmpty &sipStrings_QtGui[50839]
#define sipNameNr___len__ 50847
#define sipName___len__ &sipStrings_QtGui[50847]
#define sipNameNr_options 50855
#define sipName_options &sipStrings_QtGui[50855]
#define sipNameNr_setData 50863
#define sipName_setData &sipStrings_QtGui[50863]
#define sipNameNr_sibling 50871
#define sipName_sibling &sipStrings_QtGui[50871]
#define sipNameNr_isValid 50879
#define sipName_isValid &sipStrings_QtGui[50879]
#define sipNameNr_message 50887
#define sipName_message &sipStrings_QtGui[50887]
#define sipNameNr_Running 44044
#define sipName_Running &sipStrings_QtGui[44044]
#define sipNameNr_Forward 50895
#define sipName_Forward &sipStrings_QtGui[50895]
#define sipNameNr_Checked 50903
#define sipName_Checked &sipStrings_QtGui[50903]
#define sipNameNr_DotLine 29210
#define sipName_DotLine &sipStrings_QtGui[29210]
#define sipNameNr_magenta 39887
#define sipName_magenta &sipStrings_QtGui[39887]
#define sipNameNr___xor__ 50911
#define sipName___xor__ &sipStrings_QtGui[50911]
#define sipNameNr___ior__ 50919
#define sipName___ior__ &sipStrings_QtGui[50919]
#define sipNameNr___and__ 50927
#define sipName___and__ &sipStrings_QtGui[50927]
#define sipNameNr___int__ 50935
#define sipName___int__ &sipStrings_QtGui[50935]
#define sipNameNr_raise_ 50943
#define sipName_raise_ &sipStrings_QtGui[50943]
#define sipNameNr_normal 50950
#define sipName_normal &sipStrings_QtGui[50950]
#define sipNameNr_TxNone 50957
#define sipName_TxNone &sipStrings_QtGui[50957]
#define sipNameNr_rowEnd 50964
#define sipName_rowEnd &sipStrings_QtGui[50964]
#define sipNameNr_cellAt 50971
#define sipName_cellAt &sipStrings_QtGui[50971]
#define sipNameNr_NoWrap 50978
#define sipName_NoWrap &sipStrings_QtGui[50978]
#define sipNameNr_lineAt 50985
#define sipName_lineAt &sipStrings_QtGui[50985]
#define sipNameNr_border 50992
#define sipName_border &sipStrings_QtGui[50992]
#define sipNameNr_InFlow 50999
#define sipName_InFlow &sipStrings_QtGui[50999]
#define sipNameNr_marker 51006
#define sipName_marker &sipStrings_QtGui[51006]
#define sipNameNr_indent 51013
#define sipName_indent &sipStrings_QtGui[51013]
#define sipNameNr_stacks 51020
#define sipName_stacks &sipStrings_QtGui[51020]
#define sipNameNr_Stacks 10287
#define sipName_Stacks &sipStrings_QtGui[10287]
#define sipNameNr_print_ 51027
#define sipName_print_ &sipStrings_QtGui[51027]
#define sipNameNr_toHtml 51034
#define sipName_toHtml &sipStrings_QtGui[51034]
#define sipNameNr_NoMove 51041
#define sipName_NoMove &sipStrings_QtGui[51041]
#define sipNameNr_anchor 51048
#define sipName_anchor &sipStrings_QtGui[51048]
#define sipNameNr_stereo 51055
#define sipName_stereo &sipStrings_QtGui[51055]
#define sipNameNr_qAlpha 51062
#define sipName_qAlpha &sipStrings_QtGui[51062]
#define sipNameNr_qGreen 51069
#define sipName_qGreen &sipStrings_QtGui[51069]
#define sipNameNr_alpha8 51076
#define sipName_alpha8 &sipStrings_QtGui[51076]
#define sipNameNr_green8 51083
#define sipName_green8 &sipStrings_QtGui[51083]
#define sipNameNr_scalar 51090
#define sipName_scalar &sipStrings_QtGui[51090]
#define sipNameNr_closed 51097
#define sipName_closed &sipStrings_QtGui[51097]
#define sipNameNr_layout 51104
#define sipName_layout &sipStrings_QtGui[51104]
#define sipNameNr_YUV411 51111
#define sipName_YUV411 &sipStrings_QtGui[51111]
#define sipNameNr_YUV422 51118
#define sipName_YUV422 &sipStrings_QtGui[51118]
#define sipNameNr_YUV444 51125
#define sipName_YUV444 &sipStrings_QtGui[51125]
#define sipNameNr_widthF 51132
#define sipName_widthF &sipStrings_QtGui[51132]
#define sipNameNr_shadow 51139
#define sipName_shadow &sipStrings_QtGui[51139]
#define sipNameNr_NoRole 51146
#define sipName_NoRole &sipStrings_QtGui[51146]
#define sipNameNr_Shadow 51153
#define sipName_Shadow &sipStrings_QtGui[51153]
#define sipNameNr_Button 51160
#define sipName_Button &sipStrings_QtGui[51160]
#define sipNameNr_quadTo 51167
#define sipName_quadTo &sipStrings_QtGui[51167]
#define sipNameNr_lineTo 51174
#define sipName_lineTo &sipStrings_QtGui[51174]
#define sipNameNr_OpenVG 51181
#define sipName_OpenVG &sipStrings_QtGui[51181]
#define sipNameNr_Raster 51188
#define sipName_Raster &sipStrings_QtGui[51188]
#define sipNameNr_OpenGL 9570
#define sipName_OpenGL &sipStrings_QtGui[9570]
#define sipNameNr_scaleY 51195
#define sipName_scaleY &sipStrings_QtGui[51195]
#define sipNameNr_scaleX 51202
#define sipName_scaleX &sipStrings_QtGui[51202]
#define sipNameNr_setPen 51209
#define sipName_setPen &sipStrings_QtGui[51209]
#define sipNameNr_Cicero 51216
#define sipName_Cicero &sipStrings_QtGui[51216]
#define sipNameNr_Prc32K 51223
#define sipName_Prc32K &sipStrings_QtGui[51223]
#define sipNameNr_Prc16K 51230
#define sipName_Prc16K &sipStrings_QtGui[51230]
#define sipNameNr_SuperB 51237
#define sipName_SuperB &sipStrings_QtGui[51237]
#define sipNameNr_SuperA 51244
#define sipName_SuperA &sipStrings_QtGui[51244]
#define sipNameNr_Quarto 51251
#define sipName_Quarto &sipStrings_QtGui[51251]
#define sipNameNr_JisB10 51258
#define sipName_JisB10 &sipStrings_QtGui[51258]
#define sipNameNr_A4Plus 51265
#define sipName_A4Plus &sipStrings_QtGui[51265]
#define sipNameNr_Ledger 51272
#define sipName_Ledger &sipStrings_QtGui[51272]
#define sipNameNr_Letter 51279
#define sipName_Letter &sipStrings_QtGui[51279]
#define sipNameNr_rebind 51286
#define sipName_rebind &sipStrings_QtGui[51286]
#define sipNameNr_Binder 1427
#define sipName_Binder &sipStrings_QtGui[1427]
#define sipNameNr_Origin 3125
#define sipName_Origin &sipStrings_QtGui[3125]
#define sipNameNr_Repeat 19299
#define sipName_Repeat &sipStrings_QtGui[19299]
#define sipNameNr_UInt32 51293
#define sipName_UInt32 &sipStrings_QtGui[51293]
#define sipNameNr_UInt16 51300
#define sipName_UInt16 &sipStrings_QtGui[51300]
#define sipNameNr_layers 51307
#define sipName_layers &sipStrings_QtGui[51307]
#define sipNameNr_RGB5A1 31199
#define sipName_RGB5A1 &sipStrings_QtGui[31199]
#define sipNameNr_R5G6B5 31185
#define sipName_R5G6B5 &sipStrings_QtGui[31185]
#define sipNameNr_RGB9E5 51314
#define sipName_RGB9E5 &sipStrings_QtGui[51314]
#define sipNameNr_RGB32F 51321
#define sipName_RGB32F &sipStrings_QtGui[51321]
#define sipNameNr_RGB16F 51328
#define sipName_RGB16F &sipStrings_QtGui[51328]
#define sipNameNr_RGB32I 51335
#define sipName_RGB32I &sipStrings_QtGui[51335]
#define sipNameNr_RGB16I 51342
#define sipName_RGB16I &sipStrings_QtGui[51342]
#define sipNameNr_RGBA8I 51349
#define sipName_RGBA8I &sipStrings_QtGui[51349]
#define sipNameNr_RGB32U 51356
#define sipName_RGB32U &sipStrings_QtGui[51356]
#define sipNameNr_RGB16U 51363
#define sipName_RGB16U &sipStrings_QtGui[51363]
#define sipNameNr_RGBA8U 51370
#define sipName_RGBA8U &sipStrings_QtGui[51370]
#define sipNameNr_Target 3215
#define sipName_Target &sipStrings_QtGui[3215]
#define sipNameNr_stride 51377
#define sipName_stride &sipStrings_QtGui[51377]
#define sipNameNr_Vertex 51384
#define sipName_Vertex &sipStrings_QtGui[51384]
#define sipNameNr_mipmap 51391
#define sipName_mipmap &sipStrings_QtGui[51391]
#define sipNameNr_Source 4690
#define sipName_Source &sipStrings_QtGui[4690]
#define sipNameNr_shares 51398
#define sipName_shares &sipStrings_QtGui[51398]
#define sipNameNr_QMovie 51405
#define sipName_QMovie &sipStrings_QtGui[51405]
#define sipNameNr_setRow 51412
#define sipName_setRow &sipStrings_QtGui[51412]
#define sipNameNr_lookAt 51419
#define sipName_lookAt &sipStrings_QtGui[51419]
#define sipNameNr_rotate 51426
#define sipName_rotate &sipStrings_QtGui[51426]
#define sipNameNr_vector 51433
#define sipName_vector &sipStrings_QtGui[51433]
#define sipNameNr_Cancel 51440
#define sipName_Cancel &sipStrings_QtGui[51440]
#define sipNameNr_SaveAs 51447
#define sipName_SaveAs &sipStrings_QtGui[51447]
#define sipNameNr_Italic 29715
#define sipName_Italic &sipStrings_QtGui[29715]
#define sipNameNr_AddTab 51454
#define sipName_AddTab &sipStrings_QtGui[51454]
#define sipNameNr_ZoomIn 51461
#define sipName_ZoomIn &sipStrings_QtGui[51461]
#define sipNameNr_Delete 51468
#define sipName_Delete &sipStrings_QtGui[51468]
#define sipNameNr_Action 13014
#define sipName_Action &sipStrings_QtGui[13014]
#define sipNameNr_metric 51475
#define sipName_metric &sipStrings_QtGui[51475]
#define sipNameNr_isMask 51482
#define sipName_isMask &sipStrings_QtGui[51482]
#define sipNameNr_Active 27366
#define sipName_Active &sipStrings_QtGui[27366]
#define sipNameNr_inFont 51489
#define sipName_inFont &sipStrings_QtGui[51489]
#define sipNameNr_ascent 51496
#define sipName_ascent &sipStrings_QtGui[51496]
#define sipNameNr_styles 51503
#define sipName_styles &sipStrings_QtGui[51503]
#define sipNameNr_Symbol 51510
#define sipName_Symbol &sipStrings_QtGui[51510]
#define sipNameNr_Thaana 51517
#define sipName_Thaana &sipStrings_QtGui[51517]
#define sipNameNr_italic 51524
#define sipName_italic &sipStrings_QtGui[51524]
#define sipNameNr_weight 51531
#define sipName_weight &sipStrings_QtGui[51531]
#define sipNameNr_family 51538
#define sipName_family &sipStrings_QtGui[51538]
#define sipNameNr_Medium 51545
#define sipName_Medium &sipStrings_QtGui[51545]
#define sipNameNr_Normal 37176
#define sipName_Normal &sipStrings_QtGui[37176]
#define sipNameNr_Weight 29729
#define sipName_Weight &sipStrings_QtGui[29729]
#define sipNameNr_Reason 6496
#define sipName_Reason &sipStrings_QtGui[6496]
#define sipNameNr_reason 51552
#define sipName_reason &sipStrings_QtGui[51552]
#define sipNameNr_Eraser 39312
#define sipName_Eraser &sipStrings_QtGui[39312]
#define sipNameNr_Stylus 28806
#define sipName_Stylus &sipStrings_QtGui[28806]
#define sipNameNr_oldPos 51559
#define sipName_oldPos &sipStrings_QtGui[51559]
#define sipNameNr_button 51566
#define sipName_button &sipStrings_QtGui[51566]
#define sipNameNr_source 15855
#define sipName_source &sipStrings_QtGui[15855]
#define sipNameNr_screen 44715
#define sipName_screen &sipStrings_QtGui[44715]
#define sipNameNr_setPos 51573
#define sipName_setPos &sipStrings_QtGui[51573]
#define sipNameNr_bitmap 51580
#define sipName_bitmap &sipStrings_QtGui[51580]
#define sipNameNr_radius 51587
#define sipName_radius &sipStrings_QtGui[51587]
#define sipNameNr_spread 51594
#define sipName_spread &sipStrings_QtGui[51594]
#define sipNameNr_OldHat 51601
#define sipName_OldHat &sipStrings_QtGui[51601]
#define sipNameNr_Preset 20145
#define sipName_Preset &sipStrings_QtGui[20145]
#define sipNameNr_Spread 20163
#define sipName_Spread &sipStrings_QtGui[20163]
#define sipNameNr_pixmap 51608
#define sipName_pixmap &sipStrings_QtGui[51608]
#define sipNameNr_violet 43836
#define sipName_violet &sipStrings_QtGui[43836]
#define sipNameNr_tomato 51615
#define sipName_tomato &sipStrings_QtGui[51615]
#define sipNameNr_silver 51622
#define sipName_silver &sipStrings_QtGui[51622]
#define sipNameNr_sienna 51629
#define sipName_sienna &sipStrings_QtGui[51629]
#define sipNameNr_salmon 39828
#define sipName_salmon &sipStrings_QtGui[39828]
#define sipNameNr_purple 36360
#define sipName_purple &sipStrings_QtGui[36360]
#define sipNameNr_orchid 36373
#define sipName_orchid &sipStrings_QtGui[36373]
#define sipNameNr_orange 43869
#define sipName_orange &sipStrings_QtGui[43869]
#define sipNameNr_maroon 51636
#define sipName_maroon &sipStrings_QtGui[51636]
#define sipNameNr_indigo 51643
#define sipName_indigo &sipStrings_QtGui[51643]
#define sipNameNr_bisque 51650
#define sipName_bisque &sipStrings_QtGui[51650]
#define sipNameNr_Yellow 43902
#define sipName_Yellow &sipStrings_QtGui[43902]
#define sipNameNr_Color1 51657
#define sipName_Color1 &sipStrings_QtGui[51657]
#define sipNameNr_Color0 51664
#define sipName_Color0 &sipStrings_QtGui[51664]
#define sipNameNr_HexRgb 51671
#define sipName_HexRgb &sipStrings_QtGui[51671]
#define sipNameNr_setHsl 51678
#define sipName_setHsl &sipStrings_QtGui[51678]
#define sipNameNr_getHsl 51685
#define sipName_getHsl &sipStrings_QtGui[51685]
#define sipNameNr_hslHue 51692
#define sipName_hslHue &sipStrings_QtGui[51692]
#define sipNameNr_hsvHue 51699
#define sipName_hsvHue &sipStrings_QtGui[51699]
#define sipNameNr_darker 51706
#define sipName_darker &sipStrings_QtGui[51706]
#define sipNameNr_toCmyk 51713
#define sipName_toCmyk &sipStrings_QtGui[51713]
#define sipNameNr_blackF 51720
#define sipName_blackF &sipStrings_QtGui[51720]
#define sipNameNr_setHsv 51727
#define sipName_setHsv &sipStrings_QtGui[51727]
#define sipNameNr_getHsv 51734
#define sipName_getHsv &sipStrings_QtGui[51734]
#define sipNameNr_valueF 51741
#define sipName_valueF &sipStrings_QtGui[51741]
#define sipNameNr_setRgb 51748
#define sipName_setRgb &sipStrings_QtGui[51748]
#define sipNameNr_getRgb 51755
#define sipName_getRgb &sipStrings_QtGui[51755]
#define sipNameNr_greenF 51762
#define sipName_greenF &sipStrings_QtGui[51762]
#define sipNameNr_setRed 51769
#define sipName_setRed &sipStrings_QtGui[51769]
#define sipNameNr_alphaF 51776
#define sipName_alphaF &sipStrings_QtGui[51776]
#define sipNameNr_rgba64 51783
#define sipName_rgba64 &sipStrings_QtGui[51783]
#define sipNameNr_matrix 51790
#define sipName_matrix &sipStrings_QtGui[51790]
#define sipNameNr_scroll 51797
#define sipName_scroll &sipStrings_QtGui[51797]
#define sipNameNr_region 51804
#define sipName_region &sipStrings_QtGui[51804]
#define sipNameNr_window 51811
#define sipName_window &sipStrings_QtGui[51811]
#define sipNameNr_update 51818
#define sipName_update &sipStrings_QtGui[51818]
#define sipNameNr_cursor 51825
#define sipName_cursor &sipStrings_QtGui[51825]
#define sipNameNr_Cursor 11519
#define sipName_Cursor &sipStrings_QtGui[11519]
#define sipNameNr_scaled 51832
#define sipName_scaled &sipStrings_QtGui[51832]
#define sipNameNr_Format 2702
#define sipName_Format &sipStrings_QtGui[2702]
#define sipNameNr_cancel 51839
#define sipName_cancel &sipStrings_QtGui[51839]
#define sipNameNr_commit 51846
#define sipName_commit &sipStrings_QtGui[51846]
#define sipNameNr_create 51853
#define sipName_create &sipStrings_QtGui[51853]
#define sipNameNr_united 51860
#define sipName_united &sipStrings_QtGui[51860]
#define sipNameNr_moveTo 51867
#define sipName_moveTo &sipStrings_QtGui[51867]
#define sipNameNr_regExp 51874
#define sipName_regExp &sipStrings_QtGui[51874]
#define sipNameNr_QImage 51881
#define sipName_QImage &sipStrings_QtGui[51881]
#define sipNameNr_QColor 51888
#define sipName_QColor &sipStrings_QtGui[51888]
#define sipNameNr_QBrush 51895
#define sipName_QBrush &sipStrings_QtGui[51895]
#define sipNameNr_Access 11321
#define sipName_Access &sipStrings_QtGui[11321]
#define sipNameNr_margin 51902
#define sipName_margin &sipStrings_QtGui[51902]
#define sipNameNr_factor 51909
#define sipName_factor &sipStrings_QtGui[51909]
#define sipNameNr_setTop 51916
#define sipName_setTop &sipStrings_QtGui[51916]
#define sipNameNr_Syriac 51923
#define sipName_Syriac &sipStrings_QtGui[51923]
#define sipNameNr_Telugu 51930
#define sipName_Telugu &sipStrings_QtGui[51930]
#define sipNameNr_Korean 51937
#define sipName_Korean &sipStrings_QtGui[51937]
#define sipNameNr_Hebrew 51944
#define sipName_Hebrew &sipStrings_QtGui[51944]
#define sipNameNr_Arabic 51951
#define sipName_Arabic &sipStrings_QtGui[51951]
#define sipNameNr_center 51958
#define sipName_center &sipStrings_QtGui[51958]
#define sipNameNr_height 51965
#define sipName_height &sipStrings_QtGui[51965]
#define sipNameNr_bottom 51972
#define sipName_bottom &sipStrings_QtGui[51972]
#define sipNameNr_select 49073
#define sipName_select &sipStrings_QtGui[49073]
#define sipNameNr_offset 51979
#define sipName_offset &sipStrings_QtGui[51979]
#define sipNameNr_handle 51986
#define sipName_handle &sipStrings_QtGui[51986]
#define sipNameNr_Custom 51993
#define sipName_Custom &sipStrings_QtGui[51993]
#define sipNameNr_Linear 14413
#define sipName_Linear &sipStrings_QtGui[14413]
#define sipNameNr_filter 52000
#define sipName_filter &sipStrings_QtGui[52000]
#define sipNameNr_Hidden 52007
#define sipName_Hidden &sipStrings_QtGui[52007]
#define sipNameNr_Filter 9363
#define sipName_Filter &sipStrings_QtGui[9363]
#define sipNameNr_status 52014
#define sipName_status &sipStrings_QtGui[52014]
#define sipNameNr_ignore 52021
#define sipName_ignore &sipStrings_QtGui[52021]
#define sipNameNr_accept 52028
#define sipName_accept &sipStrings_QtGui[52028]
#define sipNameNr_notify 52035
#define sipName_notify &sipStrings_QtGui[52035]
#define sipNameNr_option 52042
#define sipName_option &sipStrings_QtGui[52042]
#define sipNameNr_device 52049
#define sipName_device &sipStrings_QtGui[52049]
#define sipNameNr_locale 52056
#define sipName_locale &sipStrings_QtGui[52056]
#define sipNameNr_System 4156
#define sipName_System &sipStrings_QtGui[4156]
#define sipNameNr_format 24882
#define sipName_format &sipStrings_QtGui[24882]
#define sipNameNr___ge__ 52063
#define sipName___ge__ &sipStrings_QtGui[52063]
#define sipNameNr___le__ 52070
#define sipName___le__ &sipStrings_QtGui[52070]
#define sipNameNr___gt__ 52077
#define sipName___gt__ &sipStrings_QtGui[52077]
#define sipNameNr_before 52084
#define sipName_before &sipStrings_QtGui[52084]
#define sipNameNr_remove 52091
#define sipName_remove &sipStrings_QtGui[52091]
#define sipNameNr_insert 52098
#define sipName_insert &sipStrings_QtGui[52098]
#define sipNameNr_append 52105
#define sipName_append &sipStrings_QtGui[52105]
#define sipNameNr_length 52112
#define sipName_length &sipStrings_QtGui[52112]
#define sipNameNr_detach 52119
#define sipName_detach &sipStrings_QtGui[52119]
#define sipNameNr_resize 52126
#define sipName_resize &sipStrings_QtGui[52126]
#define sipNameNr_isNull 52133
#define sipName_isNull &sipStrings_QtGui[52133]
#define sipNameNr_target 52140
#define sipName_target &sipStrings_QtGui[52140]
#define sipNameNr_revert 52147
#define sipName_revert &sipStrings_QtGui[52147]
#define sipNameNr_submit 52154
#define sipName_submit &sipStrings_QtGui[52154]
#define sipNameNr_action 52161
#define sipName_action &sipStrings_QtGui[52161]
#define sipNameNr___lt__ 52168
#define sipName___lt__ &sipStrings_QtGui[52168]
#define sipNameNr_column 52175
#define sipName_column &sipStrings_QtGui[52175]
#define sipNameNr_object 52182
#define sipName_object &sipStrings_QtGui[52182]
#define sipNameNr_parent 30359
#define sipName_parent &sipStrings_QtGui[30359]
#define sipNameNr_Paused 47135
#define sipName_Paused &sipStrings_QtGui[47135]
#define sipNameNr_Window 16501
#define sipName_Window &sipStrings_QtGui[16501]
#define sipNameNr_yellow 13308
#define sipName_yellow &sipStrings_QtGui[13308]
#define sipNameNr___ne__ 52189
#define sipName___ne__ &sipStrings_QtGui[52189]
#define sipNameNr___eq__ 52196
#define sipName___eq__ &sipStrings_QtGui[52196]
#define sipNameNr___or__ 52203
#define sipName___or__ &sipStrings_QtGui[52203]
#define sipNameNr_alert 52210
#define sipName_alert &sipStrings_QtGui[52210]
#define sipNameNr_lower 52216
#define sipName_lower &sipStrings_QtGui[52216]
#define sipNameNr_winId 52222
#define sipName_winId &sipStrings_QtGui[52222]
#define sipNameNr_fixup 52228
#define sipName_fixup &sipStrings_QtGui[52228]
#define sipNameNr_delim 52234
#define sipName_delim &sipStrings_QtGui[52234]
#define sipNameNr_print 52240
#define sipName_print &sipStrings_QtGui[52240]
#define sipNameNr_Right 31942
#define sipName_Right &sipStrings_QtGui[31942]
#define sipNameNr_Start 22485
#define sipName_Start &sipStrings_QtGui[22485]
#define sipNameNr_qGray 52246
#define sipName_qGray &sipStrings_QtGui[52246]
#define sipNameNr_qRgba 52252
#define sipName_qRgba &sipStrings_QtGui[52252]
#define sipNameNr_qBlue 52258
#define sipName_qBlue &sipStrings_QtGui[52258]
#define sipNameNr_blue8 52264
#define sipName_blue8 &sipStrings_QtGui[52264]
#define sipNameNr_xored 52270
#define sipName_xored &sipStrings_QtGui[52270]
#define sipNameNr_nlerp 52276
#define sipName_nlerp &sipStrings_QtGui[52276]
#define sipNameNr_slerp 52282
#define sipName_slerp &sipStrings_QtGui[52282]
#define sipNameNr_AtEnd 52288
#define sipName_AtEnd &sipStrings_QtGui[52288]
#define sipNameNr_title 52294
#define sipName_title &sipStrings_QtGui[52294]
#define sipNameNr_light 37549
#define sipName_light &sipStrings_QtGui[37549]
#define sipNameNr_arcTo 52300
#define sipName_arcTo &sipStrings_QtGui[52300]
#define sipNameNr_rects 52306
#define sipName_rects &sipStrings_QtGui[52306]
#define sipNameNr_shear 52312
#define sipName_shear &sipStrings_QtGui[52312]
#define sipNameNr_begin 52318
#define sipName_begin &sipStrings_QtGui[52318]
#define sipNameNr_Didot 52324
#define sipName_Didot &sipStrings_QtGui[52324]
#define sipNameNr_units 52330
#define sipName_units &sipStrings_QtGui[52330]
#define sipNameNr_AnsiB 52336
#define sipName_AnsiB &sipStrings_QtGui[52336]
#define sipNameNr_AnsiA 52342
#define sipName_AnsiA &sipStrings_QtGui[52342]
#define sipNameNr_ArchE 52348
#define sipName_ArchE &sipStrings_QtGui[52348]
#define sipNameNr_ArchD 52354
#define sipName_ArchD &sipStrings_QtGui[52354]
#define sipNameNr_ArchC 52360
#define sipName_ArchC &sipStrings_QtGui[52360]
#define sipNameNr_ArchB 52366
#define sipName_ArchB &sipStrings_QtGui[52366]
#define sipNameNr_ArchA 52372
#define sipName_ArchA &sipStrings_QtGui[52372]
#define sipNameNr_AnsiE 52378
#define sipName_AnsiE &sipStrings_QtGui[52378]
#define sipNameNr_AnsiD 52384
#define sipName_AnsiD &sipStrings_QtGui[52384]
#define sipNameNr_AnsiC 52390
#define sipName_AnsiC &sipStrings_QtGui[52390]
#define sipNameNr_JisB9 52396
#define sipName_JisB9 &sipStrings_QtGui[52396]
#define sipNameNr_JisB8 52402
#define sipName_JisB8 &sipStrings_QtGui[52402]
#define sipNameNr_JisB7 52408
#define sipName_JisB7 &sipStrings_QtGui[52408]
#define sipNameNr_JisB6 52414
#define sipName_JisB6 &sipStrings_QtGui[52414]
#define sipNameNr_JisB5 52420
#define sipName_JisB5 &sipStrings_QtGui[52420]
#define sipNameNr_JisB4 52426
#define sipName_JisB4 &sipStrings_QtGui[52426]
#define sipNameNr_JisB3 52432
#define sipName_JisB3 &sipStrings_QtGui[52432]
#define sipNameNr_JisB2 52438
#define sipName_JisB2 &sipStrings_QtGui[52438]
#define sipNameNr_JisB1 52444
#define sipName_JisB1 &sipStrings_QtGui[52444]
#define sipNameNr_JisB0 52450
#define sipName_JisB0 &sipStrings_QtGui[52450]
#define sipNameNr_Folio 52456
#define sipName_Folio &sipStrings_QtGui[52456]
#define sipNameNr_Legal 16464
#define sipName_Legal &sipStrings_QtGui[16464]
#define sipNameNr_Int32 51294
#define sipName_Int32 &sipStrings_QtGui[51294]
#define sipNameNr_Int16 51301
#define sipName_Int16 &sipStrings_QtGui[51301]
#define sipNameNr_UInt8 52462
#define sipName_UInt8 &sipStrings_QtGui[52462]
#define sipNameNr_Alpha 18886
#define sipName_Alpha &sipStrings_QtGui[18886]
#define sipNameNr_faces 52468
#define sipName_faces &sipStrings_QtGui[52468]
#define sipNameNr_SRGB8 52474
#define sipName_SRGB8 &sipStrings_QtGui[52474]
#define sipNameNr_D24S8 34840
#define sipName_D24S8 &sipStrings_QtGui[34840]
#define sipNameNr_RGBA4 34866
#define sipName_RGBA4 &sipStrings_QtGui[34866]
#define sipNameNr_RG3B2 38365
#define sipName_RG3B2 &sipStrings_QtGui[38365]
#define sipNameNr_RG32F 52480
#define sipName_RG32F &sipStrings_QtGui[52480]
#define sipNameNr_RG16F 52486
#define sipName_RG16F &sipStrings_QtGui[52486]
#define sipNameNr_RG32I 52492
#define sipName_RG32I &sipStrings_QtGui[52492]
#define sipNameNr_RG16I 52498
#define sipName_RG16I &sipStrings_QtGui[52498]
#define sipNameNr_RGB8I 52504
#define sipName_RGB8I &sipStrings_QtGui[52504]
#define sipNameNr_RG32U 52510
#define sipName_RG32U &sipStrings_QtGui[52510]
#define sipNameNr_RG16U 52516
#define sipName_RG16U &sipStrings_QtGui[52516]
#define sipNameNr_RGB8U 52522
#define sipName_RGB8U &sipStrings_QtGui[52522]
#define sipNameNr_Depth 34151
#define sipName_Depth &sipStrings_QtGui[34151]
#define sipNameNr_Types 960
#define sipName_Types &sipStrings_QtGui[960]
#define sipNameNr_LibGL 52528
#define sipName_LibGL &sipStrings_QtGui[52528]
#define sipNameNr_speed 52534
#define sipName_speed &sipStrings_QtGui[52534]
#define sipNameNr_ortho 52540
#define sipName_ortho &sipStrings_QtGui[52540]
#define sipNameNr_Print 52546
#define sipName_Print &sipStrings_QtGui[52546]
#define sipNameNr_Paste 52552
#define sipName_Paste &sipStrings_QtGui[52552]
#define sipNameNr_Click 52558
#define sipName_Click &sipStrings_QtGui[52558]
#define sipNameNr_pixel 52564
#define sipName_pixel &sipStrings_QtGui[52564]
#define sipNameNr_valid 28447
#define sipName_valid &sipStrings_QtGui[28447]
#define sipNameNr_depth 52570
#define sipName_depth &sipStrings_QtGui[52570]
#define sipNameNr_sizes 52576
#define sipName_sizes &sipStrings_QtGui[52576]
#define sipNameNr_clone 52582
#define sipName_clone &sipStrings_QtGui[52582]
#define sipNameNr_paint 52588
#define sipName_paint &sipStrings_QtGui[52588]
#define sipNameNr_Runic 52594
#define sipName_Runic &sipStrings_QtGui[52594]
#define sipNameNr_Ogham 52600
#define sipName_Ogham &sipStrings_QtGui[52600]
#define sipNameNr_Style 1822
#define sipName_Style &sipStrings_QtGui[1822]
#define sipNameNr_Light 5977
#define sipName_Light &sipStrings_QtGui[5977]
#define sipNameNr_Serif 45996
#define sipName_Serif &sipStrings_QtGui[45996]
#define sipNameNr_Times 52606
#define sipName_Times &sipStrings_QtGui[52606]
#define sipNameNr_Token 52612
#define sipName_Token &sipStrings_QtGui[52612]
#define sipNameNr_Other 52618
#define sipName_Other &sipStrings_QtGui[52618]
#define sipNameNr_Mouse 43177
#define sipName_Mouse &sipStrings_QtGui[43177]
#define sipNameNr_yTilt 52624
#define sipName_yTilt &sipStrings_QtGui[52624]
#define sipNameNr_xTilt 52630
#define sipName_xTilt &sipStrings_QtGui[52630]
#define sipNameNr_phase 52636
#define sipName_phase &sipStrings_QtGui[52636]
#define sipNameNr_QDrag 52642
#define sipName_QDrag &sipStrings_QtGui[52642]
#define sipNameNr_gamma 52648
#define sipName_gamma &sipStrings_QtGui[52648]
#define sipNameNr_Gamma 16103
#define sipName_Gamma &sipStrings_QtGui[16103]
#define sipNameNr_stops 52654
#define sipName_stops &sipStrings_QtGui[52654]
#define sipNameNr_brush 48363
#define sipName_brush &sipStrings_QtGui[48363]
#define sipNameNr_wheat 52660
#define sipName_wheat &sipStrings_QtGui[52660]
#define sipNameNr_olive 52666
#define sipName_olive &sipStrings_QtGui[52666]
#define sipNameNr_linen 52672
#define sipName_linen &sipStrings_QtGui[52672]
#define sipNameNr_khaki 46686
#define sipName_khaki &sipStrings_QtGui[46686]
#define sipNameNr_ivory 52678
#define sipName_ivory &sipStrings_QtGui[52678]
#define sipNameNr_coral 43804
#define sipName_coral &sipStrings_QtGui[43804]
#define sipNameNr_brown 39793
#define sipName_brown &sipStrings_QtGui[39793]
#define sipNameNr_beige 52684
#define sipName_beige &sipStrings_QtGui[52684]
#define sipNameNr_azure 52690
#define sipName_azure &sipStrings_QtGui[52690]
#define sipNameNr_Green 34801
#define sipName_Green &sipStrings_QtGui[34801]
#define sipNameNr_White 35997
#define sipName_White &sipStrings_QtGui[35997]
#define sipNameNr_Black 52696
#define sipName_Black &sipStrings_QtGui[52696]
#define sipNameNr_toHsl 52702
#define sipName_toHsl &sipStrings_QtGui[52702]
#define sipNameNr_toHsv 52708
#define sipName_toHsv &sipStrings_QtGui[52708]
#define sipNameNr_toRgb 39373
#define sipName_toRgb &sipStrings_QtGui[39373]
#define sipNameNr_cyanF 52714
#define sipName_cyanF &sipStrings_QtGui[52714]
#define sipNameNr_blueF 52720
#define sipName_blueF &sipStrings_QtGui[52720]
#define sipNameNr_alpha 52726
#define sipName_alpha &sipStrings_QtGui[52726]
#define sipNameNr_block 52732
#define sipName_block &sipStrings_QtGui[52732]
#define sipNameNr_Point 8627
#define sipName_Point &sipStrings_QtGui[8627]
#define sipNameNr_shape 52738
#define sipName_shape &sipStrings_QtGui[52738]
#define sipNameNr_scale 10640
#define sipName_scale &sipStrings_QtGui[10640]
#define sipNameNr_codec 52744
#define sipName_codec &sipStrings_QtGui[52744]
#define sipNameNr_types 52750
#define sipName_types &sipStrings_QtGui[52750]
#define sipNameNr_color 52756
#define sipName_color &sipStrings_QtGui[52756]
#define sipNameNr_image 52762
#define sipName_image &sipStrings_QtGui[52762]
#define sipNameNr_QIcon 52768
#define sipName_QIcon &sipStrings_QtGui[52768]
#define sipNameNr_QFont 52774
#define sipName_QFont &sipStrings_QtGui[52774]
#define sipNameNr_style 52780
#define sipName_style &sipStrings_QtGui[52780]
#define sipNameNr_Khmer 52786
#define sipName_Khmer &sipStrings_QtGui[52786]
#define sipNameNr_Tamil 52792
#define sipName_Tamil &sipStrings_QtGui[52792]
#define sipNameNr_Oriya 52798
#define sipName_Oriya &sipStrings_QtGui[52798]
#define sipNameNr_Latin 52804
#define sipName_Latin &sipStrings_QtGui[52804]
#define sipNameNr_Greek 52810
#define sipName_Greek &sipStrings_QtGui[52810]
#define sipNameNr_angle 9479
#define sipName_angle &sipStrings_QtGui[9479]
#define sipNameNr_point 52816
#define sipName_point &sipStrings_QtGui[52816]
#define sipNameNr_hints 52822
#define sipName_hints &sipStrings_QtGui[52822]
#define sipNameNr_merge 52828
#define sipName_merge &sipStrings_QtGui[52828]
#define sipNameNr_write 52834
#define sipName_write &sipStrings_QtGui[52834]
#define sipNameNr_unmap 52840
#define sipName_unmap &sipStrings_QtGui[52840]
#define sipNameNr_error 52846
#define sipName_error &sipStrings_QtGui[52846]
#define sipNameNr_Close 52852
#define sipName_Close &sipStrings_QtGui[52852]
#define sipNameNr_exec_ 52858
#define sipName_exec_ &sipStrings_QtGui[52858]
#define sipNameNr_Flags 892
#define sipName_Flags &sipStrings_QtGui[892]
#define sipNameNr_reset 20146
#define sipName_reset &sipStrings_QtGui[20146]
#define sipNameNr_width 52864
#define sipName_width &sipStrings_QtGui[52864]
#define sipNameNr_right 52870
#define sipName_right &sipStrings_QtGui[52870]
#define sipNameNr_atEnd 52876
#define sipName_atEnd &sipStrings_QtGui[52876]
#define sipNameNr_close 52882
#define sipName_close &sipStrings_QtGui[52882]
#define sipNameNr_clear 52888
#define sipName_clear &sipStrings_QtGui[52888]
#define sipNameNr_first 52894
#define sipName_first &sipStrings_QtGui[52894]
#define sipNameNr_match 52900
#define sipName_match &sipStrings_QtGui[52900]
#define sipNameNr_buddy 52906
#define sipName_buddy &sipStrings_QtGui[52906]
#define sipNameNr_order 10134
#define sipName_order &sipStrings_QtGui[10134]
#define sipNameNr_count 52912
#define sipName_count &sipStrings_QtGui[52912]
#define sipNameNr_value 52918
#define sipName_value &sipStrings_QtGui[52918]
#define sipNameNr_index 52924
#define sipName_index &sipStrings_QtGui[52924]
#define sipNameNr_model 52930
#define sipName_model &sipStrings_QtGui[52930]
#define sipNameNr_child 52936
#define sipName_child &sipStrings_QtGui[52936]
#define sipNameNr_flush 52942
#define sipName_flush &sipStrings_QtGui[52942]
#define sipNameNr_flags 52948
#define sipName_flags &sipStrings_QtGui[52948]
#define sipNameNr_event 52954
#define sipName_event &sipStrings_QtGui[52954]
#define sipNameNr_start 52960
#define sipName_start &sipStrings_QtGui[52960]
#define sipNameNr_state 23923
#define sipName_state &sipStrings_QtGui[23923]
#define sipNameNr_State 6471
#define sipName_State &sipStrings_QtGui[6471]
#define sipNameNr_green 20182
#define sipName_green &sipStrings_QtGui[20182]
#define sipNameNr_white 36426
#define sipName_white &sipStrings_QtGui[36426]
#define sipNameNr_black 52966
#define sipName_black &sipStrings_QtGui[52966]
#define sipNameNr_setW 52972
#define sipName_setW &sipStrings_QtGui[52972]
#define sipNameNr_Area 26273
#define sipName_Area &sipStrings_QtGui[26273]
#define sipNameNr_edge 52977
#define sipName_edge &sipStrings_QtGui[52977]
#define sipNameNr_tabs 52982
#define sipName_tabs &sipStrings_QtGui[52982]
#define sipNameNr_redo 52987
#define sipName_redo &sipStrings_QtGui[52987]
#define sipNameNr_undo 52992
#define sipName_undo &sipStrings_QtGui[52992]
#define sipNameNr_Down 52997
#define sipName_Down &sipStrings_QtGui[52997]
#define sipNameNr_Left 21602
#define sipName_Left &sipStrings_QtGui[21602]
#define sipNameNr_rows 53002
#define sipName_rows &sipStrings_QtGui[53002]
#define sipNameNr_qRgb 53007
#define sipName_qRgb &sipStrings_QtGui[53007]
#define sipNameNr_qRed 53012
#define sipName_qRed &sipStrings_QtGui[53012]
#define sipNameNr_red8 53017
#define sipName_red8 &sipStrings_QtGui[53017]
#define sipNameNr_setZ 53022
#define sipName_setZ &sipStrings_QtGui[53022]
#define sipNameNr_axis 53027
#define sipName_axis &sipStrings_QtGui[53027]
#define sipNameNr_find 53032
#define sipName_find &sipStrings_QtGui[53032]
#define sipNameNr_IMC4 53037
#define sipName_IMC4 &sipStrings_QtGui[53037]
#define sipNameNr_IMC3 53042
#define sipName_IMC3 &sipStrings_QtGui[53042]
#define sipNameNr_IMC2 53047
#define sipName_IMC2 &sipStrings_QtGui[53047]
#define sipNameNr_IMC1 53052
#define sipName_IMC1 &sipStrings_QtGui[53052]
#define sipNameNr_NV21 53057
#define sipName_NV21 &sipStrings_QtGui[53057]
#define sipNameNr_NV12 53062
#define sipName_NV12 &sipStrings_QtGui[53062]
#define sipNameNr_YUYV 53067
#define sipName_YUYV &sipStrings_QtGui[53067]
#define sipNameNr_UYVY 53072
#define sipName_UYVY &sipStrings_QtGui[53072]
#define sipNameNr_YV12 53077
#define sipName_YV12 &sipStrings_QtGui[53077]
#define sipNameNr_CMYK 53082
#define sipName_CMYK &sipStrings_QtGui[53082]
#define sipNameNr_play 53087
#define sipName_play &sipStrings_QtGui[53087]
#define sipNameNr_join 53092
#define sipName_join &sipStrings_QtGui[53092]
#define sipNameNr_Link 53097
#define sipName_Link &sipStrings_QtGui[53097]
#define sipNameNr_Base 30627
#define sipName_Base &sipStrings_QtGui[30627]
#define sipNameNr_Dark 39602
#define sipName_Dark &sipStrings_QtGui[39602]
#define sipNameNr_dark 53102
#define sipName_dark &sipStrings_QtGui[53102]
#define sipNameNr_Pica 53107
#define sipName_Pica &sipStrings_QtGui[53107]
#define sipNameNr_Inch 14075
#define sipName_Inch &sipStrings_QtGui[14075]
#define sipNameNr_Unit 12785
#define sipName_Unit &sipStrings_QtGui[12785]
#define sipNameNr_Note 53112
#define sipName_Note &sipStrings_QtGui[53112]
#define sipNameNr_blit 53117
#define sipName_blit &sipStrings_QtGui[53117]
#define sipNameNr_Int8 52463
#define sipName_Int8 &sipStrings_QtGui[52463]
#define sipNameNr_BGRA 53122
#define sipName_BGRA &sipStrings_QtGui[53122]
#define sipNameNr_RGBA 53127
#define sipName_RGBA &sipStrings_QtGui[53127]
#define sipNameNr_D32F 53132
#define sipName_D32F &sipStrings_QtGui[53132]
#define sipNameNr_R32F 53137
#define sipName_R32F &sipStrings_QtGui[53137]
#define sipNameNr_R16F 53142
#define sipName_R16F &sipStrings_QtGui[53142]
#define sipNameNr_R32I 53147
#define sipName_R32I &sipStrings_QtGui[53147]
#define sipNameNr_R16I 53152
#define sipName_R16I &sipStrings_QtGui[53152]
#define sipNameNr_RG8I 53157
#define sipName_RG8I &sipStrings_QtGui[53157]
#define sipNameNr_R32U 53162
#define sipName_R32U &sipStrings_QtGui[53162]
#define sipNameNr_R16U 53167
#define sipName_R16U &sipStrings_QtGui[53167]
#define sipNameNr_RG8U 53172
#define sipName_RG8U &sipStrings_QtGui[53172]
#define sipNameNr_bind 51288
#define sipName_bind &sipStrings_QtGui[51288]
#define sipNameNr_key4 53177
#define sipName_key4 &sipStrings_QtGui[53177]
#define sipNameNr_key3 53182
#define sipName_key3 &sipStrings_QtGui[53182]
#define sipNameNr_key2 53187
#define sipName_key2 &sipStrings_QtGui[53187]
#define sipNameNr_Quit 53192
#define sipName_Quit &sipStrings_QtGui[53192]
#define sipNameNr_Find 53197
#define sipName_Find &sipStrings_QtGui[53197]
#define sipNameNr_Back 53202
#define sipName_Back &sipStrings_QtGui[53202]
#define sipNameNr_Redo 53207
#define sipName_Redo &sipStrings_QtGui[53207]
#define sipNameNr_Undo 53212
#define sipName_Undo &sipStrings_QtGui[53212]
#define sipNameNr_Copy 38654
#define sipName_Copy &sipStrings_QtGui[38654]
#define sipNameNr_Save 53217
#define sipName_Save &sipStrings_QtGui[53217]
#define sipNameNr_hide 53222
#define sipName_hide &sipStrings_QtGui[53222]
#define sipNameNr_show 53227
#define sipName_show &sipStrings_QtGui[53227]
#define sipNameNr_icon 53232
#define sipName_icon &sipStrings_QtGui[53232]
#define sipNameNr_font 53237
#define sipName_font &sipStrings_QtGui[53237]
#define sipNameNr_bold 53242
#define sipName_bold &sipStrings_QtGui[53242]
#define sipNameNr_Bold 45977
#define sipName_Bold &sipStrings_QtGui[45977]
#define sipNameNr_Thin 53247
#define sipName_Thin &sipStrings_QtGui[53247]
#define sipNameNr_href 53252
#define sipName_href &sipStrings_QtGui[53252]
#define sipNameNr_Ruby 53257
#define sipName_Ruby &sipStrings_QtGui[53257]
#define sipNameNr_Puck 53262
#define sipName_Puck &sipStrings_QtGui[53262]
#define sipNameNr_posF 53267
#define sipName_posF &sipStrings_QtGui[53267]
#define sipNameNr_hotY 53272
#define sipName_hotY &sipStrings_QtGui[53272]
#define sipNameNr_hotX 53277
#define sipName_hotX &sipStrings_QtGui[53277]
#define sipNameNr_SRgb 53282
#define sipName_SRgb &sipStrings_QtGui[53282]
#define sipNameNr_Mode 1462
#define sipName_Mode &sipStrings_QtGui[1462]
#define sipNameNr_Nega 53287
#define sipName_Nega &sipStrings_QtGui[53287]
#define sipNameNr_teal 53292
#define sipName_teal &sipStrings_QtGui[53292]
#define sipNameNr_snow 53297
#define sipName_snow &sipStrings_QtGui[53297]
#define sipNameNr_plum 53302
#define sipName_plum &sipStrings_QtGui[53302]
#define sipNameNr_pink 46597
#define sipName_pink &sipStrings_QtGui[46597]
#define sipNameNr_peru 53307
#define sipName_peru &sipStrings_QtGui[53307]
#define sipNameNr_navy 53312
#define sipName_navy &sipStrings_QtGui[53312]
#define sipNameNr_lime 53317
#define sipName_lime &sipStrings_QtGui[53317]
#define sipNameNr_grey 29033
#define sipName_grey &sipStrings_QtGui[29033]
#define sipNameNr_gold 53322
#define sipName_gold &sipStrings_QtGui[53322]
#define sipNameNr_aqua 53327
#define sipName_aqua &sipStrings_QtGui[53327]
#define sipNameNr_Cyan 48724
#define sipName_Cyan &sipStrings_QtGui[48724]
#define sipNameNr_Blue 38342
#define sipName_Blue &sipStrings_QtGui[38342]
#define sipNameNr_Gray 46757
#define sipName_Gray &sipStrings_QtGui[46757]
#define sipNameNr_hueF 53332
#define sipName_hueF &sipStrings_QtGui[53332]
#define sipNameNr_rgba 53337
#define sipName_rgba &sipStrings_QtGui[53337]
#define sipNameNr_redF 53342
#define sipName_redF &sipStrings_QtGui[53342]
#define sipNameNr_Cmyk 21432
#define sipName_Cmyk &sipStrings_QtGui[21432]
#define sipNameNr_Spec 36453
#define sipName_Spec &sipStrings_QtGui[36453]
#define sipNameNr_item 53347
#define sipName_item &sipStrings_QtGui[53347]
#define sipNameNr_rect 53352
#define sipName_rect &sipStrings_QtGui[53352]
#define sipNameNr_draw 53357
#define sipName_draw &sipStrings_QtGui[53357]
#define sipNameNr_clip 53362
#define sipName_clip &sipStrings_QtGui[53362]
#define sipNameNr_save 53367
#define sipName_save &sipStrings_QtGui[53367]
#define sipNameNr_mask 53372
#define sipName_mask &sipStrings_QtGui[53372]
#define sipNameNr_Open 53377
#define sipName_Open &sipStrings_QtGui[53377]
#define sipNameNr_sync 53382
#define sipName_sync &sipStrings_QtGui[53382]
#define sipNameNr_setY 53387
#define sipName_setY &sipStrings_QtGui[53387]
#define sipNameNr_setX 53392
#define sipName_setX &sipStrings_QtGui[53392]
#define sipNameNr_text 240
#define sipName_text &sipStrings_QtGui[240]
#define sipNameNr_QPen 53397
#define sipName_QPen &sipStrings_QtGui[53397]
#define sipNameNr_Thai 53402
#define sipName_Thai &sipStrings_QtGui[53402]
#define sipNameNr_load 53407
#define sipName_load &sipStrings_QtGui[53407]
#define sipNameNr_read 20165
#define sipName_read &sipStrings_QtGui[20165]
#define sipNameNr_Text 12134
#define sipName_Text &sipStrings_QtGui[12134]
#define sipNameNr_file 394
#define sipName_file &sipStrings_QtGui[394]
#define sipNameNr_copy 53412
#define sipName_copy &sipStrings_QtGui[53412]
#define sipNameNr_link 53417
#define sipName_link &sipStrings_QtGui[53417]
#define sipNameNr_Size 4524
#define sipName_Size &sipStrings_QtGui[4524]
#define sipNameNr_Name 6342
#define sipName_Name &sipStrings_QtGui[6342]
#define sipNameNr_spec 53422
#define sipName_spec &sipStrings_QtGui[53422]
#define sipNameNr_User 50754
#define sipName_User &sipStrings_QtGui[50754]
#define sipNameNr_exec 53427
#define sipName_exec &sipStrings_QtGui[53427]
#define sipNameNr_mode 53432
#define sipName_mode &sipStrings_QtGui[53432]
#define sipNameNr_Flag 1165
#define sipName_Flag &sipStrings_QtGui[1165]
#define sipNameNr_next 53437
#define sipName_next &sipStrings_QtGui[53437]
#define sipNameNr_Type 280
#define sipName_Type &sipStrings_QtGui[280]
#define sipNameNr_name 53442
#define sipName_name &sipStrings_QtGui[53442]
#define sipNameNr_base 32055
#define sipName_base &sipStrings_QtGui[32055]
#define sipNameNr_left 53447
#define sipName_left &sipStrings_QtGui[53447]
#define sipNameNr_bits 53452
#define sipName_bits &sipStrings_QtGui[53452]
#define sipNameNr_fill 53457
#define sipName_fill &sipStrings_QtGui[53457]
#define sipNameNr_size 17717
#define sipName_size &sipStrings_QtGui[17717]
#define sipNameNr_type 21279
#define sipName_type &sipStrings_QtGui[21279]
#define sipNameNr_from 53462
#define sipName_from &sipStrings_QtGui[53462]
#define sipNameNr_last 53467
#define sipName_last &sipStrings_QtGui[53467]
#define sipNameNr_span 53472
#define sipName_span &sipStrings_QtGui[53472]
#define sipNameNr_sort 53477
#define sipName_sort &sipStrings_QtGui[53477]
#define sipNameNr_swap 53482
#define sipName_swap &sipStrings_QtGui[53482]
#define sipNameNr_data 9158
#define sipName_data &sipStrings_QtGui[9158]
#define sipNameNr_role 53487
#define sipName_role &sipStrings_QtGui[53487]
#define sipNameNr_stop 53492
#define sipName_stop &sipStrings_QtGui[53492]
#define sipNameNr_Edge 23076
#define sipName_Edge &sipStrings_QtGui[23076]
#define sipNameNr_cyan 46627
#define sipName_cyan &sipStrings_QtGui[46627]
#define sipNameNr_blue 25924
#define sipName_blue &sipStrings_QtGui[25924]
#define sipNameNr_gray 29048
#define sipName_gray &sipStrings_QtGui[29048]
#define sipNameNr_Tab 20549
#define sipName_Tab &sipStrings_QtGui[20549]
#define sipNameNr_End 33789
#define sipName_End &sipStrings_QtGui[33789]
#define sipNameNr_Y16 53497
#define sipName_Y16 &sipStrings_QtGui[53497]
#define sipNameNr_YUV 53501
#define sipName_YUV &sipStrings_QtGui[53501]
#define sipNameNr_HSV 53505
#define sipName_HSV &sipStrings_QtGui[53505]
#define sipNameNr_HSL 53509
#define sipName_HSL &sipStrings_QtGui[53509]
#define sipNameNr_Mid 53513
#define sipName_Mid &sipStrings_QtGui[53513]
#define sipNameNr_All 18096
#define sipName_All &sipStrings_QtGui[18096]
#define sipNameNr_Pdf 53517
#define sipName_Pdf &sipStrings_QtGui[53517]
#define sipNameNr_SVG 53521
#define sipName_SVG &sipStrings_QtGui[53521]
#define sipNameNr_X11 53525
#define sipName_X11 &sipStrings_QtGui[53525]
#define sipNameNr_pen 53378
#define sipName_pen &sipStrings_QtGui[53378]
#define sipNameNr_A10 53529
#define sipName_A10 &sipStrings_QtGui[53529]
#define sipNameNr_DLE 53533
#define sipName_DLE &sipStrings_QtGui[53533]
#define sipNameNr_C5E 53537
#define sipName_C5E &sipStrings_QtGui[53537]
#define sipNameNr_B10 51261
#define sipName_B10 &sipStrings_QtGui[51261]
#define sipNameNr_BGR 53541
#define sipName_BGR &sipStrings_QtGui[53541]
#define sipNameNr_RGB 53545
#define sipName_RGB &sipStrings_QtGui[53545]
#define sipNameNr_D32 53549
#define sipName_D32 &sipStrings_QtGui[53549]
#define sipNameNr_D24 53553
#define sipName_D24 &sipStrings_QtGui[53553]
#define sipNameNr_D16 53557
#define sipName_D16 &sipStrings_QtGui[53557]
#define sipNameNr_R8I 53561
#define sipName_R8I &sipStrings_QtGui[53561]
#define sipNameNr_R8U 53565
#define sipName_R8U &sipStrings_QtGui[53565]
#define sipNameNr_log 53569
#define sipName_log &sipStrings_QtGui[53569]
#define sipNameNr_m33 53573
#define sipName_m33 &sipStrings_QtGui[53573]
#define sipNameNr_m32 53577
#define sipName_m32 &sipStrings_QtGui[53577]
#define sipNameNr_m31 53581
#define sipName_m31 &sipStrings_QtGui[53581]
#define sipNameNr_m23 53585
#define sipName_m23 &sipStrings_QtGui[53585]
#define sipNameNr_m22 53589
#define sipName_m22 &sipStrings_QtGui[53589]
#define sipNameNr_m21 53593
#define sipName_m21 &sipStrings_QtGui[53593]
#define sipNameNr_m13 53597
#define sipName_m13 &sipStrings_QtGui[53597]
#define sipNameNr_m12 53601
#define sipName_m12 &sipStrings_QtGui[53601]
#define sipNameNr_m11 53605
#define sipName_m11 &sipStrings_QtGui[53605]
#define sipNameNr_Cut 53609
#define sipName_Cut &sipStrings_QtGui[53609]
#define sipNameNr_New 53613
#define sipName_New &sipStrings_QtGui[53613]
#define sipNameNr_Off 53617
#define sipName_Off &sipStrings_QtGui[53617]
#define sipNameNr_Any 53621
#define sipName_Any &sipStrings_QtGui[53621]
#define sipNameNr_tip 53625
#define sipName_tip &sipStrings_QtGui[53625]
#define sipNameNr_tan 50699
#define sipName_tan &sipStrings_QtGui[50699]
#define sipNameNr_Svg 13332
#define sipName_Svg &sipStrings_QtGui[13332]
#define sipNameNr_Red 42068
#define sipName_Red &sipStrings_QtGui[42068]
#define sipNameNr_hue 53629
#define sipName_hue &sipStrings_QtGui[53629]
#define sipNameNr_rgb 50387
#define sipName_rgb &sipStrings_QtGui[50387]
#define sipNameNr_Hsl 24117
#define sipName_Hsl &sipStrings_QtGui[24117]
#define sipNameNr_Hsv 24101
#define sipName_Hsv &sipStrings_QtGui[24101]
#define sipNameNr_Rgb 32812
#define sipName_Rgb &sipStrings_QtGui[32812]
#define sipNameNr_Pen 10796
#define sipName_Pen &sipStrings_QtGui[10796]
#define sipNameNr_cap 53633
#define sipName_cap &sipStrings_QtGui[53633]
#define sipNameNr_add 53637
#define sipName_add &sipStrings_QtGui[53637]
#define sipNameNr_url 53641
#define sipName_url &sipStrings_QtGui[53641]
#define sipNameNr_Nko 53645
#define sipName_Nko &sipStrings_QtGui[53645]
#define sipNameNr_Lao 53649
#define sipName_Lao &sipStrings_QtGui[53649]
#define sipNameNr_top 2016
#define sipName_top &sipStrings_QtGui[2016]
#define sipNameNr_map 24373
#define sipName_map &sipStrings_QtGui[24373]
#define sipNameNr_key 53653
#define sipName_key &sipStrings_QtGui[53653]
#define sipNameNr_mid 53657
#define sipName_mid &sipStrings_QtGui[53657]
#define sipNameNr_pos 53661
#define sipName_pos &sipStrings_QtGui[53661]
#define sipNameNr_end 16485
#define sipName_end &sipStrings_QtGui[16485]
#define sipNameNr_row 53665
#define sipName_row &sipStrings_QtGui[53665]
#define sipNameNr_Key 6317
#define sipName_Key &sipStrings_QtGui[6317]
#define sipNameNr_red 25893
#define sipName_red &sipStrings_QtGui[25893]
#define sipNameNr_Up 53669
#define sipName_Up &sipStrings_QtGui[53669]
#define sipNameNr_Y8 53672
#define sipName_Y8 &sipStrings_QtGui[53672]
#define sipNameNr_sw 53675
#define sipName_sw &sipStrings_QtGui[53675]
#define sipNameNr_sh 4997
#define sipName_sh &sipStrings_QtGui[4997]
#define sipNameNr_sy 50148
#define sipName_sy &sipStrings_QtGui[50148]
#define sipNameNr_sx 53678
#define sipName_sx &sipStrings_QtGui[53678]
#define sipNameNr_B9 52399
#define sipName_B9 &sipStrings_QtGui[52399]
#define sipNameNr_B8 52405
#define sipName_B8 &sipStrings_QtGui[52405]
#define sipNameNr_B7 52411
#define sipName_B7 &sipStrings_QtGui[52411]
#define sipNameNr_B6 41937
#define sipName_B6 &sipStrings_QtGui[41937]
#define sipNameNr_B4 41959
#define sipName_B4 &sipStrings_QtGui[41959]
#define sipNameNr_B3 52435
#define sipName_B3 &sipStrings_QtGui[52435]
#define sipNameNr_B2 38368
#define sipName_B2 &sipStrings_QtGui[38368]
#define sipNameNr_B1 52447
#define sipName_B1 &sipStrings_QtGui[52447]
#define sipNameNr_B0 52453
#define sipName_B0 &sipStrings_QtGui[52453]
#define sipNameNr_A9 53681
#define sipName_A9 &sipStrings_QtGui[53681]
#define sipNameNr_A8 34856
#define sipName_A8 &sipStrings_QtGui[34856]
#define sipNameNr_A7 53684
#define sipName_A7 &sipStrings_QtGui[53684]
#define sipNameNr_A6 53687
#define sipName_A6 &sipStrings_QtGui[53687]
#define sipNameNr_A5 53690
#define sipName_A5 &sipStrings_QtGui[53690]
#define sipNameNr_A3 53693
#define sipName_A3 &sipStrings_QtGui[53693]
#define sipNameNr_A2 27820
#define sipName_A2 &sipStrings_QtGui[27820]
#define sipNameNr_A1 31203
#define sipName_A1 &sipStrings_QtGui[31203]
#define sipNameNr_A0 53696
#define sipName_A0 &sipStrings_QtGui[53696]
#define sipNameNr_B5 31189
#define sipName_B5 &sipStrings_QtGui[31189]
#define sipNameNr_A4 34869
#define sipName_A4 &sipStrings_QtGui[34869]
#define sipNameNr_RG 53699
#define sipName_RG &sipStrings_QtGui[53699]
#define sipNameNr_S8 34843
#define sipName_S8 &sipStrings_QtGui[34843]
#define sipNameNr_On 53702
#define sipName_On &sipStrings_QtGui[53702]
#define sipNameNr_dy 52909
#define sipName_dy &sipStrings_QtGui[52909]
#define sipNameNr_dx 53705
#define sipName_dx &sipStrings_QtGui[53705]
#define sipNameNr_at 2706
#define sipName_at &sipStrings_QtGui[2706]
#define sipNameNr_on 321
#define sipName_on &sipStrings_QtGui[321]
#define sipNameNr_id 18061
#define sipName_id &sipStrings_QtGui[18061]
#define sipNameNr_Qt 53708
#define sipName_Qt &sipStrings_QtGui[53708]
#define sipNameNr_w 13313
#define sipName_w &sipStrings_QtGui[13313]
#define sipNameNr_z 53711
#define sipName_z &sipStrings_QtGui[53711]
#define sipNameNr_x 11759
#define sipName_x &sipStrings_QtGui[11759]
#define sipNameNr_y 153
#define sipName_y &sipStrings_QtGui[153]
#define sipNameNr_n 322
#define sipName_n &sipStrings_QtGui[322]

#define sipMalloc                   sipAPI_QtGui->api_malloc
#define sipFree                     sipAPI_QtGui->api_free
#define sipBuildResult              sipAPI_QtGui->api_build_result
#define sipCallMethod               sipAPI_QtGui->api_call_method
#define sipCallProcedureMethod      sipAPI_QtGui->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtGui->api_call_error_handler
#define sipParseResultEx            sipAPI_QtGui->api_parse_result_ex
#define sipParseResult              sipAPI_QtGui->api_parse_result
#define sipParseArgs                sipAPI_QtGui->api_parse_args
#define sipParseKwdArgs             sipAPI_QtGui->api_parse_kwd_args
#define sipParsePair                sipAPI_QtGui->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtGui->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtGui->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtGui->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtGui->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtGui->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtGui->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtGui->api_add_exception
#define sipNoFunction               sipAPI_QtGui->api_no_function
#define sipNoMethod                 sipAPI_QtGui->api_no_method
#define sipAbstractMethod           sipAPI_QtGui->api_abstract_method
#define sipBadClass                 sipAPI_QtGui->api_bad_class
#define sipBadCatcherResult         sipAPI_QtGui->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtGui->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtGui->api_bad_operator_arg
#define sipTrace                    sipAPI_QtGui->api_trace
#define sipTransferBack             sipAPI_QtGui->api_transfer_back
#define sipTransferTo               sipAPI_QtGui->api_transfer_to
#define sipTransferBreak            sipAPI_QtGui->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtGui->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtGui->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtGui->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtGui->api_voidptr_type
#define sipGetPyObject              sipAPI_QtGui->api_get_pyobject
#define sipGetAddress               sipAPI_QtGui->api_get_address
#define sipGetMixinAddress          sipAPI_QtGui->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtGui->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtGui->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtGui->api_is_py_method
#define sipCallHook                 sipAPI_QtGui->api_call_hook
#define sipEndThread                sipAPI_QtGui->api_end_thread
#define sipConnectRx                sipAPI_QtGui->api_connect_rx
#define sipDisconnectRx             sipAPI_QtGui->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtGui->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtGui->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtGui->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtGui->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtGui->api_free_sipslot
#define sipSameSlot                 sipAPI_QtGui->api_same_slot
#define sipPySlotExtend             sipAPI_QtGui->api_pyslot_extend
#define sipConvertRx                sipAPI_QtGui->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtGui->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtGui->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtGui->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtGui->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtGui->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtGui->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtGui->api_convert_to_bool
#define sipReleaseType              sipAPI_QtGui->api_release_type
#define sipConvertFromType          sipAPI_QtGui->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtGui->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtGui->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtGui->api_convert_from_enum
#define sipGetState                 sipAPI_QtGui->api_get_state
#define sipExportSymbol             sipAPI_QtGui->api_export_symbol
#define sipImportSymbol             sipAPI_QtGui->api_import_symbol
#define sipFindType                 sipAPI_QtGui->api_find_type
#define sipFindNamedEnum            sipAPI_QtGui->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtGui->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtGui->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtGui->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtGui->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtGui->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtGui->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtGui->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtGui->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtGui->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtGui->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtGui->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtGui->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtGui->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtGui->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtGui->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtGui->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtGui->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtGui->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtGui->api_deprecated
#define sipGetReference             sipAPI_QtGui->api_get_reference
#define sipKeepReference            sipAPI_QtGui->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtGui->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtGui->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtGui->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtGui->api_type_scope
#define sipResolveTypedef           sipAPI_QtGui->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtGui->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtGui->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtGui->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtGui->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtGui->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtGui->api_init_mixin
#define sipExportModule             sipAPI_QtGui->api_export_module
#define sipInitModule               sipAPI_QtGui->api_init_module
#define sipGetInterpreter           sipAPI_QtGui->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtGui->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtGui->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtGui->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtGui->api_py_type_dict
#define sipPyTypeName               sipAPI_QtGui->api_py_type_name
#define sipGetCFunction             sipAPI_QtGui->api_get_c_function
#define sipGetMethod                sipAPI_QtGui->api_get_method
#define sipFromMethod               sipAPI_QtGui->api_from_method
#define sipGetDate                  sipAPI_QtGui->api_get_date
#define sipFromDate                 sipAPI_QtGui->api_from_date
#define sipGetDateTime              sipAPI_QtGui->api_get_datetime
#define sipFromDateTime             sipAPI_QtGui->api_from_datetime
#define sipGetTime                  sipAPI_QtGui->api_get_time
#define sipFromTime                 sipAPI_QtGui->api_from_time
#define sipIsUserType               sipAPI_QtGui->api_is_user_type
#define sipGetFrame                 sipAPI_QtGui->api_get_frame
#define sipCheckPluginForType       sipAPI_QtGui->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtGui->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtGui->api_unicode_write
#define sipUnicodeData              sipAPI_QtGui->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtGui->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtGui->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtGui->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtGui->api_is_derived_class
#define sipGetUserObject            sipAPI_QtGui->api_get_user_object
#define sipSetUserObject            sipAPI_QtGui->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtGui->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtGui->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtGui->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtGui->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtGui->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtGui->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtGui->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtGui->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtGui->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtGui->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtGui->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtGui->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtGui->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtGui->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtGui->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtGui->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtGui->api_map_int_to_class
#define sipFindClass                sipAPI_QtGui->api_find_class
#define sipFindMappedType           sipAPI_QtGui->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtGui->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtGui->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtGui->api_enable_gc
#define sipPrintObject              sipAPI_QtGui->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtGui->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtGui[];

#define sipType_QAbstractTextDocumentLayout sipExportedTypes_QtGui[1]
#define sipClass_QAbstractTextDocumentLayout sipExportedTypes_QtGui[1]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout;

#define sipType_QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[3]
#define sipClass_QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[3]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection;

#define sipType_QAbstractTextDocumentLayout_PaintContext sipExportedTypes_QtGui[2]
#define sipClass_QAbstractTextDocumentLayout_PaintContext sipExportedTypes_QtGui[2]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext;

#define sipType_QTextObjectInterface sipExportedTypes_QtGui[341]
#define sipClass_QTextObjectInterface sipExportedTypes_QtGui[341]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextObjectInterface;

#define sipType_QBackingStore sipExportedTypes_QtGui[6]
#define sipClass_QBackingStore sipExportedTypes_QtGui[6]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QBackingStore;

#define sipType_QPaintDevice sipExportedTypes_QtGui[198]
#define sipClass_QPaintDevice sipExportedTypes_QtGui[198]->u.td_wrapper_type

#define sipType_QPaintDevice_PaintDeviceMetric sipExportedTypes_QtGui[199]
#define sipEnum_QPaintDevice_PaintDeviceMetric sipExportedTypes_QtGui[199]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDevice;

#define sipType_QPixmap sipExportedTypes_QtGui[238]
#define sipClass_QPixmap sipExportedTypes_QtGui[238]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPixmap;

#define sipType_QBitmap sipExportedTypes_QtGui[7]
#define sipClass_QBitmap sipExportedTypes_QtGui[7]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QBitmap;

#define sipType_QColor sipExportedTypes_QtGui[12]
#define sipClass_QColor sipExportedTypes_QtGui[12]->u.td_wrapper_type

#define sipType_QColor_NameFormat sipExportedTypes_QtGui[13]
#define sipEnum_QColor_NameFormat sipExportedTypes_QtGui[13]->u.td_py_type

#define sipType_QColor_Spec sipExportedTypes_QtGui[14]
#define sipEnum_QColor_Spec sipExportedTypes_QtGui[14]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QColor;

#define sipType_QColorConstants sipExportedTypes_QtGui[15]
#define sipClass_QColorConstants sipExportedTypes_QtGui[15]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants;

#define sipType_QColorConstants_Svg sipExportedTypes_QtGui[16]
#define sipClass_QColorConstants_Svg sipExportedTypes_QtGui[16]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants_Svg;

#define sipType_QBrush sipExportedTypes_QtGui[8]
#define sipClass_QBrush sipExportedTypes_QtGui[8]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QBrush;

#define sipType_QGradient sipExportedTypes_QtGui[56]
#define sipClass_QGradient sipExportedTypes_QtGui[56]->u.td_wrapper_type

#define sipType_QGradient_Preset sipExportedTypes_QtGui[58]
#define sipEnum_QGradient_Preset sipExportedTypes_QtGui[58]->u.td_py_type

#define sipType_QGradient_Spread sipExportedTypes_QtGui[59]
#define sipEnum_QGradient_Spread sipExportedTypes_QtGui[59]->u.td_py_type

#define sipType_QGradient_Type sipExportedTypes_QtGui[60]
#define sipEnum_QGradient_Type sipExportedTypes_QtGui[60]->u.td_py_type

#define sipType_QGradient_CoordinateMode sipExportedTypes_QtGui[57]
#define sipEnum_QGradient_CoordinateMode sipExportedTypes_QtGui[57]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QGradient;

#define sipType_QLinearGradient sipExportedTypes_QtGui[97]
#define sipClass_QLinearGradient sipExportedTypes_QtGui[97]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QLinearGradient;

#define sipType_QRadialGradient sipExportedTypes_QtGui[247]
#define sipClass_QRadialGradient sipExportedTypes_QtGui[247]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRadialGradient;

#define sipType_QConicalGradient sipExportedTypes_QtGui[22]
#define sipClass_QConicalGradient sipExportedTypes_QtGui[22]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QConicalGradient;

#define sipType_QClipboard sipExportedTypes_QtGui[9]
#define sipClass_QClipboard sipExportedTypes_QtGui[9]->u.td_wrapper_type

#define sipType_QClipboard_Mode sipExportedTypes_QtGui[10]
#define sipEnum_QClipboard_Mode sipExportedTypes_QtGui[10]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QClipboard;

#define sipType_QColorSpace sipExportedTypes_QtGui[17]
#define sipClass_QColorSpace sipExportedTypes_QtGui[17]->u.td_wrapper_type

#define sipType_QColorSpace_TransferFunction sipExportedTypes_QtGui[20]
#define sipEnum_QColorSpace_TransferFunction sipExportedTypes_QtGui[20]->u.td_py_type

#define sipType_QColorSpace_Primaries sipExportedTypes_QtGui[19]
#define sipEnum_QColorSpace_Primaries sipExportedTypes_QtGui[19]->u.td_py_type

#define sipType_QColorSpace_NamedColorSpace sipExportedTypes_QtGui[18]
#define sipEnum_QColorSpace_NamedColorSpace sipExportedTypes_QtGui[18]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QColorSpace;

#define sipType_QColorTransform sipExportedTypes_QtGui[21]
#define sipClass_QColorTransform sipExportedTypes_QtGui[21]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QColorTransform;

#define sipType_QCursor sipExportedTypes_QtGui[25]
#define sipClass_QCursor sipExportedTypes_QtGui[25]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QCursor;

#define sipType_QDesktopServices sipExportedTypes_QtGui[26]
#define sipClass_QDesktopServices sipExportedTypes_QtGui[26]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDesktopServices;

#define sipType_QDrag sipExportedTypes_QtGui[29]
#define sipClass_QDrag sipExportedTypes_QtGui[29]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDrag;

#define sipType_QInputEvent sipExportedTypes_QtGui[84]
#define sipClass_QInputEvent sipExportedTypes_QtGui[84]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QInputEvent;

#define sipType_QMouseEvent sipExportedTypes_QtGui[125]
#define sipClass_QMouseEvent sipExportedTypes_QtGui[125]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMouseEvent;

#define sipType_QHoverEvent sipExportedTypes_QtGui[64]
#define sipClass_QHoverEvent sipExportedTypes_QtGui[64]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QHoverEvent;

#define sipType_QWheelEvent sipExportedTypes_QtGui[382]
#define sipClass_QWheelEvent sipExportedTypes_QtGui[382]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QWheelEvent;

#define sipType_QTabletEvent sipExportedTypes_QtGui[284]
#define sipClass_QTabletEvent sipExportedTypes_QtGui[284]->u.td_wrapper_type

#define sipType_QTabletEvent_PointerType sipExportedTypes_QtGui[285]
#define sipEnum_QTabletEvent_PointerType sipExportedTypes_QtGui[285]->u.td_py_type

#define sipType_QTabletEvent_TabletDevice sipExportedTypes_QtGui[286]
#define sipEnum_QTabletEvent_TabletDevice sipExportedTypes_QtGui[286]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTabletEvent;

#define sipType_QKeyEvent sipExportedTypes_QtGui[92]
#define sipClass_QKeyEvent sipExportedTypes_QtGui[92]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QKeyEvent;

#define sipType_QFocusEvent sipExportedTypes_QtGui[37]
#define sipClass_QFocusEvent sipExportedTypes_QtGui[37]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QFocusEvent;

#define sipType_QPaintEvent sipExportedTypes_QtGui[209]
#define sipClass_QPaintEvent sipExportedTypes_QtGui[209]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEvent;

#define sipType_QMoveEvent sipExportedTypes_QtGui[126]
#define sipClass_QMoveEvent sipExportedTypes_QtGui[126]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMoveEvent;

#define sipType_QResizeEvent sipExportedTypes_QtGui[257]
#define sipClass_QResizeEvent sipExportedTypes_QtGui[257]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QResizeEvent;

#define sipType_QCloseEvent sipExportedTypes_QtGui[11]
#define sipClass_QCloseEvent sipExportedTypes_QtGui[11]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QCloseEvent;

#define sipType_QIconDragEvent sipExportedTypes_QtGui[68]
#define sipClass_QIconDragEvent sipExportedTypes_QtGui[68]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QIconDragEvent;

#define sipType_QShowEvent sipExportedTypes_QtGui[265]
#define sipClass_QShowEvent sipExportedTypes_QtGui[265]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QShowEvent;

#define sipType_QHideEvent sipExportedTypes_QtGui[63]
#define sipClass_QHideEvent sipExportedTypes_QtGui[63]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QHideEvent;

#define sipType_QContextMenuEvent sipExportedTypes_QtGui[23]
#define sipClass_QContextMenuEvent sipExportedTypes_QtGui[23]->u.td_wrapper_type

#define sipType_QContextMenuEvent_Reason sipExportedTypes_QtGui[24]
#define sipEnum_QContextMenuEvent_Reason sipExportedTypes_QtGui[24]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QContextMenuEvent;

#define sipType_QInputMethodEvent sipExportedTypes_QtGui[87]
#define sipClass_QInputMethodEvent sipExportedTypes_QtGui[87]->u.td_wrapper_type

#define sipType_QInputMethodEvent_AttributeType sipExportedTypes_QtGui[89]
#define sipEnum_QInputMethodEvent_AttributeType sipExportedTypes_QtGui[89]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent;

#define sipType_QInputMethodEvent_Attribute sipExportedTypes_QtGui[88]
#define sipClass_QInputMethodEvent_Attribute sipExportedTypes_QtGui[88]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent_Attribute;

#define sipType_QInputMethodQueryEvent sipExportedTypes_QtGui[90]
#define sipClass_QInputMethodQueryEvent sipExportedTypes_QtGui[90]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodQueryEvent;

#define sipType_QDropEvent sipExportedTypes_QtGui[33]
#define sipClass_QDropEvent sipExportedTypes_QtGui[33]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDropEvent;

#define sipType_QDragMoveEvent sipExportedTypes_QtGui[32]
#define sipClass_QDragMoveEvent sipExportedTypes_QtGui[32]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDragMoveEvent;

#define sipType_QDragEnterEvent sipExportedTypes_QtGui[30]
#define sipClass_QDragEnterEvent sipExportedTypes_QtGui[30]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDragEnterEvent;

#define sipType_QDragLeaveEvent sipExportedTypes_QtGui[31]
#define sipClass_QDragLeaveEvent sipExportedTypes_QtGui[31]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QDragLeaveEvent;

#define sipType_QHelpEvent sipExportedTypes_QtGui[62]
#define sipClass_QHelpEvent sipExportedTypes_QtGui[62]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QHelpEvent;

#define sipType_QStatusTipEvent sipExportedTypes_QtGui[271]
#define sipClass_QStatusTipEvent sipExportedTypes_QtGui[271]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QStatusTipEvent;

#define sipType_QWhatsThisClickedEvent sipExportedTypes_QtGui[381]
#define sipClass_QWhatsThisClickedEvent sipExportedTypes_QtGui[381]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QWhatsThisClickedEvent;

#define sipType_QActionEvent sipExportedTypes_QtGui[5]
#define sipClass_QActionEvent sipExportedTypes_QtGui[5]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QActionEvent;

#define sipType_QFileOpenEvent sipExportedTypes_QtGui[36]
#define sipClass_QFileOpenEvent sipExportedTypes_QtGui[36]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QFileOpenEvent;

#define sipType_QShortcutEvent sipExportedTypes_QtGui[264]
#define sipClass_QShortcutEvent sipExportedTypes_QtGui[264]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QShortcutEvent;

#define sipType_QWindowStateChangeEvent sipExportedTypes_QtGui[386]
#define sipClass_QWindowStateChangeEvent sipExportedTypes_QtGui[386]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QWindowStateChangeEvent;

#define sipType_QTouchEvent sipExportedTypes_QtGui[356]
#define sipClass_QTouchEvent sipExportedTypes_QtGui[356]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent;

#define sipType_QTouchEvent_TouchPoint sipExportedTypes_QtGui[357]
#define sipClass_QTouchEvent_TouchPoint sipExportedTypes_QtGui[357]->u.td_wrapper_type

#define sipType_QTouchEvent_TouchPoint_InfoFlag sipExportedTypes_QtGui[358]
#define sipEnum_QTouchEvent_TouchPoint_InfoFlag sipExportedTypes_QtGui[358]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint;

#define sipType_QTouchEvent_TouchPoint_InfoFlags sipExportedTypes_QtGui[359]
#define sipClass_QTouchEvent_TouchPoint_InfoFlags sipExportedTypes_QtGui[359]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint_InfoFlags;

#define sipType_QExposeEvent sipExportedTypes_QtGui[35]
#define sipClass_QExposeEvent sipExportedTypes_QtGui[35]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QExposeEvent;

#define sipType_QScrollPrepareEvent sipExportedTypes_QtGui[262]
#define sipClass_QScrollPrepareEvent sipExportedTypes_QtGui[262]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QScrollPrepareEvent;

#define sipType_QScrollEvent sipExportedTypes_QtGui[260]
#define sipClass_QScrollEvent sipExportedTypes_QtGui[260]->u.td_wrapper_type

#define sipType_QScrollEvent_ScrollState sipExportedTypes_QtGui[261]
#define sipEnum_QScrollEvent_ScrollState sipExportedTypes_QtGui[261]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QScrollEvent;

#define sipType_QEnterEvent sipExportedTypes_QtGui[34]
#define sipClass_QEnterEvent sipExportedTypes_QtGui[34]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QEnterEvent;

#define sipType_QAction sipExportedTypes_QtGui[4]
#define sipClass_QAction sipExportedTypes_QtGui[4]->u.td_wrapper_type

#define sipType_QNativeGestureEvent sipExportedTypes_QtGui[130]
#define sipClass_QNativeGestureEvent sipExportedTypes_QtGui[130]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QNativeGestureEvent;

#define sipType_QPlatformSurfaceEvent sipExportedTypes_QtGui[241]
#define sipClass_QPlatformSurfaceEvent sipExportedTypes_QtGui[241]->u.td_wrapper_type

#define sipType_QPlatformSurfaceEvent_SurfaceEventType sipExportedTypes_QtGui[242]
#define sipEnum_QPlatformSurfaceEvent_SurfaceEventType sipExportedTypes_QtGui[242]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPlatformSurfaceEvent;

#define sipType_QPointingDeviceUniqueId sipExportedTypes_QtGui[243]
#define sipClass_QPointingDeviceUniqueId sipExportedTypes_QtGui[243]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPointingDeviceUniqueId;

#define sipType_QFont sipExportedTypes_QtGui[38]
#define sipClass_QFont sipExportedTypes_QtGui[38]->u.td_wrapper_type

#define sipType_QFont_HintingPreference sipExportedTypes_QtGui[40]
#define sipEnum_QFont_HintingPreference sipExportedTypes_QtGui[40]->u.td_py_type

#define sipType_QFont_SpacingType sipExportedTypes_QtGui[41]
#define sipEnum_QFont_SpacingType sipExportedTypes_QtGui[41]->u.td_py_type

#define sipType_QFont_Capitalization sipExportedTypes_QtGui[39]
#define sipEnum_QFont_Capitalization sipExportedTypes_QtGui[39]->u.td_py_type

#define sipType_QFont_Stretch sipExportedTypes_QtGui[42]
#define sipEnum_QFont_Stretch sipExportedTypes_QtGui[42]->u.td_py_type

#define sipType_QFont_Style sipExportedTypes_QtGui[43]
#define sipEnum_QFont_Style sipExportedTypes_QtGui[43]->u.td_py_type

#define sipType_QFont_Weight sipExportedTypes_QtGui[46]
#define sipEnum_QFont_Weight sipExportedTypes_QtGui[46]->u.td_py_type

#define sipType_QFont_StyleStrategy sipExportedTypes_QtGui[45]
#define sipEnum_QFont_StyleStrategy sipExportedTypes_QtGui[45]->u.td_py_type

#define sipType_QFont_StyleHint sipExportedTypes_QtGui[44]
#define sipEnum_QFont_StyleHint sipExportedTypes_QtGui[44]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QFont;

#define sipType_QFontDatabase sipExportedTypes_QtGui[47]
#define sipClass_QFontDatabase sipExportedTypes_QtGui[47]->u.td_wrapper_type

#define sipType_QFontDatabase_SystemFont sipExportedTypes_QtGui[48]
#define sipEnum_QFontDatabase_SystemFont sipExportedTypes_QtGui[48]->u.td_py_type

#define sipType_QFontDatabase_WritingSystem sipExportedTypes_QtGui[49]
#define sipEnum_QFontDatabase_WritingSystem sipExportedTypes_QtGui[49]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QFontDatabase;

#define sipType_QFontInfo sipExportedTypes_QtGui[50]
#define sipClass_QFontInfo sipExportedTypes_QtGui[50]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QFontInfo;

#define sipType_QFontMetrics sipExportedTypes_QtGui[51]
#define sipClass_QFontMetrics sipExportedTypes_QtGui[51]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetrics;

#define sipType_QFontMetricsF sipExportedTypes_QtGui[52]
#define sipClass_QFontMetricsF sipExportedTypes_QtGui[52]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetricsF;

#define sipType_QMatrix4x3 sipExportedTypes_QtGui[123]
#define sipClass_QMatrix4x3 sipExportedTypes_QtGui[123]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x3;

#define sipType_QMatrix4x2 sipExportedTypes_QtGui[122]
#define sipClass_QMatrix4x2 sipExportedTypes_QtGui[122]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x2;

#define sipType_QMatrix3x4 sipExportedTypes_QtGui[121]
#define sipClass_QMatrix3x4 sipExportedTypes_QtGui[121]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x4;

#define sipType_QMatrix3x3 sipExportedTypes_QtGui[120]
#define sipClass_QMatrix3x3 sipExportedTypes_QtGui[120]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x3;

#define sipType_QMatrix3x2 sipExportedTypes_QtGui[119]
#define sipClass_QMatrix3x2 sipExportedTypes_QtGui[119]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x2;

#define sipType_QMatrix2x4 sipExportedTypes_QtGui[118]
#define sipClass_QMatrix2x4 sipExportedTypes_QtGui[118]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x4;

#define sipType_QMatrix2x3 sipExportedTypes_QtGui[117]
#define sipClass_QMatrix2x3 sipExportedTypes_QtGui[117]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x3;

#define sipType_QMatrix2x2 sipExportedTypes_QtGui[116]
#define sipClass_QMatrix2x2 sipExportedTypes_QtGui[116]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x2;

#define sipType_QGlyphRun sipExportedTypes_QtGui[53]
#define sipClass_QGlyphRun sipExportedTypes_QtGui[53]->u.td_wrapper_type

#define sipType_QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[54]
#define sipEnum_QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[54]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun;

#define sipType_QGlyphRun_GlyphRunFlags sipExportedTypes_QtGui[55]
#define sipClass_QGlyphRun_GlyphRunFlags sipExportedTypes_QtGui[55]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun_GlyphRunFlags;

#define sipType_QGuiApplication sipExportedTypes_QtGui[61]
#define sipClass_QGuiApplication sipExportedTypes_QtGui[61]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QGuiApplication;

#define sipType_QIcon sipExportedTypes_QtGui[65]
#define sipClass_QIcon sipExportedTypes_QtGui[65]->u.td_wrapper_type

#define sipType_QIcon_State sipExportedTypes_QtGui[67]
#define sipEnum_QIcon_State sipExportedTypes_QtGui[67]->u.td_py_type

#define sipType_QIcon_Mode sipExportedTypes_QtGui[66]
#define sipEnum_QIcon_Mode sipExportedTypes_QtGui[66]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QIcon;

#define sipType_QIconEngine sipExportedTypes_QtGui[69]
#define sipClass_QIconEngine sipExportedTypes_QtGui[69]->u.td_wrapper_type

#define sipType_QIconEngine_IconEngineHook sipExportedTypes_QtGui[71]
#define sipEnum_QIconEngine_IconEngineHook sipExportedTypes_QtGui[71]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine;

#define sipType_QIconEngine_AvailableSizesArgument sipExportedTypes_QtGui[70]
#define sipClass_QIconEngine_AvailableSizesArgument sipExportedTypes_QtGui[70]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_AvailableSizesArgument;

#define sipType_QIconEngine_ScaledPixmapArgument sipExportedTypes_QtGui[72]
#define sipClass_QIconEngine_ScaledPixmapArgument sipExportedTypes_QtGui[72]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument;

#define sipType_QImage sipExportedTypes_QtGui[73]
#define sipClass_QImage sipExportedTypes_QtGui[73]->u.td_wrapper_type

#define sipType_QImage_Format sipExportedTypes_QtGui[74]
#define sipEnum_QImage_Format sipExportedTypes_QtGui[74]->u.td_py_type

#define sipType_QImage_InvertMode sipExportedTypes_QtGui[75]
#define sipEnum_QImage_InvertMode sipExportedTypes_QtGui[75]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QImage;

#define sipType_QImageIOHandler sipExportedTypes_QtGui[76]
#define sipClass_QImageIOHandler sipExportedTypes_QtGui[76]->u.td_wrapper_type

#define sipType_QImageIOHandler_Transformation sipExportedTypes_QtGui[78]
#define sipEnum_QImageIOHandler_Transformation sipExportedTypes_QtGui[78]->u.td_py_type

#define sipType_QImageIOHandler_ImageOption sipExportedTypes_QtGui[77]
#define sipEnum_QImageIOHandler_ImageOption sipExportedTypes_QtGui[77]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler;

#define sipType_QImageIOHandler_Transformations sipExportedTypes_QtGui[79]
#define sipClass_QImageIOHandler_Transformations sipExportedTypes_QtGui[79]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler_Transformations;

#define sipType_QImageReader sipExportedTypes_QtGui[80]
#define sipClass_QImageReader sipExportedTypes_QtGui[80]->u.td_wrapper_type

#define sipType_QImageReader_ImageReaderError sipExportedTypes_QtGui[81]
#define sipEnum_QImageReader_ImageReaderError sipExportedTypes_QtGui[81]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QImageReader;

#define sipType_QImageWriter sipExportedTypes_QtGui[82]
#define sipClass_QImageWriter sipExportedTypes_QtGui[82]->u.td_wrapper_type

#define sipType_QImageWriter_ImageWriterError sipExportedTypes_QtGui[83]
#define sipEnum_QImageWriter_ImageWriterError sipExportedTypes_QtGui[83]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QImageWriter;

#define sipType_QInputMethod sipExportedTypes_QtGui[85]
#define sipClass_QInputMethod sipExportedTypes_QtGui[85]->u.td_wrapper_type

#define sipType_QInputMethod_Action sipExportedTypes_QtGui[86]
#define sipEnum_QInputMethod_Action sipExportedTypes_QtGui[86]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethod;

#define sipType_QKeySequence sipExportedTypes_QtGui[93]
#define sipClass_QKeySequence sipExportedTypes_QtGui[93]->u.td_wrapper_type

#define sipType_QKeySequence_StandardKey sipExportedTypes_QtGui[96]
#define sipEnum_QKeySequence_StandardKey sipExportedTypes_QtGui[96]->u.td_py_type

#define sipType_QKeySequence_SequenceMatch sipExportedTypes_QtGui[95]
#define sipEnum_QKeySequence_SequenceMatch sipExportedTypes_QtGui[95]->u.td_py_type

#define sipType_QKeySequence_SequenceFormat sipExportedTypes_QtGui[94]
#define sipEnum_QKeySequence_SequenceFormat sipExportedTypes_QtGui[94]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QKeySequence;

#define sipType_QMatrix4x4 sipExportedTypes_QtGui[124]
#define sipClass_QMatrix4x4 sipExportedTypes_QtGui[124]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x4;

#define sipType_QMovie sipExportedTypes_QtGui[127]
#define sipClass_QMovie sipExportedTypes_QtGui[127]->u.td_wrapper_type

#define sipType_QMovie_CacheMode sipExportedTypes_QtGui[128]
#define sipEnum_QMovie_CacheMode sipExportedTypes_QtGui[128]->u.td_py_type

#define sipType_QMovie_MovieState sipExportedTypes_QtGui[129]
#define sipEnum_QMovie_MovieState sipExportedTypes_QtGui[129]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QMovie;

#define sipType_QSurface sipExportedTypes_QtGui[273]
#define sipClass_QSurface sipExportedTypes_QtGui[273]->u.td_wrapper_type

#define sipType_QSurface_SurfaceType sipExportedTypes_QtGui[275]
#define sipEnum_QSurface_SurfaceType sipExportedTypes_QtGui[275]->u.td_py_type

#define sipType_QSurface_SurfaceClass sipExportedTypes_QtGui[274]
#define sipEnum_QSurface_SurfaceClass sipExportedTypes_QtGui[274]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QSurface;

#define sipType_QOffscreenSurface sipExportedTypes_QtGui[131]
#define sipClass_QOffscreenSurface sipExportedTypes_QtGui[131]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOffscreenSurface;

#define sipType_QOpenGLBuffer sipExportedTypes_QtGui[132]
#define sipClass_QOpenGLBuffer sipExportedTypes_QtGui[132]->u.td_wrapper_type

#define sipType_QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtGui[134]
#define sipEnum_QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtGui[134]->u.td_py_type

#define sipType_QOpenGLBuffer_Access sipExportedTypes_QtGui[133]
#define sipEnum_QOpenGLBuffer_Access sipExportedTypes_QtGui[133]->u.td_py_type

#define sipType_QOpenGLBuffer_UsagePattern sipExportedTypes_QtGui[137]
#define sipEnum_QOpenGLBuffer_UsagePattern sipExportedTypes_QtGui[137]->u.td_py_type

#define sipType_QOpenGLBuffer_Type sipExportedTypes_QtGui[136]
#define sipEnum_QOpenGLBuffer_Type sipExportedTypes_QtGui[136]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer;

#define sipType_QOpenGLBuffer_RangeAccessFlags sipExportedTypes_QtGui[135]
#define sipClass_QOpenGLBuffer_RangeAccessFlags sipExportedTypes_QtGui[135]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer_RangeAccessFlags;

#define sipType_QOpenGLContextGroup sipExportedTypes_QtGui[140]
#define sipClass_QOpenGLContextGroup sipExportedTypes_QtGui[140]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContextGroup;

#define sipType_QOpenGLContext sipExportedTypes_QtGui[138]
#define sipClass_QOpenGLContext sipExportedTypes_QtGui[138]->u.td_wrapper_type

#define sipType_QOpenGLContext_OpenGLModuleType sipExportedTypes_QtGui[139]
#define sipEnum_QOpenGLContext_OpenGLModuleType sipExportedTypes_QtGui[139]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContext;

#define sipType_QOpenGLVersionProfile sipExportedTypes_QtGui[181]
#define sipClass_QOpenGLVersionProfile sipExportedTypes_QtGui[181]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVersionProfile;

#define sipType_QOpenGLDebugMessage sipExportedTypes_QtGui[143]
#define sipClass_QOpenGLDebugMessage sipExportedTypes_QtGui[143]->u.td_wrapper_type

#define sipType_QOpenGLDebugMessage_Severity sipExportedTypes_QtGui[145]
#define sipEnum_QOpenGLDebugMessage_Severity sipExportedTypes_QtGui[145]->u.td_py_type

#define sipType_QOpenGLDebugMessage_Type sipExportedTypes_QtGui[148]
#define sipEnum_QOpenGLDebugMessage_Type sipExportedTypes_QtGui[148]->u.td_py_type

#define sipType_QOpenGLDebugMessage_Source sipExportedTypes_QtGui[146]
#define sipEnum_QOpenGLDebugMessage_Source sipExportedTypes_QtGui[146]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage;

#define sipType_QOpenGLDebugMessage_Sources sipExportedTypes_QtGui[147]
#define sipClass_QOpenGLDebugMessage_Sources sipExportedTypes_QtGui[147]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Sources;

#define sipType_QOpenGLDebugMessage_Types sipExportedTypes_QtGui[149]
#define sipClass_QOpenGLDebugMessage_Types sipExportedTypes_QtGui[149]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Types;

#define sipType_QOpenGLDebugMessage_Severities sipExportedTypes_QtGui[144]
#define sipClass_QOpenGLDebugMessage_Severities sipExportedTypes_QtGui[144]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Severities;

#define sipType_QOpenGLDebugLogger sipExportedTypes_QtGui[141]
#define sipClass_QOpenGLDebugLogger sipExportedTypes_QtGui[141]->u.td_wrapper_type

#define sipType_QOpenGLDebugLogger_LoggingMode sipExportedTypes_QtGui[142]
#define sipEnum_QOpenGLDebugLogger_LoggingMode sipExportedTypes_QtGui[142]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugLogger;

#define sipType_QOpenGLFramebufferObject sipExportedTypes_QtGui[150]
#define sipClass_QOpenGLFramebufferObject sipExportedTypes_QtGui[150]->u.td_wrapper_type

#define sipType_QOpenGLFramebufferObject_FramebufferRestorePolicy sipExportedTypes_QtGui[152]
#define sipEnum_QOpenGLFramebufferObject_FramebufferRestorePolicy sipExportedTypes_QtGui[152]->u.td_py_type

#define sipType_QOpenGLFramebufferObject_Attachment sipExportedTypes_QtGui[151]
#define sipEnum_QOpenGLFramebufferObject_Attachment sipExportedTypes_QtGui[151]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObject;

#define sipType_QOpenGLFramebufferObjectFormat sipExportedTypes_QtGui[153]
#define sipClass_QOpenGLFramebufferObjectFormat sipExportedTypes_QtGui[153]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObjectFormat;

#define sipType_QOpenGLPaintDevice sipExportedTypes_QtGui[154]
#define sipClass_QOpenGLPaintDevice sipExportedTypes_QtGui[154]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPaintDevice;

#define sipType_QOpenGLPixelTransferOptions sipExportedTypes_QtGui[155]
#define sipClass_QOpenGLPixelTransferOptions sipExportedTypes_QtGui[155]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPixelTransferOptions;

#define sipType_QOpenGLShader sipExportedTypes_QtGui[156]
#define sipClass_QOpenGLShader sipExportedTypes_QtGui[156]->u.td_wrapper_type

#define sipType_QOpenGLShader_ShaderTypeBit sipExportedTypes_QtGui[158]
#define sipEnum_QOpenGLShader_ShaderTypeBit sipExportedTypes_QtGui[158]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader;

#define sipType_QOpenGLShader_ShaderType sipExportedTypes_QtGui[157]
#define sipClass_QOpenGLShader_ShaderType sipExportedTypes_QtGui[157]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader_ShaderType;

#define sipType_QOpenGLShaderProgram sipExportedTypes_QtGui[159]
#define sipClass_QOpenGLShaderProgram sipExportedTypes_QtGui[159]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShaderProgram;

#define sipType_QOpenGLTexture sipExportedTypes_QtGui[160]
#define sipClass_QOpenGLTexture sipExportedTypes_QtGui[160]->u.td_wrapper_type

#define sipType_QOpenGLTexture_ComparisonMode sipExportedTypes_QtGui[163]
#define sipEnum_QOpenGLTexture_ComparisonMode sipExportedTypes_QtGui[163]->u.td_py_type

#define sipType_QOpenGLTexture_ComparisonFunction sipExportedTypes_QtGui[162]
#define sipEnum_QOpenGLTexture_ComparisonFunction sipExportedTypes_QtGui[162]->u.td_py_type

#define sipType_QOpenGLTexture_CoordinateDirection sipExportedTypes_QtGui[164]
#define sipEnum_QOpenGLTexture_CoordinateDirection sipExportedTypes_QtGui[164]->u.td_py_type

#define sipType_QOpenGLTexture_WrapMode sipExportedTypes_QtGui[178]
#define sipEnum_QOpenGLTexture_WrapMode sipExportedTypes_QtGui[178]->u.td_py_type

#define sipType_QOpenGLTexture_Filter sipExportedTypes_QtGui[169]
#define sipEnum_QOpenGLTexture_Filter sipExportedTypes_QtGui[169]->u.td_py_type

#define sipType_QOpenGLTexture_DepthStencilMode sipExportedTypes_QtGui[166]
#define sipEnum_QOpenGLTexture_DepthStencilMode sipExportedTypes_QtGui[166]->u.td_py_type

#define sipType_QOpenGLTexture_SwizzleValue sipExportedTypes_QtGui[174]
#define sipEnum_QOpenGLTexture_SwizzleValue sipExportedTypes_QtGui[174]->u.td_py_type

#define sipType_QOpenGLTexture_SwizzleComponent sipExportedTypes_QtGui[173]
#define sipEnum_QOpenGLTexture_SwizzleComponent sipExportedTypes_QtGui[173]->u.td_py_type

#define sipType_QOpenGLTexture_Feature sipExportedTypes_QtGui[167]
#define sipEnum_QOpenGLTexture_Feature sipExportedTypes_QtGui[167]->u.td_py_type

#define sipType_QOpenGLTexture_PixelType sipExportedTypes_QtGui[172]
#define sipEnum_QOpenGLTexture_PixelType sipExportedTypes_QtGui[172]->u.td_py_type

#define sipType_QOpenGLTexture_PixelFormat sipExportedTypes_QtGui[171]
#define sipEnum_QOpenGLTexture_PixelFormat sipExportedTypes_QtGui[171]->u.td_py_type

#define sipType_QOpenGLTexture_CubeMapFace sipExportedTypes_QtGui[165]
#define sipEnum_QOpenGLTexture_CubeMapFace sipExportedTypes_QtGui[165]->u.td_py_type

#define sipType_QOpenGLTexture_TextureFormat sipExportedTypes_QtGui[176]
#define sipEnum_QOpenGLTexture_TextureFormat sipExportedTypes_QtGui[176]->u.td_py_type

#define sipType_QOpenGLTexture_TextureUnitReset sipExportedTypes_QtGui[177]
#define sipEnum_QOpenGLTexture_TextureUnitReset sipExportedTypes_QtGui[177]->u.td_py_type

#define sipType_QOpenGLTexture_MipMapGeneration sipExportedTypes_QtGui[170]
#define sipEnum_QOpenGLTexture_MipMapGeneration sipExportedTypes_QtGui[170]->u.td_py_type

#define sipType_QOpenGLTexture_BindingTarget sipExportedTypes_QtGui[161]
#define sipEnum_QOpenGLTexture_BindingTarget sipExportedTypes_QtGui[161]->u.td_py_type

#define sipType_QOpenGLTexture_Target sipExportedTypes_QtGui[175]
#define sipEnum_QOpenGLTexture_Target sipExportedTypes_QtGui[175]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture;

#define sipType_QOpenGLTexture_Features sipExportedTypes_QtGui[168]
#define sipClass_QOpenGLTexture_Features sipExportedTypes_QtGui[168]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture_Features;

#define sipType_QOpenGLTextureBlitter sipExportedTypes_QtGui[179]
#define sipClass_QOpenGLTextureBlitter sipExportedTypes_QtGui[179]->u.td_wrapper_type

#define sipType_QOpenGLTextureBlitter_Origin sipExportedTypes_QtGui[180]
#define sipEnum_QOpenGLTextureBlitter_Origin sipExportedTypes_QtGui[180]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTextureBlitter;

#define sipType_QAbstractOpenGLFunctions sipExportedTypes_QtGui[0]
#define sipClass_QAbstractOpenGLFunctions sipExportedTypes_QtGui[0]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractOpenGLFunctions;

#define sipType_QOpenGLVertexArrayObject sipExportedTypes_QtGui[182]
#define sipClass_QOpenGLVertexArrayObject sipExportedTypes_QtGui[182]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject;

#define sipType_QOpenGLVertexArrayObject_Binder sipExportedTypes_QtGui[183]
#define sipClass_QOpenGLVertexArrayObject_Binder sipExportedTypes_QtGui[183]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject_Binder;

#define sipType_QWindow sipExportedTypes_QtGui[383]
#define sipClass_QWindow sipExportedTypes_QtGui[383]->u.td_wrapper_type

#define sipType_QWindow_Visibility sipExportedTypes_QtGui[385]
#define sipEnum_QWindow_Visibility sipExportedTypes_QtGui[385]->u.td_py_type

#define sipType_QWindow_AncestorMode sipExportedTypes_QtGui[384]
#define sipEnum_QWindow_AncestorMode sipExportedTypes_QtGui[384]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QWindow;

#define sipType_QPaintDeviceWindow sipExportedTypes_QtGui[200]
#define sipClass_QPaintDeviceWindow sipExportedTypes_QtGui[200]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDeviceWindow;

#define sipType_QOpenGLWindow sipExportedTypes_QtGui[184]
#define sipClass_QOpenGLWindow sipExportedTypes_QtGui[184]->u.td_wrapper_type

#define sipType_QOpenGLWindow_UpdateBehavior sipExportedTypes_QtGui[185]
#define sipEnum_QOpenGLWindow_UpdateBehavior sipExportedTypes_QtGui[185]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLWindow;

#define sipType_QPagedPaintDevice sipExportedTypes_QtGui[194]
#define sipClass_QPagedPaintDevice sipExportedTypes_QtGui[194]->u.td_wrapper_type

#define sipType_QPagedPaintDevice_PdfVersion sipExportedTypes_QtGui[197]
#define sipEnum_QPagedPaintDevice_PdfVersion sipExportedTypes_QtGui[197]->u.td_py_type

#define sipType_QPagedPaintDevice_PageSize sipExportedTypes_QtGui[196]
#define sipEnum_QPagedPaintDevice_PageSize sipExportedTypes_QtGui[196]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice;

#define sipType_QPagedPaintDevice_Margins sipExportedTypes_QtGui[195]
#define sipClass_QPagedPaintDevice_Margins sipExportedTypes_QtGui[195]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice_Margins;

#define sipType_QPageLayout sipExportedTypes_QtGui[186]
#define sipClass_QPageLayout sipExportedTypes_QtGui[186]->u.td_wrapper_type

#define sipType_QPageLayout_Mode sipExportedTypes_QtGui[187]
#define sipEnum_QPageLayout_Mode sipExportedTypes_QtGui[187]->u.td_py_type

#define sipType_QPageLayout_Orientation sipExportedTypes_QtGui[188]
#define sipEnum_QPageLayout_Orientation sipExportedTypes_QtGui[188]->u.td_py_type

#define sipType_QPageLayout_Unit sipExportedTypes_QtGui[189]
#define sipEnum_QPageLayout_Unit sipExportedTypes_QtGui[189]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPageLayout;

#define sipType_QPageSize sipExportedTypes_QtGui[190]
#define sipClass_QPageSize sipExportedTypes_QtGui[190]->u.td_wrapper_type

#define sipType_QPageSize_SizeMatchPolicy sipExportedTypes_QtGui[192]
#define sipEnum_QPageSize_SizeMatchPolicy sipExportedTypes_QtGui[192]->u.td_py_type

#define sipType_QPageSize_Unit sipExportedTypes_QtGui[193]
#define sipEnum_QPageSize_Unit sipExportedTypes_QtGui[193]->u.td_py_type

#define sipType_QPageSize_PageSizeId sipExportedTypes_QtGui[191]
#define sipEnum_QPageSize_PageSizeId sipExportedTypes_QtGui[191]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPageSize;

#define sipType_QPainter sipExportedTypes_QtGui[210]
#define sipClass_QPainter sipExportedTypes_QtGui[210]->u.td_wrapper_type

#define sipType_QPainter_PixmapFragmentHint sipExportedTypes_QtGui[213]
#define sipEnum_QPainter_PixmapFragmentHint sipExportedTypes_QtGui[213]->u.td_py_type

#define sipType_QPainter_CompositionMode sipExportedTypes_QtGui[211]
#define sipEnum_QPainter_CompositionMode sipExportedTypes_QtGui[211]->u.td_py_type

#define sipType_QPainter_RenderHint sipExportedTypes_QtGui[215]
#define sipEnum_QPainter_RenderHint sipExportedTypes_QtGui[215]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainter;

#define sipType_QPainter_RenderHints sipExportedTypes_QtGui[216]
#define sipClass_QPainter_RenderHints sipExportedTypes_QtGui[216]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_RenderHints;

#define sipType_QPainter_PixmapFragment sipExportedTypes_QtGui[212]
#define sipClass_QPainter_PixmapFragment sipExportedTypes_QtGui[212]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragment;

#define sipType_QPainter_PixmapFragmentHints sipExportedTypes_QtGui[214]
#define sipClass_QPainter_PixmapFragmentHints sipExportedTypes_QtGui[214]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragmentHints;

#define sipType_QTextItem sipExportedTypes_QtGui[326]
#define sipClass_QTextItem sipExportedTypes_QtGui[326]->u.td_wrapper_type

#define sipType_QTextItem_RenderFlag sipExportedTypes_QtGui[327]
#define sipEnum_QTextItem_RenderFlag sipExportedTypes_QtGui[327]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem;

#define sipType_QTextItem_RenderFlags sipExportedTypes_QtGui[328]
#define sipClass_QTextItem_RenderFlags sipExportedTypes_QtGui[328]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem_RenderFlags;

#define sipType_QPaintEngine sipExportedTypes_QtGui[201]
#define sipClass_QPaintEngine sipExportedTypes_QtGui[201]->u.td_wrapper_type

#define sipType_QPaintEngine_Type sipExportedTypes_QtGui[207]
#define sipEnum_QPaintEngine_Type sipExportedTypes_QtGui[207]->u.td_py_type

#define sipType_QPaintEngine_PolygonDrawMode sipExportedTypes_QtGui[206]
#define sipEnum_QPaintEngine_PolygonDrawMode sipExportedTypes_QtGui[206]->u.td_py_type

#define sipType_QPaintEngine_DirtyFlag sipExportedTypes_QtGui[202]
#define sipEnum_QPaintEngine_DirtyFlag sipExportedTypes_QtGui[202]->u.td_py_type

#define sipType_QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[204]
#define sipEnum_QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[204]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine;

#define sipType_QPaintEngine_PaintEngineFeatures sipExportedTypes_QtGui[205]
#define sipClass_QPaintEngine_PaintEngineFeatures sipExportedTypes_QtGui[205]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_PaintEngineFeatures;

#define sipType_QPaintEngine_DirtyFlags sipExportedTypes_QtGui[203]
#define sipClass_QPaintEngine_DirtyFlags sipExportedTypes_QtGui[203]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_DirtyFlags;

#define sipType_QPaintEngineState sipExportedTypes_QtGui[208]
#define sipClass_QPaintEngineState sipExportedTypes_QtGui[208]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngineState;

#define sipType_QPainterPath sipExportedTypes_QtGui[217]
#define sipClass_QPainterPath sipExportedTypes_QtGui[217]->u.td_wrapper_type

#define sipType_QPainterPath_ElementType sipExportedTypes_QtGui[219]
#define sipEnum_QPainterPath_ElementType sipExportedTypes_QtGui[219]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath;

#define sipType_QPainterPath_Element sipExportedTypes_QtGui[218]
#define sipClass_QPainterPath_Element sipExportedTypes_QtGui[218]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath_Element;

#define sipType_QPainterPathStroker sipExportedTypes_QtGui[220]
#define sipClass_QPainterPathStroker sipExportedTypes_QtGui[220]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPathStroker;

#define sipType_QPalette sipExportedTypes_QtGui[223]
#define sipClass_QPalette sipExportedTypes_QtGui[223]->u.td_wrapper_type

#define sipType_QPalette_ColorRole sipExportedTypes_QtGui[225]
#define sipEnum_QPalette_ColorRole sipExportedTypes_QtGui[225]->u.td_py_type

#define sipType_QPalette_ColorGroup sipExportedTypes_QtGui[224]
#define sipEnum_QPalette_ColorGroup sipExportedTypes_QtGui[224]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPalette;

#define sipType_QPdfWriter sipExportedTypes_QtGui[226]
#define sipClass_QPdfWriter sipExportedTypes_QtGui[226]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPdfWriter;

#define sipType_QPen sipExportedTypes_QtGui[227]
#define sipClass_QPen sipExportedTypes_QtGui[227]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPen;

#define sipType_QPicture sipExportedTypes_QtGui[228]
#define sipClass_QPicture sipExportedTypes_QtGui[228]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPicture;

#define sipType_QPictureIO sipExportedTypes_QtGui[229]
#define sipClass_QPictureIO sipExportedTypes_QtGui[229]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPictureIO;

#define sipType_QPixelFormat sipExportedTypes_QtGui[230]
#define sipClass_QPixelFormat sipExportedTypes_QtGui[230]->u.td_wrapper_type

#define sipType_QPixelFormat_ByteOrder sipExportedTypes_QtGui[234]
#define sipEnum_QPixelFormat_ByteOrder sipExportedTypes_QtGui[234]->u.td_py_type

#define sipType_QPixelFormat_YUVLayout sipExportedTypes_QtGui[237]
#define sipEnum_QPixelFormat_YUVLayout sipExportedTypes_QtGui[237]->u.td_py_type

#define sipType_QPixelFormat_TypeInterpretation sipExportedTypes_QtGui[236]
#define sipEnum_QPixelFormat_TypeInterpretation sipExportedTypes_QtGui[236]->u.td_py_type

#define sipType_QPixelFormat_AlphaPremultiplied sipExportedTypes_QtGui[232]
#define sipEnum_QPixelFormat_AlphaPremultiplied sipExportedTypes_QtGui[232]->u.td_py_type

#define sipType_QPixelFormat_AlphaPosition sipExportedTypes_QtGui[231]
#define sipEnum_QPixelFormat_AlphaPosition sipExportedTypes_QtGui[231]->u.td_py_type

#define sipType_QPixelFormat_AlphaUsage sipExportedTypes_QtGui[233]
#define sipEnum_QPixelFormat_AlphaUsage sipExportedTypes_QtGui[233]->u.td_py_type

#define sipType_QPixelFormat_ColorModel sipExportedTypes_QtGui[235]
#define sipEnum_QPixelFormat_ColorModel sipExportedTypes_QtGui[235]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QPixelFormat;

#define sipType_QPixmapCache sipExportedTypes_QtGui[239]
#define sipClass_QPixmapCache sipExportedTypes_QtGui[239]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache;

#define sipType_QPixmapCache_Key sipExportedTypes_QtGui[240]
#define sipClass_QPixmapCache_Key sipExportedTypes_QtGui[240]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache_Key;

#define sipType_QPolygon sipExportedTypes_QtGui[244]
#define sipClass_QPolygon sipExportedTypes_QtGui[244]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPolygon;

#define sipType_QPolygonF sipExportedTypes_QtGui[245]
#define sipClass_QPolygonF sipExportedTypes_QtGui[245]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QPolygonF;

#define sipType_QQuaternion sipExportedTypes_QtGui[246]
#define sipClass_QQuaternion sipExportedTypes_QtGui[246]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion;

#define sipType_QRasterWindow sipExportedTypes_QtGui[248]
#define sipClass_QRasterWindow sipExportedTypes_QtGui[248]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRasterWindow;

#define sipType_QRawFont sipExportedTypes_QtGui[249]
#define sipClass_QRawFont sipExportedTypes_QtGui[249]->u.td_wrapper_type

#define sipType_QRawFont_LayoutFlag sipExportedTypes_QtGui[251]
#define sipEnum_QRawFont_LayoutFlag sipExportedTypes_QtGui[251]->u.td_py_type

#define sipType_QRawFont_AntialiasingType sipExportedTypes_QtGui[250]
#define sipEnum_QRawFont_AntialiasingType sipExportedTypes_QtGui[250]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont;

#define sipType_QRawFont_LayoutFlags sipExportedTypes_QtGui[252]
#define sipClass_QRawFont_LayoutFlags sipExportedTypes_QtGui[252]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont_LayoutFlags;

#define sipType_QRegion sipExportedTypes_QtGui[254]
#define sipClass_QRegion sipExportedTypes_QtGui[254]->u.td_wrapper_type

#define sipType_QRegion_RegionType sipExportedTypes_QtGui[255]
#define sipEnum_QRegion_RegionType sipExportedTypes_QtGui[255]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QRegion;

#define sipType_QRgba64 sipExportedTypes_QtGui[258]
#define sipClass_QRgba64 sipExportedTypes_QtGui[258]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRgba64;

#define sipType_QScreen sipExportedTypes_QtGui[259]
#define sipClass_QScreen sipExportedTypes_QtGui[259]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QScreen;

#define sipType_QStandardItemModel sipExportedTypes_QtGui[268]
#define sipClass_QStandardItemModel sipExportedTypes_QtGui[268]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItemModel;

#define sipType_QStandardItem sipExportedTypes_QtGui[266]
#define sipClass_QStandardItem sipExportedTypes_QtGui[266]->u.td_wrapper_type

#define sipType_QStandardItem_ItemType sipExportedTypes_QtGui[267]
#define sipEnum_QStandardItem_ItemType sipExportedTypes_QtGui[267]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItem;

#define sipType_QStaticText sipExportedTypes_QtGui[269]
#define sipClass_QStaticText sipExportedTypes_QtGui[269]->u.td_wrapper_type

#define sipType_QStaticText_PerformanceHint sipExportedTypes_QtGui[270]
#define sipEnum_QStaticText_PerformanceHint sipExportedTypes_QtGui[270]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QStaticText;

#define sipType_QStyleHints sipExportedTypes_QtGui[272]
#define sipClass_QStyleHints sipExportedTypes_QtGui[272]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QStyleHints;

#define sipType_QSurfaceFormat sipExportedTypes_QtGui[276]
#define sipClass_QSurfaceFormat sipExportedTypes_QtGui[276]->u.td_wrapper_type

#define sipType_QSurfaceFormat_ColorSpace sipExportedTypes_QtGui[277]
#define sipEnum_QSurfaceFormat_ColorSpace sipExportedTypes_QtGui[277]->u.td_py_type

#define sipType_QSurfaceFormat_OpenGLContextProfile sipExportedTypes_QtGui[280]
#define sipEnum_QSurfaceFormat_OpenGLContextProfile sipExportedTypes_QtGui[280]->u.td_py_type

#define sipType_QSurfaceFormat_RenderableType sipExportedTypes_QtGui[281]
#define sipEnum_QSurfaceFormat_RenderableType sipExportedTypes_QtGui[281]->u.td_py_type

#define sipType_QSurfaceFormat_SwapBehavior sipExportedTypes_QtGui[282]
#define sipEnum_QSurfaceFormat_SwapBehavior sipExportedTypes_QtGui[282]->u.td_py_type

#define sipType_QSurfaceFormat_FormatOption sipExportedTypes_QtGui[278]
#define sipEnum_QSurfaceFormat_FormatOption sipExportedTypes_QtGui[278]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat;

#define sipType_QSurfaceFormat_FormatOptions sipExportedTypes_QtGui[279]
#define sipClass_QSurfaceFormat_FormatOptions sipExportedTypes_QtGui[279]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat_FormatOptions;

#define sipType_QSyntaxHighlighter sipExportedTypes_QtGui[283]
#define sipClass_QSyntaxHighlighter sipExportedTypes_QtGui[283]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QSyntaxHighlighter;

#define sipType_QTextCursor sipExportedTypes_QtGui[298]
#define sipClass_QTextCursor sipExportedTypes_QtGui[298]->u.td_wrapper_type

#define sipType_QTextCursor_SelectionType sipExportedTypes_QtGui[301]
#define sipEnum_QTextCursor_SelectionType sipExportedTypes_QtGui[301]->u.td_py_type

#define sipType_QTextCursor_MoveOperation sipExportedTypes_QtGui[300]
#define sipEnum_QTextCursor_MoveOperation sipExportedTypes_QtGui[300]->u.td_py_type

#define sipType_QTextCursor_MoveMode sipExportedTypes_QtGui[299]
#define sipEnum_QTextCursor_MoveMode sipExportedTypes_QtGui[299]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextCursor;


extern sipClassTypeDef sipTypeDef_QtGui_Qt;

#define sipType_QTextDocument sipExportedTypes_QtGui[302]
#define sipClass_QTextDocument sipExportedTypes_QtGui[302]->u.td_wrapper_type

#define sipType_QTextDocument_MarkdownFeature sipExportedTypes_QtGui[305]
#define sipEnum_QTextDocument_MarkdownFeature sipExportedTypes_QtGui[305]->u.td_py_type

#define sipType_QTextDocument_Stacks sipExportedTypes_QtGui[309]
#define sipEnum_QTextDocument_Stacks sipExportedTypes_QtGui[309]->u.td_py_type

#define sipType_QTextDocument_ResourceType sipExportedTypes_QtGui[308]
#define sipEnum_QTextDocument_ResourceType sipExportedTypes_QtGui[308]->u.td_py_type

#define sipType_QTextDocument_FindFlag sipExportedTypes_QtGui[303]
#define sipEnum_QTextDocument_FindFlag sipExportedTypes_QtGui[303]->u.td_py_type

#define sipType_QTextDocument_MetaInformation sipExportedTypes_QtGui[307]
#define sipEnum_QTextDocument_MetaInformation sipExportedTypes_QtGui[307]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument;

#define sipType_QTextDocument_FindFlags sipExportedTypes_QtGui[304]
#define sipClass_QTextDocument_FindFlags sipExportedTypes_QtGui[304]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_FindFlags;

#define sipType_QTextDocument_MarkdownFeatures sipExportedTypes_QtGui[306]
#define sipClass_QTextDocument_MarkdownFeatures sipExportedTypes_QtGui[306]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_MarkdownFeatures;

#define sipType_QTextDocumentFragment sipExportedTypes_QtGui[310]
#define sipClass_QTextDocumentFragment sipExportedTypes_QtGui[310]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentFragment;

#define sipType_QTextDocumentWriter sipExportedTypes_QtGui[311]
#define sipClass_QTextDocumentWriter sipExportedTypes_QtGui[311]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentWriter;

#define sipType_QTextLength sipExportedTypes_QtGui[332]
#define sipClass_QTextLength sipExportedTypes_QtGui[332]->u.td_wrapper_type

#define sipType_QTextLength_Type sipExportedTypes_QtGui[333]
#define sipEnum_QTextLength_Type sipExportedTypes_QtGui[333]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextLength;

#define sipType_QTextFormat sipExportedTypes_QtGui[312]
#define sipClass_QTextFormat sipExportedTypes_QtGui[312]->u.td_wrapper_type

#define sipType_QTextFormat_Property sipExportedTypes_QtGui[317]
#define sipEnum_QTextFormat_Property sipExportedTypes_QtGui[317]->u.td_py_type

#define sipType_QTextFormat_PageBreakFlag sipExportedTypes_QtGui[315]
#define sipEnum_QTextFormat_PageBreakFlag sipExportedTypes_QtGui[315]->u.td_py_type

#define sipType_QTextFormat_ObjectTypes sipExportedTypes_QtGui[314]
#define sipEnum_QTextFormat_ObjectTypes sipExportedTypes_QtGui[314]->u.td_py_type

#define sipType_QTextFormat_FormatType sipExportedTypes_QtGui[313]
#define sipEnum_QTextFormat_FormatType sipExportedTypes_QtGui[313]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat;

#define sipType_QTextFormat_PageBreakFlags sipExportedTypes_QtGui[316]
#define sipClass_QTextFormat_PageBreakFlags sipExportedTypes_QtGui[316]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat_PageBreakFlags;

#define sipType_QTextCharFormat sipExportedTypes_QtGui[294]
#define sipClass_QTextCharFormat sipExportedTypes_QtGui[294]->u.td_wrapper_type

#define sipType_QTextCharFormat_FontPropertiesInheritanceBehavior sipExportedTypes_QtGui[295]
#define sipEnum_QTextCharFormat_FontPropertiesInheritanceBehavior sipExportedTypes_QtGui[295]->u.td_py_type

#define sipType_QTextCharFormat_UnderlineStyle sipExportedTypes_QtGui[296]
#define sipEnum_QTextCharFormat_UnderlineStyle sipExportedTypes_QtGui[296]->u.td_py_type

#define sipType_QTextCharFormat_VerticalAlignment sipExportedTypes_QtGui[297]
#define sipEnum_QTextCharFormat_VerticalAlignment sipExportedTypes_QtGui[297]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextCharFormat;

#define sipType_QTextBlockFormat sipExportedTypes_QtGui[289]
#define sipClass_QTextBlockFormat sipExportedTypes_QtGui[289]->u.td_wrapper_type

#define sipType_QTextBlockFormat_MarkerType sipExportedTypes_QtGui[291]
#define sipEnum_QTextBlockFormat_MarkerType sipExportedTypes_QtGui[291]->u.td_py_type

#define sipType_QTextBlockFormat_LineHeightTypes sipExportedTypes_QtGui[290]
#define sipEnum_QTextBlockFormat_LineHeightTypes sipExportedTypes_QtGui[290]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockFormat;

#define sipType_QTextListFormat sipExportedTypes_QtGui[338]
#define sipClass_QTextListFormat sipExportedTypes_QtGui[338]->u.td_wrapper_type

#define sipType_QTextListFormat_Style sipExportedTypes_QtGui[339]
#define sipEnum_QTextListFormat_Style sipExportedTypes_QtGui[339]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextListFormat;

#define sipType_QTextImageFormat sipExportedTypes_QtGui[324]
#define sipClass_QTextImageFormat sipExportedTypes_QtGui[324]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextImageFormat;

#define sipType_QTextFrameFormat sipExportedTypes_QtGui[321]
#define sipClass_QTextFrameFormat sipExportedTypes_QtGui[321]->u.td_wrapper_type

#define sipType_QTextFrameFormat_BorderStyle sipExportedTypes_QtGui[322]
#define sipEnum_QTextFrameFormat_BorderStyle sipExportedTypes_QtGui[322]->u.td_py_type

#define sipType_QTextFrameFormat_Position sipExportedTypes_QtGui[323]
#define sipEnum_QTextFrameFormat_Position sipExportedTypes_QtGui[323]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrameFormat;

#define sipType_QTextTableFormat sipExportedTypes_QtGui[351]
#define sipClass_QTextTableFormat sipExportedTypes_QtGui[351]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableFormat;

#define sipType_QTextTableCellFormat sipExportedTypes_QtGui[350]
#define sipClass_QTextTableCellFormat sipExportedTypes_QtGui[350]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCellFormat;

#define sipType_QTextInlineObject sipExportedTypes_QtGui[325]
#define sipClass_QTextInlineObject sipExportedTypes_QtGui[325]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextInlineObject;

#define sipType_QTextLayout sipExportedTypes_QtGui[329]
#define sipClass_QTextLayout sipExportedTypes_QtGui[329]->u.td_wrapper_type

#define sipType_QTextLayout_CursorMode sipExportedTypes_QtGui[330]
#define sipEnum_QTextLayout_CursorMode sipExportedTypes_QtGui[330]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout;

#define sipType_QTextLayout_FormatRange sipExportedTypes_QtGui[331]
#define sipClass_QTextLayout_FormatRange sipExportedTypes_QtGui[331]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout_FormatRange;

#define sipType_QTextLine sipExportedTypes_QtGui[334]
#define sipClass_QTextLine sipExportedTypes_QtGui[334]->u.td_wrapper_type

#define sipType_QTextLine_CursorPosition sipExportedTypes_QtGui[335]
#define sipEnum_QTextLine_CursorPosition sipExportedTypes_QtGui[335]->u.td_py_type

#define sipType_QTextLine_Edge sipExportedTypes_QtGui[336]
#define sipEnum_QTextLine_Edge sipExportedTypes_QtGui[336]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextLine;

#define sipType_QTextObject sipExportedTypes_QtGui[340]
#define sipClass_QTextObject sipExportedTypes_QtGui[340]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextObject;

#define sipType_QTextBlockGroup sipExportedTypes_QtGui[292]
#define sipClass_QTextBlockGroup sipExportedTypes_QtGui[292]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockGroup;

#define sipType_QTextList sipExportedTypes_QtGui[337]
#define sipClass_QTextList sipExportedTypes_QtGui[337]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextList;

#define sipType_QTextFrame sipExportedTypes_QtGui[319]
#define sipClass_QTextFrame sipExportedTypes_QtGui[319]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame;

#define sipType_QTextFrame_iterator sipExportedTypes_QtGui[320]
#define sipClass_QTextFrame_iterator sipExportedTypes_QtGui[320]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame_iterator;

#define sipType_QTextBlock sipExportedTypes_QtGui[287]
#define sipClass_QTextBlock sipExportedTypes_QtGui[287]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock;

#define sipType_QTextBlock_iterator sipExportedTypes_QtGui[288]
#define sipClass_QTextBlock_iterator sipExportedTypes_QtGui[288]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock_iterator;

#define sipType_QTextFragment sipExportedTypes_QtGui[318]
#define sipClass_QTextFragment sipExportedTypes_QtGui[318]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextFragment;

#define sipType_QTextBlockUserData sipExportedTypes_QtGui[293]
#define sipClass_QTextBlockUserData sipExportedTypes_QtGui[293]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockUserData;

#define sipType_QTextOption sipExportedTypes_QtGui[342]
#define sipClass_QTextOption sipExportedTypes_QtGui[342]->u.td_wrapper_type

#define sipType_QTextOption_TabType sipExportedTypes_QtGui[346]
#define sipEnum_QTextOption_TabType sipExportedTypes_QtGui[346]->u.td_py_type

#define sipType_QTextOption_Flag sipExportedTypes_QtGui[343]
#define sipEnum_QTextOption_Flag sipExportedTypes_QtGui[343]->u.td_py_type

#define sipType_QTextOption_WrapMode sipExportedTypes_QtGui[347]
#define sipEnum_QTextOption_WrapMode sipExportedTypes_QtGui[347]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption;

#define sipType_QTextOption_Flags sipExportedTypes_QtGui[344]
#define sipClass_QTextOption_Flags sipExportedTypes_QtGui[344]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Flags;

#define sipType_QTextOption_Tab sipExportedTypes_QtGui[345]
#define sipClass_QTextOption_Tab sipExportedTypes_QtGui[345]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Tab;

#define sipType_QTextTableCell sipExportedTypes_QtGui[349]
#define sipClass_QTextTableCell sipExportedTypes_QtGui[349]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCell;

#define sipType_QTextTable sipExportedTypes_QtGui[348]
#define sipClass_QTextTable sipExportedTypes_QtGui[348]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTextTable;

#define sipType_QTouchDevice sipExportedTypes_QtGui[352]
#define sipClass_QTouchDevice sipExportedTypes_QtGui[352]->u.td_wrapper_type

#define sipType_QTouchDevice_CapabilityFlag sipExportedTypes_QtGui[354]
#define sipEnum_QTouchDevice_CapabilityFlag sipExportedTypes_QtGui[354]->u.td_py_type

#define sipType_QTouchDevice_DeviceType sipExportedTypes_QtGui[355]
#define sipEnum_QTouchDevice_DeviceType sipExportedTypes_QtGui[355]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice;

#define sipType_QTouchDevice_Capabilities sipExportedTypes_QtGui[353]
#define sipClass_QTouchDevice_Capabilities sipExportedTypes_QtGui[353]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice_Capabilities;

#define sipType_QTransform sipExportedTypes_QtGui[360]
#define sipClass_QTransform sipExportedTypes_QtGui[360]->u.td_wrapper_type

#define sipType_QTransform_TransformationType sipExportedTypes_QtGui[361]
#define sipEnum_QTransform_TransformationType sipExportedTypes_QtGui[361]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QTransform;

#define sipType_QValidator sipExportedTypes_QtGui[362]
#define sipClass_QValidator sipExportedTypes_QtGui[362]->u.td_wrapper_type

#define sipType_QValidator_State sipExportedTypes_QtGui[363]
#define sipEnum_QValidator_State sipExportedTypes_QtGui[363]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QValidator;

#define sipType_QIntValidator sipExportedTypes_QtGui[91]
#define sipClass_QIntValidator sipExportedTypes_QtGui[91]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QIntValidator;

#define sipType_QDoubleValidator sipExportedTypes_QtGui[27]
#define sipClass_QDoubleValidator sipExportedTypes_QtGui[27]->u.td_wrapper_type

#define sipType_QDoubleValidator_Notation sipExportedTypes_QtGui[28]
#define sipEnum_QDoubleValidator_Notation sipExportedTypes_QtGui[28]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtGui_QDoubleValidator;

#define sipType_QRegExpValidator sipExportedTypes_QtGui[253]
#define sipClass_QRegExpValidator sipExportedTypes_QtGui[253]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRegExpValidator;

#define sipType_QRegularExpressionValidator sipExportedTypes_QtGui[256]
#define sipClass_QRegularExpressionValidator sipExportedTypes_QtGui[256]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QRegularExpressionValidator;

#define sipType_QVector2D sipExportedTypes_QtGui[364]
#define sipClass_QVector2D sipExportedTypes_QtGui[364]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QVector2D;

#define sipType_QVector3D sipExportedTypes_QtGui[365]
#define sipClass_QVector3D sipExportedTypes_QtGui[365]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QVector3D;

#define sipType_QVector4D sipExportedTypes_QtGui[366]
#define sipClass_QVector4D sipExportedTypes_QtGui[366]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtGui_QVector4D;

#define sipType_QList_0111QTouchDevice sipExportedTypes_QtGui[113]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0111QTouchDevice;

#define sipType_QList_0101QTextFrame sipExportedTypes_QtGui[110]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QTextFrame;

#define sipType_QList_0100QTextBlock sipExportedTypes_QtGui[109]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextBlock;

#define sipType_QList_0100QGlyphRun sipExportedTypes_QtGui[99]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QGlyphRun;

#define sipType_QVector_0100QTextLayout_FormatRange sipExportedTypes_QtGui[376]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextLayout_FormatRange sipExportedTypes_QtGui[111]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextOption_Tab sipExportedTypes_QtGui[112]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextOption_Tab;

#define sipType_QVector_0100QTextLength sipExportedTypes_QtGui[377]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLength;

#define sipType_QVector_0100QTextFormat sipExportedTypes_QtGui[375]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextFormat;

#define sipType_QList_0101QStandardItem sipExportedTypes_QtGui[108]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QStandardItem;

#define sipType_QList_0100QPolygonF sipExportedTypes_QtGui[105]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPolygonF;

#define sipType_QVector_0100QRect sipExportedTypes_QtGui[372]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QRect;

#define sipType_QVector_0100QRectF sipExportedTypes_QtGui[373]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QRectF;

#define sipType_QVector_0100QPoint sipExportedTypes_QtGui[371]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QPoint;

#define sipType_QVector_0100QLine sipExportedTypes_QtGui[368]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QLine;

#define sipType_QVector_0100QLineF sipExportedTypes_QtGui[369]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QLineF;

#define sipType_QList_0101QOpenGLShader sipExportedTypes_QtGui[104]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLShader;

#define sipType_QVector_0100QSize sipExportedTypes_QtGui[374]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QSize;

#define sipType_QList_0100QOpenGLDebugMessage sipExportedTypes_QtGui[103]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QOpenGLDebugMessage;

#define sipType_QSet_0100QByteArray sipExportedTypes_QtGui[263]

extern sipMappedTypeDef sipTypeDef_QtGui_QSet_0100QByteArray;

#define sipType_QList_0101QOpenGLContext sipExportedTypes_QtGui[102]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLContext;

#define sipType_QList_0100QKeySequence sipExportedTypes_QtGui[101]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QKeySequence;

#define sipType_QList_0101QScreen sipExportedTypes_QtGui[106]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QScreen;

#define sipType_QList_0100QTouchEvent_TouchPoint sipExportedTypes_QtGui[114]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTouchEvent_TouchPoint;

#define sipType_QList_0100QInputMethodEvent_Attribute sipExportedTypes_QtGui[100]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute;

#define sipType_QList_0100QSize sipExportedTypes_QtGui[107]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QSize;

#define sipType_QVector_0100QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[367]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QAbstractTextDocumentLayout_Selection;

#define sipType_QList_0101QWindow sipExportedTypes_QtGui[115]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QWindow;

#define sipType_QVector_0600QPair_2400_0100QColor sipExportedTypes_QtGui[370]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0600QPair_2400_0100QColor;

#define sipType_QVector_2400 sipExportedTypes_QtGui[379]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2400;

#define sipType_QVector_2200 sipExportedTypes_QtGui[378]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2200;

#define sipType_QVector_1900 sipExportedTypes_QtGui[380]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_1900;

#define sipType_QList_0100QFontDatabase_WritingSystem sipExportedTypes_QtGui[98]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem;

#define sipType_QPair_2200_2200 sipExportedTypes_QtGui[222]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_2200_2200;

#define sipType_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter sipExportedTypes_QtGui[221]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtGui;
extern sipExportedModuleDef sipModuleAPI_QtGui;
extern sipTypeDef *sipExportedTypes_QtGui[];

#if !defined(sipType_Qt)
#define sipType_Qt sipImportedTypes_QtGui_QtCore[42].it_td
#define sipClass_Qt sipImportedTypes_QtGui_QtCore[42].it_td->u.td_wrapper_type
#endif

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipImportedTypes_QtGui_QtCore[59].it_td
#define sipEnum_Qt_HighDpiScaleFactorRoundingPolicy sipImportedTypes_QtGui_QtCore[59].it_td->u.td_py_type

#define sipType_Qt_TabFocusBehavior sipImportedTypes_QtGui_QtCore[83].it_td
#define sipEnum_Qt_TabFocusBehavior sipImportedTypes_QtGui_QtCore[83].it_td->u.td_py_type

#define sipType_Qt_MouseEventSource sipImportedTypes_QtGui_QtCore[72].it_td
#define sipEnum_Qt_MouseEventSource sipImportedTypes_QtGui_QtCore[72].it_td->u.td_py_type

#define sipType_Qt_ScrollPhase sipImportedTypes_QtGui_QtCore[80].it_td
#define sipEnum_Qt_ScrollPhase sipImportedTypes_QtGui_QtCore[80].it_td->u.td_py_type

#define sipType_Qt_NativeGestureType sipImportedTypes_QtGui_QtCore[73].it_td
#define sipEnum_Qt_NativeGestureType sipImportedTypes_QtGui_QtCore[73].it_td->u.td_py_type

#define sipType_Qt_ApplicationState sipImportedTypes_QtGui_QtCore[44].it_td
#define sipEnum_Qt_ApplicationState sipImportedTypes_QtGui_QtCore[44].it_td->u.td_py_type

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtGui_QtCore[60].it_td
#define sipEnum_Qt_HitTestAccuracy sipImportedTypes_QtGui_QtCore[60].it_td->u.td_py_type

#define sipType_Qt_WhiteSpaceMode sipImportedTypes_QtGui_QtCore[89].it_td
#define sipEnum_Qt_WhiteSpaceMode sipImportedTypes_QtGui_QtCore[89].it_td->u.td_py_type

#define sipType_Qt_ScreenOrientation sipImportedTypes_QtGui_QtCore[78].it_td
#define sipEnum_Qt_ScreenOrientation sipImportedTypes_QtGui_QtCore[78].it_td->u.td_py_type

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtGui_QtCore[51].it_td
#define sipEnum_Qt_CursorMoveStyle sipImportedTypes_QtGui_QtCore[51].it_td->u.td_py_type

#define sipType_Qt_TouchPointState sipImportedTypes_QtGui_QtCore[86].it_td
#define sipEnum_Qt_TouchPointState sipImportedTypes_QtGui_QtCore[86].it_td->u.td_py_type

#define sipType_Qt_SizeMode sipImportedTypes_QtGui_QtCore[81].it_td
#define sipEnum_Qt_SizeMode sipImportedTypes_QtGui_QtCore[81].it_td->u.td_py_type

#define sipType_Qt_Axis sipImportedTypes_QtGui_QtCore[46].it_td
#define sipEnum_Qt_Axis sipImportedTypes_QtGui_QtCore[46].it_td->u.td_py_type

#define sipType_Qt_MaskMode sipImportedTypes_QtGui_QtCore[67].it_td
#define sipEnum_Qt_MaskMode sipImportedTypes_QtGui_QtCore[67].it_td->u.td_py_type

#define sipType_Qt_WindowModality sipImportedTypes_QtGui_QtCore[91].it_td
#define sipEnum_Qt_WindowModality sipImportedTypes_QtGui_QtCore[91].it_td->u.td_py_type

#define sipType_Qt_CheckState sipImportedTypes_QtGui_QtCore[49].it_td
#define sipEnum_Qt_CheckState sipImportedTypes_QtGui_QtCore[49].it_td->u.td_py_type

#define sipType_Qt_DropAction sipImportedTypes_QtGui_QtCore[53].it_td
#define sipEnum_Qt_DropAction sipImportedTypes_QtGui_QtCore[53].it_td->u.td_py_type

#define sipType_Qt_LayoutDirection sipImportedTypes_QtGui_QtCore[66].it_td
#define sipEnum_Qt_LayoutDirection sipImportedTypes_QtGui_QtCore[66].it_td->u.td_py_type

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[63].it_td
#define sipEnum_Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[63].it_td->u.td_py_type

#define sipType_Qt_FocusReason sipImportedTypes_QtGui_QtCore[57].it_td
#define sipEnum_Qt_FocusReason sipImportedTypes_QtGui_QtCore[57].it_td->u.td_py_type

#define sipType_Qt_TransformationMode sipImportedTypes_QtGui_QtCore[88].it_td
#define sipEnum_Qt_TransformationMode sipImportedTypes_QtGui_QtCore[88].it_td->u.td_py_type

#define sipType_Qt_ClipOperation sipImportedTypes_QtGui_QtCore[50].it_td
#define sipEnum_Qt_ClipOperation sipImportedTypes_QtGui_QtCore[50].it_td->u.td_py_type

#define sipType_Qt_FillRule sipImportedTypes_QtGui_QtCore[56].it_td
#define sipEnum_Qt_FillRule sipImportedTypes_QtGui_QtCore[56].it_td->u.td_py_type

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtGui_QtCore[45].it_td
#define sipEnum_Qt_AspectRatioMode sipImportedTypes_QtGui_QtCore[45].it_td->u.td_py_type

#define sipType_Qt_TextFormat sipImportedTypes_QtGui_QtCore[85].it_td
#define sipEnum_Qt_TextFormat sipImportedTypes_QtGui_QtCore[85].it_td->u.td_py_type

#define sipType_Qt_CursorShape sipImportedTypes_QtGui_QtCore[52].it_td
#define sipEnum_Qt_CursorShape sipImportedTypes_QtGui_QtCore[52].it_td->u.td_py_type

#define sipType_Qt_BrushStyle sipImportedTypes_QtGui_QtCore[48].it_td
#define sipEnum_Qt_BrushStyle sipImportedTypes_QtGui_QtCore[48].it_td->u.td_py_type

#define sipType_Qt_PenJoinStyle sipImportedTypes_QtGui_QtCore[76].it_td
#define sipEnum_Qt_PenJoinStyle sipImportedTypes_QtGui_QtCore[76].it_td->u.td_py_type

#define sipType_Qt_PenCapStyle sipImportedTypes_QtGui_QtCore[75].it_td
#define sipEnum_Qt_PenCapStyle sipImportedTypes_QtGui_QtCore[75].it_td->u.td_py_type

#define sipType_Qt_PenStyle sipImportedTypes_QtGui_QtCore[77].it_td
#define sipEnum_Qt_PenStyle sipImportedTypes_QtGui_QtCore[77].it_td->u.td_py_type

#define sipType_Qt_BGMode sipImportedTypes_QtGui_QtCore[47].it_td
#define sipEnum_Qt_BGMode sipImportedTypes_QtGui_QtCore[47].it_td->u.td_py_type

#define sipType_Qt_WindowState sipImportedTypes_QtGui_QtCore[92].it_td
#define sipEnum_Qt_WindowState sipImportedTypes_QtGui_QtCore[92].it_td->u.td_py_type

#define sipType_Qt_WindowType sipImportedTypes_QtGui_QtCore[94].it_td
#define sipEnum_Qt_WindowType sipImportedTypes_QtGui_QtCore[94].it_td->u.td_py_type

#define sipType_Qt_TextElideMode sipImportedTypes_QtGui_QtCore[84].it_td
#define sipEnum_Qt_TextElideMode sipImportedTypes_QtGui_QtCore[84].it_td->u.td_py_type

#define sipType_Qt_SortOrder sipImportedTypes_QtGui_QtCore[82].it_td
#define sipEnum_Qt_SortOrder sipImportedTypes_QtGui_QtCore[82].it_td->u.td_py_type

#define sipType_Qt_Orientation sipImportedTypes_QtGui_QtCore[74].it_td
#define sipEnum_Qt_Orientation sipImportedTypes_QtGui_QtCore[74].it_td->u.td_py_type

#define sipType_Qt_MouseButton sipImportedTypes_QtGui_QtCore[69].it_td
#define sipEnum_Qt_MouseButton sipImportedTypes_QtGui_QtCore[69].it_td->u.td_py_type

#define sipType_Qt_GlobalColor sipImportedTypes_QtGui_QtCore[58].it_td
#define sipEnum_Qt_GlobalColor sipImportedTypes_QtGui_QtCore[58].it_td->u.td_py_type

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtGui_QtCore[65].it_td
#define sipClass_Qt_KeyboardModifiers sipImportedTypes_QtGui_QtCore[65].it_td->u.td_wrapper_type

#define sipType_Qt_MouseButtons sipImportedTypes_QtGui_QtCore[70].it_td
#define sipClass_Qt_MouseButtons sipImportedTypes_QtGui_QtCore[70].it_td->u.td_wrapper_type

#define sipType_Qt_Alignment sipImportedTypes_QtGui_QtCore[43].it_td
#define sipClass_Qt_Alignment sipImportedTypes_QtGui_QtCore[43].it_td->u.td_wrapper_type

#define sipType_Qt_WindowFlags sipImportedTypes_QtGui_QtCore[90].it_td
#define sipClass_Qt_WindowFlags sipImportedTypes_QtGui_QtCore[90].it_td->u.td_wrapper_type

#define sipType_Qt_WindowStates sipImportedTypes_QtGui_QtCore[93].it_td
#define sipClass_Qt_WindowStates sipImportedTypes_QtGui_QtCore[93].it_td->u.td_wrapper_type

#define sipType_Qt_ImageConversionFlags sipImportedTypes_QtGui_QtCore[61].it_td
#define sipClass_Qt_ImageConversionFlags sipImportedTypes_QtGui_QtCore[61].it_td->u.td_wrapper_type

#define sipType_Qt_InputMethodQueries sipImportedTypes_QtGui_QtCore[62].it_td
#define sipClass_Qt_InputMethodQueries sipImportedTypes_QtGui_QtCore[62].it_td->u.td_wrapper_type

#define sipType_Qt_DropActions sipImportedTypes_QtGui_QtCore[54].it_td
#define sipClass_Qt_DropActions sipImportedTypes_QtGui_QtCore[54].it_td->u.td_wrapper_type

#define sipType_Qt_ItemFlags sipImportedTypes_QtGui_QtCore[64].it_td
#define sipClass_Qt_ItemFlags sipImportedTypes_QtGui_QtCore[64].it_td->u.td_wrapper_type

#define sipType_Qt_MatchFlags sipImportedTypes_QtGui_QtCore[68].it_td
#define sipClass_Qt_MatchFlags sipImportedTypes_QtGui_QtCore[68].it_td->u.td_wrapper_type

#define sipType_Qt_TouchPointStates sipImportedTypes_QtGui_QtCore[87].it_td
#define sipClass_Qt_TouchPointStates sipImportedTypes_QtGui_QtCore[87].it_td->u.td_wrapper_type

#define sipType_Qt_ScreenOrientations sipImportedTypes_QtGui_QtCore[79].it_td
#define sipClass_Qt_ScreenOrientations sipImportedTypes_QtGui_QtCore[79].it_td->u.td_wrapper_type

#define sipType_Qt_Edges sipImportedTypes_QtGui_QtCore[55].it_td
#define sipClass_Qt_Edges sipImportedTypes_QtGui_QtCore[55].it_td->u.td_wrapper_type

#define sipType_Qt_MouseEventFlags sipImportedTypes_QtGui_QtCore[71].it_td
#define sipClass_Qt_MouseEventFlags sipImportedTypes_QtGui_QtCore[71].it_td->u.td_wrapper_type

#define sipType_QObject sipImportedTypes_QtGui_QtCore[25].it_td
#define sipClass_QObject sipImportedTypes_QtGui_QtCore[25].it_td->u.td_wrapper_type

#define sipType_QModelIndex sipImportedTypes_QtGui_QtCore[24].it_td
#define sipClass_QModelIndex sipImportedTypes_QtGui_QtCore[24].it_td->u.td_wrapper_type

#define sipType_QAbstractItemModel sipImportedTypes_QtGui_QtCore[0].it_td
#define sipClass_QAbstractItemModel sipImportedTypes_QtGui_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QIODevice sipImportedTypes_QtGui_QtCore[10].it_td
#define sipClass_QIODevice sipImportedTypes_QtGui_QtCore[10].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtGui_QtCore[1].it_td
#define sipClass_QByteArray sipImportedTypes_QtGui_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QCoreApplication sipImportedTypes_QtGui_QtCore[4].it_td
#define sipClass_QCoreApplication sipImportedTypes_QtGui_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtGui_QtCore[6].it_td
#define sipClass_QEvent sipImportedTypes_QtGui_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QEvent_Type sipImportedTypes_QtGui_QtCore[7].it_td
#define sipEnum_QEvent_Type sipImportedTypes_QtGui_QtCore[7].it_td->u.td_py_type

#define sipType_QTimerEvent sipImportedTypes_QtGui_QtCore[38].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtGui_QtCore[38].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtGui_QtCore[3].it_td
#define sipClass_QChildEvent sipImportedTypes_QtGui_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QDataStream sipImportedTypes_QtGui_QtCore[5].it_td
#define sipClass_QDataStream sipImportedTypes_QtGui_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QFile sipImportedTypes_QtGui_QtCore[8].it_td
#define sipClass_QFile sipImportedTypes_QtGui_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QIODevice_OpenMode sipImportedTypes_QtGui_QtCore[11].it_td
#define sipClass_QIODevice_OpenMode sipImportedTypes_QtGui_QtCore[11].it_td->u.td_wrapper_type

#define sipType_QLine sipImportedTypes_QtGui_QtCore[12].it_td
#define sipClass_QLine sipImportedTypes_QtGui_QtCore[12].it_td->u.td_wrapper_type

#define sipType_QLineF sipImportedTypes_QtGui_QtCore[13].it_td
#define sipClass_QLineF sipImportedTypes_QtGui_QtCore[13].it_td->u.td_wrapper_type

#define sipType_QLocale sipImportedTypes_QtGui_QtCore[18].it_td
#define sipClass_QLocale sipImportedTypes_QtGui_QtCore[18].it_td->u.td_wrapper_type

#define sipType_QMargins sipImportedTypes_QtGui_QtCore[20].it_td
#define sipClass_QMargins sipImportedTypes_QtGui_QtCore[20].it_td->u.td_wrapper_type

#define sipType_QMarginsF sipImportedTypes_QtGui_QtCore[21].it_td
#define sipClass_QMarginsF sipImportedTypes_QtGui_QtCore[21].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtGui_QtCore[22].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtGui_QtCore[22].it_td->u.td_wrapper_type

#define sipType_QMimeData sipImportedTypes_QtGui_QtCore[23].it_td
#define sipClass_QMimeData sipImportedTypes_QtGui_QtCore[23].it_td->u.td_wrapper_type

#define sipType_QPoint sipImportedTypes_QtGui_QtCore[27].it_td
#define sipClass_QPoint sipImportedTypes_QtGui_QtCore[27].it_td->u.td_wrapper_type

#define sipType_QPointF sipImportedTypes_QtGui_QtCore[28].it_td
#define sipClass_QPointF sipImportedTypes_QtGui_QtCore[28].it_td->u.td_wrapper_type

#define sipType_QRect sipImportedTypes_QtGui_QtCore[29].it_td
#define sipClass_QRect sipImportedTypes_QtGui_QtCore[29].it_td->u.td_wrapper_type

#define sipType_QRectF sipImportedTypes_QtGui_QtCore[30].it_td
#define sipClass_QRectF sipImportedTypes_QtGui_QtCore[30].it_td->u.td_wrapper_type

#define sipType_QRegExp sipImportedTypes_QtGui_QtCore[31].it_td
#define sipClass_QRegExp sipImportedTypes_QtGui_QtCore[31].it_td->u.td_wrapper_type

#define sipType_QRegularExpression sipImportedTypes_QtGui_QtCore[32].it_td
#define sipClass_QRegularExpression sipImportedTypes_QtGui_QtCore[32].it_td->u.td_wrapper_type

#define sipType_QSize sipImportedTypes_QtGui_QtCore[33].it_td
#define sipClass_QSize sipImportedTypes_QtGui_QtCore[33].it_td->u.td_wrapper_type

#define sipType_QSizeF sipImportedTypes_QtGui_QtCore[34].it_td
#define sipClass_QSizeF sipImportedTypes_QtGui_QtCore[34].it_td->u.td_wrapper_type

#define sipType_QTextCodec sipImportedTypes_QtGui_QtCore[37].it_td
#define sipClass_QTextCodec sipImportedTypes_QtGui_QtCore[37].it_td->u.td_wrapper_type

#define sipType_QUrl sipImportedTypes_QtGui_QtCore[39].it_td
#define sipClass_QUrl sipImportedTypes_QtGui_QtCore[39].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtGui_QtCore[40].it_td
#define sipClass_QVariant sipImportedTypes_QtGui_QtCore[40].it_td->u.td_wrapper_type

#define sipType_QVector_0100QPointF sipImportedTypes_QtGui_QtCore[41].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtGui_QtCore[9].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtGui_QtCore[19].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtGui_QtCore[14].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtGui_QtCore[15].it_td

#define sipType_QPair_1800_1800 sipImportedTypes_QtGui_QtCore[26].it_td

#define sipType_QStringList sipImportedTypes_QtGui_QtCore[36].it_td

#define sipType_QList_2400 sipImportedTypes_QtGui_QtCore[17].it_td

#define sipType_QList_1800 sipImportedTypes_QtGui_QtCore[16].it_td

#define sipType_QString sipImportedTypes_QtGui_QtCore[35].it_td

#define sipType_QChar sipImportedTypes_QtGui_QtCore[2].it_td

#define sipType_quintptr sipImportedTypes_QtGui_QtCore[95].it_td
extern sipImportedTypeDef sipImportedTypes_QtGui_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtGui_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtGui_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtGui_qt_metacast;
#line 173 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontmetrics.sip"
// Used by QFontMetrics and QFontMetricsF.
int *qtgui_tabarray(PyObject *l);
#line 321 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtgui_cleanup_qobjects_t)();
extern pyqt5_qtgui_cleanup_qobjects_t pyqt5_qtgui_cleanup_qobjects;

typedef char **(*pyqt5_qtgui_from_argv_list_t)(PyObject *, int &);
extern pyqt5_qtgui_from_argv_list_t pyqt5_qtgui_from_argv_list;

typedef void (*pyqt5_qtgui_update_argv_list_t)(PyObject *, int, char **);
extern pyqt5_qtgui_update_argv_list_t pyqt5_qtgui_update_argv_list;
#line 267 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimage.sip"
const char **QtGui_ListToArray(PyObject *lst);
void QtGui_DeleteArray(const char **arr);
#line 216 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qmatrix4x4.sip"
// Helpers for the matrix classes.
typedef float PYQT_FLOAT;

sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column);
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values);
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list);
#line 335 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglshaderprogram.sip"
#include "qpyopengl_api.h"
#line 256 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td);
#line 10810 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipAPIQtGui.h"

#endif
