/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtCoreAPI_H
#define _QtCoreAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QCommandLineParser__OptionsAfterPositionalArgumentsMode 0
#define sipName_QCommandLineParser__OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[0]
#define sipNameNr_QCommandLineParser__SingleDashWordOptionMode 56
#define sipName_QCommandLineParser__SingleDashWordOptionMode &sipStrings_QtCore[56]
#define sipNameNr_101 101
#define sipName_101 &sipStrings_QtCore[101]
#define sipNameNr_QXmlStreamReader__ReadElementTextBehaviour 144
#define sipName_QXmlStreamReader__ReadElementTextBehaviour &sipStrings_QtCore[144]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTabletEvents 187
#define sipName_AA_SynthesizeMouseForUnhandledTabletEvents &sipStrings_QtCore[187]
#define sipNameNr_AA_UseStyleSheetPropagationInWidgetStyles 230
#define sipName_AA_UseStyleSheetPropagationInWidgetStyles &sipStrings_QtCore[230]
#define sipNameNr_AA_SynthesizeMouseForUnhandledTouchEvents 272
#define sipName_AA_SynthesizeMouseForUnhandledTouchEvents &sipStrings_QtCore[272]
#define sipNameNr_AA_SynthesizeTouchForUnhandledMouseEvents 314
#define sipName_AA_SynthesizeTouchForUnhandledMouseEvents &sipStrings_QtCore[314]
#define sipNameNr_356 356
#define sipName_356 &sipStrings_QtCore[356]
#define sipNameNr_StateMachineChildModeSetToParallelError 396
#define sipName_StateMachineChildModeSetToParallelError &sipStrings_QtCore[396]
#define sipNameNr_AA_DontCheckOpenGLContextThreadAffinity 436
#define sipName_AA_DontCheckOpenGLContextThreadAffinity &sipStrings_QtCore[436]
#define sipNameNr_476 476
#define sipName_476 &sipStrings_QtCore[476]
#define sipNameNr_QSystemSemaphore__SystemSemaphoreError 515
#define sipName_QSystemSemaphore__SystemSemaphoreError &sipStrings_QtCore[515]
#define sipNameNr_SouthGeorgiaAndTheSouthSandwichIslands 554
#define sipName_SouthGeorgiaAndTheSouthSandwichIslands &sipStrings_QtCore[554]
#define sipNameNr_setOptionsAfterPositionalArgumentsMode 593
#define sipName_setOptionsAfterPositionalArgumentsMode &sipStrings_QtCore[593]
#define sipNameNr_QLocale__FloatingPointPrecisionOption 632
#define sipName_QLocale__FloatingPointPrecisionOption &sipStrings_QtCore[632]
#define sipNameNr_QAbstractItemModel__CheckIndexOptions 670
#define sipName_QAbstractItemModel__CheckIndexOptions &sipStrings_QtCore[670]
#define sipNameNr_708 708
#define sipName_708 &sipStrings_QtCore[708]
#define sipNameNr_QTextBoundaryFinder__BoundaryReasons 745
#define sipName_QTextBoundaryFinder__BoundaryReasons &sipStrings_QtCore[745]
#define sipNameNr_QAbstractItemModel__CheckIndexOption 782
#define sipName_QAbstractItemModel__CheckIndexOption &sipStrings_QtCore[782]
#define sipNameNr_QAbstractItemModel__LayoutChangeHint 819
#define sipName_QAbstractItemModel__LayoutChangeHint &sipStrings_QtCore[819]
#define sipNameNr_Qt__HighDpiScaleFactorRoundingPolicy 856
#define sipName_Qt__HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[856]
#define sipNameNr_QTextBoundaryFinder__BoundaryReason 893
#define sipName_QTextBoundaryFinder__BoundaryReason &sipStrings_QtCore[893]
#define sipNameNr_QItemSelectionModel__SelectionFlags 929
#define sipName_QItemSelectionModel__SelectionFlags &sipStrings_QtCore[929]
#define sipNameNr_QDataStream__FloatingPointPrecision 965
#define sipName_QDataStream__FloatingPointPrecision &sipStrings_QtCore[965]
#define sipNameNr_OptionsAfterPositionalArgumentsMode 20
#define sipName_OptionsAfterPositionalArgumentsMode &sipStrings_QtCore[20]
#define sipNameNr_QCborStreamReader__StringResultCode 1001
#define sipName_QCborStreamReader__StringResultCode &sipStrings_QtCore[1001]
#define sipNameNr_QAbstractTransition__TransitionType 1037
#define sipName_QAbstractTransition__TransitionType &sipStrings_QtCore[1037]
#define sipNameNr_QAbstractEventDispatcher__TimerInfo 1073
#define sipName_QAbstractEventDispatcher__TimerInfo &sipStrings_QtCore[1073]
#define sipNameNr_MaximizeUsingFullscreenGeometryHint 1109
#define sipName_MaximizeUsingFullscreenGeometryHint &sipStrings_QtCore[1109]
#define sipNameNr_NoCommonAncestorForTransitionError 1145
#define sipName_NoCommonAncestorForTransitionError &sipStrings_QtCore[1145]
#define sipNameNr_QRegularExpression__PatternOptions 1180
#define sipName_QRegularExpression__PatternOptions &sipStrings_QtCore[1180]
#define sipNameNr_QItemSelectionModel__SelectionFlag 1215
#define sipName_QItemSelectionModel__SelectionFlag &sipStrings_QtCore[1215]
#define sipNameNr_QAbstractAnimation__DeletionPolicy 1250
#define sipName_QAbstractAnimation__DeletionPolicy &sipStrings_QtCore[1250]
#define sipNameNr_MouseEventSynthesizedByApplication 1285
#define sipName_MouseEventSynthesizedByApplication &sipStrings_QtCore[1285]
#define sipNameNr_AA_DontShowShortcutsInContextMenus 1320
#define sipName_AA_DontShowShortcutsInContextMenus &sipStrings_QtCore[1320]
#define sipNameNr_WA_ContentsMarginsRespectsSafeArea 1355
#define sipName_WA_ContentsMarginsRespectsSafeArea &sipStrings_QtCore[1355]
#define sipNameNr_WA_TouchPadAcceptSingleTouchEvents 1390
#define sipName_WA_TouchPadAcceptSingleTouchEvents &sipStrings_QtCore[1390]
#define sipNameNr_QTextBoundaryFinder__BoundaryType 1425
#define sipName_QTextBoundaryFinder__BoundaryType &sipStrings_QtCore[1425]
#define sipNameNr_NoDefaultStateInHistoryStateError 1459
#define sipName_NoDefaultStateInHistoryStateError &sipStrings_QtCore[1459]
#define sipNameNr_DontCheckSubjectStringMatchOption 1493
#define sipName_DontCheckSubjectStringMatchOption &sipStrings_QtCore[1493]
#define sipNameNr_QRegularExpression__PatternOption 1527
#define sipName_QRegularExpression__PatternOption &sipStrings_QtCore[1527]
#define sipNameNr_AA_DisableWindowContextHelpButton 1561
#define sipName_AA_DisableWindowContextHelpButton &sipStrings_QtCore[1561]
#define sipNameNr_AA_DontCreateNativeWidgetSiblings 1595
#define sipName_AA_DontCreateNativeWidgetSiblings &sipStrings_QtCore[1595]
#define sipNameNr_WA_X11NetWmWindowTypeNotification 1629
#define sipName_WA_X11NetWmWindowTypeNotification &sipStrings_QtCore[1629]
#define sipNameNr_WA_X11NetWmWindowTypeDropDownMenu 1663
#define sipName_WA_X11NetWmWindowTypeDropDownMenu &sipStrings_QtCore[1663]
#define sipNameNr_QUrl__UserInputResolutionOptions 1697
#define sipName_QUrl__UserInputResolutionOptions &sipStrings_QtCore[1697]
#define sipNameNr_QUrl__ComponentFormattingOptions 1730
#define sipName_QUrl__ComponentFormattingOptions &sipStrings_QtCore[1730]
#define sipNameNr_QStandardPaths__StandardLocation 1763
#define sipName_QStandardPaths__StandardLocation &sipStrings_QtCore[1763]
#define sipNameNr_recursiveFilteringEnabledChanged 1796
#define sipName_recursiveFilteringEnabledChanged &sipStrings_QtCore[1796]
#define sipNameNr_QSharedMemory__SharedMemoryError 1829
#define sipName_QSharedMemory__SharedMemoryError &sipStrings_QtCore[1829]
#define sipNameNr_QRegularExpression__MatchOptions 1862
#define sipName_QRegularExpression__MatchOptions &sipStrings_QtCore[1862]
#define sipNameNr_UnitedStatesMinorOutlyingIslands 1895
#define sipName_UnitedStatesMinorOutlyingIslands &sipStrings_QtCore[1895]
#define sipNameNr_NonClientAreaMouseButtonDblClick 1928
#define sipName_NonClientAreaMouseButtonDblClick &sipStrings_QtCore[1928]
#define sipNameNr_ApplicationLayoutDirectionChange 1961
#define sipName_ApplicationLayoutDirectionChange &sipStrings_QtCore[1961]
#define sipNameNr_QByteArray__Base64DecodingStatus 1994
#define sipName_QByteArray__Base64DecodingStatus &sipStrings_QtCore[1994]
#define sipNameNr_HighDpiScaleFactorRoundingPolicy 860
#define sipName_HighDpiScaleFactorRoundingPolicy &sipStrings_QtCore[860]
#define sipNameNr_NavigationModeCursorForceVisible 2027
#define sipName_NavigationModeCursorForceVisible &sipStrings_QtCore[2027]
#define sipNameNr_IgnoredGesturesPropagateToParent 2060
#define sipName_IgnoredGesturesPropagateToParent &sipStrings_QtCore[2060]
#define sipNameNr_AA_MSWindowsUseDirect3DByDefault 2093
#define sipName_AA_MSWindowsUseDirect3DByDefault &sipStrings_QtCore[2093]
#define sipNameNr_2126 2126
#define sipName_2126 &sipStrings_QtCore[2126]
#define sipNameNr_QUrl__UserInputResolutionOption 2158
#define sipName_QUrl__UserInputResolutionOption &sipStrings_QtCore[2158]
#define sipNameNr_QUrl__ComponentFormattingOption 2190
#define sipName_QUrl__ComponentFormattingOption &sipStrings_QtCore[2190]
#define sipNameNr_QTextStream__RealNumberNotation 2222
#define sipName_QTextStream__RealNumberNotation &sipStrings_QtCore[2222]
#define sipNameNr_QRegularExpressionMatchIterator 2254
#define sipName_QRegularExpressionMatchIterator &sipStrings_QtCore[2254]
#define sipNameNr_QRegularExpression__MatchOption 2286
#define sipName_QRegularExpression__MatchOption &sipStrings_QtCore[2286]
#define sipNameNr_DontAutomaticallyOptimizeOption 2318
#define sipName_DontAutomaticallyOptimizeOption &sipStrings_QtCore[2318]
#define sipNameNr_QOperatingSystemVersion__OSType 2350
#define sipName_QOperatingSystemVersion__OSType &sipStrings_QtCore[2350]
#define sipNameNr_QDeadlineTimer__ForeverConstant 2382
#define sipName_QDeadlineTimer__ForeverConstant &sipStrings_QtCore[2382]
#define sipNameNr_NonClientAreaMouseButtonRelease 2414
#define sipName_NonClientAreaMouseButtonRelease &sipStrings_QtCore[2414]
#define sipNameNr_NavigationModeKeypadDirectional 2446
#define sipName_NavigationModeKeypadDirectional &sipStrings_QtCore[2446]
#define sipNameNr_AA_DisableNativeVirtualKeyboard 2478
#define sipName_AA_DisableNativeVirtualKeyboard &sipStrings_QtCore[2478]
#define sipNameNr_2510 2510
#define sipName_2510 &sipStrings_QtCore[2510]
#define sipNameNr_2541 2541
#define sipName_2541 &sipStrings_QtCore[2541]
#define sipNameNr_QXmlStreamNamespaceDeclaration 2572
#define sipName_QXmlStreamNamespaceDeclaration &sipStrings_QtCore[2572]
#define sipNameNr_QEventLoop__ProcessEventsFlags 2603
#define sipName_QEventLoop__ProcessEventsFlags &sipStrings_QtCore[2603]
#define sipNameNr_AA_CompressHighFrequencyEvents 2634
#define sipName_AA_CompressHighFrequencyEvents &sipStrings_QtCore[2634]
#define sipNameNr_WA_X11NetWmWindowTypePopupMenu 2665
#define sipName_WA_X11NetWmWindowTypePopupMenu &sipStrings_QtCore[2665]
#define sipNameNr_addExtraNamespaceDeclarations 2696
#define sipName_addExtraNamespaceDeclarations &sipStrings_QtCore[2696]
#define sipNameNr_QXmlStreamNotationDeclaration 2726
#define sipName_QXmlStreamNotationDeclaration &sipStrings_QtCore[2726]
#define sipNameNr_QStandardPaths__LocateOptions 2756
#define sipName_QStandardPaths__LocateOptions &sipStrings_QtCore[2756]
#define sipNameNr_QRegularExpression__MatchType 2786
#define sipName_QRegularExpression__MatchType &sipStrings_QtCore[2786]
#define sipNameNr_QReadWriteLock__RecursionMode 2816
#define sipName_QReadWriteLock__RecursionMode &sipStrings_QtCore[2816]
#define sipNameNr_QLocale__CurrencySymbolFormat 2846
#define sipName_QLocale__CurrencySymbolFormat &sipStrings_QtCore[2846]
#define sipNameNr_IncludeTrailingZeroesAfterDot 2876
#define sipName_IncludeTrailingZeroesAfterDot &sipStrings_QtCore[2876]
#define sipNameNr_QLibraryInfo__LibraryLocation 2906
#define sipName_QLibraryInfo__LibraryLocation &sipStrings_QtCore[2906]
#define sipNameNr_QJsonDocument__DataValidation 2936
#define sipName_QJsonDocument__DataValidation &sipStrings_QtCore[2936]
#define sipNameNr_QEventLoop__ProcessEventsFlag 2966
#define sipName_QEventLoop__ProcessEventsFlag &sipStrings_QtCore[2966]
#define sipNameNr_QCryptographicHash__Algorithm 2996
#define sipName_QCryptographicHash__Algorithm &sipStrings_QtCore[2996]
#define sipNameNr_NonClientAreaMouseButtonPress 3026
#define sipName_NonClientAreaMouseButtonPress &sipStrings_QtCore[3026]
#define sipNameNr_GraphicsSceneMouseDoubleClick 3056
#define sipName_GraphicsSceneMouseDoubleClick &sipStrings_QtCore[3056]
#define sipNameNr_QAbstractAnimation__Direction 3086
#define sipName_QAbstractAnimation__Direction &sipStrings_QtCore[3086]
#define sipNameNr_MouseEventSynthesizedBySystem 3116
#define sipName_MouseEventSynthesizedBySystem &sipStrings_QtCore[3116]
#define sipNameNr_WindowOverridesSystemGestures 3146
#define sipName_WindowOverridesSystemGestures &sipStrings_QtCore[3146]
#define sipNameNr_3176 3176
#define sipName_3176 &sipStrings_QtCore[3176]
#define sipNameNr_addExtraNamespaceDeclaration 3205
#define sipName_addExtraNamespaceDeclaration &sipStrings_QtCore[3205]
#define sipNameNr_QSystemSemaphore__AccessMode 3234
#define sipName_QSystemSemaphore__AccessMode &sipStrings_QtCore[3234]
#define sipNameNr_QStateMachine__EventPriority 3263
#define sipName_QStateMachine__EventPriority &sipStrings_QtCore[3263]
#define sipNameNr_QStandardPaths__LocateOption 3292
#define sipName_QStandardPaths__LocateOption &sipStrings_QtCore[3292]
#define sipNameNr_filterCaseSensitivityChanged 3321
#define sipName_filterCaseSensitivityChanged &sipStrings_QtCore[3321]
#define sipNameNr_setRecursiveFilteringEnabled 3350
#define sipName_setRecursiveFilteringEnabled &sipStrings_QtCore[3350]
#define sipNameNr_QProcess__ProcessChannelMode 3379
#define sipName_QProcess__ProcessChannelMode &sipStrings_QtCore[3379]
#define sipNameNr_FloatingPointPrecisionOption 641
#define sipName_FloatingPointPrecisionOption &sipStrings_QtCore[641]
#define sipNameNr_RejectTrailingZeroesAfterDot 3408
#define sipName_RejectTrailingZeroesAfterDot &sipStrings_QtCore[3408]
#define sipNameNr_SaintVincentAndTheGrenadines 3437
#define sipName_SaintVincentAndTheGrenadines &sipStrings_QtCore[3437]
#define sipNameNr_QFileDevice__FileHandleFlags 3466
#define sipName_QFileDevice__FileHandleFlags &sipStrings_QtCore[3466]
#define sipNameNr_QConcatenateTablesProxyModel 3495
#define sipName_QConcatenateTablesProxyModel &sipStrings_QtCore[3495]
#define sipNameNr_ParseAsCompactedShortOptions 3524
#define sipName_ParseAsCompactedShortOptions &sipStrings_QtCore[3524]
#define sipNameNr_QByteArray__FromBase64Result 3553
#define sipName_QByteArray__FromBase64Result &sipStrings_QtCore[3553]
#define sipNameNr_MouseEventCreatedDoubleClick 3582
#define sipName_MouseEventCreatedDoubleClick &sipStrings_QtCore[3582]
#define sipNameNr_InvertedLandscapeOrientation 3611
#define sipName_InvertedLandscapeOrientation &sipStrings_QtCore[3611]
#define sipNameNr_NavigationModeKeypadTabOrder 3640
#define sipName_NavigationModeKeypadTabOrder &sipStrings_QtCore[3640]
#define sipNameNr_WA_X11NetWmWindowTypeToolTip 3669
#define sipName_WA_X11NetWmWindowTypeToolTip &sipStrings_QtCore[3669]
#define sipNameNr_WA_X11NetWmWindowTypeUtility 3698
#define sipName_WA_X11NetWmWindowTypeUtility &sipStrings_QtCore[3698]
#define sipNameNr_WA_X11NetWmWindowTypeToolBar 3727
#define sipName_WA_X11NetWmWindowTypeToolBar &sipStrings_QtCore[3727]
#define sipNameNr_WA_X11NetWmWindowTypeDesktop 3756
#define sipName_WA_X11NetWmWindowTypeDesktop &sipStrings_QtCore[3756]
#define sipNameNr_WA_DontCreateNativeAncestors 3785
#define sipName_WA_DontCreateNativeAncestors &sipStrings_QtCore[3785]
#define sipNameNr_WA_TransparentForMouseEvents 3814
#define sipName_WA_TransparentForMouseEvents &sipStrings_QtCore[3814]
#define sipNameNr_WA_NoChildEventsFromChildren 3843
#define sipName_WA_NoChildEventsFromChildren &sipStrings_QtCore[3843]
#define sipNameNr_MSWindowsFixedSizeDialogHint 3872
#define sipName_MSWindowsFixedSizeDialogHint &sipStrings_QtCore[3872]
#define sipNameNr_3901 3901
#define sipName_3901 &sipStrings_QtCore[3901]
#define sipNameNr_PrematureEndOfDocumentError 3929
#define sipName_PrematureEndOfDocumentError &sipStrings_QtCore[3929]
#define sipNameNr_processingInstructionTarget 3957
#define sipName_processingInstructionTarget &sipStrings_QtCore[3957]
#define sipNameNr_QXmlStreamReader__TokenType 3985
#define sipName_QXmlStreamReader__TokenType &sipStrings_QtCore[3985]
#define sipNameNr_QXmlStreamEntityDeclaration 4013
#define sipName_QXmlStreamEntityDeclaration &sipStrings_QtCore[4013]
#define sipNameNr_QTextStream__FieldAlignment 4041
#define sipName_QTextStream__FieldAlignment &sipStrings_QtCore[4041]
#define sipNameNr_QTextCodec__ConversionFlags 4069
#define sipName_QTextCodec__ConversionFlags &sipStrings_QtCore[4069]
#define sipNameNr_QStateMachine__WrappedEvent 4097
#define sipName_QStateMachine__WrappedEvent &sipStrings_QtCore[4097]
#define sipNameNr_isRecursiveFilteringEnabled 4125
#define sipName_isRecursiveFilteringEnabled &sipStrings_QtCore[4125]
#define sipNameNr_wildcardToRegularExpression 4153
#define sipName_wildcardToRegularExpression &sipStrings_QtCore[4153]
#define sipNameNr_ExtendedPatternSyntaxOption 4181
#define sipName_ExtendedPatternSyntaxOption &sipStrings_QtCore[4181]
#define sipNameNr_InscriptionalParthianScript 4209
#define sipName_InscriptionalParthianScript &sipStrings_QtCore[4209]
#define sipNameNr_RejectLeadingZeroInExponent 4237
#define sipName_RejectLeadingZeroInExponent &sipStrings_QtCore[4237]
#define sipNameNr_LatinAmericaAndTheCaribbean 4265
#define sipName_LatinAmericaAndTheCaribbean &sipStrings_QtCore[4265]
#define sipNameNr_BritishIndianOceanTerritory 4293
#define sipName_BritishIndianOceanTerritory &sipStrings_QtCore[4293]
#define sipNameNr_QJsonParseError__ParseError 4321
#define sipName_QJsonParseError__ParseError &sipStrings_QtCore[4321]
#define sipNameNr_QFileDevice__MemoryMapFlags 4349
#define sipName_QFileDevice__MemoryMapFlags &sipStrings_QtCore[4349]
#define sipNameNr_QFileDevice__FileHandleFlag 4377
#define sipName_QFileDevice__FileHandleFlag &sipStrings_QtCore[4377]
#define sipNameNr_QDirIterator__IteratorFlags 4405
#define sipName_QDirIterator__IteratorFlags &sipStrings_QtCore[4405]
#define sipNameNr_QDynamicPropertyChangeEvent 4433
#define sipName_QDynamicPropertyChangeEvent &sipStrings_QtCore[4433]
#define sipNameNr_ApplicationWindowIconChange 4461
#define sipName_ApplicationWindowIconChange &sipStrings_QtCore[4461]
#define sipNameNr_setSingleDashWordOptionMode 4489
#define sipName_setSingleDashWordOptionMode &sipStrings_QtCore[4489]
#define sipNameNr_AbortOnBase64DecodingErrors 4517
#define sipName_AbortOnBase64DecodingErrors &sipStrings_QtCore[4517]
#define sipNameNr_InvertedPortraitOrientation 4545
#define sipName_InvertedPortraitOrientation &sipStrings_QtCore[4545]
#define sipNameNr_Key_Dead_Longsolidusoverlay 4573
#define sipName_Key_Dead_Longsolidusoverlay &sipStrings_QtCore[4573]
#define sipNameNr_Key_Dead_Abovereversedcomma 4601
#define sipName_Key_Dead_Abovereversedcomma &sipStrings_QtCore[4601]
#define sipNameNr_WA_X11NetWmWindowTypeDialog 4629
#define sipName_WA_X11NetWmWindowTypeDialog &sipStrings_QtCore[4629]
#define sipNameNr_WA_X11NetWmWindowTypeSplash 4657
#define sipName_WA_X11NetWmWindowTypeSplash &sipStrings_QtCore[4657]
#define sipNameNr_WindowContextHelpButtonHint 4685
#define sipName_WindowContextHelpButtonHint &sipStrings_QtCore[4685]
#define sipNameNr_4713 4713
#define sipName_4713 &sipStrings_QtCore[4713]
#define sipNameNr_4740 4740
#define sipName_4740 &sipStrings_QtCore[4740]
#define sipNameNr_writeProcessingInstruction 4767
#define sipName_writeProcessingInstruction &sipStrings_QtCore[4767]
#define sipNameNr_defaultQueryValueDelimiter 4794
#define sipName_defaultQueryValueDelimiter &sipStrings_QtCore[4794]
#define sipNameNr_UserInputResolutionOptions 1703
#define sipName_UserInputResolutionOptions &sipStrings_QtCore[1703]
#define sipNameNr_ComponentFormattingOptions 1736
#define sipName_ComponentFormattingOptions &sipStrings_QtCore[1736]
#define sipNameNr_QTextCodec__ConverterState 4821
#define sipName_QTextCodec__ConverterState &sipStrings_QtCore[4821]
#define sipNameNr_QTextCodec__ConversionFlag 4848
#define sipName_QTextCodec__ConversionFlag &sipStrings_QtCore[4848]
#define sipNameNr_QStateMachine__SignalEvent 4875
#define sipName_QStateMachine__SignalEvent &sipStrings_QtCore[4875]
#define sipNameNr_sortCaseSensitivityChanged 4902
#define sipName_sortCaseSensitivityChanged &sipStrings_QtCore[4902]
#define sipNameNr_setFilterRegularExpression 4929
#define sipName_setFilterRegularExpression &sipStrings_QtCore[4929]
#define sipNameNr_PartialPreferCompleteMatch 4956
#define sipName_PartialPreferCompleteMatch &sipStrings_QtCore[4956]
#define sipNameNr_OptimizeOnFirstUsageOption 4983
#define sipName_OptimizeOnFirstUsageOption &sipStrings_QtCore[4983]
#define sipNameNr_UseUnicodePropertiesOption 5010
#define sipName_UseUnicodePropertiesOption &sipStrings_QtCore[5010]
#define sipNameNr_DotMatchesEverythingOption 5037
#define sipName_DotMatchesEverythingOption &sipStrings_QtCore[5037]
#define sipNameNr_QProcess__InputChannelMode 5064
#define sipName_QProcess__InputChannelMode &sipStrings_QtCore[5064]
#define sipNameNr_mimeTypeForFileNameAndData 5091
#define sipName_mimeTypeForFileNameAndData &sipStrings_QtCore[5091]
#define sipNameNr_QMessageAuthenticationCode 5118
#define sipName_QMessageAuthenticationCode &sipStrings_QtCore[5118]
#define sipNameNr_AnatolianHieroglyphsScript 5145
#define sipName_AnatolianHieroglyphsScript &sipStrings_QtCore[5145]
#define sipNameNr_InscriptionalPahlaviScript 5172
#define sipName_InscriptionalPahlaviScript &sipStrings_QtCore[5172]
#define sipNameNr_QLocale__MeasurementSystem 5199
#define sipName_QLocale__MeasurementSystem &sipStrings_QtCore[5199]
#define sipNameNr_SvalbardAndJanMayenIslands 5226
#define sipName_SvalbardAndJanMayenIslands &sipStrings_QtCore[5226]
#define sipNameNr_QHistoryState__HistoryType 5253
#define sipName_QHistoryState__HistoryType &sipStrings_QtCore[5253]
#define sipNameNr_QDirIterator__IteratorFlag 5280
#define sipName_QDirIterator__IteratorFlag &sipStrings_QtCore[5280]
#define sipNameNr_ParseAsPositionalArguments 5307
#define sipName_ParseAsPositionalArguments &sipStrings_QtCore[5307]
#define sipNameNr_IgnoreBase64DecodingErrors 5334
#define sipName_IgnoreBase64DecodingErrors &sipStrings_QtCore[5334]
#define sipNameNr_QAbstractNativeEventFilter 5361
#define sipName_QAbstractNativeEventFilter &sipStrings_QtCore[5361]
#define sipNameNr_Qt__ItemSelectionOperation 5388
#define sipName_Qt__ItemSelectionOperation &sipStrings_QtCore[5388]
#define sipNameNr_DontStartGestureOnChildren 5415
#define sipName_DontStartGestureOnChildren &sipStrings_QtCore[5415]
#define sipNameNr_IntersectsItemBoundingRect 5442
#define sipName_IntersectsItemBoundingRect &sipStrings_QtCore[5442]
#define sipNameNr_AA_ImmediateWidgetCreation 5469
#define sipName_AA_ImmediateWidgetCreation &sipStrings_QtCore[5469]
#define sipNameNr_WidgetWithChildrenShortcut 5496
#define sipName_WidgetWithChildrenShortcut &sipStrings_QtCore[5496]
#define sipNameNr_KeepAspectRatioByExpanding 5523
#define sipName_KeepAspectRatioByExpanding &sipStrings_QtCore[5523]
#define sipNameNr_Key_Dead_Belowverticalline 5550
#define sipName_Key_Dead_Belowverticalline &sipStrings_QtCore[5550]
#define sipNameNr_Key_Dead_Aboveverticalline 5577
#define sipName_Key_Dead_Aboveverticalline &sipStrings_QtCore[5577]
#define sipNameNr_Key_KeyboardBrightnessDown 5604
#define sipName_Key_KeyboardBrightnessDown &sipStrings_QtCore[5604]
#define sipNameNr_WA_X11NetWmWindowTypeCombo 5631
#define sipName_WA_X11NetWmWindowTypeCombo &sipStrings_QtCore[5631]
#define sipNameNr_WA_MacAlwaysShowToolWindow 5658
#define sipName_WA_MacAlwaysShowToolWindow &sipStrings_QtCore[5658]
#define sipNameNr_WA_WState_ExplicitShowHide 5685
#define sipName_WA_WState_ExplicitShowHide &sipStrings_QtCore[5685]
#define sipNameNr_WindowFullscreenButtonHint 5712
#define sipName_WindowFullscreenButtonHint &sipStrings_QtCore[5712]
#define sipNameNr_MacWindowToolBarButtonHint 5739
#define sipName_MacWindowToolBarButtonHint &sipStrings_QtCore[5739]
#define sipNameNr_X11BypassWindowManagerHint 5766
#define sipName_X11BypassWindowManagerHint &sipStrings_QtCore[5766]
#define sipNameNr_5793 5793
#define sipName_5793 &sipStrings_QtCore[5793]
#define sipNameNr_processingInstructionData 5819
#define sipName_processingInstructionData &sipStrings_QtCore[5819]
#define sipNameNr_defaultQueryPairDelimiter 5845
#define sipName_defaultQueryPairDelimiter &sipStrings_QtCore[5845]
#define sipNameNr_UserInputResolutionOption 2164
#define sipName_UserInputResolutionOption &sipStrings_QtCore[2164]
#define sipNameNr_ComponentFormattingOption 2196
#define sipName_ComponentFormattingOption &sipStrings_QtCore[2196]
#define sipNameNr_QUrl__UrlFormattingOption 5871
#define sipName_QUrl__UrlFormattingOption &sipStrings_QtCore[5871]
#define sipNameNr_QSharedMemory__AccessMode 5897
#define sipName_QSharedMemory__AccessMode &sipStrings_QtCore[5897]
#define sipNameNr_QSequentialAnimationGroup 5923
#define sipName_QSequentialAnimationGroup &sipStrings_QtCore[5923]
#define sipNameNr_DataSizeTraditionalFormat 5949
#define sipName_DataSizeTraditionalFormat &sipStrings_QtCore[5949]
#define sipNameNr_EgyptianHieroglyphsScript 5975
#define sipName_EgyptianHieroglyphsScript &sipStrings_QtCore[5975]
#define sipNameNr_OmitLeadingZeroInExponent 6001
#define sipName_OmitLeadingZeroInExponent &sipStrings_QtCore[6001]
#define sipNameNr_UnitedStatesVirginIslands 6027
#define sipName_UnitedStatesVirginIslands &sipStrings_QtCore[6027]
#define sipNameNr_DemocraticRepublicOfKorea 6053
#define sipName_DemocraticRepublicOfKorea &sipStrings_QtCore[6053]
#define sipNameNr_FrenchSouthernTerritories 6079
#define sipName_FrenchSouthernTerritories &sipStrings_QtCore[6079]
#define sipNameNr_DemocraticRepublicOfCongo 6105
#define sipName_DemocraticRepublicOfCongo &sipStrings_QtCore[6105]
#define sipNameNr_StandardMoroccanTamazight 6131
#define sipName_StandardMoroccanTamazight &sipStrings_QtCore[6131]
#define sipNameNr_ExportExternalSymbolsHint 6157
#define sipName_ExportExternalSymbolsHint &sipStrings_QtCore[6157]
#define sipNameNr_QJsonDocument__JsonFormat 6183
#define sipName_QJsonDocument__JsonFormat &sipStrings_QtCore[6183]
#define sipNameNr_columnIntersectsSelection 6209
#define sipName_columnIntersectsSelection &sipStrings_QtCore[6209]
#define sipNameNr_setFloatingPointPrecision 6235
#define sipName_setFloatingPointPrecision &sipStrings_QtCore[6235]
#define sipNameNr_RequestSoftwareInputPanel 6261
#define sipName_RequestSoftwareInputPanel &sipStrings_QtCore[6261]
#define sipNameNr_GraphicsSceneMouseRelease 6287
#define sipName_GraphicsSceneMouseRelease &sipStrings_QtCore[6287]
#define sipNameNr_setApplicationDescription 6313
#define sipName_setApplicationDescription &sipStrings_QtCore[6313]
#define sipNameNr_QCommandLineOption__Flags 6339
#define sipName_QCommandLineOption__Flags &sipStrings_QtCore[6339]
#define sipNameNr_QByteArray__Base64Options 6365
#define sipName_QByteArray__Base64Options &sipStrings_QtCore[6365]
#define sipNameNr_changePersistentIndexList 6391
#define sipName_changePersistentIndexList &sipStrings_QtCore[6391]
#define sipNameNr_QAbstractAnimation__State 6417
#define sipName_QAbstractAnimation__State &sipStrings_QtCore[6417]
#define sipNameNr_MouseEventSynthesizedByQt 6443
#define sipName_MouseEventSynthesizedByQt &sipStrings_QtCore[6443]
#define sipNameNr_ImhDialableCharactersOnly 6469
#define sipName_ImhDialableCharactersOnly &sipStrings_QtCore[6469]
#define sipNameNr_LinksAccessibleByKeyboard 6495
#define sipName_LinksAccessibleByKeyboard &sipStrings_QtCore[6495]
#define sipNameNr_AA_DisableShaderDiskCache 6521
#define sipName_AA_DisableShaderDiskCache &sipStrings_QtCore[6521]
#define sipNameNr_AA_MacDontSwapCtrlAndMeta 6547
#define sipName_AA_MacDontSwapCtrlAndMeta &sipStrings_QtCore[6547]
#define sipNameNr_AccessibleDescriptionRole 6573
#define sipName_AccessibleDescriptionRole &sipStrings_QtCore[6573]
#define sipNameNr_Key_Dead_Semivoiced_Sound 6599
#define sipName_Key_Dead_Semivoiced_Sound &sipStrings_QtCore[6599]
#define sipNameNr_WA_X11NetWmWindowTypeMenu 6625
#define sipName_WA_X11NetWmWindowTypeMenu &sipStrings_QtCore[6625]
#define sipNameNr_WA_X11NetWmWindowTypeDock 6651
#define sipName_WA_X11NetWmWindowTypeDock &sipStrings_QtCore[6651]
#define sipNameNr_WA_InputMethodTransparent 6677
#define sipName_WA_InputMethodTransparent &sipStrings_QtCore[6677]
#define sipNameNr_WA_NoChildEventsForParent 6703
#define sipName_WA_NoChildEventsForParent &sipStrings_QtCore[6703]
#define sipNameNr_WindowTransparentForInput 6729
#define sipName_WindowTransparentForInput &sipStrings_QtCore[6729]
#define sipNameNr_BypassGraphicsProxyWidget 6755
#define sipName_BypassGraphicsProxyWidget &sipStrings_QtCore[6755]
#define sipNameNr_TextIncludeTrailingSpaces 6781
#define sipName_TextIncludeTrailingSpaces &sipStrings_QtCore[6781]
#define sipNameNr_ErrorOnUnexpectedElement 6807
#define sipName_ErrorOnUnexpectedElement &sipStrings_QtCore[6807]
#define sipNameNr_ReadElementTextBehaviour 162
#define sipName_ReadElementTextBehaviour &sipStrings_QtCore[162]
#define sipNameNr_QXmlStreamEntityResolver 6832
#define sipName_QXmlStreamEntityResolver &sipStrings_QtCore[6832]
#define sipNameNr_windowsIdToDefaultIanaId 6857
#define sipName_windowsIdToDefaultIanaId &sipStrings_QtCore[6857]
#define sipNameNr_setGenerateByteOrderMark 6882
#define sipName_setGenerateByteOrderMark &sipStrings_QtCore[6882]
#define sipNameNr_QTextStream__NumberFlags 6907
#define sipName_QTextStream__NumberFlags &sipStrings_QtCore[6907]
#define sipNameNr_dynamicSortFilterChanged 6932
#define sipName_dynamicSortFilterChanged &sipStrings_QtCore[6932]
#define sipNameNr_setFilterCaseSensitivity 6957
#define sipName_setFilterCaseSensitivity &sipStrings_QtCore[6957]
#define sipNameNr_InvertedGreedinessOption 6982
#define sipName_InvertedGreedinessOption &sipStrings_QtCore[6982]
#define sipNameNr_setStandardOutputProcess 7007
#define sipName_setStandardOutputProcess &sipStrings_QtCore[7007]
#define sipNameNr_QProcess__ProcessChannel 7032
#define sipName_QProcess__ProcessChannel &sipStrings_QtCore[7032]
#define sipNameNr_QMimeDatabase__MatchMode 7057
#define sipName_QMimeDatabase__MatchMode &sipStrings_QtCore[7057]
#define sipNameNr_QLocale__DataSizeFormats 7082
#define sipName_QLocale__DataSizeFormats &sipStrings_QtCore[7082]
#define sipNameNr_CanadianAboriginalScript 7107
#define sipName_CanadianAboriginalScript &sipStrings_QtCore[7107]
#define sipNameNr_TraditionalChineseScript 7132
#define sipName_TraditionalChineseScript &sipStrings_QtCore[7132]
#define sipNameNr_defaultTransitionChanged 7157
#define sipName_defaultTransitionChanged &sipStrings_QtCore[7157]
#define sipNameNr_QFileDevice__Permissions 7182
#define sipName_QFileDevice__Permissions &sipStrings_QtCore[7182]
#define sipNameNr_QElapsedTimer__ClockType 7207
#define sipName_QElapsedTimer__ClockType &sipStrings_QtCore[7207]
#define sipNameNr_fromMSecsSinceStartOfDay 7232
#define sipName_fromMSecsSinceStartOfDay &sipStrings_QtCore[7232]
#define sipNameNr_GraphicsSceneContextMenu 7257
#define sipName_GraphicsSceneContextMenu &sipStrings_QtCore[7257]
#define sipNameNr_ApplicationPaletteChange 7282
#define sipName_ApplicationPaletteChange &sipStrings_QtCore[7282]
#define sipNameNr_clearPositionalArguments 7307
#define sipName_clearPositionalArguments &sipStrings_QtCore[7307]
#define sipNameNr_SingleDashWordOptionMode 76
#define sipName_SingleDashWordOptionMode &sipStrings_QtCore[76]
#define sipNameNr_QCommandLineOption__Flag 7332
#define sipName_QCommandLineOption__Flag &sipStrings_QtCore[7332]
#define sipNameNr_QByteArray__Base64Option 7357
#define sipName_QByteArray__Base64Option &sipStrings_QtCore[7357]
#define sipNameNr_columnsAboutToBeInserted 7382
#define sipName_columnsAboutToBeInserted &sipStrings_QtCore[7382]
#define sipNameNr_installNativeEventFilter 7407
#define sipName_installNativeEventFilter &sipStrings_QtCore[7407]
#define sipNameNr_unregisterSocketNotifier 7432
#define sipName_unregisterSocketNotifier &sipStrings_QtCore[7432]
#define sipNameNr_QAbstractEventDispatcher 7457
#define sipName_QAbstractEventDispatcher &sipStrings_QtCore[7457]
#define sipNameNr_MouseEventNotSynthesized 7482
#define sipName_MouseEventNotSynthesized &sipStrings_QtCore[7482]
#define sipNameNr_NavigationModeCursorAuto 7507
#define sipName_NavigationModeCursorAuto &sipStrings_QtCore[7507]
#define sipNameNr_Qt__TextInteractionFlags 7532
#define sipName_Qt__TextInteractionFlags &sipStrings_QtCore[7532]
#define sipNameNr_TextSelectableByKeyboard 7557
#define sipName_TextSelectableByKeyboard &sipStrings_QtCore[7557]
#define sipNameNr_ContainsItemBoundingRect 7582
#define sipName_ContainsItemBoundingRect &sipStrings_QtCore[7582]
#define sipNameNr_AA_DisableSessionManager 7607
#define sipName_AA_DisableSessionManager &sipStrings_QtCore[7607]
#define sipNameNr_AA_DisableHighDpiScaling 7632
#define sipName_AA_DisableHighDpiScaling &sipStrings_QtCore[7632]
#define sipNameNr_Qt__ApplicationAttribute 7657
#define sipName_Qt__ApplicationAttribute &sipStrings_QtCore[7657]
#define sipNameNr_ToolButtonTextBesideIcon 7682
#define sipName_ToolButtonTextBesideIcon &sipStrings_QtCore[7682]
#define sipNameNr_ImInputItemClipRectangle 7707
#define sipName_ImInputItemClipRectangle &sipStrings_QtCore[7707]
#define sipNameNr_BlockingQueuedConnection 7732
#define sipName_BlockingQueuedConnection &sipStrings_QtCore[7732]
#define sipNameNr_Key_Dead_Belowcircumflex 7757
#define sipName_Key_Dead_Belowcircumflex &sipStrings_QtCore[7757]
#define sipNameNr_Key_MediaTogglePlayPause 7782
#define sipName_Key_MediaTogglePlayPause &sipStrings_QtCore[7782]
#define sipNameNr_Key_KeyboardBrightnessUp 7807
#define sipName_Key_KeyboardBrightnessUp &sipStrings_QtCore[7807]
#define sipNameNr_Qt__ImageConversionFlags 7832
#define sipName_Qt__ImageConversionFlags &sipStrings_QtCore[7832]
#define sipNameNr_WA_TranslucentBackground 7857
#define sipName_WA_TranslucentBackground &sipStrings_QtCore[7857]
#define sipNameNr_WA_X11NetWmWindowTypeDND 7882
#define sipName_WA_X11NetWmWindowTypeDND &sipStrings_QtCore[7882]
#define sipNameNr_WA_ShowWithoutActivating 7907
#define sipName_WA_ShowWithoutActivating &sipStrings_QtCore[7907]
#define sipNameNr_WA_NoX11EventCompression 7932
#define sipName_WA_NoX11EventCompression &sipStrings_QtCore[7932]
#define sipNameNr_WindowDoesNotAcceptFocus 7957
#define sipName_WindowDoesNotAcceptFocus &sipStrings_QtCore[7957]
#define sipNameNr_WindowMaximizeButtonHint 7982
#define sipName_WindowMaximizeButtonHint &sipStrings_QtCore[7982]
#define sipNameNr_WindowMinimizeButtonHint 8007
#define sipName_WindowMinimizeButtonHint &sipStrings_QtCore[8007]
#define sipNameNr_8032 8032
#define sipName_8032 &sipStrings_QtCore[8032]
#define sipNameNr_setAutoFormattingIndent 8056
#define sipName_setAutoFormattingIndent &sipStrings_QtCore[8056]
#define sipNameNr_setEntityExpansionLimit 8080
#define sipName_setEntityExpansionLimit &sipStrings_QtCore[8080]
#define sipNameNr_QXmlStreamReader__Error 8104
#define sipName_QXmlStreamReader__Error &sipStrings_QtCore[8104]
#define sipNameNr_isProcessingInstruction 8128
#define sipName_isProcessingInstruction &sipStrings_QtCore[8128]
#define sipNameNr_resolveUndeclaredEntity 8152
#define sipName_resolveUndeclaredEntity &sipStrings_QtCore[8152]
#define sipNameNr_QUrl__FormattingOptions 8176
#define sipName_QUrl__FormattingOptions &sipStrings_QtCore[8176]
#define sipNameNr_isInterruptionRequested 8200
#define sipName_isInterruptionRequested &sipStrings_QtCore[8200]
#define sipNameNr_qSetRealNumberPrecision 8224
#define sipName_qSetRealNumberPrecision &sipStrings_QtCore[8224]
#define sipNameNr_QTextStream__NumberFlag 8248
#define sipName_QTextStream__NumberFlag &sipStrings_QtCore[8248]
#define sipNameNr_filterRegularExpression 8272
#define sipName_filterRegularExpression &sipStrings_QtCore[8272]
#define sipNameNr_currentAnimationChanged 8296
#define sipName_currentAnimationChanged &sipStrings_QtCore[8296]
#define sipNameNr_QRegularExpressionMatch 8320
#define sipName_QRegularExpressionMatch &sipStrings_QtCore[8320]
#define sipNameNr_PartialPreferFirstMatch 8344
#define sipName_PartialPreferFirstMatch &sipStrings_QtCore[8344]
#define sipNameNr_readyReadStandardOutput 8368
#define sipName_readyReadStandardOutput &sipStrings_QtCore[8368]
#define sipNameNr_QParallelAnimationGroup 8392
#define sipName_QParallelAnimationGroup &sipStrings_QtCore[8392]
#define sipNameNr_QOperatingSystemVersion 8416
#define sipName_QOperatingSystemVersion &sipStrings_QtCore[8416]
#define sipNameNr_QMetaObject__Connection 8440
#define sipName_QMetaObject__Connection &sipStrings_QtCore[8440]
#define sipNameNr_QMetaMethod__MethodType 8464
#define sipName_QMetaMethod__MethodType &sipStrings_QtCore[8464]
#define sipNameNr_QLocale__DataSizeFormat 8488
#define sipName_QLocale__DataSizeFormat &sipStrings_QtCore[8488]
#define sipNameNr_QLocale__QuotationStyle 8512
#define sipName_QLocale__QuotationStyle &sipStrings_QtCore[8512]
#define sipNameNr_CaucasianAlbanianScript 8536
#define sipName_CaucasianAlbanianScript &sipStrings_QtCore[8536]
#define sipNameNr_SimplifiedChineseScript 8560
#define sipName_SimplifiedChineseScript &sipStrings_QtCore[8560]
#define sipNameNr_HeardAndMcDonaldIslands 8584
#define sipName_HeardAndMcDonaldIslands &sipStrings_QtCore[8584]
#define sipNameNr_ManichaeanMiddlePersian 8608
#define sipName_ManichaeanMiddlePersian &sipStrings_QtCore[8608]
#define sipNameNr_CentralMoroccoTamazight 8632
#define sipName_CentralMoroccoTamazight &sipStrings_QtCore[8632]
#define sipNameNr_QIODevice__OpenModeFlag 8656
#define sipName_QIODevice__OpenModeFlag &sipStrings_QtCore[8656]
#define sipNameNr_QFileDevice__Permission 8680
#define sipName_QFileDevice__Permission &sipStrings_QtCore[8680]
#define sipNameNr_setPreciseRemainingTime 8704
#define sipName_setPreciseRemainingTime &sipStrings_QtCore[8704]
#define sipNameNr_CloseSoftwareInputPanel 8728
#define sipName_CloseSoftwareInputPanel &sipStrings_QtCore[8728]
#define sipNameNr_GraphicsSceneHoverLeave 8752
#define sipName_GraphicsSceneHoverLeave &sipStrings_QtCore[8752]
#define sipNameNr_GraphicsSceneHoverEnter 8776
#define sipName_GraphicsSceneHoverEnter &sipStrings_QtCore[8776]
#define sipNameNr_GraphicsSceneMousePress 8800
#define sipName_GraphicsSceneMousePress &sipStrings_QtCore[8800]
#define sipNameNr_QCborStreamReader__Type 8824
#define sipName_QCborStreamReader__Type &sipStrings_QtCore[8824]
#define sipNameNr_QCalendar__YearMonthDay 8848
#define sipName_QCalendar__YearMonthDay &sipStrings_QtCore[8848]
#define sipNameNr_columnsAboutToBeRemoved 8872
#define sipName_columnsAboutToBeRemoved &sipStrings_QtCore[8872]
#define sipNameNr_removeNativeEventFilter 8896
#define sipName_removeNativeEventFilter &sipStrings_QtCore[8896]
#define sipNameNr_WhiteSpaceModeUndefined 8920
#define sipName_WhiteSpaceModeUndefined &sipStrings_QtCore[8920]
#define sipNameNr_FindChildrenRecursively 8944
#define sipName_FindChildrenRecursively &sipStrings_QtCore[8944]
#define sipNameNr_ImhFormattedNumbersOnly 8968
#define sipName_ImhFormattedNumbersOnly &sipStrings_QtCore[8968]
#define sipNameNr_Qt__TextInteractionFlag 8992
#define sipName_Qt__TextInteractionFlag &sipStrings_QtCore[8992]
#define sipNameNr_AA_CompressTabletEvents 9016
#define sipName_AA_CompressTabletEvents &sipStrings_QtCore[9016]
#define sipNameNr_AA_DontUseNativeDialogs 9040
#define sipName_AA_DontUseNativeDialogs &sipStrings_QtCore[9040]
#define sipNameNr_AA_EnableHighDpiScaling 9064
#define sipName_AA_EnableHighDpiScaling &sipStrings_QtCore[9064]
#define sipNameNr_AA_DontUseNativeMenuBar 9088
#define sipName_AA_DontUseNativeMenuBar &sipStrings_QtCore[9088]
#define sipNameNr_AA_MacPluginApplication 9112
#define sipName_AA_MacPluginApplication &sipStrings_QtCore[9112]
#define sipNameNr_AA_DontShowIconsInMenus 9136
#define sipName_AA_DontShowIconsInMenus &sipStrings_QtCore[9136]
#define sipNameNr_ToolButtonTextUnderIcon 9160
#define sipName_ToolButtonTextUnderIcon &sipStrings_QtCore[9160]
#define sipNameNr_ActiveWindowFocusReason 9184
#define sipName_ActiveWindowFocusReason &sipStrings_QtCore[9184]
#define sipNameNr_Key_Dead_Belowdiaeresis 9208
#define sipName_Key_Dead_Belowdiaeresis &sipStrings_QtCore[9208]
#define sipNameNr_Qt__ImageConversionFlag 9232
#define sipName_Qt__ImageConversionFlag &sipStrings_QtCore[9232]
#define sipNameNr_WA_MSWindowsUseDirect3D 9256
#define sipName_WA_MSWindowsUseDirect3D &sipStrings_QtCore[9256]
#define sipNameNr_WA_LayoutUsesWidgetRect 9280
#define sipName_WA_LayoutUsesWidgetRect &sipStrings_QtCore[9280]
#define sipNameNr_WA_WState_OwnSizePolicy 9304
#define sipName_WA_WState_OwnSizePolicy &sipStrings_QtCore[9304]
#define sipNameNr_WA_WState_ConfigPending 9328
#define sipName_WA_WState_ConfigPending &sipStrings_QtCore[9328]
#define sipNameNr_WA_ForceUpdatesDisabled 9352
#define sipName_WA_ForceUpdatesDisabled &sipStrings_QtCore[9352]
#define sipNameNr_BypassWindowManagerHint 5769
#define sipName_BypassWindowManagerHint &sipStrings_QtCore[5769]
#define sipNameNr_WindowStaysOnBottomHint 9376
#define sipName_WindowStaysOnBottomHint &sipStrings_QtCore[9376]
#define sipNameNr_WindowMinMaxButtonsHint 9400
#define sipName_WindowMinMaxButtonsHint &sipStrings_QtCore[9400]
#define sipNameNr_TextJustificationForced 9424
#define sipName_TextJustificationForced &sipStrings_QtCore[9424]
#define sipNameNr_qUnregisterResourceData 9448
#define sipName_qUnregisterResourceData &sipStrings_QtCore[9448]
#define sipNameNr_9472 9472
#define sipName_9472 &sipStrings_QtCore[9472]
#define sipNameNr_9495 9495
#define sipName_9495 &sipStrings_QtCore[9495]
#define sipNameNr_currentCpuArchitecture 9518
#define sipName_currentCpuArchitecture &sipStrings_QtCore[9518]
#define sipNameNr_UnexpectedElementError 9541
#define sipName_UnexpectedElementError &sipStrings_QtCore[9541]
#define sipNameNr_setNamespaceProcessing 9564
#define sipName_setNamespaceProcessing &sipStrings_QtCore[9564]
#define sipNameNr_QTextStreamManipulator 9587
#define sipName_QTextStreamManipulator &sipStrings_QtCore[9587]
#define sipNameNr_setRealNumberPrecision 9610
#define sipName_setRealNumberPrecision &sipStrings_QtCore[9610]
#define sipNameNr_setGlobalRestorePolicy 9633
#define sipName_setGlobalRestorePolicy &sipStrings_QtCore[9633]
#define sipNameNr_removeDefaultAnimation 9656
#define sipName_removeDefaultAnimation &sipStrings_QtCore[9656]
#define sipNameNr_sortLocaleAwareChanged 9679
#define sipName_sortLocaleAwareChanged &sipStrings_QtCore[9679]
#define sipNameNr_setSortCaseSensitivity 9702
#define sipName_setSortCaseSensitivity &sipStrings_QtCore[9702]
#define sipNameNr_setDirectWriteFallback 9725
#define sipName_setDirectWriteFallback &sipStrings_QtCore[9725]
#define sipNameNr_QResource__Compression 9748
#define sipName_QResource__Compression &sipStrings_QtCore[9748]
#define sipNameNr_unregisterResourceData 9771
#define sipName_unregisterResourceData &sipStrings_QtCore[9771]
#define sipNameNr_QRegExp__PatternSyntax 9794
#define sipName_QRegExp__PatternSyntax &sipStrings_QtCore[9794]
#define sipNameNr_readyReadStandardError 9817
#define sipName_readyReadStandardError &sipStrings_QtCore[9817]
#define sipNameNr_ForwardedOutputChannel 9840
#define sipName_ForwardedOutputChannel &sipStrings_QtCore[9840]
#define sipNameNr_QProcess__ProcessState 9863
#define sipName_QProcess__ProcessState &sipStrings_QtCore[9863]
#define sipNameNr_QProcess__ProcessError 9886
#define sipName_QProcess__ProcessError &sipStrings_QtCore[9886]
#define sipNameNr_QGenericReturnArgument 9909
#define sipName_QGenericReturnArgument &sipStrings_QtCore[9909]
#define sipNameNr_qInstallMessageHandler 9932
#define sipName_qInstallMessageHandler &sipStrings_QtCore[9932]
#define sipNameNr_QLocale__NumberOptions 9955
#define sipName_QLocale__NumberOptions &sipStrings_QtCore[9955]
#define sipNameNr_SaintPierreAndMiquelon 9978
#define sipName_SaintPierreAndMiquelon &sipStrings_QtCore[9978]
#define sipNameNr_PalestinianTerritories 10001
#define sipName_PalestinianTerritories &sipStrings_QtCore[10001]
#define sipNameNr_WallisAndFutunaIslands 10024
#define sipName_WallisAndFutunaIslands &sipStrings_QtCore[10024]
#define sipNameNr_NorthernMarianaIslands 10047
#define sipName_NorthernMarianaIslands &sipStrings_QtCore[10047]
#define sipNameNr_PeoplesRepublicOfCongo 10070
#define sipName_PeoplesRepublicOfCongo &sipStrings_QtCore[10070]
#define sipNameNr_CentralAfricanRepublic 10093
#define sipName_CentralAfricanRepublic &sipStrings_QtCore[10093]
#define sipNameNr_LibraryExecutablesPath 10116
#define sipName_LibraryExecutablesPath &sipStrings_QtCore[10116]
#define sipNameNr_rowIntersectsSelection 10139
#define sipName_rowIntersectsSelection &sipStrings_QtCore[10139]
#define sipNameNr_setCurrentWriteChannel 10162
#define sipName_setCurrentWriteChannel &sipStrings_QtCore[10162]
#define sipNameNr_FileMetadataChangeTime 10185
#define sipName_FileMetadataChangeTime &sipStrings_QtCore[10185]
#define sipNameNr_QFileDevice__FileError 10208
#define sipName_QFileDevice__FileError &sipStrings_QtCore[10208]
#define sipNameNr_ExcludeSocketNotifiers 10231
#define sipName_ExcludeSocketNotifiers &sipStrings_QtCore[10231]
#define sipNameNr_ExcludeUserInputEvents 10254
#define sipName_ExcludeUserInputEvents &sipStrings_QtCore[10254]
#define sipNameNr_currentMSecsSinceEpoch 10277
#define sipName_currentMSecsSinceEpoch &sipStrings_QtCore[10277]
#define sipNameNr_floatingPointPrecision 10300
#define sipName_floatingPointPrecision &sipStrings_QtCore[10300]
#define sipNameNr_FloatingPointPrecision 978
#define sipName_FloatingPointPrecision &sipStrings_QtCore[978]
#define sipNameNr_QDataStream__ByteOrder 10323
#define sipName_QDataStream__ByteOrder &sipStrings_QtCore[10323]
#define sipNameNr_ApplicationStateChange 10346
#define sipName_ApplicationStateChange &sipStrings_QtCore[10346]
#define sipNameNr_NonClientAreaMouseMove 10369
#define sipName_NonClientAreaMouseMove &sipStrings_QtCore[10369]
#define sipNameNr_GraphicsSceneDragLeave 10392
#define sipName_GraphicsSceneDragLeave &sipStrings_QtCore[10392]
#define sipNameNr_GraphicsSceneDragEnter 10415
#define sipName_GraphicsSceneDragEnter &sipStrings_QtCore[10415]
#define sipNameNr_GraphicsSceneHoverMove 10438
#define sipName_GraphicsSceneHoverMove &sipStrings_QtCore[10438]
#define sipNameNr_GraphicsSceneMouseMove 10461
#define sipName_GraphicsSceneMouseMove &sipStrings_QtCore[10461]
#define sipNameNr_ApplicationDeactivated 10484
#define sipName_ApplicationDeactivated &sipStrings_QtCore[10484]
#define sipNameNr_applicationDescription 10507
#define sipName_applicationDescription &sipStrings_QtCore[10507]
#define sipNameNr_mapSelectionFromSource 10530
#define sipName_mapSelectionFromSource &sipStrings_QtCore[10530]
#define sipNameNr_layoutAboutToBeChanged 10553
#define sipName_layoutAboutToBeChanged &sipStrings_QtCore[10553]
#define sipNameNr_registerSocketNotifier 7434
#define sipName_registerSocketNotifier &sipStrings_QtCore[7434]
#define sipNameNr_ItemSelectionOperation 5392
#define sipName_ItemSelectionOperation &sipStrings_QtCore[5392]
#define sipNameNr_SmartZoomNativeGesture 10576
#define sipName_SmartZoomNativeGesture &sipStrings_QtCore[10576]
#define sipNameNr_FindDirectChildrenOnly 10599
#define sipName_FindDirectChildrenOnly &sipStrings_QtCore[10599]
#define sipNameNr_Qt__ScreenOrientations 10622
#define sipName_Qt__ScreenOrientations &sipStrings_QtCore[10622]
#define sipNameNr_ReceivePartialGestures 10645
#define sipName_ReceivePartialGestures &sipStrings_QtCore[10645]
#define sipNameNr_AnchorHorizontalCenter 10668
#define sipName_AnchorHorizontalCenter &sipStrings_QtCore[10668]
#define sipNameNr_ImhEmailCharactersOnly 10691
#define sipName_ImhEmailCharactersOnly &sipStrings_QtCore[10691]
#define sipNameNr_Qt__WindowFrameSection 10714
#define sipName_Qt__WindowFrameSection &sipStrings_QtCore[10714]
#define sipNameNr_TextBrowserInteraction 10737
#define sipName_TextBrowserInteraction &sipStrings_QtCore[10737]
#define sipNameNr_LinksAccessibleByMouse 10760
#define sipName_LinksAccessibleByMouse &sipStrings_QtCore[10760]
#define sipNameNr_AA_ShareOpenGLContexts 10783
#define sipName_AA_ShareOpenGLContexts &sipStrings_QtCore[10783]
#define sipNameNr_MatchRegularExpression 10806
#define sipName_MatchRegularExpression &sipStrings_QtCore[10806]
#define sipNameNr_Qt__InputMethodQueries 10829
#define sipName_Qt__InputMethodQueries &sipStrings_QtCore[10829]
#define sipNameNr_Qt__TransformationMode 10852
#define sipName_Qt__TransformationMode &sipStrings_QtCore[10852]
#define sipNameNr_DefaultLocaleShortDate 10875
#define sipName_DefaultLocaleShortDate &sipStrings_QtCore[10875]
#define sipNameNr_ConicalGradientPattern 10898
#define sipName_ConicalGradientPattern &sipStrings_QtCore[10898]
#define sipNameNr_Key_Dead_Capital_Schwa 10921
#define sipName_Key_Dead_Capital_Schwa &sipStrings_QtCore[10921]
#define sipNameNr_Key_Dead_Invertedbreve 10944
#define sipName_Key_Dead_Invertedbreve &sipStrings_QtCore[10944]
#define sipNameNr_Key_KeyboardLightOnOff 10967
#define sipName_Key_KeyboardLightOnOff &sipStrings_QtCore[10967]
#define sipNameNr_WA_X11DoNotAcceptFocus 10990
#define sipName_WA_X11DoNotAcceptFocus &sipStrings_QtCore[10990]
#define sipNameNr_WA_KeyboardFocusChange 11013
#define sipName_WA_KeyboardFocusChange &sipStrings_QtCore[11013]
#define sipNameNr_WA_WState_InPaintEvent 11036
#define sipName_WA_WState_InPaintEvent &sipStrings_QtCore[11036]
#define sipNameNr_WA_WState_CompressKeys 11059
#define sipName_WA_WState_CompressKeys &sipStrings_QtCore[11059]
#define sipNameNr_NoDropShadowWindowHint 11082
#define sipName_NoDropShadowWindowHint &sipStrings_QtCore[11082]
#define sipNameNr_11105 11105
#define sipName_11105 &sipStrings_QtCore[11105]
#define sipNameNr_11127 11127
#define sipName_11127 &sipStrings_QtCore[11127]
#define sipNameNr_writeDefaultNamespace 11149
#define sipName_writeDefaultNamespace &sipStrings_QtCore[11149]
#define sipNameNr_namespaceDeclarations 11171
#define sipName_namespaceDeclarations &sipStrings_QtCore[11171]
#define sipNameNr_ProcessingInstruction 4772
#define sipName_ProcessingInstruction &sipStrings_QtCore[4772]
#define sipNameNr_NormalizePathSegments 11193
#define sipName_NormalizePathSegments &sipStrings_QtCore[11193]
#define sipNameNr_isTimeZoneIdAvailable 11215
#define sipName_isTimeZoneIdAvailable &sipStrings_QtCore[11215]
#define sipNameNr_QTimeZone__OffsetData 11237
#define sipName_QTimeZone__OffsetData &sipStrings_QtCore[11237]
#define sipNameNr_QTimeLine__CurveShape 11259
#define sipName_QTimeLine__CurveShape &sipStrings_QtCore[11259]
#define sipNameNr_setTerminationEnabled 11281
#define sipName_setTerminationEnabled &sipStrings_QtCore[11281]
#define sipNameNr_setRealNumberNotation 11303
#define sipName_setRealNumberNotation &sipStrings_QtCore[11303]
#define sipNameNr_generateByteOrderMark 11325
#define sipName_generateByteOrderMark &sipStrings_QtCore[11325]
#define sipNameNr_DontRestoreProperties 11347
#define sipName_DontRestoreProperties &sipStrings_QtCore[11347]
#define sipNameNr_QState__RestorePolicy 11369
#define sipName_QState__RestorePolicy &sipStrings_QtCore[11369]
#define sipNameNr_GenericConfigLocation 11391
#define sipName_GenericConfigLocation &sipStrings_QtCore[11391]
#define sipNameNr_filterCaseSensitivity 11413
#define sipName_filterCaseSensitivity &sipStrings_QtCore[11413]
#define sipNameNr_QSortFilterProxyModel 11435
#define sipName_QSortFilterProxyModel &sipStrings_QtCore[11435]
#define sipNameNr_QSocketNotifier__Type 11457
#define sipName_QSocketNotifier__Type &sipStrings_QtCore[11457]
#define sipNameNr_setAtomicSyncRequired 11479
#define sipName_setAtomicSyncRequired &sipStrings_QtCore[11479]
#define sipNameNr_CaseInsensitiveOption 11501
#define sipName_CaseInsensitiveOption &sipStrings_QtCore[11501]
#define sipNameNr_ForwardedInputChannel 11523
#define sipName_ForwardedInputChannel &sipStrings_QtCore[11523]
#define sipNameNr_setProcessEnvironment 11545
#define sipName_setProcessEnvironment &sipStrings_QtCore[11545]
#define sipNameNr_setStandardOutputFile 11567
#define sipName_setStandardOutputFile &sipStrings_QtCore[11567]
#define sipNameNr_setProcessChannelMode 11589
#define sipName_setProcessChannelMode &sipStrings_QtCore[11589]
#define sipNameNr_readAllStandardOutput 11611
#define sipName_readAllStandardOutput &sipStrings_QtCore[11611]
#define sipNameNr_ForwardedErrorChannel 11633
#define sipName_ForwardedErrorChannel &sipStrings_QtCore[11633]
#define sipNameNr_QObjectCleanupHandler 11655
#define sipName_QObjectCleanupHandler &sipStrings_QtCore[11655]
#define sipNameNr_QMutex__RecursionMode 11677
#define sipName_QMutex__RecursionMode &sipStrings_QtCore[11677]
#define sipNameNr_relativePropertyIndex 11699
#define sipName_relativePropertyIndex &sipStrings_QtCore[11699]
#define sipNameNr_FloatingPointShortest 11721
#define sipName_FloatingPointShortest &sipStrings_QtCore[11721]
#define sipNameNr_HanWithBopomofoScript 11743
#define sipName_HanWithBopomofoScript &sipStrings_QtCore[11743]
#define sipNameNr_OldNorthArabianScript 11765
#define sipName_OldNorthArabianScript &sipStrings_QtCore[11765]
#define sipNameNr_PollardPhoneticScript 11787
#define sipName_PollardPhoneticScript &sipStrings_QtCore[11787]
#define sipNameNr_OldSouthArabianScript 11809
#define sipName_OldSouthArabianScript &sipStrings_QtCore[11809]
#define sipNameNr_MeroiticCursiveScript 11831
#define sipName_MeroiticCursiveScript &sipStrings_QtCore[11831]
#define sipNameNr_ImperialAramaicScript 11853
#define sipName_ImperialAramaicScript &sipStrings_QtCore[11853]
#define sipNameNr_QLocale__NumberOption 11875
#define sipName_QLocale__NumberOption &sipStrings_QtCore[11875]
#define sipNameNr_TurksAndCaicosIslands 11897
#define sipName_TurksAndCaicosIslands &sipStrings_QtCore[11897]
#define sipNameNr_UnboundedIntersection 11919
#define sipName_UnboundedIntersection &sipStrings_QtCore[11919]
#define sipNameNr_QLineF__IntersectType 11941
#define sipName_QLineF__IntersectType &sipStrings_QtCore[11941]
#define sipNameNr_setFileNameAndVersion 11963
#define sipName_setFileNameAndVersion &sipStrings_QtCore[11963]
#define sipNameNr_LoadArchiveMemberHint 11985
#define sipName_LoadArchiveMemberHint &sipStrings_QtCore[11985]
#define sipNameNr_ResolveAllSymbolsHint 12007
#define sipName_ResolveAllSymbolsHint &sipStrings_QtCore[12007]
#define sipNameNr_IllegalEscapeSequence 12029
#define sipName_IllegalEscapeSequence &sipStrings_QtCore[12029]
#define sipNameNr_MissingValueSeparator 12051
#define sipName_MissingValueSeparator &sipStrings_QtCore[12051]
#define sipNameNr_setCurrentReadChannel 12073
#define sipName_setCurrentReadChannel &sipStrings_QtCore[12073]
#define sipNameNr_QFileDevice__FileTime 12095
#define sipName_QFileDevice__FileTime &sipStrings_QtCore[12095]
#define sipNameNr_addCubicBezierSegment 12117
#define sipName_addCubicBezierSegment &sipStrings_QtCore[12117]
#define sipNameNr_nameFiltersFromString 12139
#define sipName_nameFiltersFromString &sipStrings_QtCore[12139]
#define sipNameNr_currentSecsSinceEpoch 12161
#define sipName_currentSecsSinceEpoch &sipStrings_QtCore[12161]
#define sipNameNr_DynamicPropertyChange 12183
#define sipName_DynamicPropertyChange &sipStrings_QtCore[12183]
#define sipNameNr_GraphicsSceneDragMove 12205
#define sipName_GraphicsSceneDragMove &sipStrings_QtCore[12205]
#define sipNameNr_ApplicationDeactivate 12227
#define sipName_ApplicationDeactivate &sipStrings_QtCore[12227]
#define sipNameNr_LayoutDirectionChange 1972
#define sipName_LayoutDirectionChange &sipStrings_QtCore[1972]
#define sipNameNr_ApplicationFontChange 12249
#define sipName_ApplicationFontChange &sipStrings_QtCore[12249]
#define sipNameNr_setApplicationVersion 12271
#define sipName_setApplicationVersion &sipStrings_QtCore[12271]
#define sipNameNr_setOrganizationDomain 12293
#define sipName_setOrganizationDomain &sipStrings_QtCore[12293]
#define sipNameNr_addPositionalArgument 12315
#define sipName_addPositionalArgument &sipStrings_QtCore[12315]
#define sipNameNr_standaloneWeekDayName 12337
#define sipName_standaloneWeekDayName &sipStrings_QtCore[12337]
#define sipNameNr_columnsAboutToBeMoved 12359
#define sipName_columnsAboutToBeMoved &sipStrings_QtCore[12359]
#define sipNameNr_changePersistentIndex 12381
#define sipName_changePersistentIndex &sipStrings_QtCore[12381]
#define sipNameNr_rowsAboutToBeInserted 12403
#define sipName_rowsAboutToBeInserted &sipStrings_QtCore[12403]
#define sipNameNr_QPersistentModelIndex 12425
#define sipName_QPersistentModelIndex &sipStrings_QtCore[12425]
#define sipNameNr_Qt__NativeGestureType 12447
#define sipName_Qt__NativeGestureType &sipStrings_QtCore[12447]
#define sipNameNr_Qt__ApplicationStates 12469
#define sipName_Qt__ApplicationStates &sipStrings_QtCore[12469]
#define sipNameNr_Qt__ScreenOrientation 12491
#define sipName_Qt__ScreenOrientation &sipStrings_QtCore[12491]
#define sipNameNr_ImhExclusiveInputMask 12513
#define sipName_ImhExclusiveInputMask &sipStrings_QtCore[12513]
#define sipNameNr_TextEditorInteraction 12535
#define sipName_TextEditorInteraction &sipStrings_QtCore[12535]
#define sipNameNr_TextSelectableByMouse 12557
#define sipName_TextSelectableByMouse &sipStrings_QtCore[12557]
#define sipNameNr_Qt__ItemSelectionMode 12579
#define sipName_Qt__ItemSelectionMode &sipStrings_QtCore[12579]
#define sipNameNr_AA_ForceRasterWidgets 12601
#define sipName_AA_ForceRasterWidgets &sipStrings_QtCore[12601]
#define sipNameNr_ToolButtonFollowStyle 12623
#define sipName_ToolButtonFollowStyle &sipStrings_QtCore[12623]
#define sipNameNr_Qt__ContextMenuPolicy 12645
#define sipName_Qt__ContextMenuPolicy &sipStrings_QtCore[12645]
#define sipNameNr_DefaultLocaleLongDate 12667
#define sipName_DefaultLocaleLongDate &sipStrings_QtCore[12667]
#define sipNameNr_SystemLocaleShortDate 12689
#define sipName_SystemLocaleShortDate &sipStrings_QtCore[12689]
#define sipNameNr_RadialGradientPattern 12711
#define sipName_RadialGradientPattern &sipStrings_QtCore[12711]
#define sipNameNr_LinearGradientPattern 12733
#define sipName_LinearGradientPattern &sipStrings_QtCore[12733]
#define sipNameNr_Key_MonBrightnessDown 12755
#define sipName_Key_MonBrightnessDown &sipStrings_QtCore[12755]
#define sipNameNr_Key_Dead_Voiced_Sound 12777
#define sipName_Key_Dead_Voiced_Sound &sipStrings_QtCore[12777]
#define sipNameNr_Key_Hiragana_Katakana 12799
#define sipName_Key_Hiragana_Katakana &sipStrings_QtCore[12799]
#define sipNameNr_Key_PreviousCandidate 12821
#define sipName_Key_PreviousCandidate &sipStrings_QtCore[12821]
#define sipNameNr_Key_MultipleCandidate 12843
#define sipName_Key_MultipleCandidate &sipStrings_QtCore[12843]
#define sipNameNr_WA_MacFrameworkScaled 12865
#define sipName_WA_MacFrameworkScaled &sipStrings_QtCore[12865]
#define sipNameNr_WA_AlwaysShowToolTips 12887
#define sipName_WA_AlwaysShowToolTips &sipStrings_QtCore[12887]
#define sipNameNr_WA_NoMousePropagation 12909
#define sipName_WA_NoMousePropagation &sipStrings_QtCore[12909]
#define sipNameNr_WA_SetLayoutDirection 12931
#define sipName_WA_SetLayoutDirection &sipStrings_QtCore[12931]
#define sipNameNr_WA_LayoutOnEntireRect 12953
#define sipName_WA_LayoutOnEntireRect &sipStrings_QtCore[12953]
#define sipNameNr_WA_PendingResizeEvent 12975
#define sipName_WA_PendingResizeEvent &sipStrings_QtCore[12975]
#define sipNameNr_WA_InputMethodEnabled 12997
#define sipName_WA_InputMethodEnabled &sipStrings_QtCore[12997]
#define sipNameNr_WA_NoSystemBackground 13019
#define sipName_WA_NoSystemBackground &sipStrings_QtCore[13019]
#define sipNameNr_WindowCloseButtonHint 13041
#define sipName_WindowCloseButtonHint &sipStrings_QtCore[13041]
#define sipNameNr_WindowShadeButtonHint 13063
#define sipName_WindowShadeButtonHint &sipStrings_QtCore[13063]
#define sipNameNr_Qt__KeyboardModifiers 13085
#define sipName_Qt__KeyboardModifiers &sipStrings_QtCore[13085]
#define sipNameNr_pyqtSetPickleProtocol 13107
#define sipName_pyqtSetPickleProtocol &sipStrings_QtCore[13107]
#define sipNameNr_qRegisterResourceData 13129
#define sipName_qRegisterResourceData &sipStrings_QtCore[13129]
#define sipNameNr_13151 13151
#define sipName_13151 &sipStrings_QtCore[13151]
#define sipNameNr_buildCpuArchitecture 13172
#define sipName_buildCpuArchitecture &sipStrings_QtCore[13172]
#define sipNameNr_writeEntityReference 13193
#define sipName_writeEntityReference &sipStrings_QtCore[13193]
#define sipNameNr_autoFormattingIndent 13214
#define sipName_autoFormattingIndent &sipStrings_QtCore[13214]
#define sipNameNr_entityExpansionLimit 13235
#define sipName_entityExpansionLimit &sipStrings_QtCore[13235]
#define sipNameNr_readNextStartElement 13256
#define sipName_readNextStartElement &sipStrings_QtCore[13256]
#define sipNameNr_notationDeclarations 13277
#define sipName_notationDeclarations &sipStrings_QtCore[13277]
#define sipNameNr_IncludeChildElements 13298
#define sipName_IncludeChildElements &sipStrings_QtCore[13298]
#define sipNameNr_isStandaloneDocument 13319
#define sipName_isStandaloneDocument &sipStrings_QtCore[13319]
#define sipNameNr_QXmlStreamAttributes 13340
#define sipName_QXmlStreamAttributes &sipStrings_QtCore[13340]
#define sipNameNr_PersistentModelIndex 12426
#define sipName_PersistentModelIndex &sipStrings_QtCore[12426]
#define sipNameNr_QTransposeProxyModel 13361
#define sipName_QTransposeProxyModel &sipStrings_QtCore[13361]
#define sipNameNr_availableTimeZoneIds 13382
#define sipName_availableTimeZoneIds &sipStrings_QtCore[13382]
#define sipNameNr_QTimeLine__Direction 13403
#define sipName_QTimeLine__Direction &sipStrings_QtCore[13403]
#define sipNameNr_TimeCriticalPriority 13424
#define sipName_TimeCriticalPriority &sipStrings_QtCore[13424]
#define sipNameNr_setAutoDetectUnicode 13445
#define sipName_setAutoDetectUnicode &sipStrings_QtCore[13445]
#define sipNameNr_AlignAccountingStyle 13466
#define sipName_AlignAccountingStyle &sipStrings_QtCore[13466]
#define sipNameNr_ConvertInvalidToNull 13487
#define sipName_ConvertInvalidToNull &sipStrings_QtCore[13487]
#define sipNameNr_SystemSemaphoreError 533
#define sipName_SystemSemaphoreError &sipStrings_QtCore[533]
#define sipNameNr_QStateMachine__Error 13508
#define sipName_QStateMachine__Error &sipStrings_QtCore[13508]
#define sipNameNr_AppLocalDataLocation 13529
#define sipName_AppLocalDataLocation &sipStrings_QtCore[13529]
#define sipNameNr_GenericCacheLocation 13550
#define sipName_GenericCacheLocation &sipStrings_QtCore[13550]
#define sipNameNr_ApplicationsLocation 13571
#define sipName_ApplicationsLocation &sipStrings_QtCore[13571]
#define sipNameNr_setDynamicSortFilter 13592
#define sipName_setDynamicSortFilter &sipStrings_QtCore[13592]
#define sipNameNr_setFilterFixedString 13613
#define sipName_setFilterFixedString &sipStrings_QtCore[13613]
#define sipNameNr_isAtomicSyncRequired 13634
#define sipName_isAtomicSyncRequired &sipStrings_QtCore[13634]
#define sipNameNr_compressionAlgorithm 13655
#define sipName_compressionAlgorithm &sipStrings_QtCore[13655]
#define sipNameNr_registerResourceData 9451
#define sipName_registerResourceData &sipStrings_QtCore[9451]
#define sipNameNr_setStandardErrorFile 13676
#define sipName_setStandardErrorFile &sipStrings_QtCore[13676]
#define sipNameNr_setStandardInputFile 13697
#define sipName_setStandardInputFile &sipStrings_QtCore[13697]
#define sipNameNr_readAllStandardError 13718
#define sipName_readAllStandardError &sipStrings_QtCore[13718]
#define sipNameNr_QProcess__ExitStatus 13739
#define sipName_QProcess__ExitStatus &sipStrings_QtCore[13739]
#define sipNameNr_AndroidJellyBean_MR2 13760
#define sipName_AndroidJellyBean_MR2 &sipStrings_QtCore[13760]
#define sipNameNr_AndroidJellyBean_MR1 13781
#define sipName_AndroidJellyBean_MR1 &sipStrings_QtCore[13781]
#define sipNameNr_dynamicPropertyNames 13802
#define sipName_dynamicPropertyNames &sipStrings_QtCore[13802]
#define sipNameNr_mimeTypesForFileName 13823
#define sipName_mimeTypesForFileName &sipStrings_QtCore[13823]
#define sipNameNr_QMetaType__TypeFlags 13844
#define sipName_QMetaType__TypeFlags &sipStrings_QtCore[13844]
#define sipNameNr_QLockFile__LockError 13865
#define sipName_QLockFile__LockError &sipStrings_QtCore[13865]
#define sipNameNr_CurrencySymbolFormat 2855
#define sipName_CurrencySymbolFormat &sipStrings_QtCore[2855]
#define sipNameNr_PsalterPahlaviScript 13886
#define sipName_PsalterPahlaviScript &sipStrings_QtCore[13886]
#define sipNameNr_TraditionalHanScript 13907
#define sipName_TraditionalHanScript &sipStrings_QtCore[13907]
#define sipNameNr_DefaultNumberOptions 13928
#define sipName_DefaultNumberOptions &sipStrings_QtCore[13928]
#define sipNameNr_RejectGroupSeparator 13949
#define sipName_RejectGroupSeparator &sipStrings_QtCore[13949]
#define sipNameNr_BritishVirginIslands 13970
#define sipName_BritishVirginIslands &sipStrings_QtCore[13970]
#define sipNameNr_BosniaAndHerzegowina 13991
#define sipName_BosniaAndHerzegowina &sipStrings_QtCore[13991]
#define sipNameNr_AmericanSignLanguage 14012
#define sipName_AmericanSignLanguage &sipStrings_QtCore[14012]
#define sipNameNr_MissingNameSeparator 14033
#define sipName_MissingNameSeparator &sipStrings_QtCore[14033]
#define sipNameNr_emitSelectionChanged 14054
#define sipName_emitSelectionChanged &sipStrings_QtCore[14054]
#define sipNameNr_currentColumnChanged 14075
#define sipName_currentColumnChanged &sipStrings_QtCore[14075]
#define sipNameNr_isTransactionStarted 14096
#define sipName_isTransactionStarted &sipStrings_QtCore[14096]
#define sipNameNr_setDefaultTransition 14117
#define sipName_setDefaultTransition &sipStrings_QtCore[14117]
#define sipNameNr_FileModificationTime 14138
#define sipName_FileModificationTime &sipStrings_QtCore[14138]
#define sipNameNr_fromNativeSeparators 14159
#define sipName_fromNativeSeparators &sipStrings_QtCore[14159]
#define sipNameNr_QDateTime__YearRange 14180
#define sipName_QDateTime__YearRange &sipStrings_QtCore[14180]
#define sipNameNr_timeZoneAbbreviation 14201
#define sipName_timeZoneAbbreviation &sipStrings_QtCore[14201]
#define sipNameNr_msecsSinceStartOfDay 14222
#define sipName_msecsSinceStartOfDay &sipStrings_QtCore[14222]
#define sipNameNr_QDate__MonthNameType 14243
#define sipName_QDate__MonthNameType &sipStrings_QtCore[14243]
#define sipNameNr_QDataStream__Version 14264
#define sipName_QDataStream__Version &sipStrings_QtCore[14264]
#define sipNameNr_TabletTrackingChange 14285
#define sipName_TabletTrackingChange &sipStrings_QtCore[14285]
#define sipNameNr_TabletLeaveProximity 14306
#define sipName_TabletLeaveProximity &sipStrings_QtCore[14306]
#define sipNameNr_TabletEnterProximity 14327
#define sipName_TabletEnterProximity &sipStrings_QtCore[14327]
#define sipNameNr_KeyboardLayoutChange 14348
#define sipName_KeyboardLayoutChange &sipStrings_QtCore[14348]
#define sipNameNr_ApplicationActivated 14369
#define sipName_ApplicationActivated &sipStrings_QtCore[14369]
#define sipNameNr_pyqtRestoreInputHook 14390
#define sipName_pyqtRestoreInputHook &sipStrings_QtCore[14390]
#define sipNameNr_setIgnorePunctuation 14411
#define sipName_setIgnorePunctuation &sipStrings_QtCore[14411]
#define sipNameNr_Base64DecodingStatus 2006
#define sipName_Base64DecodingStatus &sipStrings_QtCore[2006]
#define sipNameNr_mapSelectionToSource 14432
#define sipName_mapSelectionToSource &sipStrings_QtCore[14432]
#define sipNameNr_supportedDragActions 14453
#define sipName_supportedDragActions &sipStrings_QtCore[14453]
#define sipNameNr_rowsAboutToBeRemoved 14474
#define sipName_rowsAboutToBeRemoved &sipStrings_QtCore[14474]
#define sipNameNr_supportedDropActions 14495
#define sipName_supportedDropActions &sipStrings_QtCore[14495]
#define sipNameNr_TabFocusListControls 14516
#define sipName_TabFocusListControls &sipStrings_QtCore[14516]
#define sipNameNr_TabFocusTextControls 14537
#define sipName_TabFocusTextControls &sipStrings_QtCore[14537]
#define sipNameNr_Qt__TabFocusBehavior 14558
#define sipName_Qt__TabFocusBehavior &sipStrings_QtCore[14558]
#define sipNameNr_Qt__MouseEventSource 14579
#define sipName_Qt__MouseEventSource &sipStrings_QtCore[14579]
#define sipNameNr_ApplicationSuspended 14600
#define sipName_ApplicationSuspended &sipStrings_QtCore[14600]
#define sipNameNr_Qt__ApplicationState 14621
#define sipName_Qt__ApplicationState &sipStrings_QtCore[14621]
#define sipNameNr_Qt__FindChildOptions 14642
#define sipName_Qt__FindChildOptions &sipStrings_QtCore[14642]
#define sipNameNr_LandscapeOrientation 3619
#define sipName_LandscapeOrientation &sipStrings_QtCore[3619]
#define sipNameNr_Qt__TouchPointStates 14663
#define sipName_Qt__TouchPointStates &sipStrings_QtCore[14663]
#define sipNameNr_TouchPointStationary 14684
#define sipName_TouchPointStationary &sipStrings_QtCore[14684]
#define sipNameNr_Qt__CoordinateSystem 14705
#define sipName_Qt__CoordinateSystem &sipStrings_QtCore[14705]
#define sipNameNr_AnchorVerticalCenter 14726
#define sipName_AnchorVerticalCenter &sipStrings_QtCore[14726]
#define sipNameNr_Qt__InputMethodHints 14747
#define sipName_Qt__InputMethodHints &sipStrings_QtCore[14747]
#define sipNameNr_ImhUrlCharactersOnly 14768
#define sipName_ImhUrlCharactersOnly &sipStrings_QtCore[14768]
#define sipNameNr_TextInteractionFlags 7536
#define sipName_TextInteractionFlags &sipStrings_QtCore[7536]
#define sipNameNr_AA_PluginApplication 14789
#define sipName_AA_PluginApplication &sipStrings_QtCore[14789]
#define sipNameNr_AA_UseSoftwareOpenGL 14810
#define sipName_AA_UseSoftwareOpenGL &sipStrings_QtCore[14810]
#define sipNameNr_AA_UseHighDpiPixmaps 14831
#define sipName_AA_UseHighDpiPixmaps &sipStrings_QtCore[14831]
#define sipNameNr_ApplicationAttribute 7661
#define sipName_ApplicationAttribute &sipStrings_QtCore[7661]
#define sipNameNr_ItemNeverHasChildren 14852
#define sipName_ItemNeverHasChildren &sipStrings_QtCore[14852]
#define sipNameNr_InitialSortOrderRole 14873
#define sipName_InitialSortOrderRole &sipStrings_QtCore[14873]
#define sipNameNr_Qt__InputMethodQuery 14894
#define sipName_Qt__InputMethodQuery &sipStrings_QtCore[14894]
#define sipNameNr_SmoothTransformation 14915
#define sipName_SmoothTransformation &sipStrings_QtCore[14915]
#define sipNameNr_SystemLocaleLongDate 14936
#define sipName_SystemLocaleLongDate &sipStrings_QtCore[14936]
#define sipNameNr_BottomDockWidgetArea 14957
#define sipName_BottomDockWidgetArea &sipStrings_QtCore[14957]
#define sipNameNr_Key_Dead_Small_Schwa 14978
#define sipName_Key_Dead_Small_Schwa &sipStrings_QtCore[14978]
#define sipNameNr_Key_Dead_Belowmacron 14999
#define sipName_Key_Dead_Belowmacron &sipStrings_QtCore[14999]
#define sipNameNr_Key_Dead_Doublegrave 15020
#define sipName_Key_Dead_Doublegrave &sipStrings_QtCore[15020]
#define sipNameNr_Key_LastNumberRedial 15041
#define sipName_Key_LastNumberRedial &sipStrings_QtCore[15041]
#define sipNameNr_Key_ToggleCallHangup 15062
#define sipName_Key_ToggleCallHangup &sipStrings_QtCore[15062]
#define sipNameNr_Key_ApplicationRight 15083
#define sipName_Key_ApplicationRight &sipStrings_QtCore[15083]
#define sipNameNr_Key_BrightnessAdjust 15104
#define sipName_Key_BrightnessAdjust &sipStrings_QtCore[15104]
#define sipNameNr_Key_Dead_Doubleacute 15125
#define sipName_Key_Dead_Doubleacute &sipStrings_QtCore[15125]
#define sipNameNr_Key_Hangul_PostHanja 15146
#define sipName_Key_Hangul_PostHanja &sipStrings_QtCore[15146]
#define sipNameNr_ImageConversionFlags 7836
#define sipName_ImageConversionFlags &sipStrings_QtCore[7836]
#define sipNameNr_ThresholdAlphaDither 15167
#define sipName_ThresholdAlphaDither &sipStrings_QtCore[15167]
#define sipNameNr_WA_AcceptTouchEvents 15188
#define sipName_WA_AcceptTouchEvents &sipStrings_QtCore[15188]
#define sipNameNr_WA_MacOpaqueSizeGrip 15209
#define sipName_WA_MacOpaqueSizeGrip &sipStrings_QtCore[15209]
#define sipNameNr_WA_WindowPropagation 15230
#define sipName_WA_WindowPropagation &sipStrings_QtCore[15230]
#define sipNameNr_WA_WState_Reparented 15251
#define sipName_WA_WState_Reparented &sipStrings_QtCore[15251]
#define sipNameNr_WA_MacNoClickThrough 15272
#define sipName_WA_MacNoClickThrough &sipStrings_QtCore[15272]
#define sipNameNr_WindowStaysOnTopHint 15293
#define sipName_WindowStaysOnTopHint &sipStrings_QtCore[15293]
#define sipNameNr_WindowSystemMenuHint 15314
#define sipName_WindowSystemMenuHint &sipStrings_QtCore[15314]
#define sipNameNr_AlignHorizontal_Mask 15335
#define sipName_AlignHorizontal_Mask &sipStrings_QtCore[15335]
#define sipNameNr_KeyboardModifierMask 15356
#define sipName_KeyboardModifierMask &sipStrings_QtCore[15356]
#define sipNameNr_Qt__KeyboardModifier 15377
#define sipName_Qt__KeyboardModifier &sipStrings_QtCore[15377]
#define sipNameNr_qEnvironmentVariable 15398
#define sipName_qEnvironmentVariable &sipStrings_QtCore[15398]
#define sipNameNr_15419 15419
#define sipName_15419 &sipStrings_QtCore[15419]
#define sipNameNr_namespaceProcessing 15439
#define sipName_namespaceProcessing &sipStrings_QtCore[15439]
#define sipNameNr_QXmlStreamAttribute 15459
#define sipName_QXmlStreamAttribute &sipStrings_QtCore[15459]
#define sipNameNr_QUuid__StringFormat 15479
#define sipName_QUuid__StringFormat &sipStrings_QtCore[15479]
#define sipNameNr_removeAllQueryItems 15499
#define sipName_removeAllQueryItems &sipStrings_QtCore[15499]
#define sipNameNr_queryValueDelimiter 15519
#define sipName_queryValueDelimiter &sipStrings_QtCore[15519]
#define sipNameNr_UrlFormattingOption 5877
#define sipName_UrlFormattingOption &sipStrings_QtCore[5877]
#define sipNameNr_QTimeZone__NameType 15539
#define sipName_QTimeZone__NameType &sipStrings_QtCore[15539]
#define sipNameNr_QTimeZone__TimeType 15559
#define sipName_QTimeZone__TimeType &sipStrings_QtCore[15559]
#define sipNameNr_requestInterruption 15579
#define sipName_requestInterruption &sipStrings_QtCore[15579]
#define sipNameNr_realNumberPrecision 15599
#define sipName_realNumberPrecision &sipStrings_QtCore[15599]
#define sipNameNr_QTextStream__Status 15619
#define sipName_QTextStream__Status &sipStrings_QtCore[15619]
#define sipNameNr_QTextBoundaryFinder 15639
#define sipName_QTextBoundaryFinder &sipStrings_QtCore[15639]
#define sipNameNr_globalRestorePolicy 15659
#define sipName_globalRestorePolicy &sipStrings_QtCore[15659]
#define sipNameNr_addDefaultAnimation 15679
#define sipName_addDefaultAnimation &sipStrings_QtCore[15679]
#define sipNameNr_NoInitialStateError 15699
#define sipName_NoInitialStateError &sipStrings_QtCore[15699]
#define sipNameNr_initialStateChanged 15719
#define sipName_initialStateChanged &sipStrings_QtCore[15719]
#define sipNameNr_GenericDataLocation 15739
#define sipName_GenericDataLocation &sipStrings_QtCore[15739]
#define sipNameNr_sortCaseSensitivity 15759
#define sipName_sortCaseSensitivity &sipStrings_QtCore[15759]
#define sipNameNr_filterAcceptsColumn 15779
#define sipName_filterAcceptsColumn &sipStrings_QtCore[15779]
#define sipNameNr_senderObjectChanged 15799
#define sipName_senderObjectChanged &sipStrings_QtCore[15799]
#define sipNameNr_setFallbacksEnabled 15819
#define sipName_setFallbacksEnabled &sipStrings_QtCore[15819]
#define sipNameNr_directWriteFallback 15839
#define sipName_directWriteFallback &sipStrings_QtCore[15839]
#define sipNameNr_AnchoredMatchOption 15859
#define sipName_AnchoredMatchOption &sipStrings_QtCore[15859]
#define sipNameNr_QProcessEnvironment 15879
#define sipName_QProcessEnvironment &sipStrings_QtCore[15879]
#define sipNameNr_setInputChannelMode 15899
#define sipName_setInputChannelMode &sipStrings_QtCore[15899]
#define sipNameNr_ManagedInputChannel 15919
#define sipName_ManagedInputChannel &sipStrings_QtCore[15919]
#define sipNameNr_setWorkingDirectory 15939
#define sipName_setWorkingDirectory &sipStrings_QtCore[15939]
#define sipNameNr_AndroidLollipop_MR1 15959
#define sipName_AndroidLollipop_MR1 &sipStrings_QtCore[15959]
#define sipNameNr_normalizedSignature 15979
#define sipName_normalizedSignature &sipStrings_QtCore[15979]
#define sipNameNr_QMetaType__TypeFlag 15999
#define sipName_QMetaType__TypeFlag &sipStrings_QtCore[15999]
#define sipNameNr_QMetaMethod__Access 16019
#define sipName_QMetaMethod__Access &sipStrings_QtCore[16019]
#define sipNameNr_removeStaleLockFile 16039
#define sipName_removeStaleLockFile &sipStrings_QtCore[16039]
#define sipNameNr_createSeparatedList 16059
#define sipName_createSeparatedList &sipStrings_QtCore[16059]
#define sipNameNr_CurrencyDisplayName 16079
#define sipName_CurrencyDisplayName &sipStrings_QtCore[16079]
#define sipNameNr_SimplifiedHanScript 16099
#define sipName_SimplifiedHanScript &sipStrings_QtCore[16099]
#define sipNameNr_QLocale__FormatType 16119
#define sipName_QLocale__FormatType &sipStrings_QtCore[16119]
#define sipNameNr_ArdhamagadhiPrakrit 16139
#define sipName_ArdhamagadhiPrakrit &sipStrings_QtCore[16139]
#define sipNameNr_AncientNorthArabian 16159
#define sipName_AncientNorthArabian &sipStrings_QtCore[16159]
#define sipNameNr_BoundedIntersection 16179
#define sipName_BoundedIntersection &sipStrings_QtCore[16179]
#define sipNameNr_QLibrary__LoadHints 16199
#define sipName_QLibrary__LoadHints &sipStrings_QtCore[16199]
#define sipNameNr_TerminationByNumber 16219
#define sipName_TerminationByNumber &sipStrings_QtCore[16219]
#define sipNameNr_QItemSelectionModel 16239
#define sipName_QItemSelectionModel &sipStrings_QtCore[16239]
#define sipNameNr_QItemSelectionRange 16259
#define sipName_QItemSelectionRange &sipStrings_QtCore[16259]
#define sipNameNr_channelBytesWritten 16279
#define sipName_channelBytesWritten &sipStrings_QtCore[16279]
#define sipNameNr_currentWriteChannel 16299
#define sipName_currentWriteChannel &sipStrings_QtCore[16299]
#define sipNameNr_readChannelFinished 16319
#define sipName_readChannelFinished &sipStrings_QtCore[16319]
#define sipNameNr_waitForBytesWritten 16339
#define sipName_waitForBytesWritten &sipStrings_QtCore[16339]
#define sipNameNr_QIODevice__OpenMode 16359
#define sipName_QIODevice__OpenMode &sipStrings_QtCore[16359]
#define sipNameNr_QIdentityProxyModel 16379
#define sipName_QIdentityProxyModel &sipStrings_QtCore[16379]
#define sipNameNr_defaultStateChanged 16399
#define sipName_defaultStateChanged &sipStrings_QtCore[16399]
#define sipNameNr_msecsSinceReference 16419
#define sipName_msecsSinceReference &sipStrings_QtCore[16419]
#define sipNameNr_fromMSecsSinceEpoch 16439
#define sipName_fromMSecsSinceEpoch &sipStrings_QtCore[16439]
#define sipNameNr_rollbackTransaction 16459
#define sipName_rollbackTransaction &sipStrings_QtCore[16459]
#define sipNameNr_QDataStream__Status 16479
#define sipName_QDataStream__Status &sipStrings_QtCore[16479]
#define sipNameNr_StateMachineWrapped 16499
#define sipName_StateMachineWrapped &sipStrings_QtCore[16499]
#define sipNameNr_GraphicsSceneResize 16519
#define sipName_GraphicsSceneResize &sipStrings_QtCore[16519]
#define sipNameNr_ApplicationActivate 16539
#define sipName_ApplicationActivate &sipStrings_QtCore[16539]
#define sipNameNr_MouseTrackingChange 16559
#define sipName_MouseTrackingChange &sipStrings_QtCore[16559]
#define sipNameNr_ParentAboutToChange 16579
#define sipName_ParentAboutToChange &sipStrings_QtCore[16579]
#define sipNameNr_MouseButtonDblClick 1941
#define sipName_MouseButtonDblClick &sipStrings_QtCore[1941]
#define sipNameNr_pyqtRemoveInputHook 16599
#define sipName_pyqtRemoveInputHook &sipStrings_QtCore[16599]
#define sipNameNr_applicationFilePath 16619
#define sipName_applicationFilePath &sipStrings_QtCore[16619]
#define sipNameNr_setOrganizationName 16639
#define sipName_setOrganizationName &sipStrings_QtCore[16639]
#define sipNameNr_positionalArguments 16659
#define sipName_positionalArguments &sipStrings_QtCore[16659]
#define sipNameNr_parentContainerType 16679
#define sipName_parentContainerType &sipStrings_QtCore[16679]
#define sipNameNr_standaloneMonthName 16699
#define sipName_standaloneMonthName &sipStrings_QtCore[16699]
#define sipNameNr_maximumMonthsInYear 16719
#define sipName_maximumMonthsInYear &sipStrings_QtCore[16719]
#define sipNameNr_fromPercentEncoding 16739
#define sipName_fromPercentEncoding &sipStrings_QtCore[16739]
#define sipNameNr_targetStatesChanged 16759
#define sipName_targetStatesChanged &sipStrings_QtCore[16759]
#define sipNameNr_QAbstractTransition 16779
#define sipName_QAbstractTransition &sipStrings_QtCore[16779]
#define sipNameNr_QAbstractProxyModel 16799
#define sipName_QAbstractProxyModel &sipStrings_QtCore[16799]
#define sipNameNr_QAbstractTableModel 16819
#define sipName_QAbstractTableModel &sipStrings_QtCore[16819]
#define sipNameNr_persistentIndexList 16839
#define sipName_persistentIndexList &sipStrings_QtCore[16839]
#define sipNameNr_modelAboutToBeReset 16859
#define sipName_modelAboutToBeReset &sipStrings_QtCore[16859]
#define sipNameNr_TabFocusAllControls 16879
#define sipName_TabFocusAllControls &sipStrings_QtCore[16879]
#define sipNameNr_Qt__MouseEventFlags 16899
#define sipName_Qt__MouseEventFlags &sipStrings_QtCore[16899]
#define sipNameNr_RotateNativeGesture 16919
#define sipName_RotateNativeGesture &sipStrings_QtCore[16919]
#define sipNameNr_ApplicationInactive 16939
#define sipName_ApplicationInactive &sipStrings_QtCore[16939]
#define sipNameNr_Qt__HitTestAccuracy 16959
#define sipName_Qt__HitTestAccuracy &sipStrings_QtCore[16959]
#define sipNameNr_Qt__FindChildOption 16979
#define sipName_Qt__FindChildOption &sipStrings_QtCore[16979]
#define sipNameNr_PortraitOrientation 4553
#define sipName_PortraitOrientation &sipStrings_QtCore[4553]
#define sipNameNr_Qt__CursorMoveStyle 16999
#define sipName_Qt__CursorMoveStyle &sipStrings_QtCore[16999]
#define sipNameNr_Qt__TouchPointState 17019
#define sipName_Qt__TouchPointState &sipStrings_QtCore[17019]
#define sipNameNr_ImhNoPredictiveText 17039
#define sipName_ImhNoPredictiveText &sipStrings_QtCore[17039]
#define sipNameNr_Qt__InputMethodHint 17059
#define sipName_Qt__InputMethodHint &sipStrings_QtCore[17059]
#define sipNameNr_NormalEventPriority 17079
#define sipName_NormalEventPriority &sipStrings_QtCore[17079]
#define sipNameNr_TextInteractionFlag 8996
#define sipName_TextInteractionFlag &sipStrings_QtCore[8996]
#define sipNameNr_IntersectsItemShape 17099
#define sipName_IntersectsItemShape &sipStrings_QtCore[17099]
#define sipNameNr_AA_UseDesktopOpenGL 17119
#define sipName_AA_UseDesktopOpenGL &sipStrings_QtCore[17119]
#define sipNameNr_ItemIsUserCheckable 17139
#define sipName_ItemIsUserCheckable &sipStrings_QtCore[17139]
#define sipNameNr_BackgroundColorRole 17159
#define sipName_BackgroundColorRole &sipStrings_QtCore[17159]
#define sipNameNr_LayoutDirectionAuto 17179
#define sipName_LayoutDirectionAuto &sipStrings_QtCore[17179]
#define sipNameNr_Qt__LayoutDirection 17199
#define sipName_Qt__LayoutDirection &sipStrings_QtCore[17199]
#define sipNameNr_Qt__ToolButtonStyle 17219
#define sipName_Qt__ToolButtonStyle &sipStrings_QtCore[17219]
#define sipNameNr_ImPreferredLanguage 17239
#define sipName_ImPreferredLanguage &sipStrings_QtCore[17239]
#define sipNameNr_ImMaximumTextLength 17259
#define sipName_ImMaximumTextLength &sipStrings_QtCore[17259]
#define sipNameNr_ShortcutFocusReason 17279
#define sipName_ShortcutFocusReason &sipStrings_QtCore[17279]
#define sipNameNr_ApplicationShortcut 17299
#define sipName_ApplicationShortcut &sipStrings_QtCore[17299]
#define sipNameNr_Qt__ShortcutContext 17319
#define sipName_Qt__ShortcutContext &sipStrings_QtCore[17319]
#define sipNameNr_Qt__CaseSensitivity 17339
#define sipName_Qt__CaseSensitivity &sipStrings_QtCore[17339]
#define sipNameNr_Qt__ScrollBarPolicy 17359
#define sipName_Qt__ScrollBarPolicy &sipStrings_QtCore[17359]
#define sipNameNr_Qt__DockWidgetAreas 17379
#define sipName_Qt__DockWidgetAreas &sipStrings_QtCore[17379]
#define sipNameNr_DockWidgetArea_Mask 17399
#define sipName_DockWidgetArea_Mask &sipStrings_QtCore[17399]
#define sipNameNr_RightDockWidgetArea 17419
#define sipName_RightDockWidgetArea &sipStrings_QtCore[17419]
#define sipNameNr_Qt__AspectRatioMode 17439
#define sipName_Qt__AspectRatioMode &sipStrings_QtCore[17439]
#define sipNameNr_Key_Dead_Belowcomma 17459
#define sipName_Key_Dead_Belowcomma &sipStrings_QtCore[17459]
#define sipNameNr_Key_Dead_Belowbreve 17479
#define sipName_Key_Dead_Belowbreve &sipStrings_QtCore[17479]
#define sipNameNr_Key_Dead_Belowtilde 17499
#define sipName_Key_Dead_Belowtilde &sipStrings_QtCore[17499]
#define sipNameNr_Key_Dead_Abovecomma 17519
#define sipName_Key_Dead_Abovecomma &sipStrings_QtCore[17519]
#define sipNameNr_Key_AudioCycleTrack 17539
#define sipName_Key_AudioCycleTrack &sipStrings_QtCore[17539]
#define sipNameNr_Key_AudioRandomPlay 17559
#define sipName_Key_AudioRandomPlay &sipStrings_QtCore[17559]
#define sipNameNr_Key_ApplicationLeft 17579
#define sipName_Key_ApplicationLeft &sipStrings_QtCore[17579]
#define sipNameNr_Key_MonBrightnessUp 17599
#define sipName_Key_MonBrightnessUp &sipStrings_QtCore[17599]
#define sipNameNr_Key_Dead_Circumflex 17619
#define sipName_Key_Dead_Circumflex &sipStrings_QtCore[17619]
#define sipNameNr_Key_Hangul_PreHanja 17639
#define sipName_Key_Hangul_PreHanja &sipStrings_QtCore[17639]
#define sipNameNr_Key_Zenkaku_Hankaku 17659
#define sipName_Key_Zenkaku_Hankaku &sipStrings_QtCore[17659]
#define sipNameNr_Key_SingleCandidate 17679
#define sipName_Key_SingleCandidate &sipStrings_QtCore[17679]
#define sipNameNr_ImageConversionFlag 9236
#define sipName_ImageConversionFlag &sipStrings_QtCore[9236]
#define sipNameNr_WA_StyleSheetTarget 17699
#define sipName_WA_StyleSheetTarget &sipStrings_QtCore[17699]
#define sipNameNr_WA_AlwaysStackOnTop 17719
#define sipName_WA_AlwaysStackOnTop &sipStrings_QtCore[17719]
#define sipNameNr_WA_DontShowOnScreen 17739
#define sipName_WA_DontShowOnScreen &sipStrings_QtCore[17739]
#define sipNameNr_WA_StyledBackground 17759
#define sipName_WA_StyledBackground &sipStrings_QtCore[17759]
#define sipNameNr_WA_MacShowFocusRect 17779
#define sipName_WA_MacShowFocusRect &sipStrings_QtCore[17779]
#define sipNameNr_WA_X11OpenGLOverlay 17799
#define sipName_WA_X11OpenGLOverlay &sipStrings_QtCore[17799]
#define sipNameNr_WA_TintedBackground 17819
#define sipName_WA_TintedBackground &sipStrings_QtCore[17819]
#define sipNameNr_WA_PendingMoveEvent 17839
#define sipName_WA_PendingMoveEvent &sipStrings_QtCore[17839]
#define sipNameNr_WA_OpaquePaintEvent 17859
#define sipName_WA_OpaquePaintEvent &sipStrings_QtCore[17859]
#define sipNameNr_Qt__WidgetAttribute 17879
#define sipName_Qt__WidgetAttribute &sipStrings_QtCore[17879]
#define sipNameNr_CustomizeWindowHint 17899
#define sipName_CustomizeWindowHint &sipStrings_QtCore[17899]
#define sipNameNr_FramelessWindowHint 17919
#define sipName_FramelessWindowHint &sipStrings_QtCore[17919]
#define sipNameNr_GroupSwitchModifier 17939
#define sipName_GroupSwitchModifier &sipStrings_QtCore[17939]
#define sipNameNr_17959 17959
#define sipName_17959 &sipStrings_QtCore[17959]
#define sipNameNr_17978 17978
#define sipName_17978 &sipStrings_QtCore[17978]
#define sipNameNr_writeStartDocument 17997
#define sipName_writeStartDocument &sipStrings_QtCore[17997]
#define sipNameNr_skipCurrentElement 18016
#define sipName_skipCurrentElement &sipStrings_QtCore[18016]
#define sipNameNr_NotWellFormedError 18035
#define sipName_NotWellFormedError &sipStrings_QtCore[18035]
#define sipNameNr_entityDeclarations 18054
#define sipName_entityDeclarations &sipStrings_QtCore[18054]
#define sipNameNr_allQueryItemValues 18073
#define sipName_allQueryItemValues &sipStrings_QtCore[18073]
#define sipNameNr_queryPairDelimiter 18092
#define sipName_queryPairDelimiter &sipStrings_QtCore[18092]
#define sipNameNr_setQueryDelimiters 18111
#define sipName_setQueryDelimiters &sipStrings_QtCore[18111]
#define sipNameNr_StripTrailingSlash 18130
#define sipName_StripTrailingSlash &sipStrings_QtCore[18130]
#define sipNameNr_windowsIdToIanaIds 18149
#define sipName_windowsIdToIanaIds &sipStrings_QtCore[18149]
#define sipNameNr_previousTransition 18168
#define sipName_previousTransition &sipStrings_QtCore[18168]
#define sipNameNr_daylightTimeOffset 18187
#define sipName_daylightTimeOffset &sipStrings_QtCore[18187]
#define sipNameNr_standardTimeOffset 18206
#define sipName_standardTimeOffset &sipStrings_QtCore[18206]
#define sipNameNr_yieldCurrentThread 18225
#define sipName_yieldCurrentThread &sipStrings_QtCore[18225]
#define sipNameNr_realNumberNotation 18244
#define sipName_realNumberNotation &sipStrings_QtCore[18244]
#define sipNameNr_ScientificNotation 18263
#define sipName_ScientificNotation &sipStrings_QtCore[18263]
#define sipNameNr_RealNumberNotation 2235
#define sipName_RealNumberNotation &sipStrings_QtCore[2235]
#define sipNameNr_convertFromUnicode 18282
#define sipName_convertFromUnicode &sipStrings_QtCore[18282]
#define sipNameNr_toPreviousBoundary 18301
#define sipName_toPreviousBoundary &sipStrings_QtCore[18301]
#define sipNameNr_cancelDelayedEvent 18320
#define sipName_cancelDelayedEvent &sipStrings_QtCore[18320]
#define sipNameNr_propertiesAssigned 18339
#define sipName_propertiesAssigned &sipStrings_QtCore[18339]
#define sipNameNr_setTestModeEnabled 18358
#define sipName_setTestModeEnabled &sipStrings_QtCore[18358]
#define sipNameNr_setSortLocaleAware 18377
#define sipName_setSortLocaleAware &sipStrings_QtCore[18377]
#define sipNameNr_setFilterKeyColumn 18396
#define sipName_setFilterKeyColumn &sipStrings_QtCore[18396]
#define sipNameNr_QSemaphoreReleaser 18415
#define sipName_QSemaphoreReleaser &sipStrings_QtCore[18415]
#define sipNameNr_unregisterResource 18434
#define sipName_unregisterResource &sipStrings_QtCore[18434]
#define sipNameNr_namedCaptureGroups 18453
#define sipName_namedCaptureGroups &sipStrings_QtCore[18453]
#define sipNameNr_patternErrorOffset 18472
#define sipName_patternErrorOffset &sipStrings_QtCore[18472]
#define sipNameNr_QRegExp__CaretMode 18491
#define sipName_QRegExp__CaretMode &sipStrings_QtCore[18491]
#define sipNameNr_processEnvironment 18510
#define sipName_processEnvironment &sipStrings_QtCore[18510]
#define sipNameNr_processChannelMode 18529
#define sipName_processChannelMode &sipStrings_QtCore[18529]
#define sipNameNr_ProcessChannelMode 3389
#define sipName_ProcessChannelMode &sipStrings_QtCore[3389]
#define sipNameNr_updateCurrentValue 18548
#define sipName_updateCurrentValue &sipStrings_QtCore[18548]
#define sipNameNr_QPropertyAnimation 18567
#define sipName_QPropertyAnimation &sipStrings_QtCore[18567]
#define sipNameNr_AndroidMarshmallow 18586
#define sipName_AndroidMarshmallow &sipStrings_QtCore[18586]
#define sipNameNr_indexOfConstructor 18605
#define sipName_indexOfConstructor &sipStrings_QtCore[18605]
#define sipNameNr_connectSlotsByName 18624
#define sipName_connectSlotsByName &sipStrings_QtCore[18624]
#define sipNameNr_installEventFilter 18643
#define sipName_installEventFilter &sipStrings_QtCore[18643]
#define sipNameNr_QRegularExpression 18662
#define sipName_QRegularExpression &sipStrings_QtCore[18662]
#define sipNameNr_qSetMessagePattern 18681
#define sipName_qSetMessagePattern &sipStrings_QtCore[18681]
#define sipNameNr_QMessageLogContext 18700
#define sipName_QMessageLogContext &sipStrings_QtCore[18700]
#define sipNameNr_AlternateQuotation 18719
#define sipName_AlternateQuotation &sipStrings_QtCore[18719]
#define sipNameNr_nativeLanguageName 18738
#define sipName_nativeLanguageName &sipStrings_QtCore[18738]
#define sipNameNr_OldHungarianScript 18757
#define sipName_OldHungarianScript &sipStrings_QtCore[18757]
#define sipNameNr_VarangKshitiScript 18776
#define sipName_VarangKshitiScript &sipStrings_QtCore[18776]
#define sipNameNr_MendeKikakuiScript 18795
#define sipName_MendeKikakuiScript &sipStrings_QtCore[18795]
#define sipNameNr_OmitGroupSeparator 18814
#define sipName_OmitGroupSeparator &sipStrings_QtCore[18814]
#define sipNameNr_UnitedArabEmirates 18833
#define sipName_UnitedArabEmirates &sipStrings_QtCore[18833]
#define sipNameNr_SyrianArabRepublic 18852
#define sipName_SyrianArabRepublic &sipStrings_QtCore[18852]
#define sipNameNr_SaoTomeAndPrincipe 18871
#define sipName_SaoTomeAndPrincipe &sipStrings_QtCore[18871]
#define sipNameNr_SaintKittsAndNevis 18890
#define sipName_SaintKittsAndNevis &sipStrings_QtCore[18890]
#define sipNameNr_HieroglyphicLuwian 18909
#define sipName_HieroglyphicLuwian &sipStrings_QtCore[18909]
#define sipNameNr_QLibrary__LoadHint 18928
#define sipName_QLibrary__LoadHint &sipStrings_QtCore[18928]
#define sipNameNr_UnterminatedString 18947
#define sipName_UnterminatedString &sipStrings_QtCore[18947]
#define sipNameNr_UnterminatedObject 18966
#define sipName_UnterminatedObject &sipStrings_QtCore[18966]
#define sipNameNr_currentReadChannel 18985
#define sipName_currentReadChannel &sipStrings_QtCore[18985]
#define sipNameNr_setTextModeEnabled 19004
#define sipName_setTextModeEnabled &sipStrings_QtCore[19004]
#define sipNameNr_historyTypeChanged 19023
#define sipName_historyTypeChanged &sipStrings_QtCore[19023]
#define sipNameNr_QFileSystemWatcher 19042
#define sipName_QFileSystemWatcher &sipStrings_QtCore[19042]
#define sipNameNr_metadataChangeTime 19061
#define sipName_metadataChangeTime &sipStrings_QtCore[19061]
#define sipNameNr_ProcessEventsFlags 2615
#define sipName_ProcessEventsFlags &sipStrings_QtCore[2615]
#define sipNameNr_PerformanceCounter 19080
#define sipName_PerformanceCounter &sipStrings_QtCore[19080]
#define sipNameNr_QEasingCurve__Type 19099
#define sipName_QEasingCurve__Type &sipStrings_QtCore[19099]
#define sipNameNr_toNativeSeparators 19118
#define sipName_toNativeSeparators &sipStrings_QtCore[19118]
#define sipNameNr_setPreciseDeadline 19137
#define sipName_setPreciseDeadline &sipStrings_QtCore[19137]
#define sipNameNr_remainingTimeNSecs 19156
#define sipName_remainingTimeNSecs &sipStrings_QtCore[19156]
#define sipNameNr_fromSecsSinceEpoch 19175
#define sipName_fromSecsSinceEpoch &sipStrings_QtCore[19175]
#define sipNameNr_currentDateTimeUtc 19194
#define sipName_currentDateTimeUtc &sipStrings_QtCore[19194]
#define sipNameNr_setMSecsSinceEpoch 19213
#define sipName_setMSecsSinceEpoch &sipStrings_QtCore[19213]
#define sipNameNr_QCryptographicHash 19232
#define sipName_QCryptographicHash &sipStrings_QtCore[19232]
#define sipNameNr_FocusAboutToChange 19251
#define sipName_FocusAboutToChange &sipStrings_QtCore[19251]
#define sipNameNr_StateMachineSignal 19270
#define sipName_StateMachineSignal &sipStrings_QtCore[19270]
#define sipNameNr_ContentsRectChange 19289
#define sipName_ContentsRectChange &sipStrings_QtCore[19289]
#define sipNameNr_GraphicsSceneWheel 19308
#define sipName_GraphicsSceneWheel &sipStrings_QtCore[19308]
#define sipNameNr_LeaveWhatsThisMode 19327
#define sipName_LeaveWhatsThisMode &sipStrings_QtCore[19327]
#define sipNameNr_EnterWhatsThisMode 19346
#define sipName_EnterWhatsThisMode &sipStrings_QtCore[19346]
#define sipNameNr_MouseButtonRelease 2427
#define sipName_MouseButtonRelease &sipStrings_QtCore[2427]
#define sipNameNr_qRemovePostRoutine 19365
#define sipName_qRemovePostRoutine &sipStrings_QtCore[19365]
#define sipNameNr_setQuitLockEnabled 19384
#define sipName_setQuitLockEnabled &sipStrings_QtCore[19384]
#define sipNameNr_setEventDispatcher 19403
#define sipName_setEventDispatcher &sipStrings_QtCore[19403]
#define sipNameNr_applicationVersion 19422
#define sipName_applicationVersion &sipStrings_QtCore[19422]
#define sipNameNr_applicationDirPath 19441
#define sipName_applicationDirPath &sipStrings_QtCore[19441]
#define sipNameNr_removePostedEvents 19460
#define sipName_removePostedEvents &sipStrings_QtCore[19460]
#define sipNameNr_setApplicationName 19479
#define sipName_setApplicationName &sipStrings_QtCore[19479]
#define sipNameNr_organizationDomain 19498
#define sipName_organizationDomain &sipStrings_QtCore[19498]
#define sipNameNr_unknownOptionNames 19517
#define sipName_unknownOptionNames &sipStrings_QtCore[19517]
#define sipNameNr_ParseAsLongOptions 19536
#define sipName_ParseAsLongOptions &sipStrings_QtCore[19536]
#define sipNameNr_QCommandLineParser 19555
#define sipName_QCommandLineParser &sipStrings_QtCore[19555]
#define sipNameNr_QCommandLineOption 19574
#define sipName_QCommandLineOption &sipStrings_QtCore[19574]
#define sipNameNr_setCaseSensitivity 19593
#define sipName_setCaseSensitivity &sipStrings_QtCore[19593]
#define sipNameNr_availableCalendars 19612
#define sipName_availableCalendars &sipStrings_QtCore[19612]
#define sipNameNr_minimumDaysInMonth 19631
#define sipName_minimumDaysInMonth &sipStrings_QtCore[19631]
#define sipNameNr_maximumDaysInMonth 19650
#define sipName_maximumDaysInMonth &sipStrings_QtCore[19650]
#define sipNameNr_fromBase64Encoding 19669
#define sipName_fromBase64Encoding &sipStrings_QtCore[19669]
#define sipNameNr_IllegalInputLength 19688
#define sipName_IllegalInputLength &sipStrings_QtCore[19688]
#define sipNameNr_OmitTrailingEquals 19707
#define sipName_OmitTrailingEquals &sipStrings_QtCore[19707]
#define sipNameNr_KeepTrailingEquals 19726
#define sipName_KeepTrailingEquals &sipStrings_QtCore[19726]
#define sipNameNr_InternalTransition 19745
#define sipName_InternalTransition &sipStrings_QtCore[19745]
#define sipNameNr_ExternalTransition 19764
#define sipName_ExternalTransition &sipStrings_QtCore[19764]
#define sipNameNr_targetStateChanged 19783
#define sipName_targetStateChanged &sipStrings_QtCore[19783]
#define sipNameNr_sourceModelChanged 19802
#define sipName_sourceModelChanged &sipStrings_QtCore[19802]
#define sipNameNr_QAbstractListModel 19821
#define sipName_QAbstractListModel &sipStrings_QtCore[19821]
#define sipNameNr_rowsAboutToBeMoved 19840
#define sipName_rowsAboutToBeMoved &sipStrings_QtCore[19840]
#define sipNameNr_beginRemoveColumns 19859
#define sipName_beginRemoveColumns &sipStrings_QtCore[19859]
#define sipNameNr_beginInsertColumns 19878
#define sipName_beginInsertColumns &sipStrings_QtCore[19878]
#define sipNameNr_HorizontalSortHint 19897
#define sipName_HorizontalSortHint &sipStrings_QtCore[19897]
#define sipNameNr_NoLayoutChangeHint 19916
#define sipName_NoLayoutChangeHint &sipStrings_QtCore[19916]
#define sipNameNr_QAbstractItemModel 19935
#define sipName_QAbstractItemModel &sipStrings_QtCore[19935]
#define sipNameNr_currentLoopChanged 19954
#define sipName_currentLoopChanged &sipStrings_QtCore[19954]
#define sipNameNr_QAbstractAnimation 19973
#define sipName_QAbstractAnimation &sipStrings_QtCore[19973]
#define sipNameNr_Qt__MouseEventFlag 19992
#define sipName_Qt__MouseEventFlag &sipStrings_QtCore[19992]
#define sipNameNr_SwipeNativeGesture 20011
#define sipName_SwipeNativeGesture &sipStrings_QtCore[20011]
#define sipNameNr_BeginNativeGesture 20030
#define sipName_BeginNativeGesture &sipStrings_QtCore[20030]
#define sipNameNr_Qt__WhiteSpaceMode 20049
#define sipName_Qt__WhiteSpaceMode &sipStrings_QtCore[20049]
#define sipNameNr_ScreenOrientations 10626
#define sipName_ScreenOrientations &sipStrings_QtCore[10626]
#define sipNameNr_PrimaryOrientation 20068
#define sipName_PrimaryOrientation &sipStrings_QtCore[20068]
#define sipNameNr_NavigationModeNone 20087
#define sipName_NavigationModeNone &sipStrings_QtCore[20087]
#define sipNameNr_Qt__NavigationMode 20106
#define sipName_Qt__NavigationMode &sipStrings_QtCore[20106]
#define sipNameNr_TouchPointReleased 20125
#define sipName_TouchPointReleased &sipStrings_QtCore[20125]
#define sipNameNr_LogicalCoordinates 20144
#define sipName_LogicalCoordinates &sipStrings_QtCore[20144]
#define sipNameNr_ImhPreferLowercase 20163
#define sipName_ImhPreferLowercase &sipStrings_QtCore[20163]
#define sipNameNr_ImhPreferUppercase 20182
#define sipName_ImhPreferUppercase &sipStrings_QtCore[20182]
#define sipNameNr_ImhNoAutoUppercase 20201
#define sipName_ImhNoAutoUppercase &sipStrings_QtCore[20201]
#define sipNameNr_BottomRightSection 20220
#define sipName_BottomRightSection &sipStrings_QtCore[20220]
#define sipNameNr_WindowFrameSection 10718
#define sipName_WindowFrameSection &sipStrings_QtCore[10718]
#define sipNameNr_Qt__WindowModality 20239
#define sipName_Qt__WindowModality &sipStrings_QtCore[20239]
#define sipNameNr_MatchCaseSensitive 20258
#define sipName_MatchCaseSensitive &sipStrings_QtCore[20258]
#define sipNameNr_ItemIsAutoTristate 20277
#define sipName_ItemIsAutoTristate &sipStrings_QtCore[20277]
#define sipNameNr_ItemIsUserTristate 20296
#define sipName_ItemIsUserTristate &sipStrings_QtCore[20296]
#define sipNameNr_AccessibleTextRole 20315
#define sipName_AccessibleTextRole &sipStrings_QtCore[20315]
#define sipNameNr_ToolButtonTextOnly 20334
#define sipName_ToolButtonTextOnly &sipStrings_QtCore[20334]
#define sipNameNr_ToolButtonIconOnly 20353
#define sipName_ToolButtonIconOnly &sipStrings_QtCore[20353]
#define sipNameNr_InputMethodQueries 10833
#define sipName_InputMethodQueries &sipStrings_QtCore[10833]
#define sipNameNr_ImTextBeforeCursor 20372
#define sipName_ImTextBeforeCursor &sipStrings_QtCore[20372]
#define sipNameNr_ImAbsolutePosition 20391
#define sipName_ImAbsolutePosition &sipStrings_QtCore[20391]
#define sipNameNr_ImCurrentSelection 20410
#define sipName_ImCurrentSelection &sipStrings_QtCore[20410]
#define sipNameNr_ActionsContextMenu 20429
#define sipName_ActionsContextMenu &sipStrings_QtCore[20429]
#define sipNameNr_DefaultContextMenu 20448
#define sipName_DefaultContextMenu &sipStrings_QtCore[20448]
#define sipNameNr_PreventContextMenu 20467
#define sipName_PreventContextMenu &sipStrings_QtCore[20467]
#define sipNameNr_MenuBarFocusReason 20486
#define sipName_MenuBarFocusReason &sipStrings_QtCore[20486]
#define sipNameNr_BacktabFocusReason 20505
#define sipName_BacktabFocusReason &sipStrings_QtCore[20505]
#define sipNameNr_FastTransformation 20524
#define sipName_FastTransformation &sipStrings_QtCore[20524]
#define sipNameNr_TransformationMode 10856
#define sipName_TransformationMode &sipStrings_QtCore[10856]
#define sipNameNr_Qt__ConnectionType 20543
#define sipName_Qt__ConnectionType &sipStrings_QtCore[20543]
#define sipNameNr_ScrollBarAlwaysOff 20562
#define sipName_ScrollBarAlwaysOff &sipStrings_QtCore[20562]
#define sipNameNr_AllDockWidgetAreas 20581
#define sipName_AllDockWidgetAreas &sipStrings_QtCore[20581]
#define sipNameNr_LeftDockWidgetArea 20600
#define sipName_LeftDockWidgetArea &sipStrings_QtCore[20600]
#define sipNameNr_Qt__DockWidgetArea 20619
#define sipName_Qt__DockWidgetArea &sipStrings_QtCore[20619]
#define sipNameNr_PointingHandCursor 20638
#define sipName_PointingHandCursor &sipStrings_QtCore[20638]
#define sipNameNr_Key_Dead_Belowring 20657
#define sipName_Key_Dead_Belowring &sipStrings_QtCore[20657]
#define sipNameNr_Key_TouchpadToggle 20676
#define sipName_Key_TouchpadToggle &sipStrings_QtCore[20676]
#define sipNameNr_Key_ContrastAdjust 20695
#define sipName_Key_ContrastAdjust &sipStrings_QtCore[20695]
#define sipNameNr_Key_Dead_Abovering 20714
#define sipName_Key_Dead_Abovering &sipStrings_QtCore[20714]
#define sipNameNr_Key_Dead_Diaeresis 20733
#define sipName_Key_Dead_Diaeresis &sipStrings_QtCore[20733]
#define sipNameNr_Key_Hangul_Special 20752
#define sipName_Key_Hangul_Special &sipStrings_QtCore[20752]
#define sipNameNr_Key_guillemotright 20771
#define sipName_Key_guillemotright &sipStrings_QtCore[20771]
#define sipNameNr_Key_periodcentered 20790
#define sipName_Key_periodcentered &sipStrings_QtCore[20790]
#define sipNameNr_NoFormatConversion 20809
#define sipName_NoFormatConversion &sipStrings_QtCore[20809]
#define sipNameNr_DiffuseAlphaDither 20828
#define sipName_DiffuseAlphaDither &sipStrings_QtCore[20828]
#define sipNameNr_OrderedAlphaDither 20847
#define sipName_OrderedAlphaDither &sipStrings_QtCore[20847]
#define sipNameNr_WA_MacVariableSize 20866
#define sipName_WA_MacVariableSize &sipStrings_QtCore[20866]
#define sipNameNr_WA_MacBrushedMetal 20885
#define sipName_WA_MacBrushedMetal &sipStrings_QtCore[20885]
#define sipNameNr_WA_WState_Polished 20904
#define sipName_WA_WState_Polished &sipStrings_QtCore[20904]
#define sipNameNr_WA_GrabbedShortcut 20923
#define sipName_WA_GrabbedShortcut &sipStrings_QtCore[20923]
#define sipNameNr_WA_CustomWhatsThis 20942
#define sipName_WA_CustomWhatsThis &sipStrings_QtCore[20942]
#define sipNameNr_WA_UpdatesDisabled 20961
#define sipName_WA_UpdatesDisabled &sipStrings_QtCore[20961]
#define sipNameNr_AlignVertical_Mask 20980
#define sipName_AlignVertical_Mask &sipStrings_QtCore[20980]
#define sipNameNr_pyqtPickleProtocol 20999
#define sipName_pyqtPickleProtocol &sipStrings_QtCore[20999]
#define sipNameNr_21018 21018
#define sipName_21018 &sipStrings_QtCore[21018]
#define sipNameNr_prettyProductName 21036
#define sipName_prettyProductName &sipStrings_QtCore[21036]
#define sipNameNr_writeCurrentToken 21054
#define sipName_writeCurrentToken &sipStrings_QtCore[21054]
#define sipNameNr_writeStartElement 21072
#define sipName_writeStartElement &sipStrings_QtCore[21072]
#define sipNameNr_writeEmptyElement 21090
#define sipName_writeEmptyElement &sipStrings_QtCore[21090]
#define sipNameNr_setAutoFormatting 21108
#define sipName_setAutoFormatting &sipStrings_QtCore[21108]
#define sipNameNr_setEntityResolver 21126
#define sipName_setEntityResolver &sipStrings_QtCore[21126]
#define sipNameNr_SkipChildElements 21144
#define sipName_SkipChildElements &sipStrings_QtCore[21144]
#define sipNameNr_isEntityReference 21162
#define sipName_isEntityReference &sipStrings_QtCore[21162]
#define sipNameNr_DefaultResolution 21180
#define sipName_DefaultResolution &sipStrings_QtCore[21180]
#define sipNameNr_FormattingOptions 1745
#define sipName_FormattingOptions &sipStrings_QtCore[1745]
#define sipNameNr_QUrl__ParsingMode 21198
#define sipName_QUrl__ParsingMode &sipStrings_QtCore[21198]
#define sipNameNr_ianaIdToWindowsId 21216
#define sipName_ianaIdToWindowsId &sipStrings_QtCore[21216]
#define sipNameNr_setUpdateInterval 21234
#define sipName_setUpdateInterval &sipStrings_QtCore[21234]
#define sipNameNr_activeThreadCount 21252
#define sipName_activeThreadCount &sipStrings_QtCore[21252]
#define sipNameNr_setMaxThreadCount 21270
#define sipName_setMaxThreadCount &sipStrings_QtCore[21270]
#define sipNameNr_QThread__Priority 21288
#define sipName_QThread__Priority &sipStrings_QtCore[21288]
#define sipNameNr_setFieldAlignment 21306
#define sipName_setFieldAlignment &sipStrings_QtCore[21306]
#define sipNameNr_autoDetectUnicode 21324
#define sipName_autoDetectUnicode &sipStrings_QtCore[21324]
#define sipNameNr_DefaultConversion 21342
#define sipName_DefaultConversion &sipStrings_QtCore[21342]
#define sipNameNr_setCodecForLocale 21360
#define sipName_setCodecForLocale &sipStrings_QtCore[21360]
#define sipNameNr_defaultAnimations 21378
#define sipName_defaultAnimations &sipStrings_QtCore[21378]
#define sipNameNr_errorStateChanged 21396
#define sipName_errorStateChanged &sipStrings_QtCore[21396]
#define sipNameNr_RestoreProperties 11351
#define sipName_RestoreProperties &sipStrings_QtCore[11351]
#define sipNameNr_QState__ChildMode 21414
#define sipName_QState__ChildMode &sipStrings_QtCore[21414]
#define sipNameNr_standardLocations 21432
#define sipName_standardLocations &sipStrings_QtCore[21432]
#define sipNameNr_AppConfigLocation 21450
#define sipName_AppConfigLocation &sipStrings_QtCore[21450]
#define sipNameNr_DocumentsLocation 21468
#define sipName_DocumentsLocation &sipStrings_QtCore[21468]
#define sipNameNr_filterRoleChanged 21486
#define sipName_filterRoleChanged &sipStrings_QtCore[21486]
#define sipNameNr_isSortLocaleAware 21504
#define sipName_isSortLocaleAware &sipStrings_QtCore[21504]
#define sipNameNr_dynamicSortFilter 21522
#define sipName_dynamicSortFilter &sipStrings_QtCore[21522]
#define sipNameNr_setFilterWildcard 21540
#define sipName_setFilterWildcard &sipStrings_QtCore[21540]
#define sipNameNr_QSignalTransition 21558
#define sipName_QSignalTransition &sipStrings_QtCore[21558]
#define sipNameNr_SharedMemoryError 1844
#define sipName_SharedMemoryError &sipStrings_QtCore[1844]
#define sipNameNr_QSettings__Format 21576
#define sipName_QSettings__Format &sipStrings_QtCore[21576]
#define sipNameNr_QSettings__Status 21594
#define sipName_QSettings__Status &sipStrings_QtCore[21594]
#define sipNameNr_lastCapturedIndex 21612
#define sipName_lastCapturedIndex &sipStrings_QtCore[21612]
#define sipNameNr_regularExpression 21630
#define sipName_regularExpression &sipStrings_QtCore[21630]
#define sipNameNr_setPatternOptions 21648
#define sipName_setPatternOptions &sipStrings_QtCore[21648]
#define sipNameNr_DontCaptureOption 21666
#define sipName_DontCaptureOption &sipStrings_QtCore[21666]
#define sipNameNr_setupChildProcess 21684
#define sipName_setupChildProcess &sipStrings_QtCore[21684]
#define sipNameNr_systemEnvironment 21702
#define sipName_systemEnvironment &sipStrings_QtCore[21702]
#define sipNameNr_closeWriteChannel 21720
#define sipName_closeWriteChannel &sipStrings_QtCore[21720]
#define sipNameNr_ForwardedChannels 21738
#define sipName_ForwardedChannels &sipStrings_QtCore[21738]
#define sipNameNr_QVariantAnimation 21756
#define sipName_QVariantAnimation &sipStrings_QtCore[21756]
#define sipNameNr_AndroidNougat_MR1 21774
#define sipName_AndroidNougat_MR1 &sipStrings_QtCore[21774]
#define sipNameNr_indexOfEnumerator 21792
#define sipName_indexOfEnumerator &sipStrings_QtCore[21792]
#define sipNameNr_QT_TRANSLATE_NOOP 21810
#define sipName_QT_TRANSLATE_NOOP &sipStrings_QtCore[21810]
#define sipNameNr_isSignalConnected 21828
#define sipName_isSignalConnected &sipStrings_QtCore[21828]
#define sipNameNr_senderSignalIndex 21846
#define sipName_senderSignalIndex &sipStrings_QtCore[21846]
#define sipNameNr_objectNameChanged 21864
#define sipName_objectNameChanged &sipStrings_QtCore[21864]
#define sipNameNr_removeEventFilter 21882
#define sipName_removeEventFilter &sipStrings_QtCore[21882]
#define sipNameNr_suffixForFileName 21900
#define sipName_suffixForFileName &sipStrings_QtCore[21900]
#define sipNameNr_metaObjectForType 21918
#define sipName_metaObjectForType &sipStrings_QtCore[21918]
#define sipNameNr_NeedsConstruction 21936
#define sipName_NeedsConstruction &sipStrings_QtCore[21936]
#define sipNameNr_notifySignalIndex 21954
#define sipName_notifySignalIndex &sipStrings_QtCore[21954]
#define sipNameNr_isCriticalEnabled 21972
#define sipName_isCriticalEnabled &sipStrings_QtCore[21972]
#define sipNameNr_qFormatLogMessage 21990
#define sipName_qFormatLogMessage &sipStrings_QtCore[21990]
#define sipNameNr_formattedDataSize 22008
#define sipName_formattedDataSize &sipStrings_QtCore[22008]
#define sipNameNr_DataSizeIecFormat 22026
#define sipName_DataSizeIecFormat &sipStrings_QtCore[22026]
#define sipNameNr_StandardQuotation 22044
#define sipName_StandardQuotation &sipStrings_QtCore[22044]
#define sipNameNr_nativeCountryName 22062
#define sipName_nativeCountryName &sipStrings_QtCore[22062]
#define sipNameNr_SignWritingScript 22080
#define sipName_SignWritingScript &sipStrings_QtCore[22080]
#define sipNameNr_PahawhHmongScript 22098
#define sipName_PahawhHmongScript &sipStrings_QtCore[22098]
#define sipNameNr_SylotiNagriScript 22116
#define sipName_SylotiNagriScript &sipStrings_QtCore[22116]
#define sipNameNr_SoraSompengScript 22134
#define sipName_SoraSompengScript &sipStrings_QtCore[22134]
#define sipNameNr_MeiteiMayekScript 22152
#define sipName_MeiteiMayekScript &sipStrings_QtCore[22152]
#define sipNameNr_standaloneDayName 22170
#define sipName_standaloneDayName &sipStrings_QtCore[22170]
#define sipNameNr_measurementSystem 22188
#define sipName_measurementSystem &sipStrings_QtCore[22188]
#define sipNameNr_MeasurementSystem 5208
#define sipName_MeasurementSystem &sipStrings_QtCore[5208]
#define sipNameNr_TrinidadAndTobago 22206
#define sipName_TrinidadAndTobago &sipStrings_QtCore[22206]
#define sipNameNr_RussianFederation 22224
#define sipName_RussianFederation &sipStrings_QtCore[22224]
#define sipNameNr_DominicanRepublic 22242
#define sipName_DominicanRepublic &sipStrings_QtCore[22242]
#define sipNameNr_AntiguaAndBarbuda 22260
#define sipName_AntiguaAndBarbuda &sipStrings_QtCore[22260]
#define sipNameNr_QLocale__Language 22278
#define sipName_QLocale__Language &sipStrings_QtCore[22278]
#define sipNameNr_DocumentationPath 22296
#define sipName_DocumentationPath &sipStrings_QtCore[22296]
#define sipNameNr_PreventUnloadHint 22314
#define sipName_PreventUnloadHint &sipStrings_QtCore[22314]
#define sipNameNr_IllegalUTF8String 22332
#define sipName_IllegalUTF8String &sipStrings_QtCore[22332]
#define sipNameNr_UnterminatedArray 22350
#define sipName_UnterminatedArray &sipStrings_QtCore[22350]
#define sipNameNr_currentRowChanged 22368
#define sipName_currentRowChanged &sipStrings_QtCore[22368]
#define sipNameNr_clearCurrentIndex 22386
#define sipName_clearCurrentIndex &sipStrings_QtCore[22386]
#define sipNameNr_writeChannelCount 22404
#define sipName_writeChannelCount &sipStrings_QtCore[22404]
#define sipNameNr_isTextModeEnabled 22422
#define sipName_isTextModeEnabled &sipStrings_QtCore[22422]
#define sipNameNr_defaultTransition 22440
#define sipName_defaultTransition &sipStrings_QtCore[22440]
#define sipNameNr_setExtraSelectors 22458
#define sipName_setExtraSelectors &sipStrings_QtCore[22458]
#define sipNameNr_canonicalFilePath 22476
#define sipName_canonicalFilePath &sipStrings_QtCore[22476]
#define sipNameNr_WaitForMoreEvents 22494
#define sipName_WaitForMoreEvents &sipStrings_QtCore[22494]
#define sipNameNr_ProcessEventsFlag 2978
#define sipName_ProcessEventsFlag &sipStrings_QtCore[2978]
#define sipNameNr_removeRecursively 22512
#define sipName_removeRecursively &sipStrings_QtCore[22512]
#define sipNameNr_setSecsSinceEpoch 22530
#define sipName_setSecsSinceEpoch &sipStrings_QtCore[22530]
#define sipNameNr_toMSecsSinceEpoch 22548
#define sipName_toMSecsSinceEpoch &sipStrings_QtCore[22548]
#define sipNameNr_commitTransaction 22566
#define sipName_commitTransaction &sipStrings_QtCore[22566]
#define sipNameNr_writeQVariantHash 22584
#define sipName_writeQVariantHash &sipStrings_QtCore[22584]
#define sipNameNr_writeQVariantList 22602
#define sipName_writeQVariantList &sipStrings_QtCore[22602]
#define sipNameNr_registerEventType 22620
#define sipName_registerEventType &sipStrings_QtCore[22620]
#define sipNameNr_OrientationChange 22638
#define sipName_OrientationChange &sipStrings_QtCore[22638]
#define sipNameNr_GraphicsSceneMove 22656
#define sipName_GraphicsSceneMove &sipStrings_QtCore[22656]
#define sipNameNr_GraphicsSceneDrop 22674
#define sipName_GraphicsSceneDrop &sipStrings_QtCore[22674]
#define sipNameNr_GraphicsSceneHelp 22692
#define sipName_GraphicsSceneHelp &sipStrings_QtCore[22692]
#define sipNameNr_WindowStateChange 22710
#define sipName_WindowStateChange &sipStrings_QtCore[22710]
#define sipNameNr_WindowTitleChange 22728
#define sipName_WindowTitleChange &sipStrings_QtCore[22728]
#define sipNameNr_isQuitLockEnabled 22746
#define sipName_isQuitLockEnabled &sipStrings_QtCore[22746]
#define sipNameNr_installTranslator 22764
#define sipName_installTranslator &sipStrings_QtCore[22764]
#define sipNameNr_removeLibraryPath 22782
#define sipName_removeLibraryPath &sipStrings_QtCore[22782]
#define sipNameNr_removeSourceModel 22800
#define sipName_removeSourceModel &sipStrings_QtCore[22800]
#define sipNameNr_ignorePunctuation 22818
#define sipName_ignorePunctuation &sipStrings_QtCore[22818]
#define sipNameNr_toUnsignedInteger 22836
#define sipName_toUnsignedInteger &sipStrings_QtCore[22836]
#define sipNameNr_isNegativeInteger 22854
#define sipName_isNegativeInteger &sipStrings_QtCore[22854]
#define sipNameNr_isUnsignedInteger 22872
#define sipName_isUnsignedInteger &sipStrings_QtCore[22872]
#define sipNameNr_QCborStreamReader 22890
#define sipName_QCborStreamReader &sipStrings_QtCore[22890]
#define sipNameNr_QCborStreamWriter 22908
#define sipName_QCborStreamWriter &sipStrings_QtCore[22908]
#define sipNameNr_RegularExpression 4163
#define sipName_RegularExpression &sipStrings_QtCore[4163]
#define sipNameNr_ExpectedBase64url 22926
#define sipName_ExpectedBase64url &sipStrings_QtCore[22926]
#define sipNameNr_InvalidUtf8String 22944
#define sipName_InvalidUtf8String &sipStrings_QtCore[22944]
#define sipNameNr_IllegalSimpleType 22962
#define sipName_IllegalSimpleType &sipStrings_QtCore[22962]
#define sipNameNr_QCalendar__System 22980
#define sipName_QCalendar__System &sipStrings_QtCore[22980]
#define sipNameNr_QByteArrayMatcher 22998
#define sipName_QByteArrayMatcher &sipStrings_QtCore[22998]
#define sipNameNr_Base64UrlEncoding 23016
#define sipName_Base64UrlEncoding &sipStrings_QtCore[23016]
#define sipNameNr_toPercentEncoding 23034
#define sipName_toPercentEncoding &sipStrings_QtCore[23034]
#define sipNameNr_setTransitionType 23052
#define sipName_setTransitionType &sipStrings_QtCore[23052]
#define sipNameNr_nativeEventFilter 23070
#define sipName_nativeEventFilter &sipStrings_QtCore[23070]
#define sipNameNr_CheckIndexOptions 690
#define sipName_CheckIndexOptions &sipStrings_QtCore[690]
#define sipNameNr_resetInternalData 23088
#define sipName_resetInternalData &sipStrings_QtCore[23088]
#define sipNameNr_headerDataChanged 23106
#define sipName_headerDataChanged &sipStrings_QtCore[23106]
#define sipNameNr_filterNativeEvent 23124
#define sipName_filterNativeEvent &sipStrings_QtCore[23124]
#define sipNameNr_updateCurrentTime 23142
#define sipName_updateCurrentTime &sipStrings_QtCore[23142]
#define sipNameNr_DeleteWhenStopped 23160
#define sipName_DeleteWhenStopped &sipStrings_QtCore[23160]
#define sipNameNr_ZoomNativeGesture 10581
#define sipName_ZoomNativeGesture &sipStrings_QtCore[10581]
#define sipNameNr_NativeGestureType 12451
#define sipName_NativeGestureType &sipStrings_QtCore[12451]
#define sipNameNr_ApplicationStates 12473
#define sipName_ApplicationStates &sipStrings_QtCore[12473]
#define sipNameNr_ApplicationActive 23178
#define sipName_ApplicationActive &sipStrings_QtCore[23178]
#define sipNameNr_ApplicationHidden 23196
#define sipName_ApplicationHidden &sipStrings_QtCore[23196]
#define sipNameNr_ScreenOrientation 12495
#define sipName_ScreenOrientation &sipStrings_QtCore[12495]
#define sipNameNr_TapAndHoldGesture 23214
#define sipName_TapAndHoldGesture &sipStrings_QtCore[23214]
#define sipNameNr_TouchPointPressed 23232
#define sipName_TouchPointPressed &sipStrings_QtCore[23232]
#define sipNameNr_DeviceCoordinates 23250
#define sipName_DeviceCoordinates &sipStrings_QtCore[23250]
#define sipNameNr_BottomLeftSection 23268
#define sipName_BottomLeftSection &sipStrings_QtCore[23268]
#define sipNameNr_HighEventPriority 23286
#define sipName_HighEventPriority &sipStrings_QtCore[23286]
#define sipNameNr_Qt__EventPriority 23304
#define sipName_Qt__EventPriority &sipStrings_QtCore[23304]
#define sipNameNr_NoTextInteraction 23322
#define sipName_NoTextInteraction &sipStrings_QtCore[23322]
#define sipNameNr_ContainsItemShape 23340
#define sipName_ContainsItemShape &sipStrings_QtCore[23340]
#define sipNameNr_ItemSelectionMode 12583
#define sipName_ItemSelectionMode &sipStrings_QtCore[12583]
#define sipNameNr_AA_X11InitThreads 23358
#define sipName_AA_X11InitThreads &sipStrings_QtCore[23358]
#define sipNameNr_ItemIsDropEnabled 23376
#define sipName_ItemIsDropEnabled &sipStrings_QtCore[23376]
#define sipNameNr_ItemIsDragEnabled 23394
#define sipName_ItemIsDragEnabled &sipStrings_QtCore[23394]
#define sipNameNr_TextAlignmentRole 23412
#define sipName_TextAlignmentRole &sipStrings_QtCore[23412]
#define sipNameNr_ImAnchorRectangle 23430
#define sipName_ImAnchorRectangle &sipStrings_QtCore[23430]
#define sipNameNr_ImTextAfterCursor 23448
#define sipName_ImTextAfterCursor &sipStrings_QtCore[23448]
#define sipNameNr_ImCursorRectangle 23466
#define sipName_ImCursorRectangle &sipStrings_QtCore[23466]
#define sipNameNr_ImSurroundingText 23484
#define sipName_ImSurroundingText &sipStrings_QtCore[23484]
#define sipNameNr_CustomContextMenu 23502
#define sipName_CustomContextMenu &sipStrings_QtCore[23502]
#define sipNameNr_ContextMenuPolicy 12649
#define sipName_ContextMenuPolicy &sipStrings_QtCore[12649]
#define sipNameNr_Qt__ClipOperation 23520
#define sipName_Qt__ClipOperation &sipStrings_QtCore[23520]
#define sipNameNr_BottomRightCorner 23538
#define sipName_BottomRightCorner &sipStrings_QtCore[23538]
#define sipNameNr_ScrollBarAlwaysOn 23556
#define sipName_ScrollBarAlwaysOn &sipStrings_QtCore[23556]
#define sipNameNr_ScrollBarAsNeeded 23574
#define sipName_ScrollBarAsNeeded &sipStrings_QtCore[23574]
#define sipNameNr_BottomToolBarArea 23592
#define sipName_BottomToolBarArea &sipStrings_QtCore[23592]
#define sipNameNr_TopDockWidgetArea 23610
#define sipName_TopDockWidgetArea &sipStrings_QtCore[23610]
#define sipNameNr_IgnoreAspectRatio 23628
#define sipName_IgnoreAspectRatio &sipStrings_QtCore[23628]
#define sipNameNr_UI_AnimateToolBox 23646
#define sipName_UI_AnimateToolBox &sipStrings_QtCore[23646]
#define sipNameNr_UI_AnimateTooltip 23664
#define sipName_UI_AnimateTooltip &sipStrings_QtCore[23664]
#define sipNameNr_Key_Dead_Currency 23682
#define sipName_Key_Dead_Currency &sipStrings_QtCore[23682]
#define sipNameNr_Key_MicVolumeDown 23700
#define sipName_Key_MicVolumeDown &sipStrings_QtCore[23700]
#define sipNameNr_Key_RotateWindows 23718
#define sipName_Key_RotateWindows &sipStrings_QtCore[23718]
#define sipNameNr_Key_MediaPrevious 23736
#define sipName_Key_MediaPrevious &sipStrings_QtCore[23736]
#define sipNameNr_Key_Dead_Belowdot 23754
#define sipName_Key_Dead_Belowdot &sipStrings_QtCore[23754]
#define sipNameNr_Key_Dead_Abovedot 23772
#define sipName_Key_Dead_Abovedot &sipStrings_QtCore[23772]
#define sipNameNr_Key_Hangul_Jeonja 23790
#define sipName_Key_Hangul_Jeonja &sipStrings_QtCore[23790]
#define sipNameNr_Key_Hangul_Romaja 23808
#define sipName_Key_Hangul_Romaja &sipStrings_QtCore[23808]
#define sipNameNr_Key_threequarters 23826
#define sipName_Key_threequarters &sipStrings_QtCore[23826]
#define sipNameNr_Key_threesuperior 23844
#define sipName_Key_threesuperior &sipStrings_QtCore[23844]
#define sipNameNr_Key_guillemotleft 23862
#define sipName_Key_guillemotleft &sipStrings_QtCore[23862]
#define sipNameNr_NoOpaqueDetection 23880
#define sipName_NoOpaqueDetection &sipStrings_QtCore[23880]
#define sipNameNr_WA_TabletTracking 23898
#define sipName_WA_TabletTracking &sipStrings_QtCore[23898]
#define sipNameNr_WA_AttributeCount 23916
#define sipName_WA_AttributeCount &sipStrings_QtCore[23916]
#define sipNameNr_WA_WState_Created 23934
#define sipName_WA_WState_Created &sipStrings_QtCore[23934]
#define sipNameNr_WA_PaintUnclipped 23952
#define sipName_WA_PaintUnclipped &sipStrings_QtCore[23952]
#define sipNameNr_WA_OutsideWSRange 23970
#define sipName_WA_OutsideWSRange &sipStrings_QtCore[23970]
#define sipNameNr_WA_WindowModified 23988
#define sipName_WA_WindowModified &sipStrings_QtCore[23988]
#define sipNameNr_WA_KeyCompression 24006
#define sipName_WA_KeyCompression &sipStrings_QtCore[24006]
#define sipNameNr_WA_WState_Visible 24024
#define sipName_WA_WState_Visible &sipStrings_QtCore[24024]
#define sipNameNr_WA_StaticContents 24042
#define sipName_WA_StaticContents &sipStrings_QtCore[24042]
#define sipNameNr_Qt__TextElideMode 24060
#define sipName_Qt__TextElideMode &sipStrings_QtCore[24060]
#define sipNameNr_Qt__AlignmentFlag 24078
#define sipName_Qt__AlignmentFlag &sipStrings_QtCore[24078]
#define sipNameNr_KeyboardModifiers 13089
#define sipName_KeyboardModifiers &sipStrings_QtCore[13089]
#define sipNameNr_sip_simplewrapper 24096
#define sipName_sip_simplewrapper &sipStrings_QtCore[24096]
#define sipNameNr_24114 24114
#define sipName_24114 &sipStrings_QtCore[24114]
#define sipNameNr_24131 24131
#define sipName_24131 &sipStrings_QtCore[24131]
#define sipNameNr_24148 24148
#define sipName_24148 &sipStrings_QtCore[24148]
#define sipNameNr_24165 24165
#define sipName_24165 &sipStrings_QtCore[24165]
#define sipNameNr_QSysInfo__Endian 24182
#define sipName_QSysInfo__Endian &sipStrings_QtCore[24182]
#define sipNameNr_writeEndDocument 24199
#define sipName_writeEndDocument &sipStrings_QtCore[24199]
#define sipNameNr_writeTextElement 24216
#define sipName_writeTextElement &sipStrings_QtCore[24216]
#define sipNameNr_QXmlStreamWriter 24233
#define sipName_QXmlStreamWriter &sipStrings_QtCore[24233]
#define sipNameNr_documentEncoding 24250
#define sipName_documentEncoding &sipStrings_QtCore[24250]
#define sipNameNr_QXmlStreamReader 24267
#define sipName_QXmlStreamReader &sipStrings_QtCore[24267]
#define sipNameNr_EncodeDelimiters 24284
#define sipName_EncodeDelimiters &sipStrings_QtCore[24284]
#define sipNameNr_searchDelimiters 24301
#define sipName_searchDelimiters &sipStrings_QtCore[24301]
#define sipNameNr_systemTimeZoneId 24318
#define sipName_systemTimeZoneId &sipStrings_QtCore[24318]
#define sipNameNr_QTimeLine__State 24335
#define sipName_QTimeLine__State &sipStrings_QtCore[24335]
#define sipNameNr_setExpiryTimeout 24352
#define sipName_setExpiryTimeout &sipStrings_QtCore[24352]
#define sipNameNr_idealThreadCount 24369
#define sipName_idealThreadCount &sipStrings_QtCore[24369]
#define sipNameNr_convertToUnicode 24386
#define sipName_convertToUnicode &sipStrings_QtCore[24386]
#define sipNameNr_BreakOpportunity 24403
#define sipName_BreakOpportunity &sipStrings_QtCore[24403]
#define sipNameNr_createNativeFile 24420
#define sipName_createNativeFile &sipStrings_QtCore[24420]
#define sipNameNr_QSystemSemaphore 24437
#define sipName_QSystemSemaphore &sipStrings_QtCore[24437]
#define sipNameNr_QStringListModel 24454
#define sipName_QStringListModel &sipStrings_QtCore[24454]
#define sipNameNr_postDelayedEvent 24471
#define sipName_postDelayedEvent &sipStrings_QtCore[24471]
#define sipNameNr_childModeChanged 24488
#define sipName_childModeChanged &sipStrings_QtCore[24488]
#define sipNameNr_removeTransition 24505
#define sipName_removeTransition &sipStrings_QtCore[24505]
#define sipNameNr_writableLocation 24522
#define sipName_writableLocation &sipStrings_QtCore[24522]
#define sipNameNr_DownloadLocation 24539
#define sipName_DownloadLocation &sipStrings_QtCore[24539]
#define sipNameNr_PicturesLocation 24556
#define sipName_PicturesLocation &sipStrings_QtCore[24556]
#define sipNameNr_StandardLocation 1779
#define sipName_StandardLocation &sipStrings_QtCore[1779]
#define sipNameNr_invalidateFilter 24573
#define sipName_invalidateFilter &sipStrings_QtCore[24573]
#define sipNameNr_filterAcceptsRow 24590
#define sipName_filterAcceptsRow &sipStrings_QtCore[24590]
#define sipNameNr_PermissionDenied 24607
#define sipName_PermissionDenied &sipStrings_QtCore[24607]
#define sipNameNr_setDefaultFormat 24624
#define sipName_setDefaultFormat &sipStrings_QtCore[24624]
#define sipNameNr_fallbacksEnabled 24641
#define sipName_fallbacksEnabled &sipStrings_QtCore[24641]
#define sipNameNr_QSettings__Scope 24658
#define sipName_QSettings__Scope &sipStrings_QtCore[24658]
#define sipNameNr_currentAnimation 24675
#define sipName_currentAnimation &sipStrings_QtCore[24675]
#define sipNameNr_uncompressedData 24692
#define sipName_uncompressedData &sipStrings_QtCore[24692]
#define sipNameNr_uncompressedSize 24709
#define sipName_uncompressedSize &sipStrings_QtCore[24709]
#define sipNameNr_registerResource 18436
#define sipName_registerResource &sipStrings_QtCore[18436]
#define sipNameNr_setPatternSyntax 24726
#define sipName_setPatternSyntax &sipStrings_QtCore[24726]
#define sipNameNr_QRandomGenerator 24743
#define sipName_QRandomGenerator &sipStrings_QtCore[24743]
#define sipNameNr_inputChannelMode 24760
#define sipName_inputChannelMode &sipStrings_QtCore[24760]
#define sipNameNr_InputChannelMode 5074
#define sipName_InputChannelMode &sipStrings_QtCore[5074]
#define sipNameNr_workingDirectory 24777
#define sipName_workingDirectory &sipStrings_QtCore[24777]
#define sipNameNr_closeReadChannel 24794
#define sipName_closeReadChannel &sipStrings_QtCore[24794]
#define sipNameNr_SeparateChannels 24811
#define sipName_SeparateChannels &sipStrings_QtCore[24811]
#define sipNameNr_AndroidJellyBean 24828
#define sipName_AndroidJellyBean &sipStrings_QtCore[24828]
#define sipNameNr_QGenericArgument 24845
#define sipName_QGenericArgument &sipStrings_QtCore[24845]
#define sipNameNr_constructorCount 24862
#define sipName_constructorCount &sipStrings_QtCore[24862]
#define sipNameNr_checkConnectArgs 24879
#define sipName_checkConnectArgs &sipStrings_QtCore[24879]
#define sipNameNr_indexOfClassInfo 24896
#define sipName_indexOfClassInfo &sipStrings_QtCore[24896]
#define sipNameNr_enumeratorOffset 24913
#define sipName_enumeratorOffset &sipStrings_QtCore[24913]
#define sipNameNr_staticMetaObject 24930
#define sipName_staticMetaObject &sipStrings_QtCore[24930]
#define sipNameNr_PointerToQObject 24947
#define sipName_PointerToQObject &sipStrings_QtCore[24947]
#define sipNameNr_NeedsDestruction 24964
#define sipName_NeedsDestruction &sipStrings_QtCore[24964]
#define sipNameNr_isWarningEnabled 24981
#define sipName_isWarningEnabled &sipStrings_QtCore[24981]
#define sipNameNr_QLoggingCategory 24998
#define sipName_QLoggingCategory &sipStrings_QtCore[24998]
#define sipNameNr_setStaleLockTime 25015
#define sipName_setStaleLockTime &sipStrings_QtCore[25015]
#define sipNameNr_DataSizeSIFormat 25032
#define sipName_DataSizeSIFormat &sipStrings_QtCore[25032]
#define sipNameNr_toCurrencyString 25049
#define sipName_toCurrencyString &sipStrings_QtCore[25049]
#define sipNameNr_ManichaeanScript 25066
#define sipName_ManichaeanScript &sipStrings_QtCore[25066]
#define sipNameNr_SaurashtraScript 25083
#define sipName_SaurashtraScript &sipStrings_QtCore[25083]
#define sipNameNr_PhoenicianScript 25100
#define sipName_PhoenicianScript &sipStrings_QtCore[25100]
#define sipNameNr_OldPersianScript 25117
#define sipName_OldPersianScript &sipStrings_QtCore[25117]
#define sipNameNr_KharoshthiScript 25134
#define sipName_KharoshthiScript &sipStrings_QtCore[25134]
#define sipNameNr_GlagoliticScript 25151
#define sipName_GlagoliticScript &sipStrings_QtCore[25151]
#define sipNameNr_DevanagariScript 25168
#define sipName_DevanagariScript &sipStrings_QtCore[25168]
#define sipNameNr_ImperialUKSystem 25185
#define sipName_ImperialUKSystem &sipStrings_QtCore[25185]
#define sipNameNr_ImperialUSSystem 25202
#define sipName_ImperialUSSystem &sipStrings_QtCore[25202]
#define sipNameNr_setNumberOptions 25219
#define sipName_setNumberOptions &sipStrings_QtCore[25219]
#define sipNameNr_languageToString 25236
#define sipName_languageToString &sipStrings_QtCore[25236]
#define sipNameNr_ClippertonIsland 25253
#define sipName_ClippertonIsland &sipStrings_QtCore[25253]
#define sipNameNr_CongoBrazzaville 25270
#define sipName_CongoBrazzaville &sipStrings_QtCore[25270]
#define sipNameNr_VaticanCityState 25287
#define sipName_VaticanCityState &sipStrings_QtCore[25287]
#define sipNameNr_EquatorialGuinea 25304
#define sipName_EquatorialGuinea &sipStrings_QtCore[25304]
#define sipNameNr_QLocale__Country 25321
#define sipName_QLocale__Country &sipStrings_QtCore[25321]
#define sipNameNr_UncodedLanguages 25338
#define sipName_UncodedLanguages &sipStrings_QtCore[25338]
#define sipNameNr_LargeFloweryMiao 25355
#define sipName_LargeFloweryMiao &sipStrings_QtCore[25355]
#define sipNameNr_ClassicalMandaic 25372
#define sipName_ClassicalMandaic &sipStrings_QtCore[25372]
#define sipNameNr_NorwegianNynorsk 25389
#define sipName_NorwegianNynorsk &sipStrings_QtCore[25389]
#define sipNameNr_TranslationsPath 25406
#define sipName_TranslationsPath &sipStrings_QtCore[25406]
#define sipNameNr_licensedProducts 25423
#define sipName_licensedProducts &sipStrings_QtCore[25423]
#define sipNameNr_QJsonValue__Type 25440
#define sipName_QJsonValue__Type &sipStrings_QtCore[25440]
#define sipNameNr_BypassValidation 25457
#define sipName_BypassValidation &sipStrings_QtCore[25457]
#define sipNameNr_DocumentTooLarge 25474
#define sipName_DocumentTooLarge &sipStrings_QtCore[25474]
#define sipNameNr_selectionChanged 25491
#define sipName_selectionChanged &sipStrings_QtCore[25491]
#define sipNameNr_isColumnSelected 25508
#define sipName_isColumnSelected &sipStrings_QtCore[25508]
#define sipNameNr_channelReadyRead 25525
#define sipName_channelReadyRead &sipStrings_QtCore[25525]
#define sipNameNr_readChannelCount 25542
#define sipName_readChannelCount &sipStrings_QtCore[25542]
#define sipNameNr_waitForReadyRead 25559
#define sipName_waitForReadyRead &sipStrings_QtCore[25559]
#define sipNameNr_directoryChanged 25576
#define sipName_directoryChanged &sipStrings_QtCore[25576]
#define sipNameNr_completeBaseName 25593
#define sipName_completeBaseName &sipStrings_QtCore[25593]
#define sipNameNr_MapPrivateOption 25610
#define sipName_MapPrivateOption &sipStrings_QtCore[25610]
#define sipNameNr_PermissionsError 25627
#define sipName_PermissionsError &sipStrings_QtCore[25627]
#define sipNameNr_UnspecifiedError 25644
#define sipName_UnspecifiedError &sipStrings_QtCore[25644]
#define sipNameNr_QEventTransition 25661
#define sipName_QEventTransition &sipStrings_QtCore[25661]
#define sipNameNr_QEventLoopLocker 25678
#define sipName_QEventLoopLocker &sipStrings_QtCore[25678]
#define sipNameNr_X11ExcludeTimers 25695
#define sipName_X11ExcludeTimers &sipStrings_QtCore[25695]
#define sipNameNr_MachAbsoluteTime 25712
#define sipName_MachAbsoluteTime &sipStrings_QtCore[25712]
#define sipNameNr_valueForProgress 25729
#define sipName_valueForProgress &sipStrings_QtCore[25729]
#define sipNameNr_relativeFilePath 25746
#define sipName_relativeFilePath &sipStrings_QtCore[25746]
#define sipNameNr_absoluteFilePath 25763
#define sipName_absoluteFilePath &sipStrings_QtCore[25763]
#define sipNameNr_setRemainingTime 25780
#define sipName_setRemainingTime &sipStrings_QtCore[25780]
#define sipNameNr_toSecsSinceEpoch 25797
#define sipName_toSecsSinceEpoch &sipStrings_QtCore[25797]
#define sipNameNr_setOffsetFromUtc 25814
#define sipName_setOffsetFromUtc &sipStrings_QtCore[25814]
#define sipNameNr_StandaloneFormat 25831
#define sipName_StandaloneFormat &sipStrings_QtCore[25831]
#define sipNameNr_abortTransaction 25848
#define sipName_abortTransaction &sipStrings_QtCore[25848]
#define sipNameNr_startTransaction 25865
#define sipName_startTransaction &sipStrings_QtCore[25865]
#define sipNameNr_readQVariantHash 25882
#define sipName_readQVariantHash &sipStrings_QtCore[25882]
#define sipNameNr_writeQVariantMap 25899
#define sipName_writeQVariantMap &sipStrings_QtCore[25899]
#define sipNameNr_readQVariantList 25916
#define sipName_readQVariantList &sipStrings_QtCore[25916]
#define sipNameNr_writeQStringList 25933
#define sipName_writeQStringList &sipStrings_QtCore[25933]
#define sipNameNr_WhatsThisClicked 25950
#define sipName_WhatsThisClicked &sipStrings_QtCore[25950]
#define sipNameNr_ShortcutOverride 25967
#define sipName_ShortcutOverride &sipStrings_QtCore[25967]
#define sipNameNr_ActivationChange 25984
#define sipName_ActivationChange &sipStrings_QtCore[25984]
#define sipNameNr_WindowIconChange 4472
#define sipName_WindowIconChange &sipStrings_QtCore[4472]
#define sipNameNr_WindowDeactivate 26001
#define sipName_WindowDeactivate &sipStrings_QtCore[26001]
#define sipNameNr_MouseButtonPress 3039
#define sipName_MouseButtonPress &sipStrings_QtCore[3039]
#define sipNameNr_setSetuidAllowed 26018
#define sipName_setSetuidAllowed &sipStrings_QtCore[26018]
#define sipNameNr_removeTranslator 26035
#define sipName_removeTranslator &sipStrings_QtCore[26035]
#define sipNameNr_sendPostedEvents 26052
#define sipName_sendPostedEvents &sipStrings_QtCore[26052]
#define sipNameNr_organizationName 26069
#define sipName_organizationName &sipStrings_QtCore[26069]
#define sipNameNr_QCoreApplication 26086
#define sipName_QCoreApplication &sipStrings_QtCore[26086]
#define sipNameNr_addVersionOption 26103
#define sipName_addVersionOption &sipStrings_QtCore[26103]
#define sipNameNr_ShortOptionStyle 26120
#define sipName_ShortOptionStyle &sipStrings_QtCore[26120]
#define sipNameNr_setDefaultValues 26137
#define sipName_setDefaultValues &sipStrings_QtCore[26137]
#define sipNameNr_QCollatorSortKey 26154
#define sipName_QCollatorSortKey &sipStrings_QtCore[26154]
#define sipNameNr_StringResultCode 1020
#define sipName_StringResultCode &sipStrings_QtCore[1020]
#define sipNameNr_InputOutputError 26171
#define sipName_InputOutputError &sipStrings_QtCore[26171]
#define sipNameNr_QCborError__Code 26188
#define sipName_QCborError__Code &sipStrings_QtCore[26188]
#define sipNameNr_dateTimeToString 26205
#define sipName_dateTimeToString &sipStrings_QtCore[26205]
#define sipNameNr_compressionLevel 26222
#define sipName_compressionLevel &sipStrings_QtCore[26222]
#define sipNameNr_FromBase64Result 3565
#define sipName_FromBase64Result &sipStrings_QtCore[3565]
#define sipNameNr_IllegalCharacter 26239
#define sipName_IllegalCharacter &sipStrings_QtCore[26239]
#define sipNameNr_disconnectNotify 26256
#define sipName_disconnectNotify &sipStrings_QtCore[26256]
#define sipNameNr_indexOfAnimation 26273
#define sipName_indexOfAnimation &sipStrings_QtCore[26273]
#define sipNameNr_CheckIndexOption 802
#define sipName_CheckIndexOption &sipStrings_QtCore[802]
#define sipNameNr_beginMoveColumns 26290
#define sipName_beginMoveColumns &sipStrings_QtCore[26290]
#define sipNameNr_endRemoveColumns 26307
#define sipName_endRemoveColumns &sipStrings_QtCore[26307]
#define sipNameNr_endInsertColumns 26324
#define sipName_endInsertColumns &sipStrings_QtCore[26324]
#define sipNameNr_VerticalSortHint 26341
#define sipName_VerticalSortHint &sipStrings_QtCore[26341]
#define sipNameNr_LayoutChangeHint 839
#define sipName_LayoutChangeHint &sipStrings_QtCore[839]
#define sipNameNr_registeredTimers 26358
#define sipName_registeredTimers &sipStrings_QtCore[26358]
#define sipNameNr_unregisterTimers 26375
#define sipName_unregisterTimers &sipStrings_QtCore[26375]
#define sipNameNr_hasPendingEvents 26392
#define sipName_hasPendingEvents &sipStrings_QtCore[26392]
#define sipNameNr_directionChanged 26409
#define sipName_directionChanged &sipStrings_QtCore[26409]
#define sipNameNr_RoundPreferFloor 26426
#define sipName_RoundPreferFloor &sipStrings_QtCore[26426]
#define sipNameNr_Qt__ChecksumType 26443
#define sipName_Qt__ChecksumType &sipStrings_QtCore[26443]
#define sipNameNr_EnterKeyPrevious 26460
#define sipName_EnterKeyPrevious &sipStrings_QtCore[26460]
#define sipNameNr_Qt__EnterKeyType 26477
#define sipName_Qt__EnterKeyType &sipStrings_QtCore[26477]
#define sipNameNr_ReplaceSelection 26494
#define sipName_ReplaceSelection &sipStrings_QtCore[26494]
#define sipNameNr_TabFocusBehavior 14562
#define sipName_TabFocusBehavior &sipStrings_QtCore[14562]
#define sipNameNr_MouseEventSource 14583
#define sipName_MouseEventSource &sipStrings_QtCore[14583]
#define sipNameNr_PanNativeGesture 26511
#define sipName_PanNativeGesture &sipStrings_QtCore[26511]
#define sipNameNr_EndNativeGesture 26528
#define sipName_EndNativeGesture &sipStrings_QtCore[26528]
#define sipNameNr_ApplicationState 14625
#define sipName_ApplicationState &sipStrings_QtCore[14625]
#define sipNameNr_WhiteSpaceNoWrap 26545
#define sipName_WhiteSpaceNoWrap &sipStrings_QtCore[26545]
#define sipNameNr_WhiteSpaceNormal 26562
#define sipName_WhiteSpaceNormal &sipStrings_QtCore[26562]
#define sipNameNr_FindChildOptions 14646
#define sipName_FindChildOptions &sipStrings_QtCore[14646]
#define sipNameNr_LogicalMoveStyle 26579
#define sipName_LogicalMoveStyle &sipStrings_QtCore[26579]
#define sipNameNr_Qt__GestureFlags 26596
#define sipName_Qt__GestureFlags &sipStrings_QtCore[26596]
#define sipNameNr_Qt__GestureState 26613
#define sipName_Qt__GestureState &sipStrings_QtCore[26613]
#define sipNameNr_TouchPointStates 14667
#define sipName_TouchPointStates &sipStrings_QtCore[14667]
#define sipNameNr_CoordinateSystem 14709
#define sipName_CoordinateSystem &sipStrings_QtCore[14709]
#define sipNameNr_InputMethodHints 14751
#define sipName_InputMethodHints &sipStrings_QtCore[14751]
#define sipNameNr_ImhNoTextHandles 26630
#define sipName_ImhNoTextHandles &sipStrings_QtCore[26630]
#define sipNameNr_ImhSensitiveData 26647
#define sipName_ImhSensitiveData &sipStrings_QtCore[26647]
#define sipNameNr_ImhLowercaseOnly 26664
#define sipName_ImhLowercaseOnly &sipStrings_QtCore[26664]
#define sipNameNr_ImhUppercaseOnly 26681
#define sipName_ImhUppercaseOnly &sipStrings_QtCore[26681]
#define sipNameNr_ImhPreferNumbers 26698
#define sipName_ImhPreferNumbers &sipStrings_QtCore[26698]
#define sipNameNr_LowEventPriority 26715
#define sipName_LowEventPriority &sipStrings_QtCore[26715]
#define sipNameNr_AA_NativeWindows 26732
#define sipName_AA_NativeWindows &sipStrings_QtCore[26732]
#define sipNameNr_ApplicationModal 26749
#define sipName_ApplicationModal &sipStrings_QtCore[26749]
#define sipNameNr_MatchFixedString 26766
#define sipName_MatchFixedString &sipStrings_QtCore[26766]
#define sipNameNr_ItemIsSelectable 26783
#define sipName_ItemIsSelectable &sipStrings_QtCore[26783]
#define sipNameNr_Qt__ItemDataRole 26800
#define sipName_Qt__ItemDataRole &sipStrings_QtCore[26800]
#define sipNameNr_PartiallyChecked 26817
#define sipName_PartiallyChecked &sipStrings_QtCore[26817]
#define sipNameNr_TargetMoveAction 26834
#define sipName_TargetMoveAction &sipStrings_QtCore[26834]
#define sipNameNr_ImAnchorPosition 26851
#define sipName_ImAnchorPosition &sipStrings_QtCore[26851]
#define sipNameNr_ImCursorPosition 26868
#define sipName_ImCursorPosition &sipStrings_QtCore[26868]
#define sipNameNr_InputMethodQuery 14898
#define sipName_InputMethodQuery &sipStrings_QtCore[14898]
#define sipNameNr_OtherFocusReason 26885
#define sipName_OtherFocusReason &sipStrings_QtCore[26885]
#define sipNameNr_PopupFocusReason 26902
#define sipName_PopupFocusReason &sipStrings_QtCore[26902]
#define sipNameNr_MouseFocusReason 26919
#define sipName_MouseFocusReason &sipStrings_QtCore[26919]
#define sipNameNr_UniqueConnection 26936
#define sipName_UniqueConnection &sipStrings_QtCore[26936]
#define sipNameNr_QueuedConnection 7740
#define sipName_QueuedConnection &sipStrings_QtCore[7740]
#define sipNameNr_DirectConnection 26953
#define sipName_DirectConnection &sipStrings_QtCore[26953]
#define sipNameNr_BottomLeftCorner 26970
#define sipName_BottomLeftCorner &sipStrings_QtCore[26970]
#define sipNameNr_SystemLocaleDate 26987
#define sipName_SystemLocaleDate &sipStrings_QtCore[26987]
#define sipNameNr_Qt__ToolBarAreas 27004
#define sipName_Qt__ToolBarAreas &sipStrings_QtCore[27004]
#define sipNameNr_ToolBarArea_Mask 27021
#define sipName_ToolBarArea_Mask &sipStrings_QtCore[27021]
#define sipNameNr_RightToolBarArea 27038
#define sipName_RightToolBarArea &sipStrings_QtCore[27038]
#define sipNameNr_NoDockWidgetArea 27055
#define sipName_NoDockWidgetArea &sipStrings_QtCore[27055]
#define sipNameNr_ClosedHandCursor 27072
#define sipName_ClosedHandCursor &sipStrings_QtCore[27072]
#define sipNameNr_DiagCrossPattern 27089
#define sipName_DiagCrossPattern &sipStrings_QtCore[27089]
#define sipNameNr_Qt__PenJoinStyle 27106
#define sipName_Qt__PenJoinStyle &sipStrings_QtCore[27106]
#define sipNameNr_Key_Dead_Lowline 27123
#define sipName_Key_Dead_Lowline &sipStrings_QtCore[27123]
#define sipNameNr_Key_AudioForward 27140
#define sipName_Key_AudioForward &sipStrings_QtCore[27140]
#define sipNameNr_Key_Dead_Cedilla 27157
#define sipName_Key_Dead_Cedilla &sipStrings_QtCore[27157]
#define sipNameNr_Key_Hangul_Banja 27174
#define sipName_Key_Hangul_Banja &sipStrings_QtCore[27174]
#define sipNameNr_Key_Hangul_Hanja 27191
#define sipName_Key_Hangul_Hanja &sipStrings_QtCore[27191]
#define sipNameNr_Key_Hangul_Start 27208
#define sipName_Key_Hangul_Start &sipStrings_QtCore[27208]
#define sipNameNr_Key_questiondown 27225
#define sipName_Key_questiondown &sipStrings_QtCore[27225]
#define sipNameNr_Key_nobreakspace 27242
#define sipName_Key_nobreakspace &sipStrings_QtCore[27242]
#define sipNameNr_Key_BracketRight 27259
#define sipName_Key_BracketRight &sipStrings_QtCore[27259]
#define sipNameNr_WA_MacNormalSize 27276
#define sipName_WA_MacNormalSize &sipStrings_QtCore[27276]
#define sipNameNr_WA_DeleteOnClose 27293
#define sipName_WA_DeleteOnClose &sipStrings_QtCore[27293]
#define sipNameNr_WA_NoMouseReplay 27310
#define sipName_WA_NoMouseReplay &sipStrings_QtCore[27310]
#define sipNameNr_WA_SetWindowIcon 27327
#define sipName_WA_SetWindowIcon &sipStrings_QtCore[27327]
#define sipNameNr_WA_MacMetalStyle 27344
#define sipName_WA_MacMetalStyle &sipStrings_QtCore[27344]
#define sipNameNr_WA_PendingUpdate 27361
#define sipName_WA_PendingUpdate &sipStrings_QtCore[27361]
#define sipNameNr_WA_ForceDisabled 27378
#define sipName_WA_ForceDisabled &sipStrings_QtCore[27378]
#define sipNameNr_WA_WState_Hidden 27395
#define sipName_WA_WState_Hidden &sipStrings_QtCore[27395]
#define sipNameNr_WA_PaintOnScreen 27412
#define sipName_WA_PaintOnScreen &sipStrings_QtCore[27412]
#define sipNameNr_WA_MouseTracking 27429
#define sipName_WA_MouseTracking &sipStrings_QtCore[27429]
#define sipNameNr_Qt__WindowStates 27446
#define sipName_Qt__WindowStates &sipStrings_QtCore[27446]
#define sipNameNr_WindowFullScreen 27463
#define sipName_WindowFullScreen &sipStrings_QtCore[27463]
#define sipNameNr_TextHideMnemonic 27480
#define sipName_TextHideMnemonic &sipStrings_QtCore[27480]
#define sipNameNr_TextWrapAnywhere 27497
#define sipName_TextWrapAnywhere &sipStrings_QtCore[27497]
#define sipNameNr_TextShowMnemonic 27514
#define sipName_TextShowMnemonic &sipStrings_QtCore[27514]
#define sipNameNr_Qt__Orientations 27531
#define sipName_Qt__Orientations &sipStrings_QtCore[27531]
#define sipNameNr_Qt__MouseButtons 27548
#define sipName_Qt__MouseButtons &sipStrings_QtCore[27548]
#define sipNameNr_KeyboardModifier 15381
#define sipName_KeyboardModifier &sipStrings_QtCore[15381]
#define sipNameNr_PYQT_VERSION_STR 27565
#define sipName_PYQT_VERSION_STR &sipStrings_QtCore[27565]
#define sipNameNr_27582 27582
#define sipName_27582 &sipStrings_QtCore[27582]
#define sipNameNr_27598 27598
#define sipName_27598 &sipStrings_QtCore[27598]
#define sipNameNr_machineHostName 27614
#define sipName_machineHostName &sipStrings_QtCore[27614]
#define sipNameNr_QSysInfo__Sizes 27630
#define sipName_QSysInfo__Sizes &sipStrings_QtCore[27630]
#define sipNameNr_writeEndElement 27646
#define sipName_writeEndElement &sipStrings_QtCore[27646]
#define sipNameNr_writeCharacters 27662
#define sipName_writeCharacters &sipStrings_QtCore[27662]
#define sipNameNr_writeAttributes 27678
#define sipName_writeAttributes &sipStrings_QtCore[27678]
#define sipNameNr_readElementText 27694
#define sipName_readElementText &sipStrings_QtCore[27694]
#define sipNameNr_characterOffset 27710
#define sipName_characterOffset &sipStrings_QtCore[27710]
#define sipNameNr_documentVersion 27726
#define sipName_documentVersion &sipStrings_QtCore[27726]
#define sipNameNr_isStartDocument 27742
#define sipName_isStartDocument &sipStrings_QtCore[27742]
#define sipNameNr_EntityReference 13198
#define sipName_EntityReference &sipStrings_QtCore[13198]
#define sipNameNr_removeQueryItem 27758
#define sipName_removeQueryItem &sipStrings_QtCore[27758]
#define sipNameNr_AssumeLocalFile 27774
#define sipName_AssumeLocalFile &sipStrings_QtCore[27774]
#define sipNameNr_toDisplayString 27790
#define sipName_toDisplayString &sipStrings_QtCore[27790]
#define sipNameNr_setIdnWhitelist 27806
#define sipName_setIdnWhitelist &sipStrings_QtCore[27806]
#define sipNameNr_PreferLocalFile 27822
#define sipName_PreferLocalFile &sipStrings_QtCore[27822]
#define sipNameNr_RemoveAuthority 27838
#define sipName_RemoveAuthority &sipStrings_QtCore[27838]
#define sipNameNr_hasDaylightTime 27854
#define sipName_hasDaylightTime &sipStrings_QtCore[27854]
#define sipNameNr_toggleDirection 27870
#define sipName_toggleDirection &sipStrings_QtCore[27870]
#define sipNameNr_InheritPriority 27886
#define sipName_InheritPriority &sipStrings_QtCore[27886]
#define sipNameNr_HighestPriority 27902
#define sipName_HighestPriority &sipStrings_QtCore[27902]
#define sipNameNr_currentThreadId 27918
#define sipName_currentThreadId &sipStrings_QtCore[27918]
#define sipNameNr_lowercasedigits 27934
#define sipName_lowercasedigits &sipStrings_QtCore[27934]
#define sipNameNr_uppercasedigits 27950
#define sipName_uppercasedigits &sipStrings_QtCore[27950]
#define sipNameNr_UppercaseDigits 27966
#define sipName_UppercaseDigits &sipStrings_QtCore[27966]
#define sipNameNr_ConversionFlags 4081
#define sipName_ConversionFlags &sipStrings_QtCore[4081]
#define sipNameNr_availableCodecs 27982
#define sipName_availableCodecs &sipStrings_QtCore[27982]
#define sipNameNr_codecForUtfText 27998
#define sipName_codecForUtfText &sipStrings_QtCore[27998]
#define sipNameNr_boundaryReasons 28014
#define sipName_boundaryReasons &sipStrings_QtCore[28014]
#define sipNameNr_BoundaryReasons 766
#define sipName_BoundaryReasons &sipStrings_QtCore[766]
#define sipNameNr_setFileTemplate 28030
#define sipName_setFileTemplate &sipStrings_QtCore[28030]
#define sipNameNr_setInitialState 28046
#define sipName_setInitialState &sipStrings_QtCore[28046]
#define sipNameNr_ExclusiveStates 28062
#define sipName_ExclusiveStates &sipStrings_QtCore[28062]
#define sipNameNr_LocateDirectory 28078
#define sipName_LocateDirectory &sipStrings_QtCore[28078]
#define sipNameNr_AppDataLocation 28094
#define sipName_AppDataLocation &sipStrings_QtCore[28094]
#define sipNameNr_RuntimeLocation 28110
#define sipName_RuntimeLocation &sipStrings_QtCore[28110]
#define sipNameNr_DesktopLocation 28126
#define sipName_DesktopLocation &sipStrings_QtCore[28126]
#define sipNameNr_sortRoleChanged 28142
#define sipName_sortRoleChanged &sipStrings_QtCore[28142]
#define sipNameNr_setFilterRegExp 28158
#define sipName_setFilterRegExp &sipStrings_QtCore[28158]
#define sipNameNr_filterKeyColumn 28174
#define sipName_filterKeyColumn &sipStrings_QtCore[28174]
#define sipNameNr_QSocketNotifier 28190
#define sipName_QSocketNotifier &sipStrings_QtCore[28190]
#define sipNameNr_setSenderObject 28206
#define sipName_setSenderObject &sipStrings_QtCore[28206]
#define sipNameNr_beginWriteArray 28222
#define sipName_beginWriteArray &sipStrings_QtCore[28222]
#define sipNameNr_ZstdCompression 28238
#define sipName_ZstdCompression &sipStrings_QtCore[28238]
#define sipNameNr_ZlibCompression 28254
#define sipName_ZlibCompression &sipStrings_QtCore[28254]
#define sipNameNr_hasPartialMatch 28270
#define sipName_hasPartialMatch &sipStrings_QtCore[28270]
#define sipNameNr_anchoredPattern 28286
#define sipName_anchoredPattern &sipStrings_QtCore[28286]
#define sipNameNr_MultilineOption 28302
#define sipName_MultilineOption &sipStrings_QtCore[28302]
#define sipNameNr_NoPatternOption 28318
#define sipName_NoPatternOption &sipStrings_QtCore[28318]
#define sipNameNr_moveBottomRight 28334
#define sipName_moveBottomRight &sipStrings_QtCore[28334]
#define sipNameNr_tryLockForWrite 28350
#define sipName_tryLockForWrite &sipStrings_QtCore[28350]
#define sipNameNr_setProcessState 28366
#define sipName_setProcessState &sipStrings_QtCore[28366]
#define sipNameNr_waitForFinished 28382
#define sipName_waitForFinished &sipStrings_QtCore[28382]
#define sipNameNr_manhattanLength 28398
#define sipName_manhattanLength &sipStrings_QtCore[28398]
#define sipNameNr_staticInstances 28414
#define sipName_staticInstances &sipStrings_QtCore[28414]
#define sipNameNr_setPropertyName 28430
#define sipName_setPropertyName &sipStrings_QtCore[28430]
#define sipNameNr_setTargetObject 28446
#define sipName_setTargetObject &sipStrings_QtCore[28446]
#define sipNameNr_QPauseAnimation 28462
#define sipName_QPauseAnimation &sipStrings_QtCore[28462]
#define sipNameNr_AndroidLollipop 28478
#define sipName_AndroidLollipop &sipStrings_QtCore[28478]
#define sipNameNr_MacOSHighSierra 28494
#define sipName_MacOSHighSierra &sipStrings_QtCore[28494]
#define sipNameNr_indexOfProperty 28510
#define sipName_indexOfProperty &sipStrings_QtCore[28510]
#define sipNameNr_enumeratorCount 28526
#define sipName_enumeratorCount &sipStrings_QtCore[28526]
#define sipNameNr_classInfoOffset 28542
#define sipName_classInfoOffset &sipStrings_QtCore[28542]
#define sipNameNr_QT_TR_NOOP_UTF8 28558
#define sipName_QT_TR_NOOP_UTF8 &sipStrings_QtCore[28558]
#define sipNameNr_QRecursiveMutex 28574
#define sipName_QRecursiveMutex &sipStrings_QtCore[28574]
#define sipNameNr_preferredSuffix 28590
#define sipName_preferredSuffix &sipStrings_QtCore[28590]
#define sipNameNr_parentMimeTypes 28606
#define sipName_parentMimeTypes &sipStrings_QtCore[28606]
#define sipNameNr_genericIconName 28622
#define sipName_genericIconName &sipStrings_QtCore[28622]
#define sipNameNr_mimeTypeForData 28638
#define sipName_mimeTypeForData &sipStrings_QtCore[28638]
#define sipNameNr_mimeTypeForFile 28654
#define sipName_mimeTypeForFile &sipStrings_QtCore[28654]
#define sipNameNr_mimeTypeForName 28670
#define sipName_mimeTypeForName &sipStrings_QtCore[28670]
#define sipNameNr_QMetaType__Type 28686
#define sipName_QMetaType__Type &sipStrings_QtCore[28686]
#define sipNameNr_hasNotifySignal 28702
#define sipName_hasNotifySignal &sipStrings_QtCore[28702]
#define sipNameNr_methodSignature 28718
#define sipName_methodSignature &sipStrings_QtCore[28718]
#define sipNameNr_defaultCategory 28734
#define sipName_defaultCategory &sipStrings_QtCore[28734]
#define sipNameNr_PermissionError 28750
#define sipName_PermissionError &sipStrings_QtCore[28750]
#define sipNameNr_LockFailedError 28766
#define sipName_LockFailedError &sipStrings_QtCore[28766]
#define sipNameNr_DataSizeFormats 7091
#define sipName_DataSizeFormats &sipStrings_QtCore[7091]
#define sipNameNr_matchingLocales 28782
#define sipName_matchingLocales &sipStrings_QtCore[28782]
#define sipNameNr_CurrencyIsoCode 28798
#define sipName_CurrencyIsoCode &sipStrings_QtCore[28798]
#define sipNameNr_BhaiksukiScript 28814
#define sipName_BhaiksukiScript &sipStrings_QtCore[28814]
#define sipNameNr_KhudawadiScript 28830
#define sipName_KhudawadiScript &sipStrings_QtCore[28830]
#define sipNameNr_OldPermicScript 28846
#define sipName_OldPermicScript &sipStrings_QtCore[28846]
#define sipNameNr_PauCinHauScript 28862
#define sipName_PauCinHauScript &sipStrings_QtCore[28862]
#define sipNameNr_PalmyreneScript 28878
#define sipName_PalmyreneScript &sipStrings_QtCore[28878]
#define sipNameNr_NabataeanScript 28894
#define sipName_NabataeanScript &sipStrings_QtCore[28894]
#define sipNameNr_SundaneseScript 28910
#define sipName_SundaneseScript &sipStrings_QtCore[28910]
#define sipNameNr_CuneiformScript 28926
#define sipName_CuneiformScript &sipStrings_QtCore[28926]
#define sipNameNr_SamaritanScript 28942
#define sipName_SamaritanScript &sipStrings_QtCore[28942]
#define sipNameNr_OldItalicScript 28958
#define sipName_OldItalicScript &sipStrings_QtCore[28958]
#define sipNameNr_NewTaiLueScript 28974
#define sipName_NewTaiLueScript &sipStrings_QtCore[28974]
#define sipNameNr_MalayalamScript 28990
#define sipName_MalayalamScript &sipStrings_QtCore[28990]
#define sipNameNr_MongolianScript 29006
#define sipName_MongolianScript &sipStrings_QtCore[29006]
#define sipNameNr_QLocale__Script 29022
#define sipName_QLocale__Script &sipStrings_QtCore[29022]
#define sipNameNr_countryToString 29038
#define sipName_countryToString &sipStrings_QtCore[29038]
#define sipNameNr_OutlyingOceania 29054
#define sipName_OutlyingOceania &sipStrings_QtCore[29054]
#define sipNameNr_CeutaAndMelilla 29070
#define sipName_CeutaAndMelilla &sipStrings_QtCore[29070]
#define sipNameNr_AscensionIsland 29086
#define sipName_AscensionIsland &sipStrings_QtCore[29086]
#define sipNameNr_SaintBarthelemy 29102
#define sipName_SaintBarthelemy &sipStrings_QtCore[29102]
#define sipNameNr_MarshallIslands 29118
#define sipName_MarshallIslands &sipStrings_QtCore[29118]
#define sipNameNr_RepublicOfKorea 6063
#define sipName_RepublicOfKorea &sipStrings_QtCore[6063]
#define sipNameNr_FrenchPolynesia 29134
#define sipName_FrenchPolynesia &sipStrings_QtCore[29134]
#define sipNameNr_FalklandIslands 29150
#define sipName_FalklandIslands &sipStrings_QtCore[29150]
#define sipNameNr_ChristmasIsland 29166
#define sipName_ChristmasIsland &sipStrings_QtCore[29166]
#define sipNameNr_SouthernKurdish 29182
#define sipName_SouthernKurdish &sipStrings_QtCore[29182]
#define sipNameNr_TokelauLanguage 29198
#define sipName_TokelauLanguage &sipStrings_QtCore[29198]
#define sipNameNr_LiteraryChinese 29214
#define sipName_LiteraryChinese &sipStrings_QtCore[29214]
#define sipNameNr_PrakritLanguage 29230
#define sipName_PrakritLanguage &sipStrings_QtCore[29230]
#define sipNameNr_AncientEgyptian 29246
#define sipName_AncientEgyptian &sipStrings_QtCore[29246]
#define sipNameNr_NorwegianBokmal 29262
#define sipName_NorwegianBokmal &sipStrings_QtCore[29262]
#define sipNameNr_Qml2ImportsPath 29278
#define sipName_Qml2ImportsPath &sipStrings_QtCore[29278]
#define sipNameNr_LibraryLocation 2920
#define sipName_LibraryLocation &sipStrings_QtCore[2920]
#define sipNameNr_QJsonParseError 29294
#define sipName_QJsonParseError &sipStrings_QtCore[29294]
#define sipNameNr_selectedColumns 29310
#define sipName_selectedColumns &sipStrings_QtCore[29310]
#define sipNameNr_setCurrentIndex 29326
#define sipName_setCurrentIndex &sipStrings_QtCore[29326]
#define sipNameNr_selectedIndexes 29342
#define sipName_selectedIndexes &sipStrings_QtCore[29342]
#define sipNameNr_setDefaultState 29358
#define sipName_setDefaultState &sipStrings_QtCore[29358]
#define sipNameNr_FileHandleFlags 3479
#define sipName_FileHandleFlags &sipStrings_QtCore[3479]
#define sipNameNr_DontCloseHandle 29374
#define sipName_DontCloseHandle &sipStrings_QtCore[29374]
#define sipNameNr_AutoCloseHandle 29390
#define sipName_AutoCloseHandle &sipStrings_QtCore[29390]
#define sipNameNr_NoIteratorFlags 29406
#define sipName_NoIteratorFlags &sipStrings_QtCore[29406]
#define sipNameNr_QDir__SortFlags 29422
#define sipName_QDir__SortFlags &sipStrings_QtCore[29422]
#define sipNameNr_ForeverConstant 2398
#define sipName_ForeverConstant &sipStrings_QtCore[2398]
#define sipNameNr_toOffsetFromUtc 29438
#define sipName_toOffsetFromUtc &sipStrings_QtCore[29438]
#define sipNameNr_currentDateTime 29454
#define sipName_currentDateTime &sipStrings_QtCore[29454]
#define sipNameNr_DoublePrecision 29470
#define sipName_DoublePrecision &sipStrings_QtCore[29470]
#define sipNameNr_SinglePrecision 29486
#define sipName_SinglePrecision &sipStrings_QtCore[29486]
#define sipNameNr_readQVariantMap 29502
#define sipName_readQVariantMap &sipStrings_QtCore[29502]
#define sipNameNr_readQStringList 29518
#define sipName_readQStringList &sipStrings_QtCore[29518]
#define sipNameNr_ReadCorruptData 29534
#define sipName_ReadCorruptData &sipStrings_QtCore[29534]
#define sipNameNr_PlatformSurface 29550
#define sipName_PlatformSurface &sipStrings_QtCore[29550]
#define sipNameNr_GestureOverride 29566
#define sipName_GestureOverride &sipStrings_QtCore[29566]
#define sipNameNr_WindowUnblocked 29582
#define sipName_WindowUnblocked &sipStrings_QtCore[29582]
#define sipNameNr_qAddPostRoutine 29598
#define sipName_qAddPostRoutine &sipStrings_QtCore[29598]
#define sipNameNr_isSetuidAllowed 29614
#define sipName_isSetuidAllowed &sipStrings_QtCore[29614]
#define sipNameNr_eventDispatcher 29630
#define sipName_eventDispatcher &sipStrings_QtCore[29630]
#define sipNameNr_setLibraryPaths 29646
#define sipName_setLibraryPaths &sipStrings_QtCore[29646]
#define sipNameNr_applicationName 29662
#define sipName_applicationName &sipStrings_QtCore[29662]
#define sipNameNr_setDefaultValue 29678
#define sipName_setDefaultValue &sipStrings_QtCore[29678]
#define sipNameNr_caseSensitivity 29694
#define sipName_caseSensitivity &sipStrings_QtCore[29694]
#define sipNameNr_NegativeInteger 22856
#define sipName_NegativeInteger &sipStrings_QtCore[22856]
#define sipNameNr_UnsignedInteger 22838
#define sipName_UnsignedInteger &sipStrings_QtCore[22838]
#define sipNameNr_appendUndefined 29710
#define sipName_appendUndefined &sipStrings_QtCore[29710]
#define sipNameNr_UnsupportedType 29726
#define sipName_UnsupportedType &sipStrings_QtCore[29726]
#define sipNameNr_UnexpectedBreak 29742
#define sipName_UnexpectedBreak &sipStrings_QtCore[29742]
#define sipNameNr_QCborSimpleType 29758
#define sipName_QCborSimpleType &sipStrings_QtCore[29758]
#define sipNameNr_insertAnimation 29774
#define sipName_insertAnimation &sipStrings_QtCore[29774]
#define sipNameNr_QAnimationGroup 29790
#define sipName_QAnimationGroup &sipStrings_QtCore[29790]
#define sipNameNr_removeAnimation 29806
#define sipName_removeAnimation &sipStrings_QtCore[29806]
#define sipNameNr_setTargetStates 29822
#define sipName_setTargetStates &sipStrings_QtCore[29822]
#define sipNameNr_ParentIsInvalid 29838
#define sipName_ParentIsInvalid &sipStrings_QtCore[29838]
#define sipNameNr_canDropMimeData 29854
#define sipName_canDropMimeData &sipStrings_QtCore[29854]
#define sipNameNr_beginResetModel 29870
#define sipName_beginResetModel &sipStrings_QtCore[29870]
#define sipNameNr_beginRemoveRows 29886
#define sipName_beginRemoveRows &sipStrings_QtCore[29886]
#define sipNameNr_beginInsertRows 29902
#define sipName_beginInsertRows &sipStrings_QtCore[29902]
#define sipNameNr_columnsInserted 29918
#define sipName_columnsInserted &sipStrings_QtCore[29918]
#define sipNameNr_siblingAtColumn 29934
#define sipName_siblingAtColumn &sipStrings_QtCore[29934]
#define sipNameNr_internalPointer 29950
#define sipName_internalPointer &sipStrings_QtCore[29950]
#define sipNameNr_unregisterTimer 29966
#define sipName_unregisterTimer &sipStrings_QtCore[29966]
#define sipNameNr_updateDirection 29982
#define sipName_updateDirection &sipStrings_QtCore[29982]
#define sipNameNr_currentLoopTime 29998
#define sipName_currentLoopTime &sipStrings_QtCore[29998]
#define sipNameNr_KeepWhenStopped 30014
#define sipName_KeepWhenStopped &sipStrings_QtCore[30014]
#define sipNameNr_ChecksumIso3309 30030
#define sipName_ChecksumIso3309 &sipStrings_QtCore[30030]
#define sipNameNr_EnterKeyDefault 30046
#define sipName_EnterKeyDefault &sipStrings_QtCore[30046]
#define sipNameNr_MouseEventFlags 16903
#define sipName_MouseEventFlags &sipStrings_QtCore[16903]
#define sipNameNr_Qt__ScrollPhase 30062
#define sipName_Qt__ScrollPhase &sipStrings_QtCore[30062]
#define sipNameNr_HitTestAccuracy 16963
#define sipName_HitTestAccuracy &sipStrings_QtCore[16963]
#define sipNameNr_FindChildOption 16983
#define sipName_FindChildOption &sipStrings_QtCore[16983]
#define sipNameNr_VisualMoveStyle 30078
#define sipName_VisualMoveStyle &sipStrings_QtCore[30078]
#define sipNameNr_CursorMoveStyle 17003
#define sipName_CursorMoveStyle &sipStrings_QtCore[17003]
#define sipNameNr_Qt__GestureFlag 30094
#define sipName_Qt__GestureFlag &sipStrings_QtCore[30094]
#define sipNameNr_Qt__GestureType 30110
#define sipName_Qt__GestureType &sipStrings_QtCore[30110]
#define sipNameNr_GestureCanceled 30126
#define sipName_GestureCanceled &sipStrings_QtCore[30126]
#define sipNameNr_GestureFinished 30142
#define sipName_GestureFinished &sipStrings_QtCore[30142]
#define sipNameNr_TouchPointMoved 30158
#define sipName_TouchPointMoved &sipStrings_QtCore[30158]
#define sipNameNr_TouchPointState 17023
#define sipName_TouchPointState &sipStrings_QtCore[17023]
#define sipNameNr_Qt__AnchorPoint 30174
#define sipName_Qt__AnchorPoint &sipStrings_QtCore[30174]
#define sipNameNr_InputMethodHint 17063
#define sipName_InputMethodHint &sipStrings_QtCore[17063]
#define sipNameNr_TopRightSection 30190
#define sipName_TopRightSection &sipStrings_QtCore[30190]
#define sipNameNr_MatchStartsWith 30206
#define sipName_MatchStartsWith &sipStrings_QtCore[30206]
#define sipNameNr_Qt__DropActions 30222
#define sipName_Qt__DropActions &sipStrings_QtCore[30222]
#define sipNameNr_LayoutDirection 12937
#define sipName_LayoutDirection &sipStrings_QtCore[12937]
#define sipNameNr_ToolButtonStyle 17223
#define sipName_ToolButtonStyle &sipStrings_QtCore[17223]
#define sipNameNr_Qt__FocusReason 30238
#define sipName_Qt__FocusReason &sipStrings_QtCore[30238]
#define sipNameNr_ShortcutContext 17323
#define sipName_ShortcutContext &sipStrings_QtCore[17323]
#define sipNameNr_CaseInsensitive 30254
#define sipName_CaseInsensitive &sipStrings_QtCore[30254]
#define sipNameNr_CaseSensitivity 6966
#define sipName_CaseSensitivity &sipStrings_QtCore[6966]
#define sipNameNr_ScrollBarPolicy 17363
#define sipName_ScrollBarPolicy &sipStrings_QtCore[17363]
#define sipNameNr_AllToolBarAreas 30270
#define sipName_AllToolBarAreas &sipStrings_QtCore[30270]
#define sipNameNr_LeftToolBarArea 30286
#define sipName_LeftToolBarArea &sipStrings_QtCore[30286]
#define sipNameNr_Qt__ToolBarArea 30302
#define sipName_Qt__ToolBarArea &sipStrings_QtCore[30302]
#define sipNameNr_VeryCoarseTimer 30318
#define sipName_VeryCoarseTimer &sipStrings_QtCore[30318]
#define sipNameNr_DockWidgetAreas 17383
#define sipName_DockWidgetAreas &sipStrings_QtCore[17383]
#define sipNameNr_KeepAspectRatio 30334
#define sipName_KeepAspectRatio &sipStrings_QtCore[30334]
#define sipNameNr_AspectRatioMode 17443
#define sipName_AspectRatioMode &sipStrings_QtCore[17443]
#define sipNameNr_WhatsThisCursor 30350
#define sipName_WhatsThisCursor &sipStrings_QtCore[30350]
#define sipNameNr_ForbiddenCursor 30366
#define sipName_ForbiddenCursor &sipStrings_QtCore[30366]
#define sipNameNr_SizeFDiagCursor 30382
#define sipName_SizeFDiagCursor &sipStrings_QtCore[30382]
#define sipNameNr_SizeBDiagCursor 30398
#define sipName_SizeBDiagCursor &sipStrings_QtCore[30398]
#define sipNameNr_Qt__CursorShape 30414
#define sipName_Qt__CursorShape &sipStrings_QtCore[30414]
#define sipNameNr_UI_AnimateCombo 30430
#define sipName_UI_AnimateCombo &sipStrings_QtCore[30430]
#define sipNameNr_Qt__PenCapStyle 30446
#define sipName_Qt__PenCapStyle &sipStrings_QtCore[30446]
#define sipNameNr_Key_Dead_Stroke 30462
#define sipName_Key_Dead_Stroke &sipStrings_QtCore[30462]
#define sipNameNr_Key_MicVolumeUp 30478
#define sipName_Key_MicVolumeUp &sipStrings_QtCore[30478]
#define sipNameNr_Key_ChannelDown 30494
#define sipName_Key_ChannelDown &sipStrings_QtCore[30494]
#define sipNameNr_Key_TouchpadOff 30510
#define sipName_Key_TouchpadOff &sipStrings_QtCore[30510]
#define sipNameNr_Key_CameraFocus 30526
#define sipName_Key_CameraFocus &sipStrings_QtCore[30526]
#define sipNameNr_Key_AudioRepeat 30542
#define sipName_Key_AudioRepeat &sipStrings_QtCore[30542]
#define sipNameNr_Key_MailForward 30558
#define sipName_Key_MailForward &sipStrings_QtCore[30558]
#define sipNameNr_Key_SplitScreen 30574
#define sipName_Key_SplitScreen &sipStrings_QtCore[30574]
#define sipNameNr_Key_BackForward 30590
#define sipName_Key_BackForward &sipStrings_QtCore[30590]
#define sipNameNr_Key_AudioRewind 30606
#define sipName_Key_AudioRewind &sipStrings_QtCore[30606]
#define sipNameNr_Key_AddFavorite 30622
#define sipName_Key_AddFavorite &sipStrings_QtCore[30622]
#define sipNameNr_Key_ScreenSaver 30638
#define sipName_Key_ScreenSaver &sipStrings_QtCore[30638]
#define sipNameNr_Key_LaunchMedia 30654
#define sipName_Key_LaunchMedia &sipStrings_QtCore[30654]
#define sipNameNr_Key_MediaRecord 30670
#define sipName_Key_MediaRecord &sipStrings_QtCore[30670]
#define sipNameNr_Key_Dead_Ogonek 30686
#define sipName_Key_Dead_Ogonek &sipStrings_QtCore[30686]
#define sipNameNr_Key_Dead_Macron 30702
#define sipName_Key_Dead_Macron &sipStrings_QtCore[30702]
#define sipNameNr_Key_Hangul_Jamo 30718
#define sipName_Key_Hangul_Jamo &sipStrings_QtCore[30718]
#define sipNameNr_Key_Eisu_toggle 30734
#define sipName_Key_Eisu_toggle &sipStrings_QtCore[30734]
#define sipNameNr_Key_Mode_switch 30750
#define sipName_Key_Mode_switch &sipStrings_QtCore[30750]
#define sipNameNr_Key_Ucircumflex 30766
#define sipName_Key_Ucircumflex &sipStrings_QtCore[30766]
#define sipNameNr_Key_Ocircumflex 30782
#define sipName_Key_Ocircumflex &sipStrings_QtCore[30782]
#define sipNameNr_Key_Icircumflex 30798
#define sipName_Key_Icircumflex &sipStrings_QtCore[30798]
#define sipNameNr_Key_Ecircumflex 30814
#define sipName_Key_Ecircumflex &sipStrings_QtCore[30814]
#define sipNameNr_Key_Acircumflex 30830
#define sipName_Key_Acircumflex &sipStrings_QtCore[30830]
#define sipNameNr_Key_onesuperior 30846
#define sipName_Key_onesuperior &sipStrings_QtCore[30846]
#define sipNameNr_Key_twosuperior 30862
#define sipName_Key_twosuperior &sipStrings_QtCore[30862]
#define sipNameNr_Key_ordfeminine 30878
#define sipName_Key_ordfeminine &sipStrings_QtCore[30878]
#define sipNameNr_Key_AsciiCircum 30894
#define sipName_Key_AsciiCircum &sipStrings_QtCore[30894]
#define sipNameNr_Key_BracketLeft 30910
#define sipName_Key_BracketLeft &sipStrings_QtCore[30910]
#define sipNameNr_Key_Direction_R 30926
#define sipName_Key_Direction_R &sipStrings_QtCore[30926]
#define sipNameNr_Key_Direction_L 30942
#define sipName_Key_Direction_L &sipStrings_QtCore[30942]
#define sipNameNr_TransparentMode 30958
#define sipName_TransparentMode &sipStrings_QtCore[30958]
#define sipNameNr_ThresholdDither 30974
#define sipName_ThresholdDither &sipStrings_QtCore[30974]
#define sipNameNr_WA_NativeWindow 30990
#define sipName_WA_NativeWindow &sipStrings_QtCore[30990]
#define sipNameNr_WA_MacSmallSize 31006
#define sipName_WA_MacSmallSize &sipStrings_QtCore[31006]
#define sipNameNr_WidgetAttribute 17883
#define sipName_WidgetAttribute &sipStrings_QtCore[17883]
#define sipNameNr_WindowMaximized 31022
#define sipName_WindowMaximized &sipStrings_QtCore[31022]
#define sipNameNr_WindowMinimized 31038
#define sipName_WindowMinimized &sipStrings_QtCore[31038]
#define sipNameNr_Qt__WindowState 31054
#define sipName_Qt__WindowState &sipStrings_QtCore[31054]
#define sipNameNr_Qt__WindowFlags 31070
#define sipName_Qt__WindowFlags &sipStrings_QtCore[31070]
#define sipNameNr_WindowTitleHint 31086
#define sipName_WindowTitleHint &sipStrings_QtCore[31086]
#define sipNameNr_WindowType_Mask 31102
#define sipName_WindowType_Mask &sipStrings_QtCore[31102]
#define sipNameNr_DescendingOrder 31118
#define sipName_DescendingOrder &sipStrings_QtCore[31118]
#define sipNameNr_Qt__FocusPolicy 31134
#define sipName_Qt__FocusPolicy &sipStrings_QtCore[31134]
#define sipNameNr_Qt__Orientation 31150
#define sipName_Qt__Orientation &sipStrings_QtCore[31150]
#define sipNameNr_Qt__MouseButton 31166
#define sipName_Qt__MouseButton &sipStrings_QtCore[31166]
#define sipNameNr_ControlModifier 31182
#define sipName_ControlModifier &sipStrings_QtCore[31182]
#define sipNameNr_Qt__GlobalColor 31198
#define sipName_Qt__GlobalColor &sipStrings_QtCore[31198]
#define sipNameNr_31214 31214
#define sipName_31214 &sipStrings_QtCore[31214]
#define sipNameNr_31229 31229
#define sipName_31229 &sipStrings_QtCore[31229]
#define sipNameNr_productVersion 31244
#define sipName_productVersion &sipStrings_QtCore[31244]
#define sipNameNr_writeNamespace 31259
#define sipName_writeNamespace &sipStrings_QtCore[31259]
#define sipNameNr_writeAttribute 31274
#define sipName_writeAttribute &sipStrings_QtCore[31274]
#define sipNameNr_autoFormatting 31289
#define sipName_autoFormatting &sipStrings_QtCore[31289]
#define sipNameNr_entityResolver 31304
#define sipName_entityResolver &sipStrings_QtCore[31304]
#define sipNameNr_isStartElement 31319
#define sipName_isStartElement &sipStrings_QtCore[31319]
#define sipNameNr_QWaitCondition 31334
#define sipName_QWaitCondition &sipStrings_QtCore[31334]
#define sipNameNr_QVersionNumber 31349
#define sipName_QVersionNumber &sipStrings_QtCore[31349]
#define sipNameNr_QVariant__Type 31364
#define sipName_QVariant__Type &sipStrings_QtCore[31364]
#define sipNameNr_QUuid__Version 31379
#define sipName_QUuid__Version &sipStrings_QtCore[31379]
#define sipNameNr_QUuid__Variant 31394
#define sipName_QUuid__Variant &sipStrings_QtCore[31394]
#define sipNameNr_queryItemValue 31409
#define sipName_queryItemValue &sipStrings_QtCore[31409]
#define sipNameNr_fromStringList 31424
#define sipName_fromStringList &sipStrings_QtCore[31424]
#define sipNameNr_topLevelDomain 31439
#define sipName_topLevelDomain &sipStrings_QtCore[31439]
#define sipNameNr_DecodeReserved 31454
#define sipName_DecodeReserved &sipStrings_QtCore[31454]
#define sipNameNr_EncodeReserved 31469
#define sipName_EncodeReserved &sipStrings_QtCore[31469]
#define sipNameNr_RemoveFilename 31484
#define sipName_RemoveFilename &sipStrings_QtCore[31484]
#define sipNameNr_RemoveFragment 31499
#define sipName_RemoveFragment &sipStrings_QtCore[31499]
#define sipNameNr_RemoveUserInfo 31514
#define sipName_RemoveUserInfo &sipStrings_QtCore[31514]
#define sipNameNr_RemovePassword 31529
#define sipName_RemovePassword &sipStrings_QtCore[31529]
#define sipNameNr_systemTimeZone 31544
#define sipName_systemTimeZone &sipStrings_QtCore[31544]
#define sipNameNr_nextTransition 31559
#define sipName_nextTransition &sipStrings_QtCore[31559]
#define sipNameNr_hasTransitions 31574
#define sipName_hasTransitions &sipStrings_QtCore[31574]
#define sipNameNr_setEasingCurve 31589
#define sipName_setEasingCurve &sipStrings_QtCore[31589]
#define sipNameNr_updateInterval 31604
#define sipName_updateInterval &sipStrings_QtCore[31604]
#define sipNameNr_EaseInOutCurve 31619
#define sipName_EaseInOutCurve &sipStrings_QtCore[31619]
#define sipNameNr_maxThreadCount 31634
#define sipName_maxThreadCount &sipStrings_QtCore[31634]
#define sipNameNr_globalInstance 31649
#define sipName_globalInstance &sipStrings_QtCore[31649]
#define sipNameNr_LowestPriority 31664
#define sipName_LowestPriority &sipStrings_QtCore[31664]
#define sipNameNr_qSetFieldWidth 31679
#define sipName_qSetFieldWidth &sipStrings_QtCore[31679]
#define sipNameNr_setIntegerBase 31694
#define sipName_setIntegerBase &sipStrings_QtCore[31694]
#define sipNameNr_setNumberFlags 31709
#define sipName_setNumberFlags &sipStrings_QtCore[31709]
#define sipNameNr_fieldAlignment 31724
#define sipName_fieldAlignment &sipStrings_QtCore[31724]
#define sipNameNr_skipWhiteSpace 31739
#define sipName_skipWhiteSpace &sipStrings_QtCore[31739]
#define sipNameNr_FieldAlignment 4054
#define sipName_FieldAlignment &sipStrings_QtCore[4054]
#define sipNameNr_ConverterState 4833
#define sipName_ConverterState &sipStrings_QtCore[4833]
#define sipNameNr_ConversionFlag 4860
#define sipName_ConversionFlag &sipStrings_QtCore[4860]
#define sipNameNr_codecForLocale 31754
#define sipName_codecForLocale &sipStrings_QtCore[31754]
#define sipNameNr_toNextBoundary 31769
#define sipName_toNextBoundary &sipStrings_QtCore[31769]
#define sipNameNr_MandatoryBreak 31784
#define sipName_MandatoryBreak &sipStrings_QtCore[31784]
#define sipNameNr_BoundaryReason 914
#define sipName_BoundaryReason &sipStrings_QtCore[914]
#define sipNameNr_QTemporaryFile 31799
#define sipName_QTemporaryFile &sipStrings_QtCore[31799]
#define sipNameNr_mountedVolumes 31814
#define sipName_mountedVolumes &sipStrings_QtCore[31814]
#define sipNameNr_fileSystemType 31829
#define sipName_fileSystemType &sipStrings_QtCore[31829]
#define sipNameNr_runningChanged 31844
#define sipName_runningChanged &sipStrings_QtCore[31844]
#define sipNameNr_NormalPriority 31859
#define sipName_NormalPriority &sipStrings_QtCore[31859]
#define sipNameNr_assignProperty 31874
#define sipName_assignProperty &sipStrings_QtCore[31874]
#define sipNameNr_ParallelStates 31889
#define sipName_ParallelStates &sipStrings_QtCore[31889]
#define sipNameNr_enableTestMode 31904
#define sipName_enableTestMode &sipStrings_QtCore[31904]
#define sipNameNr_findExecutable 31919
#define sipName_findExecutable &sipStrings_QtCore[31919]
#define sipNameNr_ConfigLocation 11398
#define sipName_ConfigLocation &sipStrings_QtCore[11398]
#define sipNameNr_MoviesLocation 31934
#define sipName_MoviesLocation &sipStrings_QtCore[31934]
#define sipNameNr_QStandardPaths 31949
#define sipName_QStandardPaths &sipStrings_QtCore[31949]
#define sipNameNr_removeMappings 31964
#define sipName_removeMappings &sipStrings_QtCore[31964]
#define sipNameNr_OutOfResources 31979
#define sipName_OutOfResources &sipStrings_QtCore[31979]
#define sipNameNr_beginReadArray 31994
#define sipName_beginReadArray &sipStrings_QtCore[31994]
#define sipNameNr_capturedLength 32009
#define sipName_capturedLength &sipStrings_QtCore[32009]
#define sipNameNr_patternOptions 32024
#define sipName_patternOptions &sipStrings_QtCore[32024]
#define sipNameNr_PatternOptions 1200
#define sipName_PatternOptions &sipStrings_QtCore[1200]
#define sipNameNr_CaretWontMatch 32039
#define sipName_CaretWontMatch &sipStrings_QtCore[32039]
#define sipNameNr_W3CXmlSchema11 32054
#define sipName_W3CXmlSchema11 &sipStrings_QtCore[32054]
#define sipNameNr_marginsRemoved 32069
#define sipName_marginsRemoved &sipStrings_QtCore[32069]
#define sipNameNr_moveBottomLeft 32084
#define sipName_moveBottomLeft &sipStrings_QtCore[32084]
#define sipNameNr_setBottomRight 32099
#define sipName_setBottomRight &sipStrings_QtCore[32099]
#define sipNameNr_tryLockForRead 32114
#define sipName_tryLockForRead &sipStrings_QtCore[32114]
#define sipNameNr_QReadWriteLock 32129
#define sipName_QReadWriteLock &sipStrings_QtCore[32129]
#define sipNameNr_securelySeeded 32144
#define sipName_securelySeeded &sipStrings_QtCore[32144]
#define sipNameNr_generateDouble 32159
#define sipName_generateDouble &sipStrings_QtCore[32159]
#define sipNameNr_waitForStarted 32174
#define sipName_waitForStarted &sipStrings_QtCore[32174]
#define sipNameNr_setReadChannel 32189
#define sipName_setReadChannel &sipStrings_QtCore[32189]
#define sipNameNr_MergedChannels 32204
#define sipName_MergedChannels &sipStrings_QtCore[32204]
#define sipNameNr_StandardOutput 8377
#define sipName_StandardOutput &sipStrings_QtCore[8377]
#define sipNameNr_ProcessChannel 7042
#define sipName_ProcessChannel &sipStrings_QtCore[7042]
#define sipNameNr_normalizedType 32219
#define sipName_normalizedType &sipStrings_QtCore[32219]
#define sipNameNr_classInfoCount 32234
#define sipName_classInfoCount &sipStrings_QtCore[32234]
#define sipNameNr_propertyOffset 32249
#define sipName_propertyOffset &sipStrings_QtCore[32249]
#define sipNameNr_QSignalBlocker 32264
#define sipName_QSignalBlocker &sipStrings_QtCore[32264]
#define sipNameNr_dumpObjectTree 32279
#define sipName_dumpObjectTree &sipStrings_QtCore[32279]
#define sipNameNr_dumpObjectInfo 32294
#define sipName_dumpObjectInfo &sipStrings_QtCore[32294]
#define sipNameNr_signalsBlocked 32309
#define sipName_signalsBlocked &sipStrings_QtCore[32309]
#define sipNameNr_qFloatDistance 32324
#define sipName_qFloatDistance &sipStrings_QtCore[32324]
#define sipNameNr_mimeTypeForUrl 32339
#define sipName_mimeTypeForUrl &sipStrings_QtCore[32339]
#define sipNameNr_MatchExtension 32354
#define sipName_MatchExtension &sipStrings_QtCore[32354]
#define sipNameNr_QByteArrayList 32369
#define sipName_QByteArrayList &sipStrings_QtCore[32369]
#define sipNameNr_QMetaClassInfo 32384
#define sipName_QMetaClassInfo &sipStrings_QtCore[32384]
#define sipNameNr_parameterCount 32399
#define sipName_parameterCount &sipStrings_QtCore[32399]
#define sipNameNr_parameterNames 32414
#define sipName_parameterNames &sipStrings_QtCore[32414]
#define sipNameNr_parameterTypes 32429
#define sipName_parameterTypes &sipStrings_QtCore[32429]
#define sipNameNr_setFilterRules 32444
#define sipName_setFilterRules &sipStrings_QtCore[32444]
#define sipNameNr_isDebugEnabled 32459
#define sipName_isDebugEnabled &sipStrings_QtCore[32459]
#define sipNameNr_QMessageLogger 32474
#define sipName_QMessageLogger &sipStrings_QtCore[32474]
#define sipNameNr_DataSizeFormat 8497
#define sipName_DataSizeFormat &sipStrings_QtCore[8497]
#define sipNameNr_QuotationStyle 8521
#define sipName_QuotationStyle &sipStrings_QtCore[8521]
#define sipNameNr_scriptToString 32489
#define sipName_scriptToString &sipStrings_QtCore[32489]
#define sipNameNr_currencySymbol 32504
#define sipName_currencySymbol &sipStrings_QtCore[32504]
#define sipNameNr_firstDayOfWeek 32519
#define sipName_firstDayOfWeek &sipStrings_QtCore[32519]
#define sipNameNr_CurrencySymbol 32534
#define sipName_CurrencySymbol &sipStrings_QtCore[32534]
#define sipNameNr_MahajaniScript 32549
#define sipName_MahajaniScript &sipStrings_QtCore[32549]
#define sipNameNr_DuployanScript 32564
#define sipName_DuployanScript &sipStrings_QtCore[32564]
#define sipNameNr_BassaVahScript 32579
#define sipName_BassaVahScript &sipStrings_QtCore[32579]
#define sipNameNr_HiraganaScript 32594
#define sipName_HiraganaScript &sipStrings_QtCore[32594]
#define sipNameNr_UgariticScript 32609
#define sipName_UgariticScript &sipStrings_QtCore[32609]
#define sipNameNr_TagbanwaScript 32624
#define sipName_TagbanwaScript &sipStrings_QtCore[32624]
#define sipNameNr_MeroiticScript 32639
#define sipName_MeroiticScript &sipStrings_QtCore[32639]
#define sipNameNr_MandaeanScript 32654
#define sipName_MandaeanScript &sipStrings_QtCore[32654]
#define sipNameNr_KatakanaScript 32669
#define sipName_KatakanaScript &sipStrings_QtCore[32669]
#define sipNameNr_JavaneseScript 32684
#define sipName_JavaneseScript &sipStrings_QtCore[32684]
#define sipNameNr_BugineseScript 32699
#define sipName_BugineseScript &sipStrings_QtCore[32699]
#define sipNameNr_BopomofoScript 11750
#define sipName_BopomofoScript &sipStrings_QtCore[11750]
#define sipNameNr_BalineseScript 32714
#define sipName_BalineseScript &sipStrings_QtCore[32714]
#define sipNameNr_JapaneseScript 32729
#define sipName_JapaneseScript &sipStrings_QtCore[32729]
#define sipNameNr_GujaratiScript 32744
#define sipName_GujaratiScript &sipStrings_QtCore[32744]
#define sipNameNr_GeorgianScript 32759
#define sipName_GeorgianScript &sipStrings_QtCore[32759]
#define sipNameNr_EthiopicScript 32774
#define sipName_EthiopicScript &sipStrings_QtCore[32774]
#define sipNameNr_CherokeeScript 32789
#define sipName_CherokeeScript &sipStrings_QtCore[32789]
#define sipNameNr_ArmenianScript 32804
#define sipName_ArmenianScript &sipStrings_QtCore[32804]
#define sipNameNr_TifinaghScript 32819
#define sipName_TifinaghScript &sipStrings_QtCore[32819]
#define sipNameNr_GurmukhiScript 32834
#define sipName_GurmukhiScript &sipStrings_QtCore[32834]
#define sipNameNr_CyrillicScript 32849
#define sipName_CyrillicScript &sipStrings_QtCore[32849]
#define sipNameNr_ImperialSystem 32864
#define sipName_ImperialSystem &sipStrings_QtCore[32864]
#define sipNameNr_groupSeparator 32879
#define sipName_groupSeparator &sipStrings_QtCore[32879]
#define sipNameNr_dateTimeFormat 32894
#define sipName_dateTimeFormat &sipStrings_QtCore[32894]
#define sipNameNr_TokelauCountry 32909
#define sipName_TokelauCountry &sipStrings_QtCore[32909]
#define sipNameNr_TristanDaCunha 32924
#define sipName_TristanDaCunha &sipStrings_QtCore[32924]
#define sipNameNr_SolomonIslands 32939
#define sipName_SolomonIslands &sipStrings_QtCore[32939]
#define sipNameNr_PapuaNewGuinea 32954
#define sipName_PapuaNewGuinea &sipStrings_QtCore[32954]
#define sipNameNr_WesternBalochi 32969
#define sipName_WesternBalochi &sipStrings_QtCore[32969]
#define sipNameNr_TuvaluLanguage 32984
#define sipName_TuvaluLanguage &sipStrings_QtCore[32984]
#define sipNameNr_CentralKurdish 32999
#define sipName_CentralKurdish &sipStrings_QtCore[32999]
#define sipNameNr_WesternFrisian 33014
#define sipName_WesternFrisian &sipStrings_QtCore[33014]
#define sipNameNr_KoyraboroSenni 33029
#define sipName_KoyraboroSenni &sipStrings_QtCore[33029]
#define sipNameNr_NoIntersection 33044
#define sipName_NoIntersection &sipStrings_QtCore[33044]
#define sipNameNr_fromBinaryData 33059
#define sipName_fromBinaryData &sipStrings_QtCore[33059]
#define sipNameNr_DataValidation 2951
#define sipName_DataValidation &sipStrings_QtCore[2951]
#define sipNameNr_QItemSelection 33074
#define sipName_QItemSelection &sipStrings_QtCore[33074]
#define sipNameNr_currentChanged 33089
#define sipName_currentChanged &sipStrings_QtCore[33089]
#define sipNameNr_clearSelection 33104
#define sipName_clearSelection &sipStrings_QtCore[33104]
#define sipNameNr_SelectionFlags 950
#define sipName_SelectionFlags &sipStrings_QtCore[950]
#define sipNameNr_ClearAndSelect 33119
#define sipName_ClearAndSelect &sipStrings_QtCore[33119]
#define sipNameNr_setErrorString 33134
#define sipName_setErrorString &sipStrings_QtCore[33134]
#define sipNameNr_bytesAvailable 33149
#define sipName_bytesAvailable &sipStrings_QtCore[33149]
#define sipNameNr_setHistoryType 33164
#define sipName_setHistoryType &sipStrings_QtCore[33164]
#define sipNameNr_ShallowHistory 33179
#define sipName_ShallowHistory &sipStrings_QtCore[33179]
#define sipNameNr_extraSelectors 33194
#define sipName_extraSelectors &sipStrings_QtCore[33194]
#define sipNameNr_isSymbolicLink 33209
#define sipName_isSymbolicLink &sipStrings_QtCore[33209]
#define sipNameNr_completeSuffix 33224
#define sipName_completeSuffix &sipStrings_QtCore[33224]
#define sipNameNr_FileAccessTime 33239
#define sipName_FileAccessTime &sipStrings_QtCore[33239]
#define sipNameNr_MemoryMapFlags 4362
#define sipName_MemoryMapFlags &sipStrings_QtCore[4362]
#define sipNameNr_FileHandleFlag 4390
#define sipName_FileHandleFlag &sipStrings_QtCore[4390]
#define sipNameNr_setPermissions 33254
#define sipName_setPermissions &sipStrings_QtCore[33254]
#define sipNameNr_setEventSource 33269
#define sipName_setEventSource &sipStrings_QtCore[33269]
#define sipNameNr_MonotonicClock 33284
#define sipName_MonotonicClock &sipStrings_QtCore[33284]
#define sipNameNr_Subdirectories 33299
#define sipName_Subdirectories &sipStrings_QtCore[33299]
#define sipNameNr_FollowSymlinks 33314
#define sipName_FollowSymlinks &sipStrings_QtCore[33314]
#define sipNameNr_setSearchPaths 33329
#define sipName_setSearchPaths &sipStrings_QtCore[33329]
#define sipNameNr_isAbsolutePath 33344
#define sipName_isAbsolutePath &sipStrings_QtCore[33344]
#define sipNameNr_isRelativePath 33359
#define sipName_isRelativePath &sipStrings_QtCore[33359]
#define sipNameNr_setNameFilters 33374
#define sipName_setNameFilters &sipStrings_QtCore[33374]
#define sipNameNr_QDir__SortFlag 33389
#define sipName_QDir__SortFlag &sipStrings_QtCore[33389]
#define sipNameNr_NoDotAndDotDot 33404
#define sipName_NoDotAndDotDot &sipStrings_QtCore[33404]
#define sipNameNr_PermissionMask 33419
#define sipName_PermissionMask &sipStrings_QtCore[33419]
#define sipNameNr_QDeadlineTimer 33434
#define sipName_QDeadlineTimer &sipStrings_QtCore[33434]
#define sipNameNr_isDaylightTime 33449
#define sipName_isDaylightTime &sipStrings_QtCore[33449]
#define sipNameNr_shortMonthName 33464
#define sipName_shortMonthName &sipStrings_QtCore[33464]
#define sipNameNr_ReadOnlyChange 33479
#define sipName_ReadOnlyChange &sipStrings_QtCore[33479]
#define sipNameNr_UngrabKeyboard 33494
#define sipName_UngrabKeyboard &sipStrings_QtCore[33494]
#define sipNameNr_QueryWhatsThis 33509
#define sipName_QueryWhatsThis &sipStrings_QtCore[33509]
#define sipNameNr_ModifiedChange 33524
#define sipName_ModifiedChange &sipStrings_QtCore[33524]
#define sipNameNr_IconTextChange 33539
#define sipName_IconTextChange &sipStrings_QtCore[33539]
#define sipNameNr_LanguageChange 33554
#define sipName_LanguageChange &sipStrings_QtCore[33554]
#define sipNameNr_DeferredDelete 33569
#define sipName_DeferredDelete &sipStrings_QtCore[33569]
#define sipNameNr_WindowActivate 33584
#define sipName_WindowActivate &sipStrings_QtCore[33584]
#define sipNameNr_qAddPreRoutine 33599
#define sipName_qAddPreRoutine &sipStrings_QtCore[33599]
#define sipNameNr_applicationPid 33614
#define sipName_applicationPid &sipStrings_QtCore[33614]
#define sipNameNr_disambiguation 33629
#define sipName_disambiguation &sipStrings_QtCore[33629]
#define sipNameNr_addLibraryPath 33644
#define sipName_addLibraryPath &sipStrings_QtCore[33644]
#define sipNameNr_addSourceModel 33659
#define sipName_addSourceModel &sipStrings_QtCore[33659]
#define sipNameNr_ParseAsOptions 33674
#define sipName_ParseAsOptions &sipStrings_QtCore[33674]
#define sipNameNr_HiddenFromHelp 33689
#define sipName_HiddenFromHelp &sipStrings_QtCore[33689]
#define sipNameNr_setDescription 33704
#define sipName_setDescription &sipStrings_QtCore[33704]
#define sipNameNr_setNumericMode 33719
#define sipName_setNumericMode &sipStrings_QtCore[33719]
#define sipNameNr_leaveContainer 33734
#define sipName_leaveContainer &sipStrings_QtCore[33734]
#define sipNameNr_enterContainer 33749
#define sipName_enterContainer &sipStrings_QtCore[33749]
#define sipNameNr_containerDepth 33764
#define sipName_containerDepth &sipStrings_QtCore[33764]
#define sipNameNr_ExpectedBase16 33779
#define sipName_ExpectedBase16 &sipStrings_QtCore[33779]
#define sipNameNr_ExpectedBase64 33794
#define sipName_ExpectedBase64 &sipStrings_QtCore[33794]
#define sipNameNr_NegativeBignum 33809
#define sipName_NegativeBignum &sipStrings_QtCore[33809]
#define sipNameNr_PositiveBignum 33824
#define sipName_PositiveBignum &sipStrings_QtCore[33824]
#define sipNameNr_DateTimeString 33839
#define sipName_DateTimeString &sipStrings_QtCore[33839]
#define sipNameNr_QCborKnownTags 33854
#define sipName_QCborKnownTags &sipStrings_QtCore[33854]
#define sipNameNr_NestingTooDeep 33869
#define sipName_NestingTooDeep &sipStrings_QtCore[33869]
#define sipNameNr_AdvancePastEnd 33884
#define sipName_AdvancePastEnd &sipStrings_QtCore[33884]
#define sipNameNr_decodingStatus 33899
#define sipName_decodingStatus &sipStrings_QtCore[33899]
#define sipNameNr_IllegalPadding 33914
#define sipName_IllegalPadding &sipStrings_QtCore[33914]
#define sipNameNr_Base64Encoding 19673
#define sipName_Base64Encoding &sipStrings_QtCore[19673]
#define sipNameNr_rightJustified 33929
#define sipName_rightJustified &sipStrings_QtCore[33929]
#define sipNameNr_animationCount 33944
#define sipName_animationCount &sipStrings_QtCore[33944]
#define sipNameNr_transitionType 33959
#define sipName_transitionType &sipStrings_QtCore[33959]
#define sipNameNr_TransitionType 1058
#define sipName_TransitionType &sipStrings_QtCore[1058]
#define sipNameNr_setTargetState 33974
#define sipName_setTargetState &sipStrings_QtCore[33974]
#define sipNameNr_QAbstractState 33989
#define sipName_QAbstractState &sipStrings_QtCore[33989]
#define sipNameNr_setSourceModel 34004
#define sipName_setSourceModel &sipStrings_QtCore[34004]
#define sipNameNr_DoNotUseParent 34019
#define sipName_DoNotUseParent &sipStrings_QtCore[34019]
#define sipNameNr_endMoveColumns 34034
#define sipName_endMoveColumns &sipStrings_QtCore[34034]
#define sipNameNr_columnsRemoved 34049
#define sipName_columnsRemoved &sipStrings_QtCore[34049]
#define sipNameNr_setCurrentTime 34064
#define sipName_setCurrentTime &sipStrings_QtCore[34064]
#define sipNameNr_DeletionPolicy 1270
#define sipName_DeletionPolicy &sipStrings_QtCore[1270]
#define sipNameNr_ChecksumItuV41 34079
#define sipName_ChecksumItuV41 &sipStrings_QtCore[34079]
#define sipNameNr_EnterKeySearch 34094
#define sipName_EnterKeySearch &sipStrings_QtCore[34094]
#define sipNameNr_EnterKeyReturn 34109
#define sipName_EnterKeyReturn &sipStrings_QtCore[34109]
#define sipNameNr_AddToSelection 34124
#define sipName_AddToSelection &sipStrings_QtCore[34124]
#define sipNameNr_MouseEventFlag 19996
#define sipName_MouseEventFlag &sipStrings_QtCore[19996]
#define sipNameNr_ScrollMomentum 34139
#define sipName_ScrollMomentum &sipStrings_QtCore[34139]
#define sipNameNr_WhiteSpaceMode 20053
#define sipName_WhiteSpaceMode &sipStrings_QtCore[20053]
#define sipNameNr_NavigationMode 20110
#define sipName_NavigationMode &sipStrings_QtCore[20110]
#define sipNameNr_GestureUpdated 34154
#define sipName_GestureUpdated &sipStrings_QtCore[34154]
#define sipNameNr_GestureStarted 34169
#define sipName_GestureStarted &sipStrings_QtCore[34169]
#define sipNameNr_ImhPreferLatin 34184
#define sipName_ImhPreferLatin &sipStrings_QtCore[34184]
#define sipNameNr_TopLeftSection 34199
#define sipName_TopLeftSection &sipStrings_QtCore[34199]
#define sipNameNr_MinimumDescent 34214
#define sipName_MinimumDescent &sipStrings_QtCore[34214]
#define sipNameNr_AA_UseOpenGLES 34229
#define sipName_AA_UseOpenGLES &sipStrings_QtCore[34229]
#define sipNameNr_WindowModality 20243
#define sipName_WindowModality &sipStrings_QtCore[20243]
#define sipNameNr_Qt__MatchFlags 34244
#define sipName_Qt__MatchFlags &sipStrings_QtCore[34244]
#define sipNameNr_MatchRecursive 34259
#define sipName_MatchRecursive &sipStrings_QtCore[34259]
#define sipNameNr_ItemIsTristate 34274
#define sipName_ItemIsTristate &sipStrings_QtCore[34274]
#define sipNameNr_ItemIsEditable 34289
#define sipName_ItemIsEditable &sipStrings_QtCore[34289]
#define sipNameNr_CheckStateRole 34304
#define sipName_CheckStateRole &sipStrings_QtCore[34304]
#define sipNameNr_ForegroundRole 34319
#define sipName_ForegroundRole &sipStrings_QtCore[34319]
#define sipNameNr_BackgroundRole 34334
#define sipName_BackgroundRole &sipStrings_QtCore[34334]
#define sipNameNr_DecorationRole 34349
#define sipName_DecorationRole &sipStrings_QtCore[34349]
#define sipNameNr_Qt__CheckState 34364
#define sipName_Qt__CheckState &sipStrings_QtCore[34364]
#define sipNameNr_Qt__DropAction 34379
#define sipName_Qt__DropAction &sipStrings_QtCore[34379]
#define sipNameNr_ImEnterKeyType 34394
#define sipName_ImEnterKeyType &sipStrings_QtCore[34394]
#define sipNameNr_ImPlatformData 34409
#define sipName_ImPlatformData &sipStrings_QtCore[34409]
#define sipNameNr_TabFocusReason 34424
#define sipName_TabFocusReason &sipStrings_QtCore[34424]
#define sipNameNr_WindowShortcut 34439
#define sipName_WindowShortcut &sipStrings_QtCore[34439]
#define sipNameNr_WidgetShortcut 34454
#define sipName_WidgetShortcut &sipStrings_QtCore[34454]
#define sipNameNr_AutoConnection 34469
#define sipName_AutoConnection &sipStrings_QtCore[34469]
#define sipNameNr_ConnectionType 20547
#define sipName_ConnectionType &sipStrings_QtCore[20547]
#define sipNameNr_TopRightCorner 34484
#define sipName_TopRightCorner &sipStrings_QtCore[34484]
#define sipNameNr_Qt__DateFormat 34499
#define sipName_Qt__DateFormat &sipStrings_QtCore[34499]
#define sipNameNr_TopToolBarArea 34514
#define sipName_TopToolBarArea &sipStrings_QtCore[34514]
#define sipNameNr_DockWidgetArea 14963
#define sipName_DockWidgetArea &sipStrings_QtCore[14963]
#define sipNameNr_Qt__TextFormat 34529
#define sipName_Qt__TextFormat &sipStrings_QtCore[34529]
#define sipNameNr_DragLinkCursor 34544
#define sipName_DragLinkCursor &sipStrings_QtCore[34544]
#define sipNameNr_DragMoveCursor 34559
#define sipName_DragMoveCursor &sipStrings_QtCore[34559]
#define sipNameNr_DragCopyCursor 34574
#define sipName_DragCopyCursor &sipStrings_QtCore[34574]
#define sipNameNr_OpenHandCursor 34589
#define sipName_OpenHandCursor &sipStrings_QtCore[34589]
#define sipNameNr_UI_FadeTooltip 34604
#define sipName_UI_FadeTooltip &sipStrings_QtCore[34604]
#define sipNameNr_UI_AnimateMenu 34619
#define sipName_UI_AnimateMenu &sipStrings_QtCore[34619]
#define sipNameNr_TexturePattern 34634
#define sipName_TexturePattern &sipStrings_QtCore[34634]
#define sipNameNr_Qt__BrushStyle 34649
#define sipName_Qt__BrushStyle &sipStrings_QtCore[34649]
#define sipNameNr_CustomDashLine 34664
#define sipName_CustomDashLine &sipStrings_QtCore[34664]
#define sipNameNr_DashDotDotLine 34679
#define sipName_DashDotDotLine &sipStrings_QtCore[34679]
#define sipNameNr_Key_Dead_Greek 34694
#define sipName_Key_Dead_Greek &sipStrings_QtCore[34694]
#define sipNameNr_Key_TouchpadOn 34709
#define sipName_Key_TouchpadOn &sipStrings_QtCore[34709]
#define sipNameNr_Key_MediaPause 34724
#define sipName_Key_MediaPause &sipStrings_QtCore[34724]
#define sipNameNr_Key_RotationKB 34739
#define sipName_Key_RotationKB &sipStrings_QtCore[34739]
#define sipNameNr_Key_RotationPB 34754
#define sipName_Key_RotationPB &sipStrings_QtCore[34754]
#define sipNameNr_Key_OfficeHome 34769
#define sipName_Key_OfficeHome &sipStrings_QtCore[34769]
#define sipNameNr_Key_Calculator 34784
#define sipName_Key_Calculator &sipStrings_QtCore[34784]
#define sipNameNr_Key_LaunchMail 34799
#define sipName_Key_LaunchMail &sipStrings_QtCore[34799]
#define sipNameNr_Key_TrebleDown 34814
#define sipName_Key_TrebleDown &sipStrings_QtCore[34814]
#define sipNameNr_Key_VolumeMute 34829
#define sipName_Key_VolumeMute &sipStrings_QtCore[34829]
#define sipNameNr_Key_VolumeDown 34844
#define sipName_Key_VolumeDown &sipStrings_QtCore[34844]
#define sipNameNr_Key_Dead_Caron 34859
#define sipName_Key_Dead_Caron &sipStrings_QtCore[34859]
#define sipNameNr_Key_Dead_Breve 34874
#define sipName_Key_Dead_Breve &sipStrings_QtCore[34874]
#define sipNameNr_Key_Dead_Tilde 34889
#define sipName_Key_Dead_Tilde &sipStrings_QtCore[34889]
#define sipNameNr_Key_Dead_Acute 34904
#define sipName_Key_Dead_Acute &sipStrings_QtCore[34904]
#define sipNameNr_Key_Dead_Grave 34919
#define sipName_Key_Dead_Grave &sipStrings_QtCore[34919]
#define sipNameNr_Key_Hangul_End 34934
#define sipName_Key_Hangul_End &sipStrings_QtCore[34934]
#define sipNameNr_Key_Eisu_Shift 34949
#define sipName_Key_Eisu_Shift &sipStrings_QtCore[34949]
#define sipNameNr_Key_Kana_Shift 34964
#define sipName_Key_Kana_Shift &sipStrings_QtCore[34964]
#define sipNameNr_Key_ydiaeresis 34979
#define sipName_Key_ydiaeresis &sipStrings_QtCore[34979]
#define sipNameNr_Key_Udiaeresis 34994
#define sipName_Key_Udiaeresis &sipStrings_QtCore[34994]
#define sipNameNr_Key_Odiaeresis 35009
#define sipName_Key_Odiaeresis &sipStrings_QtCore[35009]
#define sipNameNr_Key_Idiaeresis 35024
#define sipName_Key_Idiaeresis &sipStrings_QtCore[35024]
#define sipNameNr_Key_Ediaeresis 35039
#define sipName_Key_Ediaeresis &sipStrings_QtCore[35039]
#define sipNameNr_Key_Adiaeresis 35054
#define sipName_Key_Adiaeresis &sipStrings_QtCore[35054]
#define sipNameNr_Key_onequarter 35069
#define sipName_Key_onequarter &sipStrings_QtCore[35069]
#define sipNameNr_Key_registered 35084
#define sipName_Key_registered &sipStrings_QtCore[35084]
#define sipNameNr_Key_exclamdown 35099
#define sipName_Key_exclamdown &sipStrings_QtCore[35099]
#define sipNameNr_Key_AsciiTilde 35114
#define sipName_Key_AsciiTilde &sipStrings_QtCore[35114]
#define sipNameNr_Key_BraceRight 35129
#define sipName_Key_BraceRight &sipStrings_QtCore[35129]
#define sipNameNr_Key_Underscore 35144
#define sipName_Key_Underscore &sipStrings_QtCore[35144]
#define sipNameNr_Key_ParenRight 35159
#define sipName_Key_ParenRight &sipStrings_QtCore[35159]
#define sipNameNr_Key_Apostrophe 35174
#define sipName_Key_Apostrophe &sipStrings_QtCore[35174]
#define sipNameNr_Key_NumberSign 35189
#define sipName_Key_NumberSign &sipStrings_QtCore[35189]
#define sipNameNr_Key_ScrollLock 35204
#define sipName_Key_ScrollLock &sipStrings_QtCore[35204]
#define sipNameNr_WA_MacNoShadow 35219
#define sipName_WA_MacNoShadow &sipStrings_QtCore[35219]
#define sipNameNr_WA_MacMiniSize 35234
#define sipName_WA_MacMiniSize &sipStrings_QtCore[35234]
#define sipNameNr_WA_AcceptDrops 35249
#define sipName_WA_AcceptDrops &sipStrings_QtCore[35249]
#define sipNameNr_WA_QuitOnClose 35264
#define sipName_WA_QuitOnClose &sipStrings_QtCore[35264]
#define sipNameNr_WA_GroupLeader 35279
#define sipName_WA_GroupLeader &sipStrings_QtCore[35279]
#define sipNameNr_WA_MouseNoMask 35294
#define sipName_WA_MouseNoMask &sipStrings_QtCore[35294]
#define sipNameNr_WA_RightToLeft 35309
#define sipName_WA_RightToLeft &sipStrings_QtCore[35309]
#define sipNameNr_WA_InvalidSize 35324
#define sipName_WA_InvalidSize &sipStrings_QtCore[35324]
#define sipNameNr_MSWindowsOwnDC 35339
#define sipName_MSWindowsOwnDC &sipStrings_QtCore[35339]
#define sipNameNr_Qt__WindowType 35354
#define sipName_Qt__WindowType &sipStrings_QtCore[35354]
#define sipNameNr_TextExpandTabs 35369
#define sipName_TextExpandTabs &sipStrings_QtCore[35369]
#define sipNameNr_TextSingleLine 35384
#define sipName_TextSingleLine &sipStrings_QtCore[35384]
#define sipNameNr_AscendingOrder 35399
#define sipName_AscendingOrder &sipStrings_QtCore[35399]
#define sipNameNr_KeypadModifier 35414
#define sipName_KeypadModifier &sipStrings_QtCore[35414]
#define sipNameNr_QT_VERSION_STR 27567
#define sipName_QT_VERSION_STR &sipStrings_QtCore[27567]
#define sipNameNr_kernelVersion 35429
#define sipName_kernelVersion &sipStrings_QtCore[35429]
#define sipNameNr_isEndDocument 35443
#define sipName_isEndDocument &sipStrings_QtCore[35443]
#define sipNameNr_StartDocument 18002
#define sipName_StartDocument &sipStrings_QtCore[18002]
#define sipNameNr_qualifiedName 35457
#define sipName_qualifiedName &sipStrings_QtCore[35457]
#define sipNameNr_setKeyValueAt 35471
#define sipName_setKeyValueAt &sipStrings_QtCore[35471]
#define sipNameNr_setStartValue 35485
#define sipName_setStartValue &sipStrings_QtCore[35485]
#define sipNameNr_WithoutBraces 35499
#define sipName_WithoutBraces &sipStrings_QtCore[35499]
#define sipNameNr_EmbeddedPOSIX 35513
#define sipName_EmbeddedPOSIX &sipStrings_QtCore[35513]
#define sipNameNr_setQueryItems 35527
#define sipName_setQueryItems &sipStrings_QtCore[35527]
#define sipNameNr_fromUserInput 35541
#define sipName_fromUserInput &sipStrings_QtCore[35541]
#define sipNameNr_fromLocalFile 35555
#define sipName_fromLocalFile &sipStrings_QtCore[35555]
#define sipNameNr_EncodeUnicode 35569
#define sipName_EncodeUnicode &sipStrings_QtCore[35569]
#define sipNameNr_PrettyDecoded 35583
#define sipName_PrettyDecoded &sipStrings_QtCore[35583]
#define sipNameNr_setSingleShot 35597
#define sipName_setSingleShot &sipStrings_QtCore[35597]
#define sipNameNr_setCurveShape 35611
#define sipName_setCurveShape &sipStrings_QtCore[35611]
#define sipNameNr_setFrameRange 35625
#define sipName_setFrameRange &sipStrings_QtCore[35625]
#define sipNameNr_setStartFrame 35639
#define sipName_setStartFrame &sipStrings_QtCore[35639]
#define sipNameNr_releaseThread 35653
#define sipName_releaseThread &sipStrings_QtCore[35653]
#define sipNameNr_reserveThread 35667
#define sipName_reserveThread &sipStrings_QtCore[35667]
#define sipNameNr_expiryTimeout 35681
#define sipName_expiryTimeout &sipStrings_QtCore[35681]
#define sipNameNr_currentThread 35695
#define sipName_currentThread &sipStrings_QtCore[35695]
#define sipNameNr_lowercasebase 35709
#define sipName_lowercasebase &sipStrings_QtCore[35709]
#define sipNameNr_uppercasebase 35723
#define sipName_uppercasebase &sipStrings_QtCore[35723]
#define sipNameNr_setFieldWidth 35737
#define sipName_setFieldWidth &sipStrings_QtCore[35737]
#define sipNameNr_UppercaseBase 35751
#define sipName_UppercaseBase &sipStrings_QtCore[35751]
#define sipNameNr_FixedNotation 35765
#define sipName_FixedNotation &sipStrings_QtCore[35765]
#define sipNameNr_SmartNotation 35779
#define sipName_SmartNotation &sipStrings_QtCore[35779]
#define sipNameNr_availableMibs 35793
#define sipName_availableMibs &sipStrings_QtCore[35793]
#define sipNameNr_NotAtBoundary 35807
#define sipName_NotAtBoundary &sipStrings_QtCore[35807]
#define sipNameNr_setAutoRemove 35821
#define sipName_setAutoRemove &sipStrings_QtCore[35821]
#define sipNameNr_QTemporaryDir 35835
#define sipName_QTemporaryDir &sipStrings_QtCore[35835]
#define sipNameNr_setStringList 35849
#define sipName_setStringList &sipStrings_QtCore[35849]
#define sipNameNr_configuration 35863
#define sipName_configuration &sipStrings_QtCore[35863]
#define sipNameNr_QStateMachine 35877
#define sipName_QStateMachine &sipStrings_QtCore[35877]
#define sipNameNr_addTransition 35891
#define sipName_addTransition &sipStrings_QtCore[35891]
#define sipNameNr_setErrorState 35905
#define sipName_setErrorState &sipStrings_QtCore[35905]
#define sipNameNr_RestorePolicy 9642
#define sipName_RestorePolicy &sipStrings_QtCore[9642]
#define sipNameNr_LocateOptions 2772
#define sipName_LocateOptions &sipStrings_QtCore[2772]
#define sipNameNr_CacheLocation 13557
#define sipName_CacheLocation &sipStrings_QtCore[13557]
#define sipNameNr_MusicLocation 35919
#define sipName_MusicLocation &sipStrings_QtCore[35919]
#define sipNameNr_FontsLocation 35933
#define sipName_FontsLocation &sipStrings_QtCore[35933]
#define sipNameNr_setFilterRole 35947
#define sipName_setFilterRole &sipStrings_QtCore[35947]
#define sipNameNr_signalChanged 35961
#define sipName_signalChanged &sipStrings_QtCore[35961]
#define sipNameNr_QSignalMapper 35975
#define sipName_QSignalMapper &sipStrings_QtCore[35975]
#define sipNameNr_AlreadyExists 35989
#define sipName_AlreadyExists &sipStrings_QtCore[35989]
#define sipNameNr_QSharedMemory 36003
#define sipName_QSharedMemory &sipStrings_QtCore[36003]
#define sipNameNr_defaultFormat 36017
#define sipName_defaultFormat &sipStrings_QtCore[36017]
#define sipNameNr_setArrayIndex 36031
#define sipName_setArrayIndex &sipStrings_QtCore[36031]
#define sipNameNr_InvalidFormat 36045
#define sipName_InvalidFormat &sipStrings_QtCore[36045]
#define sipNameNr_cancelWriting 36059
#define sipName_cancelWriting &sipStrings_QtCore[36059]
#define sipNameNr_setAutoDelete 36073
#define sipName_setAutoDelete &sipStrings_QtCore[36073]
#define sipNameNr_NoCompression 36087
#define sipName_NoCompression &sipStrings_QtCore[36087]
#define sipNameNr_capturedStart 36101
#define sipName_capturedStart &sipStrings_QtCore[36101]
#define sipNameNr_NoMatchOption 36115
#define sipName_NoMatchOption &sipStrings_QtCore[36115]
#define sipNameNr_PatternOption 1547
#define sipName_PatternOption &sipStrings_QtCore[1547]
#define sipNameNr_capturedTexts 36129
#define sipName_capturedTexts &sipStrings_QtCore[36129]
#define sipNameNr_matchedLength 36143
#define sipName_matchedLength &sipStrings_QtCore[36143]
#define sipNameNr_patternSyntax 36157
#define sipName_patternSyntax &sipStrings_QtCore[36157]
#define sipNameNr_CaretAtOffset 36171
#define sipName_CaretAtOffset &sipStrings_QtCore[36171]
#define sipNameNr_PatternSyntax 9803
#define sipName_PatternSyntax &sipStrings_QtCore[9803]
#define sipNameNr_toAlignedRect 36185
#define sipName_toAlignedRect &sipStrings_QtCore[36185]
#define sipNameNr_setBottomLeft 36199
#define sipName_setBottomLeft &sipStrings_QtCore[36199]
#define sipNameNr_readWriteLock 36213
#define sipName_readWriteLock &sipStrings_QtCore[36213]
#define sipNameNr_recursionMode 36227
#define sipName_recursionMode &sipStrings_QtCore[36227]
#define sipNameNr_errorOccurred 36241
#define sipName_errorOccurred &sipStrings_QtCore[36241]
#define sipNameNr_startDetached 36255
#define sipName_startDetached &sipStrings_QtCore[36255]
#define sipNameNr_StandardError 9826
#define sipName_StandardError &sipStrings_QtCore[9826]
#define sipNameNr_FailedToStart 36269
#define sipName_FailedToStart &sipStrings_QtCore[36269]
#define sipNameNr_QPluginLoader 36283
#define sipName_QPluginLoader &sipStrings_QtCore[36283]
#define sipNameNr_AndroidNougat 36297
#define sipName_AndroidNougat &sipStrings_QtCore[36297]
#define sipNameNr_AndroidKitKat 36311
#define sipName_AndroidKitKat &sipStrings_QtCore[36311]
#define sipNameNr_MacOSCatalina 36325
#define sipName_MacOSCatalina &sipStrings_QtCore[36325]
#define sipNameNr_indexOfSignal 36339
#define sipName_indexOfSignal &sipStrings_QtCore[36339]
#define sipNameNr_indexOfMethod 36353
#define sipName_indexOfMethod &sipStrings_QtCore[36353]
#define sipNameNr_propertyCount 36367
#define sipName_propertyCount &sipStrings_QtCore[36367]
#define sipNameNr_setObjectName 36381
#define sipName_setObjectName &sipStrings_QtCore[36381]
#define sipNameNr_pyqtConfigure 36395
#define sipName_pyqtConfigure &sipStrings_QtCore[36395]
#define sipNameNr_RecursionMode 2832
#define sipName_RecursionMode &sipStrings_QtCore[2832]
#define sipNameNr_QMimeDatabase 36409
#define sipName_QMimeDatabase &sipStrings_QtCore[36409]
#define sipNameNr_IsEnumeration 36423
#define sipName_IsEnumeration &sipStrings_QtCore[36423]
#define sipNameNr_propertyIndex 36437
#define sipName_propertyIndex &sipStrings_QtCore[36437]
#define sipNameNr_QMetaProperty 36451
#define sipName_QMetaProperty &sipStrings_QtCore[36451]
#define sipNameNr_parameterType 36465
#define sipName_parameterType &sipStrings_QtCore[36465]
#define sipNameNr_isInfoEnabled 36479
#define sipName_isInfoEnabled &sipStrings_QtCore[36479]
#define sipNameNr_qErrnoWarning 36493
#define sipName_qErrnoWarning &sipStrings_QtCore[36493]
#define sipNameNr_QtCriticalMsg 36507
#define sipName_QtCriticalMsg &sipStrings_QtCore[36507]
#define sipNameNr_staleLockTime 36521
#define sipName_staleLockTime &sipStrings_QtCore[36521]
#define sipNameNr_MarchenScript 36535
#define sipName_MarchenScript &sipStrings_QtCore[36535]
#define sipNameNr_MultaniScript 36549
#define sipName_MultaniScript &sipStrings_QtCore[36549]
#define sipNameNr_TirhutaScript 36563
#define sipName_TirhutaScript &sipStrings_QtCore[36563]
#define sipNameNr_SiddhamScript 36577
#define sipName_SiddhamScript &sipStrings_QtCore[36577]
#define sipNameNr_LinearAScript 36591
#define sipName_LinearAScript &sipStrings_QtCore[36591]
#define sipNameNr_GranthaScript 36605
#define sipName_GranthaScript &sipStrings_QtCore[36605]
#define sipNameNr_ElbasanScript 36619
#define sipName_ElbasanScript &sipStrings_QtCore[36619]
#define sipNameNr_BrailleScript 36633
#define sipName_BrailleScript &sipStrings_QtCore[36633]
#define sipNameNr_TaiVietScript 36647
#define sipName_TaiVietScript &sipStrings_QtCore[36647]
#define sipNameNr_TagalogScript 36661
#define sipName_TagalogScript &sipStrings_QtCore[36661]
#define sipNameNr_ShavianScript 36675
#define sipName_ShavianScript &sipStrings_QtCore[36675]
#define sipNameNr_SharadaScript 36689
#define sipName_SharadaScript &sipStrings_QtCore[36689]
#define sipNameNr_PhagsPaScript 36703
#define sipName_PhagsPaScript &sipStrings_QtCore[36703]
#define sipNameNr_OsmanyaScript 36717
#define sipName_OsmanyaScript &sipStrings_QtCore[36717]
#define sipNameNr_OlChikiScript 36731
#define sipName_OlChikiScript &sipStrings_QtCore[36731]
#define sipNameNr_LinearBScript 36745
#define sipName_LinearBScript &sipStrings_QtCore[36745]
#define sipNameNr_KayahLiScript 36759
#define sipName_KayahLiScript &sipStrings_QtCore[36759]
#define sipNameNr_HanunooScript 36773
#define sipName_HanunooScript &sipStrings_QtCore[36773]
#define sipNameNr_CypriotScript 36787
#define sipName_CypriotScript &sipStrings_QtCore[36787]
#define sipNameNr_AvestanScript 36801
#define sipName_AvestanScript &sipStrings_QtCore[36801]
#define sipNameNr_SinhalaScript 36815
#define sipName_SinhalaScript &sipStrings_QtCore[36815]
#define sipNameNr_TibetanScript 36829
#define sipName_TibetanScript &sipStrings_QtCore[36829]
#define sipNameNr_MyanmarScript 36843
#define sipName_MyanmarScript &sipStrings_QtCore[36843]
#define sipNameNr_KannadaScript 36857
#define sipName_KannadaScript &sipStrings_QtCore[36857]
#define sipNameNr_BengaliScript 36871
#define sipName_BengaliScript &sipStrings_QtCore[36871]
#define sipNameNr_DeseretScript 36885
#define sipName_DeseretScript &sipStrings_QtCore[36885]
#define sipNameNr_textDirection 36899
#define sipName_textDirection &sipStrings_QtCore[36899]
#define sipNameNr_numberOptions 36913
#define sipName_numberOptions &sipStrings_QtCore[36913]
#define sipNameNr_NumberOptions 9964
#define sipName_NumberOptions &sipStrings_QtCore[9964]
#define sipNameNr_EuropeanUnion 36927
#define sipName_EuropeanUnion &sipStrings_QtCore[36927]
#define sipNameNr_TuvaluCountry 36941
#define sipName_TuvaluCountry &sipStrings_QtCore[36941]
#define sipNameNr_CanaryIslands 36955
#define sipName_CanaryIslands &sipStrings_QtCore[36955]
#define sipNameNr_CongoKinshasa 36969
#define sipName_CongoKinshasa &sipStrings_QtCore[36969]
#define sipNameNr_WesternSahara 36983
#define sipName_WesternSahara &sipStrings_QtCore[36983]
#define sipNameNr_UnitedKingdom 36997
#define sipName_UnitedKingdom &sipStrings_QtCore[36997]
#define sipNameNr_NorfolkIsland 37011
#define sipName_NorfolkIsland &sipStrings_QtCore[37011]
#define sipNameNr_Liechtenstein 37025
#define sipName_Liechtenstein &sipStrings_QtCore[37025]
#define sipNameNr_CzechRepublic 37039
#define sipName_CzechRepublic &sipStrings_QtCore[37039]
#define sipNameNr_CaymanIslands 37053
#define sipName_CaymanIslands &sipStrings_QtCore[37053]
#define sipNameNr_AmericanSamoa 37067
#define sipName_AmericanSamoa &sipStrings_QtCore[37067]
#define sipNameNr_Luxembourgish 37081
#define sipName_Luxembourgish &sipStrings_QtCore[37081]
#define sipNameNr_SouthernSotho 37095
#define sipName_SouthernSotho &sipStrings_QtCore[37095]
#define sipNameNr_MakhuwaMeetto 37109
#define sipName_MakhuwaMeetto &sipStrings_QtCore[37109]
#define sipNameNr_NorthernSotho 37123
#define sipName_NorthernSotho &sipStrings_QtCore[37123]
#define sipNameNr_SerboCroatian 37137
#define sipName_SerboCroatian &sipStrings_QtCore[37137]
#define sipNameNr_RhaetoRomance 37151
#define sipName_RhaetoRomance &sipStrings_QtCore[37151]
#define sipNameNr_NauruLanguage 37165
#define sipName_NauruLanguage &sipStrings_QtCore[37165]
#define sipNameNr_IntersectType 11949
#define sipName_IntersectType &sipStrings_QtCore[11949]
#define sipNameNr_LibrariesPath 37179
#define sipName_LibrariesPath &sipStrings_QtCore[37179]
#define sipNameNr_QJsonDocument 37193
#define sipName_QJsonDocument &sipStrings_QtCore[37193]
#define sipNameNr_MissingObject 37207
#define sipName_MissingObject &sipStrings_QtCore[37207]
#define sipNameNr_isRowSelected 37221
#define sipName_isRowSelected &sipStrings_QtCore[37221]
#define sipNameNr_ToggleCurrent 37235
#define sipName_ToggleCurrent &sipStrings_QtCore[37235]
#define sipNameNr_SelectCurrent 37249
#define sipName_SelectCurrent &sipStrings_QtCore[37249]
#define sipNameNr_SelectionFlag 1236
#define sipName_SelectionFlag &sipStrings_QtCore[1236]
#define sipNameNr_QHistoryState 37263
#define sipName_QHistoryState &sipStrings_QtCore[37263]
#define sipNameNr_QFileSelector 37277
#define sipName_QFileSelector &sipStrings_QtCore[37277]
#define sipNameNr_FileBirthTime 37291
#define sipName_FileBirthTime &sipStrings_QtCore[37291]
#define sipNameNr_PositionError 37305
#define sipName_PositionError &sipStrings_QtCore[37305]
#define sipNameNr_ResourceError 37319
#define sipName_ResourceError &sipStrings_QtCore[37319]
#define sipNameNr_symLinkTarget 37333
#define sipName_symLinkTarget &sipStrings_QtCore[37333]
#define sipNameNr_QElapsedTimer 37347
#define sipName_QElapsedTimer &sipStrings_QtCore[37347]
#define sipNameNr_toCubicSpline 37361
#define sipName_toCubicSpline &sipStrings_QtCore[37361]
#define sipNameNr_addTCBSegment 37375
#define sipName_addTCBSegment &sipStrings_QtCore[37375]
#define sipNameNr_setCustomType 37389
#define sipName_setCustomType &sipStrings_QtCore[37389]
#define sipNameNr_IteratorFlags 4419
#define sipName_IteratorFlags &sipStrings_QtCore[4419]
#define sipNameNr_listSeparator 37403
#define sipName_listSeparator &sipStrings_QtCore[37403]
#define sipNameNr_addSearchPath 37417
#define sipName_addSearchPath &sipStrings_QtCore[37417]
#define sipNameNr_entryInfoList 37431
#define sipName_entryInfoList &sipStrings_QtCore[37431]
#define sipNameNr_canonicalPath 37445
#define sipName_canonicalPath &sipStrings_QtCore[37445]
#define sipNameNr_QDir__Filters 37459
#define sipName_QDir__Filters &sipStrings_QtCore[37459]
#define sipNameNr_deadlineNSecs 37473
#define sipName_deadlineNSecs &sipStrings_QtCore[37473]
#define sipNameNr_offsetFromUtc 37487
#define sipName_offsetFromUtc &sipStrings_QtCore[37487]
#define sipNameNr_offsetSeconds 37501
#define sipName_offsetSeconds &sipStrings_QtCore[37501]
#define sipNameNr_MonthNameType 14250
#define sipName_MonthNameType &sipStrings_QtCore[14250]
#define sipNameNr_fromJulianDay 37515
#define sipName_fromJulianDay &sipStrings_QtCore[37515]
#define sipNameNr_longMonthName 37529
#define sipName_longMonthName &sipStrings_QtCore[37529]
#define sipNameNr_writeQVariant 37543
#define sipName_writeQVariant &sipStrings_QtCore[37543]
#define sipNameNr_PlatformPanel 37557
#define sipName_PlatformPanel &sipStrings_QtCore[37557]
#define sipNameNr_ScrollPrepare 37571
#define sipName_ScrollPrepare &sipStrings_QtCore[37571]
#define sipNameNr_ToolTipChange 37585
#define sipName_ToolTipChange &sipStrings_QtCore[37585]
#define sipNameNr_MacSizeChange 37599
#define sipName_MacSizeChange &sipStrings_QtCore[37599]
#define sipNameNr_ToolBarChange 37613
#define sipName_ToolBarChange &sipStrings_QtCore[37613]
#define sipNameNr_ActionRemoved 37627
#define sipName_ActionRemoved &sipStrings_QtCore[37627]
#define sipNameNr_ActionChanged 37641
#define sipName_ActionChanged &sipStrings_QtCore[37641]
#define sipNameNr_WindowBlocked 37655
#define sipName_WindowBlocked &sipStrings_QtCore[37655]
#define sipNameNr_EnabledChange 37669
#define sipName_EnabledChange &sipStrings_QtCore[37669]
#define sipNameNr_TabletRelease 37683
#define sipName_TabletRelease &sipStrings_QtCore[37683]
#define sipNameNr_UpdateRequest 37697
#define sipName_UpdateRequest &sipStrings_QtCore[37697]
#define sipNameNr_LayoutRequest 37711
#define sipName_LayoutRequest &sipStrings_QtCore[37711]
#define sipNameNr_PolishRequest 37725
#define sipName_PolishRequest &sipStrings_QtCore[37725]
#define sipNameNr_ChildPolished 37739
#define sipName_ChildPolished &sipStrings_QtCore[37739]
#define sipNameNr_PaletteChange 7293
#define sipName_PaletteChange &sipStrings_QtCore[7293]
#define sipNameNr_testAttribute 37753
#define sipName_testAttribute &sipStrings_QtCore[37753]
#define sipNameNr_addHelpOption 37767
#define sipName_addHelpOption &sipStrings_QtCore[37767]
#define sipNameNr_defaultValues 37781
#define sipName_defaultValues &sipStrings_QtCore[37781]
#define sipNameNr_readByteArray 37795
#define sipName_readByteArray &sipStrings_QtCore[37795]
#define sipNameNr_isLengthKnown 37809
#define sipName_isLengthKnown &sipStrings_QtCore[37809]
#define sipNameNr_currentOffset 37823
#define sipName_currentOffset &sipStrings_QtCore[37823]
#define sipNameNr_COSE_Encrypt0 37837
#define sipName_COSE_Encrypt0 &sipStrings_QtCore[37837]
#define sipNameNr_IllegalNumber 37851
#define sipName_IllegalNumber &sipStrings_QtCore[37851]
#define sipNameNr_partsFromDate 37865
#define sipName_partsFromDate &sipStrings_QtCore[37865]
#define sipNameNr_dateFromParts 37879
#define sipName_dateFromParts &sipStrings_QtCore[37879]
#define sipNameNr_Base64Options 6377
#define sipName_Base64Options &sipStrings_QtCore[6377]
#define sipNameNr_leftJustified 37893
#define sipName_leftJustified &sipStrings_QtCore[37893]
#define sipNameNr_connectNotify 26259
#define sipName_connectNotify &sipStrings_QtCore[26259]
#define sipNameNr_takeAnimation 37907
#define sipName_takeAnimation &sipStrings_QtCore[37907]
#define sipNameNr_activeChanged 37921
#define sipName_activeChanged &sipStrings_QtCore[37921]
#define sipNameNr_mapFromSource 37935
#define sipName_mapFromSource &sipStrings_QtCore[37935]
#define sipNameNr_endResetModel 37949
#define sipName_endResetModel &sipStrings_QtCore[37949]
#define sipNameNr_beginMoveRows 37963
#define sipName_beginMoveRows &sipStrings_QtCore[37963]
#define sipNameNr_endRemoveRows 37977
#define sipName_endRemoveRows &sipStrings_QtCore[37977]
#define sipNameNr_endInsertRows 37991
#define sipName_endInsertRows &sipStrings_QtCore[37991]
#define sipNameNr_layoutChanged 38005
#define sipName_layoutChanged &sipStrings_QtCore[38005]
#define sipNameNr_removeColumns 38019
#define sipName_removeColumns &sipStrings_QtCore[38019]
#define sipNameNr_insertColumns 38033
#define sipName_insertColumns &sipStrings_QtCore[38033]
#define sipNameNr_setHeaderData 38047
#define sipName_setHeaderData &sipStrings_QtCore[38047]
#define sipNameNr_remainingTime 38061
#define sipName_remainingTime &sipStrings_QtCore[38061]
#define sipNameNr_registerTimer 29968
#define sipName_registerTimer &sipStrings_QtCore[29968]
#define sipNameNr_processEvents 38075
#define sipName_processEvents &sipStrings_QtCore[38075]
#define sipNameNr_totalDuration 38089
#define sipName_totalDuration &sipStrings_QtCore[38089]
#define sipNameNr_NoScrollPhase 38103
#define sipName_NoScrollPhase &sipStrings_QtCore[38103]
#define sipNameNr_WhiteSpacePre 38117
#define sipName_WhiteSpacePre &sipStrings_QtCore[38117]
#define sipNameNr_CustomGesture 38131
#define sipName_CustomGesture &sipStrings_QtCore[38131]
#define sipNameNr_ImhNoEditMenu 38145
#define sipName_ImhNoEditMenu &sipStrings_QtCore[38145]
#define sipNameNr_ImhDigitsOnly 38159
#define sipName_ImhDigitsOnly &sipStrings_QtCore[38159]
#define sipNameNr_ImhHiddenText 38173
#define sipName_ImhHiddenText &sipStrings_QtCore[38173]
#define sipNameNr_BottomSection 38187
#define sipName_BottomSection &sipStrings_QtCore[38187]
#define sipNameNr_PreferredSize 38201
#define sipName_PreferredSize &sipStrings_QtCore[38201]
#define sipNameNr_EventPriority 3278
#define sipName_EventPriority &sipStrings_QtCore[3278]
#define sipNameNr_AA_SetPalette 38215
#define sipName_AA_SetPalette &sipStrings_QtCore[38215]
#define sipNameNr_MatchWildcard 38229
#define sipName_MatchWildcard &sipStrings_QtCore[38229]
#define sipNameNr_MatchEndsWith 38243
#define sipName_MatchEndsWith &sipStrings_QtCore[38243]
#define sipNameNr_MatchContains 38257
#define sipName_MatchContains &sipStrings_QtCore[38257]
#define sipNameNr_Qt__MatchFlag 38271
#define sipName_Qt__MatchFlag &sipStrings_QtCore[38271]
#define sipNameNr_Qt__ItemFlags 38285
#define sipName_Qt__ItemFlags &sipStrings_QtCore[38285]
#define sipNameNr_ItemIsEnabled 38299
#define sipName_ItemIsEnabled &sipStrings_QtCore[38299]
#define sipNameNr_TextColorRole 38313
#define sipName_TextColorRole &sipStrings_QtCore[38313]
#define sipNameNr_WhatsThisRole 38327
#define sipName_WhatsThisRole &sipStrings_QtCore[38327]
#define sipNameNr_StatusTipRole 38341
#define sipName_StatusTipRole &sipStrings_QtCore[38341]
#define sipNameNr_NoContextMenu 38355
#define sipName_NoContextMenu &sipStrings_QtCore[38355]
#define sipNameNr_NoFocusReason 38369
#define sipName_NoFocusReason &sipStrings_QtCore[38369]
#define sipNameNr_IntersectClip 38383
#define sipName_IntersectClip &sipStrings_QtCore[38383]
#define sipNameNr_ClipOperation 23524
#define sipName_ClipOperation &sipStrings_QtCore[23524]
#define sipNameNr_TopLeftCorner 38397
#define sipName_TopLeftCorner &sipStrings_QtCore[38397]
#define sipNameNr_CaseSensitive 20263
#define sipName_CaseSensitive &sipStrings_QtCore[20263]
#define sipNameNr_Qt__DayOfWeek 38411
#define sipName_Qt__DayOfWeek &sipStrings_QtCore[38411]
#define sipNameNr_OffsetFromUTC 38425
#define sipName_OffsetFromUTC &sipStrings_QtCore[38425]
#define sipNameNr_ISODateWithMs 38439
#define sipName_ISODateWithMs &sipStrings_QtCore[38439]
#define sipNameNr_NoToolBarArea 38453
#define sipName_NoToolBarArea &sipStrings_QtCore[38453]
#define sipNameNr_Qt__TimerType 38467
#define sipName_Qt__TimerType &sipStrings_QtCore[38467]
#define sipNameNr_SizeAllCursor 38481
#define sipName_SizeAllCursor &sipStrings_QtCore[38481]
#define sipNameNr_SizeHorCursor 38495
#define sipName_SizeHorCursor &sipStrings_QtCore[38495]
#define sipNameNr_SizeVerCursor 38509
#define sipName_SizeVerCursor &sipStrings_QtCore[38509]
#define sipNameNr_UpArrowCursor 38523
#define sipName_UpArrowCursor &sipStrings_QtCore[38523]
#define sipNameNr_Dense7Pattern 38537
#define sipName_Dense7Pattern &sipStrings_QtCore[38537]
#define sipNameNr_Dense6Pattern 38551
#define sipName_Dense6Pattern &sipStrings_QtCore[38551]
#define sipNameNr_Dense5Pattern 38565
#define sipName_Dense5Pattern &sipStrings_QtCore[38565]
#define sipNameNr_Dense4Pattern 38579
#define sipName_Dense4Pattern &sipStrings_QtCore[38579]
#define sipNameNr_Dense3Pattern 38593
#define sipName_Dense3Pattern &sipStrings_QtCore[38593]
#define sipNameNr_Dense2Pattern 38607
#define sipName_Dense2Pattern &sipStrings_QtCore[38607]
#define sipNameNr_Dense1Pattern 38621
#define sipName_Dense1Pattern &sipStrings_QtCore[38621]
#define sipNameNr_MPenJoinStyle 38635
#define sipName_MPenJoinStyle &sipStrings_QtCore[38635]
#define sipNameNr_Qt__ArrowType 38649
#define sipName_Qt__ArrowType &sipStrings_QtCore[38649]
#define sipNameNr_Key_ChannelUp 38663
#define sipName_Key_ChannelUp &sipStrings_QtCore[38663]
#define sipNameNr_Key_VoiceDial 38677
#define sipName_Key_VoiceDial &sipStrings_QtCore[38677]
#define sipNameNr_Key_PowerDown 38691
#define sipName_Key_PowerDown &sipStrings_QtCore[38691]
#define sipNameNr_Key_Hibernate 38705
#define sipName_Key_Hibernate &sipStrings_QtCore[38705]
#define sipNameNr_Key_Bluetooth 38719
#define sipName_Key_Bluetooth &sipStrings_QtCore[38719]
#define sipNameNr_Key_Messenger 38733
#define sipName_Key_Messenger &sipStrings_QtCore[38733]
#define sipNameNr_Key_Documents 38747
#define sipName_Key_Documents &sipStrings_QtCore[38747]
#define sipNameNr_Key_ClearGrab 38761
#define sipName_Key_ClearGrab &sipStrings_QtCore[38761]
#define sipNameNr_Key_Community 38775
#define sipName_Key_Community &sipStrings_QtCore[38775]
#define sipNameNr_Key_LightBulb 38789
#define sipName_Key_LightBulb &sipStrings_QtCore[38789]
#define sipNameNr_Key_MediaLast 38803
#define sipName_Key_MediaLast &sipStrings_QtCore[38803]
#define sipNameNr_Key_Favorites 38817
#define sipName_Key_Favorites &sipStrings_QtCore[38817]
#define sipNameNr_Key_MediaNext 38831
#define sipName_Key_MediaNext &sipStrings_QtCore[38831]
#define sipNameNr_Key_MediaStop 38845
#define sipName_Key_MediaStop &sipStrings_QtCore[38845]
#define sipNameNr_Key_MediaPlay 38859
#define sipName_Key_MediaPlay &sipStrings_QtCore[38859]
#define sipNameNr_Key_BassBoost 38873
#define sipName_Key_BassBoost &sipStrings_QtCore[38873]
#define sipNameNr_Key_Dead_Horn 38887
#define sipName_Key_Dead_Horn &sipStrings_QtCore[38887]
#define sipNameNr_Key_Dead_Hook 38901
#define sipName_Key_Dead_Hook &sipStrings_QtCore[38901]
#define sipNameNr_Key_Dead_Iota 38915
#define sipName_Key_Dead_Iota &sipStrings_QtCore[38915]
#define sipNameNr_Key_Kana_Lock 38929
#define sipName_Key_Kana_Lock &sipStrings_QtCore[38929]
#define sipNameNr_Key_Codeinput 38943
#define sipName_Key_Codeinput &sipStrings_QtCore[38943]
#define sipNameNr_Key_Multi_key 38957
#define sipName_Key_Multi_key &sipStrings_QtCore[38957]
#define sipNameNr_Key_masculine 38971
#define sipName_Key_masculine &sipStrings_QtCore[38971]
#define sipNameNr_Key_paragraph 38985
#define sipName_Key_paragraph &sipStrings_QtCore[38985]
#define sipNameNr_Key_plusminus 38999
#define sipName_Key_plusminus &sipStrings_QtCore[38999]
#define sipNameNr_Key_copyright 39013
#define sipName_Key_copyright &sipStrings_QtCore[39013]
#define sipNameNr_Key_diaeresis 39027
#define sipName_Key_diaeresis &sipStrings_QtCore[39027]
#define sipNameNr_Key_brokenbar 39041
#define sipName_Key_brokenbar &sipStrings_QtCore[39041]
#define sipNameNr_Key_BraceLeft 39055
#define sipName_Key_BraceLeft &sipStrings_QtCore[39055]
#define sipNameNr_Key_QuoteLeft 39069
#define sipName_Key_QuoteLeft &sipStrings_QtCore[39069]
#define sipNameNr_Key_Backslash 39083
#define sipName_Key_Backslash &sipStrings_QtCore[39083]
#define sipNameNr_Key_Semicolon 39097
#define sipName_Key_Semicolon &sipStrings_QtCore[39097]
#define sipNameNr_Key_ParenLeft 39111
#define sipName_Key_ParenLeft &sipStrings_QtCore[39111]
#define sipNameNr_Key_Ampersand 39125
#define sipName_Key_Ampersand &sipStrings_QtCore[39125]
#define sipNameNr_Key_Backspace 39139
#define sipName_Key_Backspace &sipStrings_QtCore[39139]
#define sipNameNr_OrderedDither 39153
#define sipName_OrderedDither &sipStrings_QtCore[39153]
#define sipNameNr_DiffuseDither 39167
#define sipName_DiffuseDither &sipStrings_QtCore[39167]
#define sipNameNr_WA_StyleSheet 39181
#define sipName_WA_StyleSheet &sipStrings_QtCore[39181]
#define sipNameNr_WA_SetPalette 39195
#define sipName_WA_SetPalette &sipStrings_QtCore[39195]
#define sipNameNr_WA_UnderMouse 39209
#define sipName_WA_UnderMouse &sipStrings_QtCore[39209]
#define sipNameNr_WindowNoState 39223
#define sipName_WindowNoState &sipStrings_QtCore[39223]
#define sipNameNr_ForeignWindow 39237
#define sipName_ForeignWindow &sipStrings_QtCore[39237]
#define sipNameNr_TextElideMode 24064
#define sipName_TextElideMode &sipStrings_QtCore[24064]
#define sipNameNr_TextDontPrint 39251
#define sipName_TextDontPrint &sipStrings_QtCore[39251]
#define sipNameNr_Qt__Alignment 39265
#define sipName_Qt__Alignment &sipStrings_QtCore[39265]
#define sipNameNr_AlignBaseline 39279
#define sipName_AlignBaseline &sipStrings_QtCore[39279]
#define sipNameNr_AlignAbsolute 39293
#define sipName_AlignAbsolute &sipStrings_QtCore[39293]
#define sipNameNr_AlignTrailing 39307
#define sipName_AlignTrailing &sipStrings_QtCore[39307]
#define sipNameNr_AlignmentFlag 24082
#define sipName_AlignmentFlag &sipStrings_QtCore[24082]
#define sipNameNr_Qt__SortOrder 39321
#define sipName_Qt__SortOrder &sipStrings_QtCore[39321]
#define sipNameNr_ExtraButton24 39335
#define sipName_ExtraButton24 &sipStrings_QtCore[39335]
#define sipNameNr_ExtraButton23 39349
#define sipName_ExtraButton23 &sipStrings_QtCore[39349]
#define sipNameNr_ExtraButton22 39363
#define sipName_ExtraButton22 &sipStrings_QtCore[39363]
#define sipNameNr_ExtraButton21 39377
#define sipName_ExtraButton21 &sipStrings_QtCore[39377]
#define sipNameNr_ExtraButton20 39391
#define sipName_ExtraButton20 &sipStrings_QtCore[39391]
#define sipNameNr_ExtraButton19 39405
#define sipName_ExtraButton19 &sipStrings_QtCore[39405]
#define sipNameNr_ExtraButton18 39419
#define sipName_ExtraButton18 &sipStrings_QtCore[39419]
#define sipNameNr_ExtraButton17 39433
#define sipName_ExtraButton17 &sipStrings_QtCore[39433]
#define sipNameNr_ExtraButton16 39447
#define sipName_ExtraButton16 &sipStrings_QtCore[39447]
#define sipNameNr_ExtraButton15 39461
#define sipName_ExtraButton15 &sipStrings_QtCore[39461]
#define sipNameNr_ExtraButton14 39475
#define sipName_ExtraButton14 &sipStrings_QtCore[39475]
#define sipNameNr_ExtraButton13 39489
#define sipName_ExtraButton13 &sipStrings_QtCore[39489]
#define sipNameNr_ExtraButton12 39503
#define sipName_ExtraButton12 &sipStrings_QtCore[39503]
#define sipNameNr_ExtraButton11 39517
#define sipName_ExtraButton11 &sipStrings_QtCore[39517]
#define sipNameNr_ExtraButton10 39531
#define sipName_ExtraButton10 &sipStrings_QtCore[39531]
#define sipNameNr_ForwardButton 39545
#define sipName_ForwardButton &sipStrings_QtCore[39545]
#define sipNameNr_UNICODE_ACCEL 39559
#define sipName_UNICODE_ACCEL &sipStrings_QtCore[39559]
#define sipNameNr_MODIFIER_MASK 39573
#define sipName_MODIFIER_MASK &sipStrings_QtCore[39573]
#define sipNameNr_ShiftModifier 39587
#define sipName_ShiftModifier &sipStrings_QtCore[39587]
#define sipNameNr_qFuzzyCompare 39601
#define sipName_qFuzzyCompare &sipStrings_QtCore[39601]
#define sipNameNr_39615 39615
#define sipName_39615 &sipStrings_QtCore[39615]
#define sipNameNr_39628 39628
#define sipName_39628 &sipStrings_QtCore[39628]
#define sipNameNr_writeComment 39641
#define sipName_writeComment &sipStrings_QtCore[39641]
#define sipNameNr_columnNumber 39654
#define sipName_columnNumber &sipStrings_QtCore[39654]
#define sipNameNr_isWhitespace 39667
#define sipName_isWhitespace &sipStrings_QtCore[39667]
#define sipNameNr_isCharacters 39680
#define sipName_isCharacters &sipStrings_QtCore[39680]
#define sipNameNr_isEndElement 39693
#define sipName_isEndElement &sipStrings_QtCore[39693]
#define sipNameNr_StartElement 13264
#define sipName_StartElement &sipStrings_QtCore[13264]
#define sipNameNr_notationName 39706
#define sipName_notationName &sipStrings_QtCore[39706]
#define sipNameNr_hasAttribute 39719
#define sipName_hasAttribute &sipStrings_QtCore[39719]
#define sipNameNr_namespaceUri 39732
#define sipName_namespaceUri &sipStrings_QtCore[39732]
#define sipNameNr_commonPrefix 39745
#define sipName_commonPrefix &sipStrings_QtCore[39745]
#define sipNameNr_isNormalized 39758
#define sipName_isNormalized &sipStrings_QtCore[39758]
#define sipNameNr_interpolated 39771
#define sipName_interpolated &sipStrings_QtCore[39771]
#define sipNameNr_setKeyValues 39784
#define sipName_setKeyValues &sipStrings_QtCore[39784]
#define sipNameNr_createUuidV5 39797
#define sipName_createUuidV5 &sipStrings_QtCore[39797]
#define sipNameNr_createUuidV3 39810
#define sipName_createUuidV3 &sipStrings_QtCore[39810]
#define sipNameNr_StringFormat 15486
#define sipName_StringFormat &sipStrings_QtCore[15486]
#define sipNameNr_addQueryItem 39823
#define sipName_addQueryItem &sipStrings_QtCore[39823]
#define sipNameNr_hasQueryItem 39836
#define sipName_hasQueryItem &sipStrings_QtCore[39836]
#define sipNameNr_idnWhitelist 39849
#define sipName_idnWhitelist &sipStrings_QtCore[39849]
#define sipNameNr_setAuthority 39862
#define sipName_setAuthority &sipStrings_QtCore[39862]
#define sipNameNr_FullyDecoded 39875
#define sipName_FullyDecoded &sipStrings_QtCore[39875]
#define sipNameNr_FullyEncoded 39888
#define sipName_FullyEncoded &sipStrings_QtCore[39888]
#define sipNameNr_EncodeSpaces 39901
#define sipName_EncodeSpaces &sipStrings_QtCore[39901]
#define sipNameNr_RemoveScheme 39914
#define sipName_RemoveScheme &sipStrings_QtCore[39914]
#define sipNameNr_TolerantMode 39927
#define sipName_TolerantMode &sipStrings_QtCore[39927]
#define sipNameNr_QUrlTwoFlags 39940
#define sipName_QUrlTwoFlags &sipStrings_QtCore[39940]
#define sipNameNr_loadFromData 39953
#define sipName_loadFromData &sipStrings_QtCore[39953]
#define sipNameNr_abbreviation 39966
#define sipName_abbreviation &sipStrings_QtCore[39966]
#define sipNameNr_DaylightTime 27857
#define sipName_DaylightTime &sipStrings_QtCore[27857]
#define sipNameNr_StandardTime 39979
#define sipName_StandardTime &sipStrings_QtCore[39979]
#define sipNameNr_isSingleShot 39992
#define sipName_isSingleShot &sipStrings_QtCore[39992]
#define sipNameNr_valueChanged 40005
#define sipName_valueChanged &sipStrings_QtCore[40005]
#define sipNameNr_frameChanged 40018
#define sipName_frameChanged &sipStrings_QtCore[40018]
#define sipNameNr_valueForTime 40031
#define sipName_valueForTime &sipStrings_QtCore[40031]
#define sipNameNr_frameForTime 40044
#define sipName_frameForTime &sipStrings_QtCore[40044]
#define sipNameNr_currentValue 40057
#define sipName_currentValue &sipStrings_QtCore[40057]
#define sipNameNr_currentFrame 40070
#define sipName_currentFrame &sipStrings_QtCore[40070]
#define sipNameNr_EaseOutCurve 40083
#define sipName_EaseOutCurve &sipStrings_QtCore[40083]
#define sipNameNr_setStackSize 40096
#define sipName_setStackSize &sipStrings_QtCore[40096]
#define sipNameNr_IdlePriority 40109
#define sipName_IdlePriority &sipStrings_QtCore[40109]
#define sipNameNr_noforcepoint 40122
#define sipName_noforcepoint &sipStrings_QtCore[40122]
#define sipNameNr_QTextDecoder 40135
#define sipName_QTextDecoder &sipStrings_QtCore[40135]
#define sipNameNr_QTextEncoder 40148
#define sipName_QTextEncoder &sipStrings_QtCore[40148]
#define sipNameNr_IgnoreHeader 40161
#define sipName_IgnoreHeader &sipStrings_QtCore[40161]
#define sipNameNr_codecForHtml 40174
#define sipName_codecForHtml &sipStrings_QtCore[40174]
#define sipNameNr_codecForName 40187
#define sipName_codecForName &sipStrings_QtCore[40187]
#define sipNameNr_isAtBoundary 40200
#define sipName_isAtBoundary &sipStrings_QtCore[40200]
#define sipNameNr_BoundaryType 1446
#define sipName_BoundaryType &sipStrings_QtCore[1446]
#define sipNameNr_fileTemplate 40213
#define sipName_fileTemplate &sipStrings_QtCore[40213]
#define sipNameNr_initialValue 40226
#define sipName_initialValue &sipStrings_QtCore[40226]
#define sipNameNr_QStorageInfo 40239
#define sipName_QStorageInfo &sipStrings_QtCore[40239]
#define sipNameNr_HighPriority 40252
#define sipName_HighPriority &sipStrings_QtCore[40252]
#define sipNameNr_WrappedEvent 4112
#define sipName_WrappedEvent &sipStrings_QtCore[4112]
#define sipNameNr_setChildMode 40265
#define sipName_setChildMode &sipStrings_QtCore[40265]
#define sipNameNr_initialState 40278
#define sipName_initialState &sipStrings_QtCore[40278]
#define sipNameNr_LocateOption 3308
#define sipName_LocateOption &sipStrings_QtCore[3308]
#define sipNameNr_DataLocation 13537
#define sipName_DataLocation &sipStrings_QtCore[13537]
#define sipNameNr_HomeLocation 40291
#define sipName_HomeLocation &sipStrings_QtCore[40291]
#define sipNameNr_TempLocation 40304
#define sipName_TempLocation &sipStrings_QtCore[40304]
#define sipNameNr_filterRegExp 40317
#define sipName_filterRegExp &sipStrings_QtCore[40317]
#define sipNameNr_senderObject 40330
#define sipName_senderObject &sipStrings_QtCore[40330]
#define sipNameNr_mappedObject 40343
#define sipName_mappedObject &sipStrings_QtCore[40343]
#define sipNameNr_mappedWidget 40356
#define sipName_mappedWidget &sipStrings_QtCore[40356]
#define sipNameNr_mappedString 40369
#define sipName_mappedString &sipStrings_QtCore[40369]
#define sipNameNr_setNativeKey 40382
#define sipName_setNativeKey &sipStrings_QtCore[40382]
#define sipNameNr_NativeFormat 40395
#define sipName_NativeFormat &sipStrings_QtCore[40395]
#define sipNameNr_isCompressed 40408
#define sipName_isCompressed &sipStrings_QtCore[40408]
#define sipNameNr_matchOptions 40421
#define sipName_matchOptions &sipStrings_QtCore[40421]
#define sipNameNr_MatchOptions 1882
#define sipName_MatchOptions &sipStrings_QtCore[1882]
#define sipNameNr_captureCount 40434
#define sipName_captureCount &sipStrings_QtCore[40434]
#define sipNameNr_WildcardUnix 40447
#define sipName_WildcardUnix &sipStrings_QtCore[40447]
#define sipNameNr_marginsAdded 40460
#define sipName_marginsAdded &sipStrings_QtCore[40460]
#define sipNameNr_moveTopRight 40473
#define sipName_moveTopRight &sipStrings_QtCore[40473]
#define sipNameNr_QWriteLocker 40486
#define sipName_QWriteLocker &sipStrings_QtCore[40486]
#define sipNameNr_lockForWrite 40499
#define sipName_lockForWrite &sipStrings_QtCore[40499]
#define sipNameNr_toStringList 40512
#define sipName_toStringList &sipStrings_QtCore[40512]
#define sipNameNr_setArguments 40525
#define sipName_setArguments &sipStrings_QtCore[40525]
#define sipNameNr_ProcessState 9873
#define sipName_ProcessState &sipStrings_QtCore[9873]
#define sipNameNr_ProcessError 9896
#define sipName_ProcessError &sipStrings_QtCore[9896]
#define sipNameNr_targetObject 40538
#define sipName_targetObject &sipStrings_QtCore[40538]
#define sipNameNr_segmentCount 40551
#define sipName_segmentCount &sipStrings_QtCore[40551]
#define sipNameNr_microVersion 40564
#define sipName_microVersion &sipStrings_QtCore[40564]
#define sipNameNr_minorVersion 40577
#define sipName_minorVersion &sipStrings_QtCore[40577]
#define sipNameNr_majorVersion 40590
#define sipName_majorVersion &sipStrings_QtCore[40590]
#define sipNameNr_OSXElCapitan 40603
#define sipName_OSXElCapitan &sipStrings_QtCore[40603]
#define sipNameNr_OSXMavericks 40616
#define sipName_OSXMavericks &sipStrings_QtCore[40616]
#define sipNameNr_Q_RETURN_ARG 40629
#define sipName_Q_RETURN_ARG &sipStrings_QtCore[40629]
#define sipNameNr_invokeMethod 40642
#define sipName_invokeMethod &sipStrings_QtCore[40642]
#define sipNameNr_methodOffset 40655
#define sipName_methodOffset &sipStrings_QtCore[40655]
#define sipNameNr_userProperty 40668
#define sipName_userProperty &sipStrings_QtCore[40668]
#define sipNameNr_moveToThread 40681
#define sipName_moveToThread &sipStrings_QtCore[40681]
#define sipNameNr_blockSignals 40694
#define sipName_blockSignals &sipStrings_QtCore[40694]
#define sipNameNr_isWindowType 40707
#define sipName_isWindowType &sipStrings_QtCore[40707]
#define sipNameNr_isWidgetType 40720
#define sipName_isWidgetType &sipStrings_QtCore[40720]
#define sipNameNr_findChildren 40733
#define sipName_findChildren &sipStrings_QtCore[40733]
#define sipNameNr_NonRecursive 40746
#define sipName_NonRecursive &sipStrings_QtCore[40746]
#define sipNameNr_QMutexLocker 40759
#define sipName_QMutexLocker &sipStrings_QtCore[40759]
#define sipNameNr_filterString 40772
#define sipName_filterString &sipStrings_QtCore[40772]
#define sipNameNr_allAncestors 40785
#define sipName_allAncestors &sipStrings_QtCore[40785]
#define sipNameNr_globPatterns 40798
#define sipName_globPatterns &sipStrings_QtCore[40798]
#define sipNameNr_allMimeTypes 40811
#define sipName_allMimeTypes &sipStrings_QtCore[40811]
#define sipNameNr_MatchContent 40824
#define sipName_MatchContent &sipStrings_QtCore[40824]
#define sipNameNr_MatchDefault 40837
#define sipName_MatchDefault &sipStrings_QtCore[40837]
#define sipNameNr_retrieveData 40850
#define sipName_retrieveData &sipStrings_QtCore[40850]
#define sipNameNr_removeFormat 40863
#define sipName_removeFormat &sipStrings_QtCore[40863]
#define sipNameNr_setColorData 40876
#define sipName_setColorData &sipStrings_QtCore[40876]
#define sipNameNr_setImageData 40889
#define sipName_setImageData &sipStrings_QtCore[40889]
#define sipNameNr_isRegistered 40902
#define sipName_isRegistered &sipStrings_QtCore[40902]
#define sipNameNr_QKeySequence 40915
#define sipName_QKeySequence &sipStrings_QtCore[40915]
#define sipNameNr_FirstGuiType 40928
#define sipName_FirstGuiType &sipStrings_QtCore[40928]
#define sipNameNr_LastCoreType 40941
#define sipName_LastCoreType &sipStrings_QtCore[40941]
#define sipNameNr_QVariantHash 22589
#define sipName_QVariantHash &sipStrings_QtCore[22589]
#define sipNameNr_QVariantList 22607
#define sipName_QVariantList &sipStrings_QtCore[22607]
#define sipNameNr_notifySignal 40954
#define sipName_notifySignal &sipStrings_QtCore[40954]
#define sipNameNr_isResettable 40967
#define sipName_isResettable &sipStrings_QtCore[40967]
#define sipNameNr_hasStdCppSet 40980
#define sipName_hasStdCppSet &sipStrings_QtCore[40980]
#define sipNameNr_isScriptable 40993
#define sipName_isScriptable &sipStrings_QtCore[40993]
#define sipNameNr_isDesignable 41006
#define sipName_isDesignable &sipStrings_QtCore[41006]
#define sipNameNr_categoryName 41019
#define sipName_categoryName &sipStrings_QtCore[41019]
#define sipNameNr_QtWarningMsg 41032
#define sipName_QtWarningMsg &sipStrings_QtCore[41032]
#define sipNameNr_TangutScript 41045
#define sipName_TangutScript &sipStrings_QtCore[41045]
#define sipNameNr_HatranScript 41058
#define sipName_HatranScript &sipStrings_QtCore[41058]
#define sipNameNr_KhojkiScript 41071
#define sipName_KhojkiScript &sipStrings_QtCore[41071]
#define sipNameNr_RejangScript 41084
#define sipName_RejangScript &sipStrings_QtCore[41084]
#define sipNameNr_OrkhonScript 41097
#define sipName_OrkhonScript &sipStrings_QtCore[41097]
#define sipNameNr_LydianScript 41110
#define sipName_LydianScript &sipStrings_QtCore[41110]
#define sipNameNr_LycianScript 41123
#define sipName_LycianScript &sipStrings_QtCore[41123]
#define sipNameNr_LepchaScript 41136
#define sipName_LepchaScript &sipStrings_QtCore[41136]
#define sipNameNr_KaithiScript 41149
#define sipName_KaithiScript &sipStrings_QtCore[41149]
#define sipNameNr_HangulScript 41162
#define sipName_HangulScript &sipStrings_QtCore[41162]
#define sipNameNr_GothicScript 41175
#define sipName_GothicScript &sipStrings_QtCore[41175]
#define sipNameNr_FraserScript 41188
#define sipName_FraserScript &sipStrings_QtCore[41188]
#define sipNameNr_CopticScript 41201
#define sipName_CopticScript &sipStrings_QtCore[41201]
#define sipNameNr_ChakmaScript 41214
#define sipName_ChakmaScript &sipStrings_QtCore[41214]
#define sipNameNr_CarianScript 41227
#define sipName_CarianScript &sipStrings_QtCore[41227]
#define sipNameNr_BrahmiScript 41240
#define sipName_BrahmiScript &sipStrings_QtCore[41240]
#define sipNameNr_SyriacScript 41253
#define sipName_SyriacScript &sipStrings_QtCore[41253]
#define sipNameNr_ThaanaScript 41266
#define sipName_ThaanaScript &sipStrings_QtCore[41266]
#define sipNameNr_TeluguScript 41279
#define sipName_TeluguScript &sipStrings_QtCore[41279]
#define sipNameNr_KoreanScript 41292
#define sipName_KoreanScript &sipStrings_QtCore[41292]
#define sipNameNr_HebrewScript 41305
#define sipName_HebrewScript &sipStrings_QtCore[41305]
#define sipNameNr_ArabicScript 41318
#define sipName_ArabicScript &sipStrings_QtCore[41318]
#define sipNameNr_positiveSign 41331
#define sipName_positiveSign &sipStrings_QtCore[41331]
#define sipNameNr_MetricSystem 41344
#define sipName_MetricSystem &sipStrings_QtCore[41344]
#define sipNameNr_negativeSign 41357
#define sipName_negativeSign &sipStrings_QtCore[41357]
#define sipNameNr_decimalPoint 41370
#define sipName_decimalPoint &sipStrings_QtCore[41370]
#define sipNameNr_NarrowFormat 41383
#define sipName_NarrowFormat &sipStrings_QtCore[41383]
#define sipNameNr_NumberOption 11884
#define sipName_NumberOption &sipStrings_QtCore[11884]
#define sipNameNr_LatinAmerica 41396
#define sipName_LatinAmerica &sipStrings_QtCore[41396]
#define sipNameNr_AlandIslands 41409
#define sipName_AlandIslands &sipStrings_QtCore[41409]
#define sipNameNr_UnitedStates 41422
#define sipName_UnitedStates &sipStrings_QtCore[41422]
#define sipNameNr_Turkmenistan 41435
#define sipName_Turkmenistan &sipStrings_QtCore[41435]
#define sipNameNr_NewCaledonia 41448
#define sipName_NewCaledonia &sipStrings_QtCore[41448]
#define sipNameNr_NauruCountry 41461
#define sipName_NauruCountry &sipStrings_QtCore[41461]
#define sipNameNr_GuineaBissau 41474
#define sipName_GuineaBissau &sipStrings_QtCore[41474]
#define sipNameNr_FrenchGuiana 41487
#define sipName_FrenchGuiana &sipStrings_QtCore[41487]
#define sipNameNr_FaroeIslands 41500
#define sipName_FaroeIslands &sipStrings_QtCore[41500]
#define sipNameNr_CocosIslands 41513
#define sipName_CocosIslands &sipStrings_QtCore[41513]
#define sipNameNr_BouvetIsland 41526
#define sipName_BouvetIsland &sipStrings_QtCore[41526]
#define sipNameNr_NorthernLuri 41539
#define sipName_NorthernLuri &sipStrings_QtCore[41539]
#define sipNameNr_SouthernSami 41552
#define sipName_SouthernSami &sipStrings_QtCore[41552]
#define sipNameNr_UpperSorbian 41565
#define sipName_UpperSorbian &sipStrings_QtCore[41565]
#define sipNameNr_LowerSorbian 41578
#define sipName_LowerSorbian &sipStrings_QtCore[41578]
#define sipNameNr_NorthernThai 41591
#define sipName_NorthernThai &sipStrings_QtCore[41591]
#define sipNameNr_EasternKayah 41604
#define sipName_EasternKayah &sipStrings_QtCore[41604]
#define sipNameNr_AncientGreek 41617
#define sipName_AncientGreek &sipStrings_QtCore[41617]
#define sipNameNr_CongoSwahili 41630
#define sipName_CongoSwahili &sipStrings_QtCore[41630]
#define sipNameNr_Kabuverdianu 41643
#define sipName_Kabuverdianu &sipStrings_QtCore[41643]
#define sipNameNr_NorthNdebele 41656
#define sipName_NorthNdebele &sipStrings_QtCore[41656]
#define sipNameNr_NorthernSami 41669
#define sipName_NorthernSami &sipStrings_QtCore[41669]
#define sipNameNr_SouthNdebele 41682
#define sipName_SouthNdebele &sipStrings_QtCore[41682]
#define sipNameNr_LastLanguage 41695
#define sipName_LastLanguage &sipStrings_QtCore[41695]
#define sipNameNr_Byelorussian 41708
#define sipName_Byelorussian &sipStrings_QtCore[41708]
#define sipNameNr_normalVector 41721
#define sipName_normalVector &sipStrings_QtCore[41721]
#define sipNameNr_isDebugBuild 41734
#define sipName_isDebugBuild &sipStrings_QtCore[41734]
#define sipNameNr_ArchDataPath 41747
#define sipName_ArchDataPath &sipStrings_QtCore[41747]
#define sipNameNr_ExamplesPath 41760
#define sipName_ExamplesPath &sipStrings_QtCore[41760]
#define sipNameNr_SettingsPath 41773
#define sipName_SettingsPath &sipStrings_QtCore[41773]
#define sipNameNr_BinariesPath 41786
#define sipName_BinariesPath &sipStrings_QtCore[41786]
#define sipNameNr_QLibraryInfo 41799
#define sipName_QLibraryInfo &sipStrings_QtCore[41799]
#define sipNameNr_setLoadHints 41812
#define sipName_setLoadHints &sipStrings_QtCore[41812]
#define sipNameNr_DeepBindHint 41825
#define sipName_DeepBindHint &sipStrings_QtCore[41825]
#define sipNameNr_toBinaryData 41838
#define sipName_toBinaryData &sipStrings_QtCore[41838]
#define sipNameNr_IllegalValue 41851
#define sipName_IllegalValue &sipStrings_QtCore[41851]
#define sipNameNr_modelChanged 41864
#define sipName_modelChanged &sipStrings_QtCore[41864]
#define sipNameNr_selectedRows 41877
#define sipName_selectedRows &sipStrings_QtCore[41877]
#define sipNameNr_hasSelection 41890
#define sipName_hasSelection &sipStrings_QtCore[41890]
#define sipNameNr_currentIndex 41903
#define sipName_currentIndex &sipStrings_QtCore[41903]
#define sipNameNr_aboutToClose 41916
#define sipName_aboutToClose &sipStrings_QtCore[41916]
#define sipNameNr_bytesWritten 41929
#define sipName_bytesWritten &sipStrings_QtCore[41929]
#define sipNameNr_bytesToWrite 41942
#define sipName_bytesToWrite &sipStrings_QtCore[41942]
#define sipNameNr_ExistingOnly 41955
#define sipName_ExistingOnly &sipStrings_QtCore[41955]
#define sipNameNr_OpenModeFlag 8667
#define sipName_OpenModeFlag &sipStrings_QtCore[8667]
#define sipNameNr_defaultState 41968
#define sipName_defaultState &sipStrings_QtCore[41968]
#define sipNameNr_allSelectors 41981
#define sipName_allSelectors &sipStrings_QtCore[41981]
#define sipNameNr_isNativePath 41994
#define sipName_isNativePath &sipStrings_QtCore[41994]
#define sipNameNr_lastModified 42007
#define sipName_lastModified &sipStrings_QtCore[42007]
#define sipNameNr_isExecutable 42020
#define sipName_isExecutable &sipStrings_QtCore[42020]
#define sipNameNr_readLineData 42033
#define sipName_readLineData &sipStrings_QtCore[42033]
#define sipNameNr_isSequential 42046
#define sipName_isSequential &sipStrings_QtCore[42046]
#define sipNameNr_TimeOutError 42059
#define sipName_TimeOutError &sipStrings_QtCore[42059]
#define sipNameNr_setEventType 42072
#define sipName_setEventType &sipStrings_QtCore[42072]
#define sipNameNr_nsecsElapsed 42085
#define sipName_nsecsElapsed &sipStrings_QtCore[42085]
#define sipNameNr_setOvershoot 42098
#define sipName_setOvershoot &sipStrings_QtCore[42098]
#define sipNameNr_setAmplitude 42111
#define sipName_setAmplitude &sipStrings_QtCore[42111]
#define sipNameNr_BezierSpline 42124
#define sipName_BezierSpline &sipStrings_QtCore[42124]
#define sipNameNr_OutInElastic 42137
#define sipName_OutInElastic &sipStrings_QtCore[42137]
#define sipNameNr_InOutElastic 42150
#define sipName_InOutElastic &sipStrings_QtCore[42150]
#define sipNameNr_QEasingCurve 42163
#define sipName_QEasingCurve &sipStrings_QtCore[42163]
#define sipNameNr_IteratorFlag 5294
#define sipName_IteratorFlag &sipStrings_QtCore[5294]
#define sipNameNr_QDirIterator 42176
#define sipName_QDirIterator &sipStrings_QtCore[42176]
#define sipNameNr_makeAbsolute 42189
#define sipName_makeAbsolute &sipStrings_QtCore[42189]
#define sipNameNr_absolutePath 42202
#define sipName_absolutePath &sipStrings_QtCore[42202]
#define sipNameNr_QDir__Filter 42215
#define sipName_QDir__Filter &sipStrings_QtCore[42215]
#define sipNameNr_setTimerType 42228
#define sipName_setTimerType &sipStrings_QtCore[42228]
#define sipNameNr_toPyDateTime 42241
#define sipName_toPyDateTime &sipStrings_QtCore[42241]
#define sipNameNr_shortDayName 42254
#define sipName_shortDayName &sipStrings_QtCore[42254]
#define sipNameNr_writeRawData 42267
#define sipName_writeRawData &sipStrings_QtCore[42267]
#define sipNameNr_readQVariant 42280
#define sipName_readQVariant &sipStrings_QtCore[42280]
#define sipNameNr_writeQString 42293
#define sipName_writeQString &sipStrings_QtCore[42293]
#define sipNameNr_setByteOrder 42306
#define sipName_setByteOrder &sipStrings_QtCore[42306]
#define sipNameNr_LittleEndian 42319
#define sipName_LittleEndian &sipStrings_QtCore[42319]
#define sipNameNr_propertyName 42332
#define sipName_propertyName &sipStrings_QtCore[42332]
#define sipNameNr_GrabKeyboard 42345
#define sipName_GrabKeyboard &sipStrings_QtCore[42345]
#define sipNameNr_CursorChange 42358
#define sipName_CursorChange &sipStrings_QtCore[42358]
#define sipNameNr_ZOrderChange 42371
#define sipName_ZOrderChange &sipStrings_QtCore[42371]
#define sipNameNr_LocaleChange 42384
#define sipName_LocaleChange &sipStrings_QtCore[42384]
#define sipNameNr_ChildRemoved 42397
#define sipName_ChildRemoved &sipStrings_QtCore[42397]
#define sipNameNr_HideToParent 42410
#define sipName_HideToParent &sipStrings_QtCore[42410]
#define sipNameNr_ShowToParent 42423
#define sipName_ShowToParent &sipStrings_QtCore[42423]
#define sipNameNr_ThreadChange 42436
#define sipName_ThreadChange &sipStrings_QtCore[42436]
#define sipNameNr_ParentChange 42449
#define sipName_ParentChange &sipStrings_QtCore[42449]
#define sipNameNr_QEvent__Type 42462
#define sipName_QEvent__Type &sipStrings_QtCore[42462]
#define sipNameNr_setAttribute 42475
#define sipName_setAttribute &sipStrings_QtCore[42475]
#define sipNameNr_libraryPaths 42488
#define sipName_libraryPaths &sipStrings_QtCore[42488]
#define sipNameNr_sourceModels 42501
#define sipName_sourceModels &sipStrings_QtCore[42501]
#define sipNameNr_setValueName 42514
#define sipName_setValueName &sipStrings_QtCore[42514]
#define sipNameNr_toSimpleType 42527
#define sipName_toSimpleType &sipStrings_QtCore[42527]
#define sipNameNr_isSimpleType 42540
#define sipName_isSimpleType &sipStrings_QtCore[42540]
#define sipNameNr_maxRecursion 42553
#define sipName_maxRecursion &sipStrings_QtCore[42553]
#define sipNameNr_COSE_Encrypt 42566
#define sipName_COSE_Encrypt &sipStrings_QtCore[42566]
#define sipNameNr_DataTooLarge 42579
#define sipName_DataTooLarge &sipStrings_QtCore[42579]
#define sipNameNr_GarbageAtEnd 42592
#define sipName_GarbageAtEnd &sipStrings_QtCore[42592]
#define sipNameNr_UnknownError 42605
#define sipName_UnknownError &sipStrings_QtCore[42605]
#define sipNameNr_monthsInYear 42618
#define sipName_monthsInYear &sipStrings_QtCore[42618]
#define sipNameNr_IslamicCivil 42631
#define sipName_IslamicCivil &sipStrings_QtCore[42631]
#define sipNameNr_YearMonthDay 8859
#define sipName_YearMonthDay &sipStrings_QtCore[8859]
#define sipNameNr_Base64Option 7369
#define sipName_Base64Option &sipStrings_QtCore[7369]
#define sipNameNr___contains__ 42644
#define sipName___contains__ &sipStrings_QtCore[42644]
#define sipNameNr_onTransition 42657
#define sipName_onTransition &sipStrings_QtCore[42657]
#define sipNameNr_addAnimation 42670
#define sipName_addAnimation &sipStrings_QtCore[42670]
#define sipNameNr_targetStates 42683
#define sipName_targetStates &sipStrings_QtCore[42683]
#define sipNameNr_IndexIsValid 42696
#define sipName_IndexIsValid &sipStrings_QtCore[42696]
#define sipNameNr_columnsMoved 42709
#define sipName_columnsMoved &sipStrings_QtCore[42709]
#define sipNameNr_removeColumn 42722
#define sipName_removeColumn &sipStrings_QtCore[42722]
#define sipNameNr_insertColumn 42735
#define sipName_insertColumn &sipStrings_QtCore[42735]
#define sipNameNr_rowsInserted 42748
#define sipName_rowsInserted &sipStrings_QtCore[42748]
#define sipNameNr_canFetchMore 42761
#define sipName_canFetchMore &sipStrings_QtCore[42761]
#define sipNameNr_dropMimeData 42774
#define sipName_dropMimeData &sipStrings_QtCore[42774]
#define sipNameNr_siblingAtRow 42787
#define sipName_siblingAtRow &sipStrings_QtCore[42787]
#define sipNameNr_aboutToBlock 42800
#define sipName_aboutToBlock &sipStrings_QtCore[42800]
#define sipNameNr_stateChanged 42813
#define sipName_stateChanged &sipStrings_QtCore[42813]
#define sipNameNr_setLoopCount 42826
#define sipName_setLoopCount &sipStrings_QtCore[42826]
#define sipNameNr_setDirection 42839
#define sipName_setDirection &sipStrings_QtCore[42839]
#define sipNameNr_ChecksumType 26447
#define sipName_ChecksumType &sipStrings_QtCore[26447]
#define sipNameNr_EnterKeyNext 42852
#define sipName_EnterKeyNext &sipStrings_QtCore[42852]
#define sipNameNr_EnterKeySend 42865
#define sipName_EnterKeySend &sipStrings_QtCore[42865]
#define sipNameNr_EnterKeyDone 42878
#define sipName_EnterKeyDone &sipStrings_QtCore[42878]
#define sipNameNr_EnterKeyType 26481
#define sipName_EnterKeyType &sipStrings_QtCore[26481]
#define sipNameNr_ScrollUpdate 42891
#define sipName_ScrollUpdate &sipStrings_QtCore[42891]
#define sipNameNr_GestureFlags 26600
#define sipName_GestureFlags &sipStrings_QtCore[26600]
#define sipNameNr_SwipeGesture 42904
#define sipName_SwipeGesture &sipStrings_QtCore[42904]
#define sipNameNr_PinchGesture 42917
#define sipName_PinchGesture &sipStrings_QtCore[42917]
#define sipNameNr_GestureState 26617
#define sipName_GestureState &sipStrings_QtCore[26617]
#define sipNameNr_AnchorBottom 42930
#define sipName_AnchorBottom &sipStrings_QtCore[42930]
#define sipNameNr_ImhMultiLine 42943
#define sipName_ImhMultiLine &sipStrings_QtCore[42943]
#define sipNameNr_ImhLatinOnly 42956
#define sipName_ImhLatinOnly &sipStrings_QtCore[42956]
#define sipNameNr_Qt__TileRule 42969
#define sipName_Qt__TileRule &sipStrings_QtCore[42969]
#define sipNameNr_TitleBarArea 42982
#define sipName_TitleBarArea &sipStrings_QtCore[42982]
#define sipNameNr_RightSection 20226
#define sipName_RightSection &sipStrings_QtCore[20226]
#define sipNameNr_Qt__SizeHint 42995
#define sipName_Qt__SizeHint &sipStrings_QtCore[42995]
#define sipNameNr_RelativeSize 43008
#define sipName_RelativeSize &sipStrings_QtCore[43008]
#define sipNameNr_AbsoluteSize 43021
#define sipName_AbsoluteSize &sipStrings_QtCore[43021]
#define sipNameNr_Qt__SizeMode 43034
#define sipName_Qt__SizeMode &sipStrings_QtCore[43034]
#define sipNameNr_MaskOutColor 43047
#define sipName_MaskOutColor &sipStrings_QtCore[43047]
#define sipNameNr_Qt__MaskMode 43060
#define sipName_Qt__MaskMode &sipStrings_QtCore[43060]
#define sipNameNr_TextEditable 43073
#define sipName_TextEditable &sipStrings_QtCore[43073]
#define sipNameNr_MatchExactly 43086
#define sipName_MatchExactly &sipStrings_QtCore[43086]
#define sipNameNr_Qt__ItemFlag 43099
#define sipName_Qt__ItemFlag &sipStrings_QtCore[43099]
#define sipNameNr_SizeHintRole 43112
#define sipName_SizeHintRole &sipStrings_QtCore[43112]
#define sipNameNr_ItemDataRole 26804
#define sipName_ItemDataRole &sipStrings_QtCore[26804]
#define sipNameNr_IgnoreAction 43125
#define sipName_IgnoreAction &sipStrings_QtCore[43125]
#define sipNameNr_ImQueryInput 43138
#define sipName_ImQueryInput &sipStrings_QtCore[43138]
#define sipNameNr_ImMicroFocus 43151
#define sipName_ImMicroFocus &sipStrings_QtCore[43151]
#define sipNameNr_Qt__FillRule 43164
#define sipName_Qt__FillRule &sipStrings_QtCore[43164]
#define sipNameNr_Qt__TimeSpec 43177
#define sipName_Qt__TimeSpec &sipStrings_QtCore[43177]
#define sipNameNr_ToolBarAreas 27008
#define sipName_ToolBarAreas &sipStrings_QtCore[27008]
#define sipNameNr_PreciseTimer 43190
#define sipName_PreciseTimer &sipStrings_QtCore[43190]
#define sipNameNr_MarkdownText 43203
#define sipName_MarkdownText &sipStrings_QtCore[43203]
#define sipNameNr_CustomCursor 43216
#define sipName_CustomCursor &sipStrings_QtCore[43216]
#define sipNameNr_BitmapCursor 43229
#define sipName_BitmapCursor &sipStrings_QtCore[43229]
#define sipNameNr_SplitHCursor 43242
#define sipName_SplitHCursor &sipStrings_QtCore[43242]
#define sipNameNr_SplitVCursor 43255
#define sipName_SplitVCursor &sipStrings_QtCore[43255]
#define sipNameNr_Qt__UIEffect 43268
#define sipName_Qt__UIEffect &sipStrings_QtCore[43268]
#define sipNameNr_FDiagPattern 43281
#define sipName_FDiagPattern &sipStrings_QtCore[43281]
#define sipNameNr_BDiagPattern 43294
#define sipName_BDiagPattern &sipStrings_QtCore[43294]
#define sipNameNr_CrossPattern 27093
#define sipName_CrossPattern &sipStrings_QtCore[27093]
#define sipNameNr_SolidPattern 43307
#define sipName_SolidPattern &sipStrings_QtCore[43307]
#define sipNameNr_SvgMiterJoin 43320
#define sipName_SvgMiterJoin &sipStrings_QtCore[43320]
#define sipNameNr_PenJoinStyle 27110
#define sipName_PenJoinStyle &sipStrings_QtCore[27110]
#define sipNameNr_MPenCapStyle 43333
#define sipName_MPenCapStyle &sipStrings_QtCore[43333]
#define sipNameNr_Qt__PenStyle 43346
#define sipName_Qt__PenStyle &sipStrings_QtCore[43346]
#define sipNameNr_Key_Settings 43359
#define sipName_Key_Settings &sipStrings_QtCore[43359]
#define sipNameNr_Key_Subtitle 43372
#define sipName_Key_Subtitle &sipStrings_QtCore[43372]
#define sipNameNr_Key_Pictures 43385
#define sipName_Key_Pictures &sipStrings_QtCore[43385]
#define sipNameNr_Key_Terminal 43398
#define sipName_Key_Terminal &sipStrings_QtCore[43398]
#define sipNameNr_Key_TaskPane 43411
#define sipName_Key_TaskPane &sipStrings_QtCore[43411]
#define sipNameNr_Key_Calendar 43424
#define sipName_Key_Calendar &sipStrings_QtCore[43424]
#define sipNameNr_Key_Explorer 43437
#define sipName_Key_Explorer &sipStrings_QtCore[43437]
#define sipNameNr_Key_ToDoList 43450
#define sipName_Key_ToDoList &sipStrings_QtCore[43450]
#define sipNameNr_Key_HotLinks 43463
#define sipName_Key_HotLinks &sipStrings_QtCore[43463]
#define sipNameNr_Key_PowerOff 43476
#define sipName_Key_PowerOff &sipStrings_QtCore[43476]
#define sipNameNr_Key_Context4 43489
#define sipName_Key_Context4 &sipStrings_QtCore[43489]
#define sipNameNr_Key_Context3 43502
#define sipName_Key_Context3 &sipStrings_QtCore[43502]
#define sipNameNr_Key_Context2 43515
#define sipName_Key_Context2 &sipStrings_QtCore[43515]
#define sipNameNr_Key_Context1 43528
#define sipName_Key_Context1 &sipStrings_QtCore[43528]
#define sipNameNr_Key_HomePage 43541
#define sipName_Key_HomePage &sipStrings_QtCore[43541]
#define sipNameNr_Key_TrebleUp 43554
#define sipName_Key_TrebleUp &sipStrings_QtCore[43554]
#define sipNameNr_Key_BassDown 43567
#define sipName_Key_BassDown &sipStrings_QtCore[43567]
#define sipNameNr_Key_VolumeUp 43580
#define sipName_Key_VolumeUp &sipStrings_QtCore[43580]
#define sipNameNr_Key_Katakana 43593
#define sipName_Key_Katakana &sipStrings_QtCore[43593]
#define sipNameNr_Key_Hiragana 43606
#define sipName_Key_Hiragana &sipStrings_QtCore[43606]
#define sipNameNr_Key_Muhenkan 43619
#define sipName_Key_Muhenkan &sipStrings_QtCore[43619]
#define sipNameNr_Key_division 43632
#define sipName_Key_division &sipStrings_QtCore[43632]
#define sipNameNr_Key_Ooblique 43645
#define sipName_Key_Ooblique &sipStrings_QtCore[43645]
#define sipNameNr_Key_multiply 43658
#define sipName_Key_multiply &sipStrings_QtCore[43658]
#define sipNameNr_Key_Ccedilla 43671
#define sipName_Key_Ccedilla &sipStrings_QtCore[43671]
#define sipNameNr_Key_currency 43684
#define sipName_Key_currency &sipStrings_QtCore[43684]
#define sipNameNr_Key_sterling 43697
#define sipName_Key_sterling &sipStrings_QtCore[43697]
#define sipNameNr_Key_Question 43710
#define sipName_Key_Question &sipStrings_QtCore[43710]
#define sipNameNr_Key_Asterisk 43723
#define sipName_Key_Asterisk &sipStrings_QtCore[43723]
#define sipNameNr_Key_QuoteDbl 43736
#define sipName_Key_QuoteDbl &sipStrings_QtCore[43736]
#define sipNameNr_Key_CapsLock 43749
#define sipName_Key_CapsLock &sipStrings_QtCore[43749]
#define sipNameNr_Key_PageDown 43762
#define sipName_Key_PageDown &sipStrings_QtCore[43762]
#define sipNameNr_PreferDither 43775
#define sipName_PreferDither &sipStrings_QtCore[43775]
#define sipNameNr_WA_SetLocale 43788
#define sipName_WA_SetLocale &sipStrings_QtCore[43788]
#define sipNameNr_WA_SetCursor 43801
#define sipName_WA_SetCursor &sipStrings_QtCore[43801]
#define sipNameNr_WindowStates 27450
#define sipName_WindowStates &sipStrings_QtCore[27450]
#define sipNameNr_WindowActive 43814
#define sipName_WindowActive &sipStrings_QtCore[43814]
#define sipNameNr_SplashScreen 43827
#define sipName_SplashScreen &sipStrings_QtCore[43827]
#define sipNameNr_TextWordWrap 43840
#define sipName_TextWordWrap &sipStrings_QtCore[43840]
#define sipNameNr_TextDontClip 43853
#define sipName_TextDontClip &sipStrings_QtCore[43853]
#define sipNameNr_Qt__TextFlag 43866
#define sipName_Qt__TextFlag &sipStrings_QtCore[43866]
#define sipNameNr_AlignVCenter 43879
#define sipName_AlignVCenter &sipStrings_QtCore[43879]
#define sipNameNr_AlignJustify 43892
#define sipName_AlignJustify &sipStrings_QtCore[43892]
#define sipNameNr_AlignHCenter 43905
#define sipName_AlignHCenter &sipStrings_QtCore[43905]
#define sipNameNr_AlignLeading 43918
#define sipName_AlignLeading &sipStrings_QtCore[43918]
#define sipNameNr_Orientations 10632
#define sipName_Orientations &sipStrings_QtCore[10632]
#define sipNameNr_MouseButtons 27552
#define sipName_MouseButtons &sipStrings_QtCore[27552]
#define sipNameNr_ExtraButton9 43931
#define sipName_ExtraButton9 &sipStrings_QtCore[43931]
#define sipNameNr_ExtraButton8 43944
#define sipName_ExtraButton8 &sipStrings_QtCore[43944]
#define sipNameNr_ExtraButton7 43957
#define sipName_ExtraButton7 &sipStrings_QtCore[43957]
#define sipNameNr_ExtraButton6 43970
#define sipName_ExtraButton6 &sipStrings_QtCore[43970]
#define sipNameNr_ExtraButton5 43983
#define sipName_ExtraButton5 &sipStrings_QtCore[43983]
#define sipNameNr_ExtraButton4 43996
#define sipName_ExtraButton4 &sipStrings_QtCore[43996]
#define sipNameNr_ExtraButton3 44009
#define sipName_ExtraButton3 &sipStrings_QtCore[44009]
#define sipNameNr_ExtraButton2 44022
#define sipName_ExtraButton2 &sipStrings_QtCore[44022]
#define sipNameNr_ExtraButton1 44035
#define sipName_ExtraButton1 &sipStrings_QtCore[44035]
#define sipNameNr_MiddleButton 44048
#define sipName_MiddleButton &sipStrings_QtCore[44048]
#define sipNameNr_Qt__Modifier 44061
#define sipName_Qt__Modifier &sipStrings_QtCore[44061]
#define sipNameNr_MetaModifier 44074
#define sipName_MetaModifier &sipStrings_QtCore[44074]
#define sipNameNr_defaultValue 44087
#define sipName_defaultValue &sipStrings_QtCore[44087]
#define sipNameNr_qSharedBuild 44100
#define sipName_qSharedBuild &sipStrings_QtCore[44100]
#define sipNameNr_PYQT_VERSION 44113
#define sipName_PYQT_VERSION &sipStrings_QtCore[44113]
#define sipNameNr_PyQt5_QtCore 44126
#define sipName_PyQt5_QtCore &sipStrings_QtCore[44126]
#define sipNameNr_44139 44139
#define sipName_44139 &sipStrings_QtCore[44139]
#define sipNameNr_productType 44151
#define sipName_productType &sipStrings_QtCore[44151]
#define sipNameNr_CustomError 44163
#define sipName_CustomError &sipStrings_QtCore[44163]
#define sipNameNr_dtdSystemId 44175
#define sipName_dtdSystemId &sipStrings_QtCore[44175]
#define sipNameNr_dtdPublicId 44187
#define sipName_dtdPublicId &sipStrings_QtCore[44187]
#define sipNameNr_tokenString 44199
#define sipName_tokenString &sipStrings_QtCore[44199]
#define sipNameNr_EndDocument 24204
#define sipName_EndDocument &sipStrings_QtCore[24204]
#define sipNameNr_suffixIndex 44211
#define sipName_suffixIndex &sipStrings_QtCore[44211]
#define sipNameNr_setEndValue 44223
#define sipName_setEndValue &sipStrings_QtCore[44223]
#define sipNameNr_EasingCurve 31592
#define sipName_EasingCurve &sipStrings_QtCore[31592]
#define sipNameNr_KeySequence 40916
#define sipName_KeySequence &sipStrings_QtCore[40916]
#define sipNameNr_fromRfc4122 44235
#define sipName_fromRfc4122 &sipStrings_QtCore[44235]
#define sipNameNr_toByteArray 44247
#define sipName_toByteArray &sipStrings_QtCore[44247]
#define sipNameNr_isLocalFile 44259
#define sipName_isLocalFile &sipStrings_QtCore[44259]
#define sipNameNr_hasFragment 44271
#define sipName_hasFragment &sipStrings_QtCore[44271]
#define sipNameNr_fromEncoded 44283
#define sipName_fromEncoded &sipStrings_QtCore[44283]
#define sipNameNr_toLocalFile 44295
#define sipName_toLocalFile &sipStrings_QtCore[44295]
#define sipNameNr_setFragment 44307
#define sipName_setFragment &sipStrings_QtCore[44307]
#define sipNameNr_defaultPort 44319
#define sipName_defaultPort &sipStrings_QtCore[44319]
#define sipNameNr_setPassword 44331
#define sipName_setPassword &sipStrings_QtCore[44331]
#define sipNameNr_setUserName 44343
#define sipName_setUserName &sipStrings_QtCore[44343]
#define sipNameNr_setUserInfo 44355
#define sipName_setUserInfo &sipStrings_QtCore[44355]
#define sipNameNr_RemoveQuery 44367
#define sipName_RemoveQuery &sipStrings_QtCore[44367]
#define sipNameNr_DecodedMode 44379
#define sipName_DecodedMode &sipStrings_QtCore[44379]
#define sipNameNr_ParsingMode 21204
#define sipName_ParsingMode &sipStrings_QtCore[21204]
#define sipNameNr_QTranslator 44391
#define sipName_QTranslator &sipStrings_QtCore[44391]
#define sipNameNr_DefaultName 44403
#define sipName_DefaultName &sipStrings_QtCore[44403]
#define sipNameNr_GenericTime 44415
#define sipName_GenericTime &sipStrings_QtCore[44415]
#define sipNameNr_setInterval 44427
#define sipName_setInterval &sipStrings_QtCore[44427]
#define sipNameNr_easingCurve 44439
#define sipName_easingCurve &sipStrings_QtCore[44439]
#define sipNameNr_setEndFrame 44451
#define sipName_setEndFrame &sipStrings_QtCore[44451]
#define sipNameNr_LinearCurve 44463
#define sipName_LinearCurve &sipStrings_QtCore[44463]
#define sipNameNr_EaseInCurve 44475
#define sipName_EaseInCurve &sipStrings_QtCore[44475]
#define sipNameNr_waitForDone 44487
#define sipName_waitForDone &sipStrings_QtCore[44487]
#define sipNameNr_QThreadPool 44499
#define sipName_QThreadPool &sipStrings_QtCore[44499]
#define sipNameNr_setPriority 44511
#define sipName_setPriority &sipStrings_QtCore[44511]
#define sipNameNr_LowPriority 44523
#define sipName_LowPriority &sipStrings_QtCore[44523]
#define sipNameNr_qSetPadChar 44535
#define sipName_qSetPadChar &sipStrings_QtCore[44535]
#define sipNameNr_noforcesign 44547
#define sipName_noforcesign &sipStrings_QtCore[44547]
#define sipNameNr_integerBase 44559
#define sipName_integerBase &sipStrings_QtCore[44559]
#define sipNameNr_numberFlags 44571
#define sipName_numberFlags &sipStrings_QtCore[44571]
#define sipNameNr_NumberFlags 6920
#define sipName_NumberFlags &sipStrings_QtCore[6920]
#define sipNameNr_QTextStream 44583
#define sipName_QTextStream &sipStrings_QtCore[44583]
#define sipNameNr_fromUnicode 44595
#define sipName_fromUnicode &sipStrings_QtCore[44595]
#define sipNameNr_makeEncoder 44607
#define sipName_makeEncoder &sipStrings_QtCore[44607]
#define sipNameNr_makeDecoder 44619
#define sipName_makeDecoder &sipStrings_QtCore[44619]
#define sipNameNr_codecForMib 44631
#define sipName_codecForMib &sipStrings_QtCore[44631]
#define sipNameNr_setPosition 44643
#define sipName_setPosition &sipStrings_QtCore[44643]
#define sipNameNr_StartOfItem 44655
#define sipName_StartOfItem &sipStrings_QtCore[44655]
#define sipNameNr_setAnimated 44667
#define sipName_setAnimated &sipStrings_QtCore[44667]
#define sipNameNr_removeState 44679
#define sipName_removeState &sipStrings_QtCore[44679]
#define sipNameNr_signalIndex 44691
#define sipName_signalIndex &sipStrings_QtCore[44691]
#define sipNameNr_SignalEvent 4890
#define sipName_SignalEvent &sipStrings_QtCore[4890]
#define sipNameNr_transitions 44703
#define sipName_transitions &sipStrings_QtCore[44703]
#define sipNameNr_displayName 44715
#define sipName_displayName &sipStrings_QtCore[44715]
#define sipNameNr_setSortRole 44727
#define sipName_setSortRole &sipStrings_QtCore[44727]
#define sipNameNr_InvalidSize 35327
#define sipName_InvalidSize &sipStrings_QtCore[35327]
#define sipNameNr_setIniCodec 44739
#define sipName_setIniCodec &sipStrings_QtCore[44739]
#define sipNameNr_childGroups 44751
#define sipName_childGroups &sipStrings_QtCore[44751]
#define sipNameNr_SystemScope 44763
#define sipName_SystemScope &sipStrings_QtCore[44763]
#define sipNameNr_FormatError 44775
#define sipName_FormatError &sipStrings_QtCore[44775]
#define sipNameNr_AccessError 44787
#define sipName_AccessError &sipStrings_QtCore[44787]
#define sipNameNr_insertPause 44799
#define sipName_insertPause &sipStrings_QtCore[44799]
#define sipNameNr_Compression 7945
#define sipName_Compression &sipStrings_QtCore[7945]
#define sipNameNr_capturedEnd 44811
#define sipName_capturedEnd &sipStrings_QtCore[44811]
#define sipNameNr_globalMatch 44823
#define sipName_globalMatch &sipStrings_QtCore[44823]
#define sipNameNr_MatchOption 1515
#define sipName_MatchOption &sipStrings_QtCore[1515]
#define sipNameNr_NormalMatch 44835
#define sipName_NormalMatch &sipStrings_QtCore[44835]
#define sipNameNr_lastIndexIn 44847
#define sipName_lastIndexIn &sipStrings_QtCore[44847]
#define sipNameNr_CaretAtZero 44859
#define sipName_CaretAtZero &sipStrings_QtCore[44859]
#define sipNameNr_FixedString 13622
#define sipName_FixedString &sipStrings_QtCore[13622]
#define sipNameNr_moveTopLeft 44871
#define sipName_moveTopLeft &sipStrings_QtCore[44871]
#define sipNameNr_setTopRight 44883
#define sipName_setTopRight &sipStrings_QtCore[44883]
#define sipNameNr_QReadLocker 44895
#define sipName_QReadLocker &sipStrings_QtCore[44895]
#define sipNameNr_lockForRead 44907
#define sipName_lockForRead &sipStrings_QtCore[44907]
#define sipNameNr_readChannel 44919
#define sipName_readChannel &sipStrings_QtCore[44919]
#define sipNameNr_setDuration 44931
#define sipName_setDuration &sipStrings_QtCore[44931]
#define sipNameNr_currentType 44943
#define sipName_currentType &sipStrings_QtCore[44943]
#define sipNameNr_AndroidOreo 44955
#define sipName_AndroidOreo &sipStrings_QtCore[44955]
#define sipNameNr_MacOSMojave 44967
#define sipName_MacOSMojave &sipStrings_QtCore[44967]
#define sipNameNr_MacOSSierra 44979
#define sipName_MacOSSierra &sipStrings_QtCore[44979]
#define sipNameNr_OSXYosemite 44991
#define sipName_OSXYosemite &sipStrings_QtCore[44991]
#define sipNameNr_constructor 45003
#define sipName_constructor &sipStrings_QtCore[45003]
#define sipNameNr_indexOfSlot 45015
#define sipName_indexOfSlot &sipStrings_QtCore[45015]
#define sipNameNr_methodCount 45027
#define sipName_methodCount &sipStrings_QtCore[45027]
#define sipNameNr_QMetaObject 45039
#define sipName_QMetaObject &sipStrings_QtCore[45039]
#define sipNameNr_Q_CLASSINFO 45051
#define sipName_Q_CLASSINFO &sipStrings_QtCore[45051]
#define sipNameNr_customEvent 45063
#define sipName_customEvent &sipStrings_QtCore[45063]
#define sipNameNr_deleteLater 45075
#define sipName_deleteLater &sipStrings_QtCore[45075]
#define sipNameNr_setProperty 45087
#define sipName_setProperty &sipStrings_QtCore[45087]
#define sipNameNr_eventFilter 45099
#define sipName_eventFilter &sipStrings_QtCore[45099]
#define sipNameNr___getattr__ 45111
#define sipName___getattr__ &sipStrings_QtCore[45111]
#define sipNameNr_isRecursive 45123
#define sipName_isRecursive &sipStrings_QtCore[45123]
#define sipNameNr_MovableType 45135
#define sipName_MovableType &sipStrings_QtCore[45135]
#define sipNameNr_QColorSpace 45147
#define sipName_QColorSpace &sipStrings_QtCore[45147]
#define sipNameNr_QJsonObject 45159
#define sipName_QJsonObject &sipStrings_QtCore[45159]
#define sipNameNr_QQuaternion 45171
#define sipName_QQuaternion &sipStrings_QtCore[45171]
#define sipNameNr_QObjectStar 45183
#define sipName_QObjectStar &sipStrings_QtCore[45183]
#define sipNameNr_QTextFormat 45195
#define sipName_QTextFormat &sipStrings_QtCore[45195]
#define sipNameNr_QTextLength 45207
#define sipName_QTextLength &sipStrings_QtCore[45207]
#define sipNameNr_QSizePolicy 45219
#define sipName_QSizePolicy &sipStrings_QtCore[45219]
#define sipNameNr_QStringList 25938
#define sipName_QStringList &sipStrings_QtCore[25938]
#define sipNameNr_QVariantMap 25904
#define sipName_QVariantMap &sipStrings_QtCore[25904]
#define sipNameNr_valueToKeys 45231
#define sipName_valueToKeys &sipStrings_QtCore[45231]
#define sipNameNr_keysToValue 45243
#define sipName_keysToValue &sipStrings_QtCore[45243]
#define sipNameNr_methodIndex 45255
#define sipName_methodIndex &sipStrings_QtCore[45255]
#define sipNameNr_Constructor 18612
#define sipName_Constructor &sipStrings_QtCore[18612]
#define sipNameNr_QMetaMethod 45267
#define sipName_QMetaMethod &sipStrings_QtCore[45267]
#define sipNameNr_QtSystemMsg 45279
#define sipName_QtSystemMsg &sipStrings_QtCore[45279]
#define sipNameNr_getLockInfo 45291
#define sipName_getLockInfo &sipStrings_QtCore[45291]
#define sipNameNr_quoteString 45303
#define sipName_quoteString &sipStrings_QtCore[45303]
#define sipNameNr_uiLanguages 45315
#define sipName_uiLanguages &sipStrings_QtCore[45315]
#define sipNameNr_OsageScript 45327
#define sipName_OsageScript &sipStrings_QtCore[45327]
#define sipNameNr_AdlamScript 45339
#define sipName_AdlamScript &sipStrings_QtCore[45339]
#define sipNameNr_TakriScript 45351
#define sipName_TakriScript &sipStrings_QtCore[45351]
#define sipNameNr_TaiLeScript 45363
#define sipName_TaiLeScript &sipStrings_QtCore[45363]
#define sipNameNr_RunicScript 45375
#define sipName_RunicScript &sipStrings_QtCore[45375]
#define sipNameNr_OghamScript 45387
#define sipName_OghamScript &sipStrings_QtCore[45387]
#define sipNameNr_LimbuScript 45399
#define sipName_LimbuScript &sipStrings_QtCore[45399]
#define sipNameNr_LannaScript 45411
#define sipName_LannaScript &sipStrings_QtCore[45411]
#define sipNameNr_BuhidScript 45423
#define sipName_BuhidScript &sipStrings_QtCore[45423]
#define sipNameNr_BatakScript 45435
#define sipName_BatakScript &sipStrings_QtCore[45435]
#define sipNameNr_BamumScript 45447
#define sipName_BamumScript &sipStrings_QtCore[45447]
#define sipNameNr_TamilScript 45459
#define sipName_TamilScript &sipStrings_QtCore[45459]
#define sipNameNr_OriyaScript 45471
#define sipName_OriyaScript &sipStrings_QtCore[45471]
#define sipNameNr_KhmerScript 45483
#define sipName_KhmerScript &sipStrings_QtCore[45483]
#define sipNameNr_GreekScript 45495
#define sipName_GreekScript &sipStrings_QtCore[45495]
#define sipNameNr_LatinScript 45507
#define sipName_LatinScript &sipStrings_QtCore[45507]
#define sipNameNr_exponential 45519
#define sipName_exponential &sipStrings_QtCore[45519]
#define sipNameNr_ShortFormat 45531
#define sipName_ShortFormat &sipStrings_QtCore[45531]
#define sipNameNr_SintMaarten 45543
#define sipName_SintMaarten &sipStrings_QtCore[45543]
#define sipNameNr_DiegoGarcia 45555
#define sipName_DiegoGarcia &sipStrings_QtCore[45555]
#define sipNameNr_SaintHelena 45567
#define sipName_SaintHelena &sipStrings_QtCore[45567]
#define sipNameNr_LastCountry 45579
#define sipName_LastCountry &sipStrings_QtCore[45579]
#define sipNameNr_SaintMartin 45591
#define sipName_SaintMartin &sipStrings_QtCore[45591]
#define sipNameNr_Switzerland 45603
#define sipName_Switzerland &sipStrings_QtCore[45603]
#define sipNameNr_SouthAfrica 45615
#define sipName_SouthAfrica &sipStrings_QtCore[45615]
#define sipNameNr_SierraLeone 45627
#define sipName_SierraLeone &sipStrings_QtCore[45627]
#define sipNameNr_SaudiArabia 45639
#define sipName_SaudiArabia &sipStrings_QtCore[45639]
#define sipNameNr_Philippines 45651
#define sipName_Philippines &sipStrings_QtCore[45651]
#define sipNameNr_Netherlands 45663
#define sipName_Netherlands &sipStrings_QtCore[45663]
#define sipNameNr_CookIslands 45675
#define sipName_CookIslands &sipStrings_QtCore[45675]
#define sipNameNr_BurkinaFaso 45687
#define sipName_BurkinaFaso &sipStrings_QtCore[45687]
#define sipNameNr_Afghanistan 45699
#define sipName_Afghanistan &sipStrings_QtCore[45699]
#define sipNameNr_Mazanderani 45711
#define sipName_Mazanderani &sipStrings_QtCore[45711]
#define sipNameNr_EasternCham 45723
#define sipName_EasternCham &sipStrings_QtCore[45723]
#define sipNameNr_Marshallese 45735
#define sipName_Marshallese &sipStrings_QtCore[45735]
#define sipNameNr_LubaKatanga 45747
#define sipName_LubaKatanga &sipStrings_QtCore[45747]
#define sipNameNr_AnyLanguage 45759
#define sipName_AnyLanguage &sipStrings_QtCore[45759]
#define sipNameNr_KoyraChiini 45771
#define sipName_KoyraChiini &sipStrings_QtCore[45771]
#define sipNameNr_SwissGerman 45783
#define sipName_SwissGerman &sipStrings_QtCore[45783]
#define sipNameNr_Kinyarwanda 45795
#define sipName_Kinyarwanda &sipStrings_QtCore[45795]
#define sipNameNr_Interlingue 45807
#define sipName_Interlingue &sipStrings_QtCore[45807]
#define sipNameNr_Interlingua 45819
#define sipName_Interlingua &sipStrings_QtCore[45819]
#define sipNameNr_Greenlandic 45831
#define sipName_Greenlandic &sipStrings_QtCore[45831]
#define sipNameNr_Azerbaijani 45843
#define sipName_Azerbaijani &sipStrings_QtCore[45843]
#define sipNameNr_ImportsPath 29282
#define sipName_ImportsPath &sipStrings_QtCore[29282]
#define sipNameNr_PluginsPath 45855
#define sipName_PluginsPath &sipStrings_QtCore[45855]
#define sipNameNr_HeadersPath 45867
#define sipName_HeadersPath &sipStrings_QtCore[45867]
#define sipNameNr_fromVariant 45879
#define sipName_fromVariant &sipStrings_QtCore[45879]
#define sipNameNr_DeepNesting 45891
#define sipName_DeepNesting &sipStrings_QtCore[45891]
#define sipNameNr___delitem__ 45903
#define sipName___delitem__ &sipStrings_QtCore[45903]
#define sipNameNr___setitem__ 45915
#define sipName___setitem__ &sipStrings_QtCore[45915]
#define sipNameNr_intersected 45927
#define sipName_intersected &sipStrings_QtCore[45927]
#define sipNameNr_setOpenMode 45939
#define sipName_setOpenMode &sipStrings_QtCore[45939]
#define sipNameNr_errorString 45951
#define sipName_errorString &sipStrings_QtCore[45951]
#define sipNameNr_historyType 45963
#define sipName_historyType &sipStrings_QtCore[45963]
#define sipNameNr_DeepHistory 45975
#define sipName_DeepHistory &sipStrings_QtCore[45975]
#define sipNameNr_HistoryType 5268
#define sipName_HistoryType &sipStrings_QtCore[5268]
#define sipNameNr_QFinalState 45987
#define sipName_QFinalState &sipStrings_QtCore[45987]
#define sipNameNr_fileChanged 45999
#define sipName_fileChanged &sipStrings_QtCore[45999]
#define sipNameNr_removePaths 46011
#define sipName_removePaths &sipStrings_QtCore[46011]
#define sipNameNr_directories 33302
#define sipName_directories &sipStrings_QtCore[33302]
#define sipNameNr_absoluteDir 46023
#define sipName_absoluteDir &sipStrings_QtCore[46023]
#define sipNameNr_setFileTime 46035
#define sipName_setFileTime &sipStrings_QtCore[46035]
#define sipNameNr_Permissions 7195
#define sipName_Permissions &sipStrings_QtCore[7195]
#define sipNameNr_ResizeError 46047
#define sipName_ResizeError &sipStrings_QtCore[46047]
#define sipNameNr_RenameError 46059
#define sipName_RenameError &sipStrings_QtCore[46059]
#define sipNameNr_RemoveError 46071
#define sipName_RemoveError &sipStrings_QtCore[46071]
#define sipNameNr_pathInTrash 46083
#define sipName_pathInTrash &sipStrings_QtCore[46083]
#define sipNameNr_moveToTrash 46095
#define sipName_moveToTrash &sipStrings_QtCore[46095]
#define sipNameNr_permissions 46107
#define sipName_permissions &sipStrings_QtCore[46107]
#define sipNameNr_handleFlags 46119
#define sipName_handleFlags &sipStrings_QtCore[46119]
#define sipNameNr_setFileName 46131
#define sipName_setFileName &sipStrings_QtCore[46131]
#define sipNameNr_QFileDevice 46143
#define sipName_QFileDevice &sipStrings_QtCore[46143]
#define sipNameNr_eventSource 46155
#define sipName_eventSource &sipStrings_QtCore[46155]
#define sipNameNr_isMonotonic 46167
#define sipName_isMonotonic &sipStrings_QtCore[46167]
#define sipNameNr_TickCounter 46179
#define sipName_TickCounter &sipStrings_QtCore[46179]
#define sipNameNr_CosineCurve 46191
#define sipName_CosineCurve &sipStrings_QtCore[46191]
#define sipNameNr_OutInBounce 46203
#define sipName_OutInBounce &sipStrings_QtCore[46203]
#define sipNameNr_InOutBounce 46215
#define sipName_InOutBounce &sipStrings_QtCore[46215]
#define sipNameNr_searchPaths 46227
#define sipName_searchPaths &sipStrings_QtCore[46227]
#define sipNameNr_currentPath 46239
#define sipName_currentPath &sipStrings_QtCore[46239]
#define sipNameNr_nameFilters 46251
#define sipName_nameFilters &sipStrings_QtCore[46251]
#define sipNameNr_LocaleAware 18384
#define sipName_LocaleAware &sipStrings_QtCore[18384]
#define sipNameNr_setDeadline 46263
#define sipName_setDeadline &sipStrings_QtCore[46263]
#define sipNameNr_setTimeZone 46275
#define sipName_setTimeZone &sipStrings_QtCore[46275]
#define sipNameNr_toLocalTime 46287
#define sipName_toLocalTime &sipStrings_QtCore[46287]
#define sipNameNr_setTimeSpec 46299
#define sipName_setTimeSpec &sipStrings_QtCore[46299]
#define sipNameNr_toJulianDay 46311
#define sipName_toJulianDay &sipStrings_QtCore[46311]
#define sipNameNr_currentDate 46323
#define sipName_currentDate &sipStrings_QtCore[46323]
#define sipNameNr_longDayName 46335
#define sipName_longDayName &sipStrings_QtCore[46335]
#define sipNameNr_readRawData 46347
#define sipName_readRawData &sipStrings_QtCore[46347]
#define sipNameNr_readQString 46359
#define sipName_readQString &sipStrings_QtCore[46359]
#define sipNameNr_writeString 46371
#define sipName_writeString &sipStrings_QtCore[46371]
#define sipNameNr_writeDouble 46383
#define sipName_writeDouble &sipStrings_QtCore[46383]
#define sipNameNr_writeUInt64 46395
#define sipName_writeUInt64 &sipStrings_QtCore[46395]
#define sipNameNr_writeUInt32 46407
#define sipName_writeUInt32 &sipStrings_QtCore[46407]
#define sipNameNr_writeUInt16 46419
#define sipName_writeUInt16 &sipStrings_QtCore[46419]
#define sipNameNr_skipRawData 46431
#define sipName_skipRawData &sipStrings_QtCore[46431]
#define sipNameNr_resetStatus 46443
#define sipName_resetStatus &sipStrings_QtCore[46443]
#define sipNameNr_WriteFailed 46455
#define sipName_WriteFailed &sipStrings_QtCore[46455]
#define sipNameNr_ReadPastEnd 46467
#define sipName_ReadPastEnd &sipStrings_QtCore[46467]
#define sipNameNr_QDataStream 46479
#define sipName_QDataStream &sipStrings_QtCore[46479]
#define sipNameNr_QChildEvent 46491
#define sipName_QChildEvent &sipStrings_QtCore[46491]
#define sipNameNr_QTimerEvent 46503
#define sipName_QTimerEvent &sipStrings_QtCore[46503]
#define sipNameNr_setAccepted 46515
#define sipName_setAccepted &sipStrings_QtCore[46515]
#define sipNameNr_spontaneous 46527
#define sipName_spontaneous &sipStrings_QtCore[46527]
#define sipNameNr_TouchCancel 46539
#define sipName_TouchCancel &sipStrings_QtCore[46539]
#define sipNameNr_WinIdChange 46551
#define sipName_WinIdChange &sipStrings_QtCore[46551]
#define sipNameNr_TouchUpdate 46563
#define sipName_TouchUpdate &sipStrings_QtCore[46563]
#define sipNameNr_UngrabMouse 46575
#define sipName_UngrabMouse &sipStrings_QtCore[46575]
#define sipNameNr_ActionAdded 46587
#define sipName_ActionAdded &sipStrings_QtCore[46587]
#define sipNameNr_StyleChange 46599
#define sipName_StyleChange &sipStrings_QtCore[46599]
#define sipNameNr_TabletPress 46611
#define sipName_TabletPress &sipStrings_QtCore[46611]
#define sipNameNr_InputMethod 46623
#define sipName_InputMethod &sipStrings_QtCore[46623]
#define sipNameNr_ContextMenu 7270
#define sipName_ContextMenu &sipStrings_QtCore[7270]
#define sipNameNr_UpdateLater 46635
#define sipName_UpdateLater &sipStrings_QtCore[46635]
#define sipNameNr_WinEventAct 46647
#define sipName_WinEventAct &sipStrings_QtCore[46647]
#define sipNameNr_aboutToQuit 46659
#define sipName_aboutToQuit &sipStrings_QtCore[46659]
#define sipNameNr_application 46671
#define sipName_application &sipStrings_QtCore[46671]
#define sipNameNr_showVersion 46683
#define sipName_showVersion &sipStrings_QtCore[46683]
#define sipNameNr_optionNames 46695
#define sipName_optionNames &sipStrings_QtCore[46695]
#define sipNameNr_description 46707
#define sipName_description &sipStrings_QtCore[46707]
#define sipNameNr_numericMode 46719
#define sipName_numericMode &sipStrings_QtCore[46719]
#define sipNameNr_isContainer 46731
#define sipName_isContainer &sipStrings_QtCore[46731]
#define sipNameNr_isUndefined 46743
#define sipName_isUndefined &sipStrings_QtCore[46743]
#define sipNameNr_isByteArray 46755
#define sipName_isByteArray &sipStrings_QtCore[46755]
#define sipNameNr_EndOfString 46767
#define sipName_EndOfString &sipStrings_QtCore[46767]
#define sipNameNr_MimeMessage 46779
#define sipName_MimeMessage &sipStrings_QtCore[46779]
#define sipNameNr_EncodedCbor 46791
#define sipName_EncodedCbor &sipStrings_QtCore[46791]
#define sipNameNr_IllegalType 46803
#define sipName_IllegalType &sipStrings_QtCore[46803]
#define sipNameNr_UnknownType 46815
#define sipName_UnknownType &sipStrings_QtCore[46815]
#define sipNameNr_weekDayName 46827
#define sipName_weekDayName &sipStrings_QtCore[46827]
#define sipNameNr_hasYearZero 46839
#define sipName_hasYearZero &sipStrings_QtCore[46839]
#define sipNameNr_isProleptic 46851
#define sipName_isProleptic &sipStrings_QtCore[46851]
#define sipNameNr_isLuniSolar 46863
#define sipName_isLuniSolar &sipStrings_QtCore[46863]
#define sipNameNr_isGregorian 46875
#define sipName_isGregorian &sipStrings_QtCore[46875]
#define sipNameNr_isDateValid 46887
#define sipName_isDateValid &sipStrings_QtCore[46887]
#define sipNameNr_daysInMonth 46899
#define sipName_daysInMonth &sipStrings_QtCore[46899]
#define sipNameNr_Unspecified 46911
#define sipName_Unspecified &sipStrings_QtCore[46911]
#define sipNameNr_qUncompress 46923
#define sipName_qUncompress &sipStrings_QtCore[46923]
#define sipNameNr_fromRawData 46935
#define sipName_fromRawData &sipStrings_QtCore[46935]
#define sipNameNr_toULongLong 46947
#define sipName_toULongLong &sipStrings_QtCore[46947]
#define sipNameNr_lastIndexOf 46959
#define sipName_lastIndexOf &sipStrings_QtCore[46959]
#define sipNameNr_canReadLine 46971
#define sipName_canReadLine &sipStrings_QtCore[46971]
#define sipNameNr___getitem__ 46983
#define sipName___getitem__ &sipStrings_QtCore[46983]
#define sipNameNr_QBasicTimer 46995
#define sipName_QBasicTimer &sipStrings_QtCore[46995]
#define sipNameNr_animationAt 47007
#define sipName_animationAt &sipStrings_QtCore[47007]
#define sipNameNr_targetState 47019
#define sipName_targetState &sipStrings_QtCore[47019]
#define sipNameNr_sourceState 47031
#define sipName_sourceState &sipStrings_QtCore[47031]
#define sipNameNr_parentState 47043
#define sipName_parentState &sipStrings_QtCore[47043]
#define sipNameNr_mapToSource 47055
#define sipName_mapToSource &sipStrings_QtCore[47055]
#define sipNameNr_sourceModel 47067
#define sipName_sourceModel &sipStrings_QtCore[47067]
#define sipNameNr_moveColumns 19866
#define sipName_moveColumns &sipStrings_QtCore[19866]
#define sipNameNr_endMoveRows 47079
#define sipName_endMoveRows &sipStrings_QtCore[47079]
#define sipNameNr_createIndex 47091
#define sipName_createIndex &sipStrings_QtCore[47091]
#define sipNameNr_rowsRemoved 47103
#define sipName_rowsRemoved &sipStrings_QtCore[47103]
#define sipNameNr_dataChanged 47115
#define sipName_dataChanged &sipStrings_QtCore[47115]
#define sipNameNr_bottomRight 47127
#define sipName_bottomRight &sipStrings_QtCore[47127]
#define sipNameNr_setItemData 47139
#define sipName_setItemData &sipStrings_QtCore[47139]
#define sipNameNr_hasChildren 47151
#define sipName_hasChildren &sipStrings_QtCore[47151]
#define sipNameNr_columnCount 47163
#define sipName_columnCount &sipStrings_QtCore[47163]
#define sipNameNr_QModelIndex 47175
#define sipName_QModelIndex &sipStrings_QtCore[47175]
#define sipNameNr_closingDown 47187
#define sipName_closingDown &sipStrings_QtCore[47187]
#define sipNameNr_updateState 47199
#define sipName_updateState &sipStrings_QtCore[47199]
#define sipNameNr_currentLoop 47211
#define sipName_currentLoop &sipStrings_QtCore[47211]
#define sipNameNr_currentTime 47223
#define sipName_currentTime &sipStrings_QtCore[47223]
#define sipNameNr_PassThrough 47235
#define sipName_PassThrough &sipStrings_QtCore[47235]
#define sipNameNr_ScrollBegin 47247
#define sipName_ScrollBegin &sipStrings_QtCore[47247]
#define sipNameNr_ScrollPhase 30066
#define sipName_ScrollPhase &sipStrings_QtCore[30066]
#define sipNameNr_GestureFlag 30098
#define sipName_GestureFlag &sipStrings_QtCore[30098]
#define sipNameNr_GestureType 12457
#define sipName_GestureType &sipStrings_QtCore[12457]
#define sipNameNr_AnchorRight 47259
#define sipName_AnchorRight &sipStrings_QtCore[47259]
#define sipNameNr_AnchorPoint 30178
#define sipName_AnchorPoint &sipStrings_QtCore[30178]
#define sipNameNr_StretchTile 47271
#define sipName_StretchTile &sipStrings_QtCore[47271]
#define sipNameNr_LeftSection 23274
#define sipName_LeftSection &sipStrings_QtCore[23274]
#define sipNameNr_MaximumSize 47283
#define sipName_MaximumSize &sipStrings_QtCore[47283]
#define sipNameNr_MinimumSize 47295
#define sipName_MinimumSize &sipStrings_QtCore[47295]
#define sipNameNr_MaskInColor 47307
#define sipName_MaskInColor &sipStrings_QtCore[47307]
#define sipNameNr_AA_Use96Dpi 47319
#define sipName_AA_Use96Dpi &sipStrings_QtCore[47319]
#define sipNameNr_WindowModal 47331
#define sipName_WindowModal &sipStrings_QtCore[47331]
#define sipNameNr_MatchRegExp 47343
#define sipName_MatchRegExp &sipStrings_QtCore[47343]
#define sipNameNr_NoItemFlags 47355
#define sipName_NoItemFlags &sipStrings_QtCore[47355]
#define sipNameNr_ToolTipRole 47367
#define sipName_ToolTipRole &sipStrings_QtCore[47367]
#define sipNameNr_DisplayRole 47379
#define sipName_DisplayRole &sipStrings_QtCore[47379]
#define sipNameNr_DropActions 14504
#define sipName_DropActions &sipStrings_QtCore[14504]
#define sipNameNr_RightToLeft 35312
#define sipName_RightToLeft &sipStrings_QtCore[35312]
#define sipNameNr_LeftToRight 47391
#define sipName_LeftToRight &sipStrings_QtCore[47391]
#define sipNameNr_FocusReason 9196
#define sipName_FocusReason &sipStrings_QtCore[9196]
#define sipNameNr_ReplaceClip 47403
#define sipName_ReplaceClip &sipStrings_QtCore[47403]
#define sipNameNr_WindingFill 47415
#define sipName_WindingFill &sipStrings_QtCore[47415]
#define sipNameNr_OddEvenFill 47427
#define sipName_OddEvenFill &sipStrings_QtCore[47427]
#define sipNameNr_RFC2822Date 47439
#define sipName_RFC2822Date &sipStrings_QtCore[47439]
#define sipNameNr_ToolBarArea 23598
#define sipName_ToolBarArea &sipStrings_QtCore[23598]
#define sipNameNr_CoarseTimer 30322
#define sipName_CoarseTimer &sipStrings_QtCore[30322]
#define sipNameNr_BlankCursor 47451
#define sipName_BlankCursor &sipStrings_QtCore[47451]
#define sipNameNr_IBeamCursor 47463
#define sipName_IBeamCursor &sipStrings_QtCore[47463]
#define sipNameNr_CrossCursor 47475
#define sipName_CrossCursor &sipStrings_QtCore[47475]
#define sipNameNr_ArrowCursor 38525
#define sipName_ArrowCursor &sipStrings_QtCore[38525]
#define sipNameNr_CursorShape 30418
#define sipName_CursorShape &sipStrings_QtCore[30418]
#define sipNameNr_UI_FadeMenu 47487
#define sipName_UI_FadeMenu &sipStrings_QtCore[47487]
#define sipNameNr_PenCapStyle 30450
#define sipName_PenCapStyle &sipStrings_QtCore[30450]
#define sipNameNr_DashDotLine 47499
#define sipName_DashDotLine &sipStrings_QtCore[47499]
#define sipNameNr_Key_MicMute 47511
#define sipName_Key_MicMute &sipStrings_QtCore[47511]
#define sipNameNr_Key_LaunchH 47523
#define sipName_Key_LaunchH &sipStrings_QtCore[47523]
#define sipNameNr_Key_LaunchG 47535
#define sipName_Key_LaunchG &sipStrings_QtCore[47535]
#define sipNameNr_Key_Suspend 47547
#define sipName_Key_Suspend &sipStrings_QtCore[47547]
#define sipNameNr_Key_TopMenu 47559
#define sipName_Key_TopMenu &sipStrings_QtCore[47559]
#define sipNameNr_Key_Battery 47571
#define sipName_Key_Battery &sipStrings_QtCore[47571]
#define sipNameNr_Key_ZoomOut 47583
#define sipName_Key_ZoomOut &sipStrings_QtCore[47583]
#define sipNameNr_Key_Support 47595
#define sipName_Key_Support &sipStrings_QtCore[47595]
#define sipNameNr_Key_MySites 47607
#define sipName_Key_MySites &sipStrings_QtCore[47607]
#define sipNameNr_Key_Meeting 47619
#define sipName_Key_Meeting &sipStrings_QtCore[47619]
#define sipNameNr_Key_Display 47631
#define sipName_Key_Display &sipStrings_QtCore[47631]
#define sipNameNr_Key_Finance 47643
#define sipName_Key_Finance &sipStrings_QtCore[47643]
#define sipNameNr_Key_History 47655
#define sipName_Key_History &sipStrings_QtCore[47655]
#define sipNameNr_Key_Printer 47667
#define sipName_Key_Printer &sipStrings_QtCore[47667]
#define sipNameNr_Key_Execute 47679
#define sipName_Key_Execute &sipStrings_QtCore[47679]
#define sipNameNr_Key_unknown 47691
#define sipName_Key_unknown &sipStrings_QtCore[47691]
#define sipNameNr_Key_LaunchF 47703
#define sipName_Key_LaunchF &sipStrings_QtCore[47703]
#define sipNameNr_Key_LaunchE 47715
#define sipName_Key_LaunchE &sipStrings_QtCore[47715]
#define sipNameNr_Key_LaunchD 47727
#define sipName_Key_LaunchD &sipStrings_QtCore[47727]
#define sipNameNr_Key_LaunchC 47739
#define sipName_Key_LaunchC &sipStrings_QtCore[47739]
#define sipNameNr_Key_LaunchB 47751
#define sipName_Key_LaunchB &sipStrings_QtCore[47751]
#define sipNameNr_Key_LaunchA 47763
#define sipName_Key_LaunchA &sipStrings_QtCore[47763]
#define sipNameNr_Key_Launch9 47775
#define sipName_Key_Launch9 &sipStrings_QtCore[47775]
#define sipNameNr_Key_Launch8 47787
#define sipName_Key_Launch8 &sipStrings_QtCore[47787]
#define sipNameNr_Key_Launch7 47799
#define sipName_Key_Launch7 &sipStrings_QtCore[47799]
#define sipNameNr_Key_Launch6 47811
#define sipName_Key_Launch6 &sipStrings_QtCore[47811]
#define sipNameNr_Key_Launch5 47823
#define sipName_Key_Launch5 &sipStrings_QtCore[47823]
#define sipNameNr_Key_Launch4 47835
#define sipName_Key_Launch4 &sipStrings_QtCore[47835]
#define sipNameNr_Key_Launch3 47847
#define sipName_Key_Launch3 &sipStrings_QtCore[47847]
#define sipNameNr_Key_Launch2 47859
#define sipName_Key_Launch2 &sipStrings_QtCore[47859]
#define sipNameNr_Key_Launch1 47871
#define sipName_Key_Launch1 &sipStrings_QtCore[47871]
#define sipNameNr_Key_Launch0 47883
#define sipName_Key_Launch0 &sipStrings_QtCore[47883]
#define sipNameNr_Key_OpenUrl 47895
#define sipName_Key_OpenUrl &sipStrings_QtCore[47895]
#define sipNameNr_Key_Standby 47907
#define sipName_Key_Standby &sipStrings_QtCore[47907]
#define sipNameNr_Key_Refresh 47919
#define sipName_Key_Refresh &sipStrings_QtCore[47919]
#define sipNameNr_Key_Forward 47931
#define sipName_Key_Forward &sipStrings_QtCore[47931]
#define sipNameNr_Key_Touroku 47943
#define sipName_Key_Touroku &sipStrings_QtCore[47943]
#define sipNameNr_Key_Hankaku 47955
#define sipName_Key_Hankaku &sipStrings_QtCore[47955]
#define sipNameNr_Key_Zenkaku 47967
#define sipName_Key_Zenkaku &sipStrings_QtCore[47967]
#define sipNameNr_Key_onehalf 47979
#define sipName_Key_onehalf &sipStrings_QtCore[47979]
#define sipNameNr_Key_cedilla 47991
#define sipName_Key_cedilla &sipStrings_QtCore[47991]
#define sipNameNr_Key_notsign 48003
#define sipName_Key_notsign &sipStrings_QtCore[48003]
#define sipNameNr_Key_section 48015
#define sipName_Key_section &sipStrings_QtCore[48015]
#define sipNameNr_Key_Greater 48027
#define sipName_Key_Greater &sipStrings_QtCore[48027]
#define sipNameNr_Key_Percent 48039
#define sipName_Key_Percent &sipStrings_QtCore[48039]
#define sipNameNr_Key_Hyper_R 48051
#define sipName_Key_Hyper_R &sipStrings_QtCore[48051]
#define sipNameNr_Key_Hyper_L 48063
#define sipName_Key_Hyper_L &sipStrings_QtCore[48063]
#define sipNameNr_Key_Super_R 48075
#define sipName_Key_Super_R &sipStrings_QtCore[48075]
#define sipNameNr_Key_Super_L 48087
#define sipName_Key_Super_L &sipStrings_QtCore[48087]
#define sipNameNr_Key_NumLock 48099
#define sipName_Key_NumLock &sipStrings_QtCore[48099]
#define sipNameNr_Key_Control 48111
#define sipName_Key_Control &sipStrings_QtCore[48111]
#define sipNameNr_Key_Backtab 48123
#define sipName_Key_Backtab &sipStrings_QtCore[48123]
#define sipNameNr_AvoidDither 48135
#define sipName_AvoidDither &sipStrings_QtCore[48135]
#define sipNameNr_WA_SetStyle 48147
#define sipName_WA_SetStyle &sipStrings_QtCore[48147]
#define sipNameNr_WA_Disabled 48159
#define sipName_WA_Disabled &sipStrings_QtCore[48159]
#define sipNameNr_WindowState 31058
#define sipName_WindowState &sipStrings_QtCore[31058]
#define sipNameNr_WindowFlags 31074
#define sipName_WindowFlags &sipStrings_QtCore[31074]
#define sipNameNr_CoverWindow 48171
#define sipName_CoverWindow &sipStrings_QtCore[48171]
#define sipNameNr_ElideMiddle 48183
#define sipName_ElideMiddle &sipStrings_QtCore[48183]
#define sipNameNr_AlignCenter 48195
#define sipName_AlignCenter &sipStrings_QtCore[48195]
#define sipNameNr_AlignBottom 48207
#define sipName_AlignBottom &sipStrings_QtCore[48207]
#define sipNameNr_StrongFocus 48219
#define sipName_StrongFocus &sipStrings_QtCore[48219]
#define sipNameNr_FocusPolicy 31138
#define sipName_FocusPolicy &sipStrings_QtCore[31138]
#define sipNameNr_Orientation 3628
#define sipName_Orientation &sipStrings_QtCore[3628]
#define sipNameNr_RightButton 48231
#define sipName_RightButton &sipStrings_QtCore[48231]
#define sipNameNr_MouseButton 31170
#define sipName_MouseButton &sipStrings_QtCore[31170]
#define sipNameNr_AltModifier 48243
#define sipName_AltModifier &sipStrings_QtCore[48243]
#define sipNameNr_transparent 48255
#define sipName_transparent &sipStrings_QtCore[48255]
#define sipNameNr_darkMagenta 48267
#define sipName_darkMagenta &sipStrings_QtCore[48267]
#define sipNameNr_GlobalColor 31202
#define sipName_GlobalColor &sipStrings_QtCore[31202]
#define sipNameNr_48279 48279
#define sipName_48279 &sipStrings_QtCore[48279]
#define sipNameNr_kernelType 48290
#define sipName_kernelType &sipStrings_QtCore[48290]
#define sipNameNr_writeCDATA 48301
#define sipName_writeCDATA &sipStrings_QtCore[48301]
#define sipNameNr_raiseError 48312
#define sipName_raiseError &sipStrings_QtCore[48312]
#define sipNameNr_attributes 48323
#define sipName_attributes &sipStrings_QtCore[48323]
#define sipNameNr_lineNumber 48334
#define sipName_lineNumber &sipStrings_QtCore[48334]
#define sipNameNr_Characters 27667
#define sipName_Characters &sipStrings_QtCore[27667]
#define sipNameNr_EndElement 27651
#define sipName_EndElement &sipStrings_QtCore[27651]
#define sipNameNr_isPrefixOf 48345
#define sipName_isPrefixOf &sipStrings_QtCore[48345]
#define sipNameNr_keyValueAt 48356
#define sipName_keyValueAt &sipStrings_QtCore[48356]
#define sipNameNr_startValue 48367
#define sipName_startValue &sipStrings_QtCore[48367]
#define sipNameNr_nameToType 48378
#define sipName_nameToType &sipStrings_QtCore[48378]
#define sipNameNr_typeToName 48389
#define sipName_typeToName &sipStrings_QtCore[48389]
#define sipNameNr_canConvert 48400
#define sipName_canConvert &sipStrings_QtCore[48400]
#define sipNameNr_ModelIndex 12436
#define sipName_ModelIndex &sipStrings_QtCore[12436]
#define sipNameNr_Quaternion 45172
#define sipName_Quaternion &sipStrings_QtCore[45172]
#define sipNameNr_TextLength 17268
#define sipName_TextLength &sipStrings_QtCore[17268]
#define sipNameNr_SizePolicy 9317
#define sipName_SizePolicy &sipStrings_QtCore[9317]
#define sipNameNr_StringList 25939
#define sipName_StringList &sipStrings_QtCore[25939]
#define sipNameNr_createUuid 48411
#define sipName_createUuid &sipStrings_QtCore[48411]
#define sipNameNr_WithBraces 48422
#define sipName_WithBraces &sipStrings_QtCore[48422]
#define sipNameNr_VerUnknown 48433
#define sipName_VerUnknown &sipStrings_QtCore[48433]
#define sipNameNr_VarUnknown 48444
#define sipName_VarUnknown &sipStrings_QtCore[48444]
#define sipNameNr_queryItems 48455
#define sipName_queryItems &sipStrings_QtCore[48455]
#define sipNameNr_isParentOf 48466
#define sipName_isParentOf &sipStrings_QtCore[48466]
#define sipNameNr_RemovePath 48477
#define sipName_RemovePath &sipStrings_QtCore[48477]
#define sipNameNr_RemovePort 48488
#define sipName_RemovePort &sipStrings_QtCore[48488]
#define sipNameNr_StrictMode 48499
#define sipName_StrictMode &sipStrings_QtCore[48499]
#define sipNameNr_offsetData 48510
#define sipName_offsetData &sipStrings_QtCore[48510]
#define sipNameNr_OffsetData 11248
#define sipName_OffsetData &sipStrings_QtCore[11248]
#define sipNameNr_OffsetName 48521
#define sipName_OffsetName &sipStrings_QtCore[48521]
#define sipNameNr_singleShot 48532
#define sipName_singleShot &sipStrings_QtCore[48532]
#define sipNameNr_curveShape 48543
#define sipName_curveShape &sipStrings_QtCore[48543]
#define sipNameNr_startFrame 48554
#define sipName_startFrame &sipStrings_QtCore[48554]
#define sipNameNr_CurveShape 11270
#define sipName_CurveShape &sipStrings_QtCore[11270]
#define sipNameNr_isFinished 48565
#define sipName_isFinished &sipStrings_QtCore[48565]
#define sipNameNr_scientific 48576
#define sipName_scientific &sipStrings_QtCore[48576]
#define sipNameNr_noshowbase 48587
#define sipName_noshowbase &sipStrings_QtCore[48587]
#define sipNameNr_forcepoint 40124
#define sipName_forcepoint &sipStrings_QtCore[40124]
#define sipNameNr_fieldWidth 48598
#define sipName_fieldWidth &sipStrings_QtCore[48598]
#define sipNameNr_setPadChar 48609
#define sipName_setPadChar &sipStrings_QtCore[48609]
#define sipNameNr_ForcePoint 48620
#define sipName_ForcePoint &sipStrings_QtCore[48620]
#define sipNameNr_NumberFlag 8261
#define sipName_NumberFlag &sipStrings_QtCore[8261]
#define sipNameNr_QTextCodec 48631
#define sipName_QTextCodec &sipStrings_QtCore[48631]
#define sipNameNr_SoftHyphen 48642
#define sipName_SoftHyphen &sipStrings_QtCore[48642]
#define sipNameNr_autoRemove 48653
#define sipName_autoRemove &sipStrings_QtCore[48653]
#define sipNameNr_stringList 48664
#define sipName_stringList &sipStrings_QtCore[48664]
#define sipNameNr_QStringRef 48675
#define sipName_QStringRef &sipStrings_QtCore[48675]
#define sipNameNr_isReadOnly 48686
#define sipName_isReadOnly &sipStrings_QtCore[48686]
#define sipNameNr_bytesTotal 48697
#define sipName_bytesTotal &sipStrings_QtCore[48697]
#define sipNameNr_setRunning 48708
#define sipName_setRunning &sipStrings_QtCore[48708]
#define sipNameNr_isAnimated 48719
#define sipName_isAnimated &sipStrings_QtCore[48719]
#define sipNameNr_clearError 48730
#define sipName_clearError &sipStrings_QtCore[48730]
#define sipNameNr_errorState 48741
#define sipName_errorState &sipStrings_QtCore[48741]
#define sipNameNr_LocateFile 48752
#define sipName_LocateFile &sipStrings_QtCore[48752]
#define sipNameNr_filterRole 48763
#define sipName_filterRole &sipStrings_QtCore[48763]
#define sipNameNr_sortColumn 48774
#define sipName_sortColumn &sipStrings_QtCore[48774]
#define sipNameNr_expandedTo 48785
#define sipName_expandedTo &sipStrings_QtCore[48785]
#define sipNameNr_setMapping 48796
#define sipName_setMapping &sipStrings_QtCore[48796]
#define sipNameNr_isAttached 48807
#define sipName_isAttached &sipStrings_QtCore[48807]
#define sipNameNr_AccessMode 3252
#define sipName_AccessMode &sipStrings_QtCore[3252]
#define sipNameNr_beginGroup 48818
#define sipName_beginGroup &sipStrings_QtCore[48818]
#define sipNameNr_tryAcquire 48829
#define sipName_tryAcquire &sipStrings_QtCore[48829]
#define sipNameNr_QSemaphore 48840
#define sipName_QSemaphore &sipStrings_QtCore[48840]
#define sipNameNr_autoDelete 48851
#define sipName_autoDelete &sipStrings_QtCore[48851]
#define sipNameNr_exactMatch 48862
#define sipName_exactMatch &sipStrings_QtCore[48862]
#define sipNameNr_setMinimal 48873
#define sipName_setMinimal &sipStrings_QtCore[48873]
#define sipNameNr_moveBottom 48884
#define sipName_moveBottom &sipStrings_QtCore[48884]
#define sipNameNr_bottomLeft 48895
#define sipName_bottomLeft &sipStrings_QtCore[48895]
#define sipNameNr_setTopLeft 48906
#define sipName_setTopLeft &sipStrings_QtCore[48906]
#define sipNameNr_moveCenter 48917
#define sipName_moveCenter &sipStrings_QtCore[48917]
#define sipNameNr_normalized 48928
#define sipName_normalized &sipStrings_QtCore[48928]
#define sipNameNr_generate64 48939
#define sipName_generate64 &sipStrings_QtCore[48939]
#define sipNameNr_nullDevice 48950
#define sipName_nullDevice &sipStrings_QtCore[48950]
#define sipNameNr_setProgram 48961
#define sipName_setProgram &sipStrings_QtCore[48961]
#define sipNameNr_exitStatus 48972
#define sipName_exitStatus &sipStrings_QtCore[48972]
#define sipNameNr_NotRunning 48983
#define sipName_NotRunning &sipStrings_QtCore[48983]
#define sipNameNr_NormalExit 48994
#define sipName_NormalExit &sipStrings_QtCore[48994]
#define sipNameNr_ExitStatus 13749
#define sipName_ExitStatus &sipStrings_QtCore[13749]
#define sipNameNr_transposed 49005
#define sipName_transposed &sipStrings_QtCore[49005]
#define sipNameNr_dotProduct 49016
#define sipName_dotProduct &sipStrings_QtCore[49016]
#define sipNameNr_Windows8_1 49027
#define sipName_Windows8_1 &sipStrings_QtCore[49027]
#define sipNameNr_Connection 7746
#define sipName_Connection &sipStrings_QtCore[7746]
#define sipNameNr_superClass 49038
#define sipName_superClass &sipStrings_QtCore[49038]
#define sipNameNr_QT_TR_NOOP 49049
#define sipName_QT_TR_NOOP &sipStrings_QtCore[49049]
#define sipNameNr_disconnect 49060
#define sipName_disconnect &sipStrings_QtCore[49060]
#define sipNameNr_childEvent 49071
#define sipName_childEvent &sipStrings_QtCore[49071]
#define sipNameNr_timerEvent 49082
#define sipName_timerEvent &sipStrings_QtCore[49082]
#define sipNameNr_startTimer 49093
#define sipName_startTimer &sipStrings_QtCore[49093]
#define sipNameNr_objectName 49104
#define sipName_objectName &sipStrings_QtCore[49104]
#define sipNameNr_metaObject 49115
#define sipName_metaObject &sipStrings_QtCore[49115]
#define sipNameNr_QCborArray 49126
#define sipName_QCborArray &sipStrings_QtCore[49126]
#define sipNameNr_QCborValue 49137
#define sipName_QCborValue &sipStrings_QtCore[49137]
#define sipNameNr_QJsonArray 49148
#define sipName_QJsonArray &sipStrings_QtCore[49148]
#define sipNameNr_QMatrix4x4 49159
#define sipName_QMatrix4x4 &sipStrings_QtCore[49159]
#define sipNameNr_QTransform 49170
#define sipName_QTransform &sipStrings_QtCore[49170]
#define sipNameNr_isRequired 49181
#define sipName_isRequired &sipStrings_QtCore[49181]
#define sipNameNr_isConstant 49192
#define sipName_isConstant &sipStrings_QtCore[49192]
#define sipNameNr_enumerator 49203
#define sipName_enumerator &sipStrings_QtCore[49203]
#define sipNameNr_isEnumType 49214
#define sipName_isEnumType &sipStrings_QtCore[49214]
#define sipNameNr_isFlagType 49225
#define sipName_isFlagType &sipStrings_QtCore[49225]
#define sipNameNr_valueToKey 49236
#define sipName_valueToKey &sipStrings_QtCore[49236]
#define sipNameNr_keyToValue 49247
#define sipName_keyToValue &sipStrings_QtCore[49247]
#define sipNameNr_returnType 49258
#define sipName_returnType &sipStrings_QtCore[49258]
#define sipNameNr_methodType 49269
#define sipName_methodType &sipStrings_QtCore[49269]
#define sipNameNr_MethodType 8477
#define sipName_MethodType &sipStrings_QtCore[8477]
#define sipNameNr_setEnabled 49280
#define sipName_setEnabled &sipStrings_QtCore[49280]
#define sipNameNr_QtFatalMsg 49291
#define sipName_QtFatalMsg &sipStrings_QtCore[49291]
#define sipNameNr_QtDebugMsg 49302
#define sipName_QtDebugMsg &sipStrings_QtCore[49302]
#define sipNameNr_JamoScript 49313
#define sipName_JamoScript &sipStrings_QtCore[49313]
#define sipNameNr_NewaScript 49324
#define sipName_NewaScript &sipStrings_QtCore[49324]
#define sipNameNr_AhomScript 49335
#define sipName_AhomScript &sipStrings_QtCore[49335]
#define sipNameNr_ModiScript 49346
#define sipName_ModiScript &sipStrings_QtCore[49346]
#define sipNameNr_ChamScript 49357
#define sipName_ChamScript &sipStrings_QtCore[49357]
#define sipNameNr_ThaiScript 49368
#define sipName_ThaiScript &sipStrings_QtCore[49368]
#define sipNameNr_toDateTime 49379
#define sipName_toDateTime &sipStrings_QtCore[49379]
#define sipNameNr_timeFormat 49390
#define sipName_timeFormat &sipStrings_QtCore[49390]
#define sipNameNr_dateFormat 49401
#define sipName_dateFormat &sipStrings_QtCore[49401]
#define sipNameNr_LongFormat 49412
#define sipName_LongFormat &sipStrings_QtCore[49412]
#define sipNameNr_FormatType 16128
#define sipName_FormatType &sipStrings_QtCore[16128]
#define sipNameNr_setDefault 49423
#define sipName_setDefault &sipStrings_QtCore[49423]
#define sipNameNr_SouthSudan 49434
#define sipName_SouthSudan &sipStrings_QtCore[49434]
#define sipNameNr_SaintLucia 49445
#define sipName_SaintLucia &sipStrings_QtCore[49445]
#define sipNameNr_SouthKorea 49456
#define sipName_SouthKorea &sipStrings_QtCore[49456]
#define sipNameNr_NorthKorea 49467
#define sipName_NorthKorea &sipStrings_QtCore[49467]
#define sipNameNr_Montenegro 49478
#define sipName_Montenegro &sipStrings_QtCore[49478]
#define sipNameNr_Uzbekistan 49489
#define sipName_Uzbekistan &sipStrings_QtCore[49489]
#define sipNameNr_Tajikistan 49500
#define sipName_Tajikistan &sipStrings_QtCore[49500]
#define sipNameNr_Seychelles 49511
#define sipName_Seychelles &sipStrings_QtCore[49511]
#define sipNameNr_PuertoRico 49522
#define sipName_PuertoRico &sipStrings_QtCore[49522]
#define sipNameNr_NewZealand 49533
#define sipName_NewZealand &sipStrings_QtCore[49533]
#define sipNameNr_Mozambique 49544
#define sipName_Mozambique &sipStrings_QtCore[49544]
#define sipNameNr_Montserrat 49555
#define sipName_Montserrat &sipStrings_QtCore[49555]
#define sipNameNr_Micronesia 49566
#define sipName_Micronesia &sipStrings_QtCore[49566]
#define sipNameNr_Mauritania 49577
#define sipName_Mauritania &sipStrings_QtCore[49577]
#define sipNameNr_Martinique 49588
#define sipName_Martinique &sipStrings_QtCore[49588]
#define sipNameNr_Madagascar 49599
#define sipName_Madagascar &sipStrings_QtCore[49599]
#define sipNameNr_Luxembourg 49610
#define sipName_Luxembourg &sipStrings_QtCore[49610]
#define sipNameNr_Kyrgyzstan 49621
#define sipName_Kyrgyzstan &sipStrings_QtCore[49621]
#define sipNameNr_Kazakhstan 49632
#define sipName_Kazakhstan &sipStrings_QtCore[49632]
#define sipNameNr_Guadeloupe 49643
#define sipName_Guadeloupe &sipStrings_QtCore[49643]
#define sipNameNr_ElSalvador 49654
#define sipName_ElSalvador &sipStrings_QtCore[49654]
#define sipNameNr_IvoryCoast 49665
#define sipName_IvoryCoast &sipStrings_QtCore[49665]
#define sipNameNr_Bangladesh 49676
#define sipName_Bangladesh &sipStrings_QtCore[49676]
#define sipNameNr_Azerbaijan 49687
#define sipName_Azerbaijan &sipStrings_QtCore[49687]
#define sipNameNr_Antarctica 49698
#define sipName_Antarctica &sipStrings_QtCore[49698]
#define sipNameNr_AnyCountry 49709
#define sipName_AnyCountry &sipStrings_QtCore[49709]
#define sipNameNr_Papiamento 49720
#define sipName_Papiamento &sipStrings_QtCore[49720]
#define sipNameNr_Saurashtra 49731
#define sipName_Saurashtra &sipStrings_QtCore[49731]
#define sipNameNr_Phoenician 49742
#define sipName_Phoenician &sipStrings_QtCore[49742]
#define sipNameNr_OldTurkish 49753
#define sipName_OldTurkish &sipStrings_QtCore[49753]
#define sipNameNr_OldPersian 49764
#define sipName_OldPersian &sipStrings_QtCore[49764]
#define sipNameNr_Limburgish 49775
#define sipName_Limburgish &sipStrings_QtCore[49775]
#define sipNameNr_Belarusian 49786
#define sipName_Belarusian &sipStrings_QtCore[49786]
#define sipNameNr_Vietnamese 49797
#define sipName_Vietnamese &sipStrings_QtCore[49797]
#define sipNameNr_Portuguese 49808
#define sipName_Portuguese &sipStrings_QtCore[49808]
#define sipNameNr_Macedonian 49819
#define sipName_Macedonian &sipStrings_QtCore[49819]
#define sipNameNr_Lithuanian 49830
#define sipName_Lithuanian &sipStrings_QtCore[49830]
#define sipNameNr_Indonesian 49841
#define sipName_Indonesian &sipStrings_QtCore[49841]
#define sipNameNr_unitVector 49852
#define sipName_unitVector &sipStrings_QtCore[49852]
#define sipNameNr_translated 49863
#define sipName_translated &sipStrings_QtCore[49863]
#define sipNameNr_PrefixPath 49874
#define sipName_PrefixPath &sipStrings_QtCore[49874]
#define sipNameNr_QJsonValue 49885
#define sipName_QJsonValue &sipStrings_QtCore[49885]
#define sipNameNr_JsonFormat 6198
#define sipName_JsonFormat &sipStrings_QtCore[6198]
#define sipNameNr_validation 49896
#define sipName_validation &sipStrings_QtCore[49896]
#define sipNameNr_ParseError 4338
#define sipName_ParseError &sipStrings_QtCore[4338]
#define sipNameNr_isSelected 49907
#define sipName_isSelected &sipStrings_QtCore[49907]
#define sipNameNr_intersects 49918
#define sipName_intersects &sipStrings_QtCore[49918]
#define sipNameNr_Unbuffered 49929
#define sipName_Unbuffered &sipStrings_QtCore[49929]
#define sipNameNr_removePath 49940
#define sipName_removePath &sipStrings_QtCore[49940]
#define sipNameNr_isJunction 49951
#define sipName_isJunction &sipStrings_QtCore[49951]
#define sipNameNr_isShortcut 49962
#define sipName_isShortcut &sipStrings_QtCore[49962]
#define sipNameNr_bundleName 49973
#define sipName_bundleName &sipStrings_QtCore[49973]
#define sipNameNr_setCaching 49984
#define sipName_setCaching &sipStrings_QtCore[49984]
#define sipNameNr_permission 49995
#define sipName_permission &sipStrings_QtCore[49995]
#define sipNameNr_isWritable 50006
#define sipName_isWritable &sipStrings_QtCore[50006]
#define sipNameNr___fspath__ 50017
#define sipName___fspath__ &sipStrings_QtCore[50017]
#define sipNameNr_unsetError 50028
#define sipName_unsetError &sipStrings_QtCore[50028]
#define sipNameNr_WriteOther 50039
#define sipName_WriteOther &sipStrings_QtCore[50039]
#define sipNameNr_WriteGroup 50050
#define sipName_WriteGroup &sipStrings_QtCore[50050]
#define sipNameNr_WriteOwner 50061
#define sipName_WriteOwner &sipStrings_QtCore[50061]
#define sipNameNr_Permission 8693
#define sipName_Permission &sipStrings_QtCore[8693]
#define sipNameNr_AbortError 50072
#define sipName_AbortError &sipStrings_QtCore[50072]
#define sipNameNr_FatalError 50083
#define sipName_FatalError &sipStrings_QtCore[50083]
#define sipNameNr_WriteError 50094
#define sipName_WriteError &sipStrings_QtCore[50094]
#define sipNameNr_decodeName 50105
#define sipName_decodeName &sipStrings_QtCore[50105]
#define sipNameNr_encodeName 50116
#define sipName_encodeName &sipStrings_QtCore[50116]
#define sipNameNr_QEventLoop 50127
#define sipName_QEventLoop &sipStrings_QtCore[50127]
#define sipNameNr_invalidate 50138
#define sipName_invalidate &sipStrings_QtCore[50138]
#define sipNameNr_SystemTime 50149
#define sipName_SystemTime &sipStrings_QtCore[50149]
#define sipNameNr_customType 50160
#define sipName_customType &sipStrings_QtCore[50160]
#define sipNameNr_OutElastic 42152
#define sipName_OutElastic &sipStrings_QtCore[42152]
#define sipNameNr_OutInQuint 50171
#define sipName_OutInQuint &sipStrings_QtCore[50171]
#define sipNameNr_InOutQuint 50182
#define sipName_InOutQuint &sipStrings_QtCore[50182]
#define sipNameNr_OutInQuart 50193
#define sipName_OutInQuart &sipStrings_QtCore[50193]
#define sipNameNr_InOutQuart 50204
#define sipName_InOutQuart &sipStrings_QtCore[50204]
#define sipNameNr_OutInCubic 50215
#define sipName_OutInCubic &sipStrings_QtCore[50215]
#define sipNameNr_InOutCubic 50226
#define sipName_InOutCubic &sipStrings_QtCore[50226]
#define sipNameNr_setCurrent 50237
#define sipName_setCurrent &sipStrings_QtCore[50237]
#define sipNameNr_isAbsolute 50248
#define sipName_isAbsolute &sipStrings_QtCore[50248]
#define sipNameNr_isRelative 50259
#define sipName_isRelative &sipStrings_QtCore[50259]
#define sipNameNr_isReadable 50270
#define sipName_isReadable &sipStrings_QtCore[50270]
#define sipNameNr_setSorting 50281
#define sipName_setSorting &sipStrings_QtCore[50281]
#define sipNameNr_IgnoreCase 50292
#define sipName_IgnoreCase &sipStrings_QtCore[50292]
#define sipNameNr_SortByMask 50303
#define sipName_SortByMask &sipStrings_QtCore[50303]
#define sipNameNr_AccessMask 50314
#define sipName_AccessMask &sipStrings_QtCore[50314]
#define sipNameNr_Executable 31923
#define sipName_Executable &sipStrings_QtCore[31923]
#define sipNameNr_AllEntries 50325
#define sipName_AllEntries &sipStrings_QtCore[50325]
#define sipNameNr_NoSymLinks 50336
#define sipName_NoSymLinks &sipStrings_QtCore[50336]
#define sipNameNr_hasExpired 50347
#define sipName_hasExpired &sipStrings_QtCore[50347]
#define sipNameNr_toTimeZone 50358
#define sipName_toTimeZone &sipStrings_QtCore[50358]
#define sipNameNr_fromTime_t 50369
#define sipName_fromTime_t &sipStrings_QtCore[50369]
#define sipNameNr_toTimeSpec 50380
#define sipName_toTimeSpec &sipStrings_QtCore[50380]
#define sipNameNr_startOfDay 50391
#define sipName_startOfDay &sipStrings_QtCore[50391]
#define sipNameNr_fromString 50402
#define sipName_fromString &sipStrings_QtCore[50402]
#define sipNameNr_weekNumber 50413
#define sipName_weekNumber &sipStrings_QtCore[50413]
#define sipNameNr_yearNumber 50424
#define sipName_yearNumber &sipStrings_QtCore[50424]
#define sipNameNr_writeBytes 50435
#define sipName_writeBytes &sipStrings_QtCore[50435]
#define sipNameNr_writeFloat 50446
#define sipName_writeFloat &sipStrings_QtCore[50446]
#define sipNameNr_writeInt64 50457
#define sipName_writeInt64 &sipStrings_QtCore[50457]
#define sipNameNr_writeInt32 50468
#define sipName_writeInt32 &sipStrings_QtCore[50468]
#define sipNameNr_writeInt16 50479
#define sipName_writeInt16 &sipStrings_QtCore[50479]
#define sipNameNr_writeUInt8 50490
#define sipName_writeUInt8 &sipStrings_QtCore[50490]
#define sipNameNr_readDouble 50501
#define sipName_readDouble &sipStrings_QtCore[50501]
#define sipNameNr_readUInt64 50512
#define sipName_readUInt64 &sipStrings_QtCore[50512]
#define sipNameNr_readUInt32 50523
#define sipName_readUInt32 &sipStrings_QtCore[50523]
#define sipNameNr_readUInt16 50534
#define sipName_readUInt16 &sipStrings_QtCore[50534]
#define sipNameNr_setVersion 50545
#define sipName_setVersion &sipStrings_QtCore[50545]
#define sipNameNr_hashLength 50556
#define sipName_hashLength &sipStrings_QtCore[50556]
#define sipNameNr_Keccak_512 50567
#define sipName_Keccak_512 &sipStrings_QtCore[50567]
#define sipNameNr_Keccak_384 50578
#define sipName_Keccak_384 &sipStrings_QtCore[50578]
#define sipNameNr_Keccak_256 50589
#define sipName_Keccak_256 &sipStrings_QtCore[50589]
#define sipNameNr_Keccak_224 50600
#define sipName_Keccak_224 &sipStrings_QtCore[50600]
#define sipNameNr_isAccepted 50611
#define sipName_isAccepted &sipStrings_QtCore[50611]
#define sipNameNr_TouchBegin 50622
#define sipName_TouchBegin &sipStrings_QtCore[50622]
#define sipNameNr_HoverLeave 8765
#define sipName_HoverLeave &sipStrings_QtCore[8765]
#define sipNameNr_HoverEnter 8789
#define sipName_HoverEnter &sipStrings_QtCore[8789]
#define sipNameNr_FontChange 12260
#define sipName_FontChange &sipStrings_QtCore[12260]
#define sipNameNr_TabletMove 50633
#define sipName_TabletMove &sipStrings_QtCore[50633]
#define sipNameNr_ChildAdded 50644
#define sipName_ChildAdded &sipStrings_QtCore[50644]
#define sipNameNr_KeyRelease 50655
#define sipName_KeyRelease &sipStrings_QtCore[50655]
#define sipNameNr_returnCode 50666
#define sipName_returnCode &sipStrings_QtCore[50666]
#define sipNameNr_addOptions 50677
#define sipName_addOptions &sipStrings_QtCore[50677]
#define sipNameNr_readString 50688
#define sipName_readString &sipStrings_QtCore[50688]
#define sipNameNr_SimpleType 22969
#define sipName_SimpleType &sipStrings_QtCore[22969]
#define sipNameNr_TextString 50699
#define sipName_TextString &sipStrings_QtCore[50699]
#define sipNameNr_ByteString 50710
#define sipName_ByteString &sipStrings_QtCore[50710]
#define sipNameNr_startArray 50721
#define sipName_startArray &sipStrings_QtCore[50721]
#define sipNameNr_appendNull 50732
#define sipName_appendNull &sipStrings_QtCore[50732]
#define sipNameNr_COSE_Sign1 50743
#define sipName_COSE_Sign1 &sipStrings_QtCore[50743]
#define sipNameNr_UnixTime_t 50754
#define sipName_UnixTime_t &sipStrings_QtCore[50754]
#define sipNameNr_QCborError 50765
#define sipName_QCborError &sipStrings_QtCore[50765]
#define sipNameNr_isLeapYear 50776
#define sipName_isLeapYear &sipStrings_QtCore[50776]
#define sipNameNr_daysInYear 50787
#define sipName_daysInYear &sipStrings_QtCore[50787]
#define sipNameNr_Milankovic 50798
#define sipName_Milankovic &sipStrings_QtCore[50798]
#define sipNameNr_setPattern 50809
#define sipName_setPattern &sipStrings_QtCore[50809]
#define sipNameNr_push_front 50820
#define sipName_push_front &sipStrings_QtCore[50820]
#define sipNameNr_fromBase64 50831
#define sipName_fromBase64 &sipStrings_QtCore[50831]
#define sipNameNr_toLongLong 50842
#define sipName_toLongLong &sipStrings_QtCore[50842]
#define sipNameNr_simplified 50853
#define sipName_simplified &sipStrings_QtCore[50853]
#define sipNameNr_startsWith 50864
#define sipName_startsWith &sipStrings_QtCore[50864]
#define sipNameNr_QByteArray 50875
#define sipName_QByteArray &sipStrings_QtCore[50875]
#define sipNameNr___rshift__ 50886
#define sipName___rshift__ &sipStrings_QtCore[50886]
#define sipNameNr___lshift__ 50897
#define sipName___lshift__ &sipStrings_QtCore[50897]
#define sipNameNr_isDetached 50908
#define sipName_isDetached &sipStrings_QtCore[50908]
#define sipNameNr_animations 50919
#define sipName_animations &sipStrings_QtCore[50919]
#define sipNameNr_checkIndex 50930
#define sipName_checkIndex &sipStrings_QtCore[50930]
#define sipNameNr_moveColumn 42724
#define sipName_moveColumn &sipStrings_QtCore[42724]
#define sipNameNr_decodeData 50941
#define sipName_decodeData &sipStrings_QtCore[50941]
#define sipNameNr_encodeData 50952
#define sipName_encodeData &sipStrings_QtCore[50952]
#define sipNameNr_modelReset 50963
#define sipName_modelReset &sipStrings_QtCore[50963]
#define sipNameNr_removeRows 50974
#define sipName_removeRows &sipStrings_QtCore[50974]
#define sipNameNr_insertRows 50985
#define sipName_insertRows &sipStrings_QtCore[50985]
#define sipNameNr_headerData 50996
#define sipName_headerData &sipStrings_QtCore[50996]
#define sipNameNr_internalId 51007
#define sipName_internalId &sipStrings_QtCore[51007]
#define sipNameNr_startingUp 51018
#define sipName_startingUp &sipStrings_QtCore[51018]
#define sipNameNr_EnterKeyGo 51029
#define sipName_EnterKeyGo &sipStrings_QtCore[51029]
#define sipNameNr_NoTabFocus 51040
#define sipName_NoTabFocus &sipStrings_QtCore[51040]
#define sipNameNr_BottomEdge 51051
#define sipName_BottomEdge &sipStrings_QtCore[51051]
#define sipNameNr_PanGesture 51062
#define sipName_PanGesture &sipStrings_QtCore[51062]
#define sipNameNr_TapGesture 51073
#define sipName_TapGesture &sipStrings_QtCore[51073]
#define sipNameNr_AnchorLeft 51084
#define sipName_AnchorLeft &sipStrings_QtCore[51084]
#define sipNameNr_RepeatTile 51095
#define sipName_RepeatTile &sipStrings_QtCore[51095]
#define sipNameNr_TopSection 51106
#define sipName_TopSection &sipStrings_QtCore[51106]
#define sipNameNr_MatchFlags 34248
#define sipName_MatchFlags &sipStrings_QtCore[34248]
#define sipNameNr_CheckState 34368
#define sipName_CheckState &sipStrings_QtCore[34368]
#define sipNameNr_ActionMask 51117
#define sipName_ActionMask &sipStrings_QtCore[51117]
#define sipNameNr_LinkAction 51128
#define sipName_LinkAction &sipStrings_QtCore[51128]
#define sipNameNr_MoveAction 26840
#define sipName_MoveAction &sipStrings_QtCore[26840]
#define sipNameNr_CopyAction 51139
#define sipName_CopyAction &sipStrings_QtCore[51139]
#define sipNameNr_DropAction 34383
#define sipName_DropAction &sipStrings_QtCore[34383]
#define sipNameNr_ImQueryAll 51150
#define sipName_ImQueryAll &sipStrings_QtCore[51150]
#define sipNameNr_Qt__Corner 51161
#define sipName_Qt__Corner &sipStrings_QtCore[51161]
#define sipNameNr_LocaleDate 26993
#define sipName_LocaleDate &sipStrings_QtCore[26993]
#define sipNameNr_DateFormat 34503
#define sipName_DateFormat &sipStrings_QtCore[34503]
#define sipNameNr_TextFormat 34533
#define sipName_TextFormat &sipStrings_QtCore[34533]
#define sipNameNr_LastCursor 51172
#define sipName_LastCursor &sipStrings_QtCore[51172]
#define sipNameNr_BusyCursor 51183
#define sipName_BusyCursor &sipStrings_QtCore[51183]
#define sipNameNr_WaitCursor 51194
#define sipName_WaitCursor &sipStrings_QtCore[51194]
#define sipNameNr_UI_General 51205
#define sipName_UI_General &sipStrings_QtCore[51205]
#define sipNameNr_VerPattern 51216
#define sipName_VerPattern &sipStrings_QtCore[51216]
#define sipNameNr_HorPattern 51227
#define sipName_HorPattern &sipStrings_QtCore[51227]
#define sipNameNr_BrushStyle 34653
#define sipName_BrushStyle &sipStrings_QtCore[34653]
#define sipNameNr_RightArrow 51238
#define sipName_RightArrow &sipStrings_QtCore[51238]
#define sipNameNr_Key_Dead_U 51249
#define sipName_Key_Dead_U &sipStrings_QtCore[51249]
#define sipNameNr_Key_Dead_u 51260
#define sipName_Key_Dead_u &sipStrings_QtCore[51260]
#define sipNameNr_Key_Dead_O 51271
#define sipName_Key_Dead_O &sipStrings_QtCore[51271]
#define sipNameNr_Key_Dead_o 51282
#define sipName_Key_Dead_o &sipStrings_QtCore[51282]
#define sipNameNr_Key_Dead_I 51293
#define sipName_Key_Dead_I &sipStrings_QtCore[51293]
#define sipNameNr_Key_Dead_i 51304
#define sipName_Key_Dead_i &sipStrings_QtCore[51304]
#define sipNameNr_Key_Dead_E 51315
#define sipName_Key_Dead_E &sipStrings_QtCore[51315]
#define sipNameNr_Key_Dead_e 51326
#define sipName_Key_Dead_e &sipStrings_QtCore[51326]
#define sipNameNr_Key_Dead_A 51337
#define sipName_Key_Dead_A &sipStrings_QtCore[51337]
#define sipNameNr_Key_Dead_a 51348
#define sipName_Key_Dead_a &sipStrings_QtCore[51348]
#define sipNameNr_Key_Yellow 51359
#define sipName_Key_Yellow &sipStrings_QtCore[51359]
#define sipNameNr_Key_Camera 51370
#define sipName_Key_Camera &sipStrings_QtCore[51370]
#define sipNameNr_Key_WebCam 51381
#define sipName_Key_WebCam &sipStrings_QtCore[51381]
#define sipNameNr_Key_ZoomIn 51392
#define sipName_Key_ZoomIn &sipStrings_QtCore[51392]
#define sipNameNr_Key_Travel 51403
#define sipName_Key_Travel &sipStrings_QtCore[51403]
#define sipNameNr_Key_Reload 51414
#define sipName_Key_Reload &sipStrings_QtCore[51414]
#define sipNameNr_Key_Option 51425
#define sipName_Key_Option &sipStrings_QtCore[51425]
#define sipNameNr_Key_MenuPB 51436
#define sipName_Key_MenuPB &sipStrings_QtCore[51436]
#define sipNameNr_Key_MenuKB 51447
#define sipName_Key_MenuKB &sipStrings_QtCore[51447]
#define sipNameNr_Key_Market 51458
#define sipName_Key_Market &sipStrings_QtCore[51458]
#define sipNameNr_Key_LogOff 51469
#define sipName_Key_LogOff &sipStrings_QtCore[51469]
#define sipNameNr_Key_iTouch 51480
#define sipName_Key_iTouch &sipStrings_QtCore[51480]
#define sipNameNr_Key_WakeUp 51491
#define sipName_Key_WakeUp &sipStrings_QtCore[51491]
#define sipNameNr_Key_Cancel 51502
#define sipName_Key_Cancel &sipStrings_QtCore[51502]
#define sipNameNr_Key_Hangup 51513
#define sipName_Key_Hangup &sipStrings_QtCore[51513]
#define sipNameNr_Key_Select 51524
#define sipName_Key_Select &sipStrings_QtCore[51524]
#define sipNameNr_Key_Search 51535
#define sipName_Key_Search &sipStrings_QtCore[51535]
#define sipNameNr_Key_BassUp 51546
#define sipName_Key_BassUp &sipStrings_QtCore[51546]
#define sipNameNr_Key_Hangul 51557
#define sipName_Key_Hangul &sipStrings_QtCore[51557]
#define sipNameNr_Key_Massyo 51568
#define sipName_Key_Massyo &sipStrings_QtCore[51568]
#define sipNameNr_Key_Romaji 51579
#define sipName_Key_Romaji &sipStrings_QtCore[51579]
#define sipNameNr_Key_Henkan 51590
#define sipName_Key_Henkan &sipStrings_QtCore[51590]
#define sipNameNr_Key_ssharp 51601
#define sipName_Key_ssharp &sipStrings_QtCore[51601]
#define sipNameNr_Key_Yacute 51612
#define sipName_Key_Yacute &sipStrings_QtCore[51612]
#define sipNameNr_Key_Uacute 51623
#define sipName_Key_Uacute &sipStrings_QtCore[51623]
#define sipNameNr_Key_Ugrave 51634
#define sipName_Key_Ugrave &sipStrings_QtCore[51634]
#define sipNameNr_Key_Otilde 51645
#define sipName_Key_Otilde &sipStrings_QtCore[51645]
#define sipNameNr_Key_Oacute 51656
#define sipName_Key_Oacute &sipStrings_QtCore[51656]
#define sipNameNr_Key_Ograve 51667
#define sipName_Key_Ograve &sipStrings_QtCore[51667]
#define sipNameNr_Key_Ntilde 51678
#define sipName_Key_Ntilde &sipStrings_QtCore[51678]
#define sipNameNr_Key_Iacute 51689
#define sipName_Key_Iacute &sipStrings_QtCore[51689]
#define sipNameNr_Key_Igrave 51700
#define sipName_Key_Igrave &sipStrings_QtCore[51700]
#define sipNameNr_Key_Eacute 51711
#define sipName_Key_Eacute &sipStrings_QtCore[51711]
#define sipNameNr_Key_Egrave 51722
#define sipName_Key_Egrave &sipStrings_QtCore[51722]
#define sipNameNr_Key_Atilde 51733
#define sipName_Key_Atilde &sipStrings_QtCore[51733]
#define sipNameNr_Key_Aacute 51744
#define sipName_Key_Aacute &sipStrings_QtCore[51744]
#define sipNameNr_Key_Agrave 51755
#define sipName_Key_Agrave &sipStrings_QtCore[51755]
#define sipNameNr_Key_degree 51766
#define sipName_Key_degree &sipStrings_QtCore[51766]
#define sipNameNr_Key_macron 51777
#define sipName_Key_macron &sipStrings_QtCore[51777]
#define sipNameNr_Key_hyphen 51788
#define sipName_Key_hyphen &sipStrings_QtCore[51788]
#define sipNameNr_Key_Period 51799
#define sipName_Key_Period &sipStrings_QtCore[51799]
#define sipNameNr_Key_Dollar 51810
#define sipName_Key_Dollar &sipStrings_QtCore[51810]
#define sipNameNr_Key_Exclam 51821
#define sipName_Key_Exclam &sipStrings_QtCore[51821]
#define sipNameNr_Key_PageUp 51832
#define sipName_Key_PageUp &sipStrings_QtCore[51832]
#define sipNameNr_Key_SysReq 51843
#define sipName_Key_SysReq &sipStrings_QtCore[51843]
#define sipNameNr_Key_Delete 51854
#define sipName_Key_Delete &sipStrings_QtCore[51854]
#define sipNameNr_Key_Insert 51865
#define sipName_Key_Insert &sipStrings_QtCore[51865]
#define sipNameNr_Key_Return 51876
#define sipName_Key_Return &sipStrings_QtCore[51876]
#define sipNameNr_Key_Escape 51887
#define sipName_Key_Escape &sipStrings_QtCore[51887]
#define sipNameNr_OpaqueMode 51898
#define sipName_OpaqueMode &sipStrings_QtCore[51898]
#define sipNameNr_Qt__BGMode 51909
#define sipName_Qt__BGMode &sipStrings_QtCore[51909]
#define sipNameNr_AutoDither 51920
#define sipName_AutoDither &sipStrings_QtCore[51920]
#define sipNameNr_WA_Resized 51931
#define sipName_WA_Resized &sipStrings_QtCore[51931]
#define sipNameNr_WA_SetFont 51942
#define sipName_WA_SetFont &sipStrings_QtCore[51942]
#define sipNameNr_WA_LaidOut 51953
#define sipName_WA_LaidOut &sipStrings_QtCore[51953]
#define sipNameNr_WindowType 35358
#define sipName_WindowType &sipStrings_QtCore[35358]
#define sipNameNr_ElideRight 51964
#define sipName_ElideRight &sipStrings_QtCore[51964]
#define sipNameNr_AlignRight 51975
#define sipName_AlignRight &sipStrings_QtCore[51975]
#define sipNameNr_WheelFocus 51986
#define sipName_WheelFocus &sipStrings_QtCore[51986]
#define sipNameNr_ClickFocus 51997
#define sipName_ClickFocus &sipStrings_QtCore[51997]
#define sipNameNr_Horizontal 52008
#define sipName_Horizontal &sipStrings_QtCore[52008]
#define sipNameNr_TaskButton 52019
#define sipName_TaskButton &sipStrings_QtCore[52019]
#define sipNameNr_BackButton 52030
#define sipName_BackButton &sipStrings_QtCore[52030]
#define sipNameNr_LeftButton 52041
#define sipName_LeftButton &sipStrings_QtCore[52041]
#define sipNameNr_AllButtons 52052
#define sipName_AllButtons &sipStrings_QtCore[52052]
#define sipNameNr_NoModifier 52063
#define sipName_NoModifier &sipStrings_QtCore[52063]
#define sipNameNr_darkYellow 52074
#define sipName_darkYellow &sipStrings_QtCore[52074]
#define sipNameNr___invert__ 52085
#define sipName___invert__ &sipStrings_QtCore[52085]
#define sipNameNr_QT_VERSION 44115
#define sipName_QT_VERSION &sipStrings_QtCore[44115]
#define sipNameNr_behaviour 52096
#define sipName_behaviour &sipStrings_QtCore[52096]
#define sipNameNr_isComment 52106
#define sipName_isComment &sipStrings_QtCore[52106]
#define sipNameNr_tokenType 52116
#define sipName_tokenType &sipStrings_QtCore[52116]
#define sipNameNr_TokenType 4003
#define sipName_TokenType &sipStrings_QtCore[4003]
#define sipNameNr_segmentAt 52126
#define sipName_segmentAt &sipStrings_QtCore[52126]
#define sipNameNr_keyValues 52136
#define sipName_keyValues &sipStrings_QtCore[52136]
#define sipNameNr_Matrix4x4 49160
#define sipName_Matrix4x4 &sipStrings_QtCore[49160]
#define sipNameNr_Transform 49171
#define sipName_Transform &sipStrings_QtCore[49171]
#define sipNameNr_toRfc4122 52146
#define sipName_toRfc4122 &sipStrings_QtCore[52146]
#define sipNameNr_Microsoft 52156
#define sipName_Microsoft &sipStrings_QtCore[52156]
#define sipNameNr_QUrlQuery 52166
#define sipName_QUrlQuery &sipStrings_QtCore[52166]
#define sipNameNr_toEncoded 52176
#define sipName_toEncoded &sipStrings_QtCore[52176]
#define sipNameNr_authority 52186
#define sipName_authority &sipStrings_QtCore[52186]
#define sipNameNr_setScheme 52196
#define sipName_setScheme &sipStrings_QtCore[52196]
#define sipNameNr_directory 52206
#define sipName_directory &sipStrings_QtCore[52206]
#define sipNameNr_ShortName 52216
#define sipName_ShortName &sipStrings_QtCore[52216]
#define sipNameNr_QTimeZone 52226
#define sipName_QTimeZone &sipStrings_QtCore[52226]
#define sipNameNr_QTimeLine 52236
#define sipName_QTimeLine &sipStrings_QtCore[52236]
#define sipNameNr_loopLevel 52246
#define sipName_loopLevel &sipStrings_QtCore[52246]
#define sipNameNr_stackSize 52256
#define sipName_stackSize &sipStrings_QtCore[52256]
#define sipNameNr_forcesign 44549
#define sipName_forcesign &sipStrings_QtCore[44549]
#define sipNameNr_maxLength 52266
#define sipName_maxLength &sipStrings_QtCore[52266]
#define sipNameNr_ForceSign 52276
#define sipName_ForceSign &sipStrings_QtCore[52276]
#define sipNameNr_toUnicode 52286
#define sipName_toUnicode &sipStrings_QtCore[52286]
#define sipNameNr_canEncode 52296
#define sipName_canEncode &sipStrings_QtCore[52296]
#define sipNameNr_EndOfItem 52306
#define sipName_EndOfItem &sipStrings_QtCore[52306]
#define sipNameNr_subvolume 52316
#define sipName_subvolume &sipStrings_QtCore[52316]
#define sipNameNr_blockSize 52326
#define sipName_blockSize &sipStrings_QtCore[52326]
#define sipNameNr_bytesFree 52336
#define sipName_bytesFree &sipStrings_QtCore[52336]
#define sipNameNr_childMode 52346
#define sipName_childMode &sipStrings_QtCore[52346]
#define sipNameNr_ChildMode 21422
#define sipName_ChildMode &sipStrings_QtCore[21422]
#define sipNameNr_locateAll 52356
#define sipName_locateAll &sipStrings_QtCore[52356]
#define sipNameNr_sortOrder 52366
#define sipName_sortOrder &sipStrings_QtCore[52366]
#define sipNameNr_activated 10497
#define sipName_activated &sipStrings_QtCore[10497]
#define sipNameNr_Exception 52376
#define sipName_Exception &sipStrings_QtCore[52376]
#define sipNameNr_boundedTo 52386
#define sipName_boundedTo &sipStrings_QtCore[52386]
#define sipNameNr_transpose 52396
#define sipName_transpose &sipStrings_QtCore[52396]
#define sipNameNr_setSignal 52406
#define sipName_setSignal &sipStrings_QtCore[52406]
#define sipNameNr_mappedInt 52416
#define sipName_mappedInt &sipStrings_QtCore[52416]
#define sipNameNr_nativeKey 52426
#define sipName_nativeKey &sipStrings_QtCore[52426]
#define sipNameNr_constData 52436
#define sipName_constData &sipStrings_QtCore[52436]
#define sipNameNr_childKeys 52446
#define sipName_childKeys &sipStrings_QtCore[52446]
#define sipNameNr_UserScope 52456
#define sipName_UserScope &sipStrings_QtCore[52456]
#define sipNameNr_IniFormat 52466
#define sipName_IniFormat &sipStrings_QtCore[52466]
#define sipNameNr_QSettings 52476
#define sipName_QSettings &sipStrings_QtCore[52476]
#define sipNameNr_semaphore 52486
#define sipName_semaphore &sipStrings_QtCore[52486]
#define sipNameNr_available 52496
#define sipName_available &sipStrings_QtCore[52496]
#define sipNameNr_QSaveFile 52506
#define sipName_QSaveFile &sipStrings_QtCore[52506]
#define sipNameNr_QRunnable 52516
#define sipName_QRunnable &sipStrings_QtCore[52516]
#define sipNameNr_QResource 52526
#define sipName_QResource &sipStrings_QtCore[52526]
#define sipNameNr_matchType 52536
#define sipName_matchType &sipStrings_QtCore[52536]
#define sipNameNr_MatchType 2806
#define sipName_MatchType &sipStrings_QtCore[2806]
#define sipNameNr_caretMode 52546
#define sipName_caretMode &sipStrings_QtCore[52546]
#define sipNameNr_isMinimal 52556
#define sipName_isMinimal &sipStrings_QtCore[52556]
#define sipNameNr_CaretMode 18500
#define sipName_CaretMode &sipStrings_QtCore[18500]
#define sipNameNr_setHeight 52566
#define sipName_setHeight &sipStrings_QtCore[52566]
#define sipNameNr_setCoords 52576
#define sipName_setCoords &sipStrings_QtCore[52576]
#define sipNameNr_getCoords 52586
#define sipName_getCoords &sipStrings_QtCore[52586]
#define sipNameNr_moveRight 52596
#define sipName_moveRight &sipStrings_QtCore[52596]
#define sipNameNr_processId 52606
#define sipName_processId &sipStrings_QtCore[52606]
#define sipNameNr_terminate 52616
#define sipName_terminate &sipStrings_QtCore[52616]
#define sipNameNr_CrashExit 52626
#define sipName_CrashExit &sipStrings_QtCore[52626]
#define sipNameNr_Windows10 52636
#define sipName_Windows10 &sipStrings_QtCore[52636]
#define sipNameNr_classInfo 52646
#define sipName_classInfo &sipStrings_QtCore[52646]
#define sipNameNr_className 52656
#define sipName_className &sipStrings_QtCore[52656]
#define sipNameNr_receivers 52666
#define sipName_receivers &sipStrings_QtCore[52666]
#define sipNameNr_destroyed 52676
#define sipName_destroyed &sipStrings_QtCore[52676]
#define sipNameNr_setParent 52686
#define sipName_setParent &sipStrings_QtCore[52686]
#define sipNameNr_killTimer 52696
#define sipName_killTimer &sipStrings_QtCore[52696]
#define sipNameNr_findChild 52706
#define sipName_findChild &sipStrings_QtCore[52706]
#define sipNameNr_qIsFinite 52716
#define sipName_qIsFinite &sipStrings_QtCore[52716]
#define sipNameNr_Recursive 34264
#define sipName_Recursive &sipStrings_QtCore[34264]
#define sipNameNr_isDefault 52726
#define sipName_isDefault &sipStrings_QtCore[52726]
#define sipNameNr_QMimeType 52736
#define sipName_QMimeType &sipStrings_QtCore[52736]
#define sipNameNr_MatchMode 7072
#define sipName_MatchMode &sipStrings_QtCore[7072]
#define sipNameNr_hasFormat 52746
#define sipName_hasFormat &sipStrings_QtCore[52746]
#define sipNameNr_colorData 52756
#define sipName_colorData &sipStrings_QtCore[52756]
#define sipNameNr_imageData 52766
#define sipName_imageData &sipStrings_QtCore[52766]
#define sipNameNr_QMimeData 52776
#define sipName_QMimeData &sipStrings_QtCore[52776]
#define sipNameNr_typeFlags 52786
#define sipName_typeFlags &sipStrings_QtCore[52786]
#define sipNameNr_TypeFlags 13855
#define sipName_TypeFlags &sipStrings_QtCore[13855]
#define sipNameNr_QPolygonF 52796
#define sipName_QPolygonF &sipStrings_QtCore[52796]
#define sipNameNr_QVector4D 52806
#define sipName_QVector4D &sipStrings_QtCore[52806]
#define sipNameNr_QVector3D 52816
#define sipName_QVector3D &sipStrings_QtCore[52816]
#define sipNameNr_QVector2D 52826
#define sipName_QVector2D &sipStrings_QtCore[52826]
#define sipNameNr_ULongLong 46949
#define sipName_ULongLong &sipStrings_QtCore[46949]
#define sipNameNr_QMetaType 52836
#define sipName_QMetaType &sipStrings_QtCore[52836]
#define sipNameNr_QMetaEnum 52846
#define sipName_QMetaEnum &sipStrings_QtCore[52846]
#define sipNameNr_Protected 52856
#define sipName_Protected &sipStrings_QtCore[52856]
#define sipNameNr_toMargins 52866
#define sipName_toMargins &sipStrings_QtCore[52866]
#define sipNameNr_QMarginsF 52876
#define sipName_QMarginsF &sipStrings_QtCore[52876]
#define sipNameNr_setBottom 52886
#define sipName_setBottom &sipStrings_QtCore[52886]
#define sipNameNr_isEnabled 52896
#define sipName_isEnabled &sipStrings_QtCore[52896]
#define sipNameNr_qCritical 52906
#define sipName_qCritical &sipStrings_QtCore[52906]
#define sipNameNr_QtInfoMsg 52916
#define sipName_QtInfoMsg &sipStrings_QtCore[52916]
#define sipNameNr_QtMsgType 52926
#define sipName_QtMsgType &sipStrings_QtCore[52926]
#define sipNameNr_LockError 13876
#define sipName_LockError &sipStrings_QtCore[13876]
#define sipNameNr_QLockFile 52936
#define sipName_QLockFile &sipStrings_QtCore[52936]
#define sipNameNr_collation 52946
#define sipName_collation &sipStrings_QtCore[52946]
#define sipNameNr_bcp47Name 52956
#define sipName_bcp47Name &sipStrings_QtCore[52956]
#define sipNameNr_MroScript 52966
#define sipName_MroScript &sipStrings_QtCore[52966]
#define sipNameNr_NkoScript 52976
#define sipName_NkoScript &sipStrings_QtCore[52976]
#define sipNameNr_HanScript 13918
#define sipName_HanScript &sipStrings_QtCore[13918]
#define sipNameNr_VaiScript 52986
#define sipName_VaiScript &sipStrings_QtCore[52986]
#define sipNameNr_LaoScript 52996
#define sipName_LaoScript &sipStrings_QtCore[52996]
#define sipNameNr_AnyScript 53006
#define sipName_AnyScript &sipStrings_QtCore[53006]
#define sipNameNr_zeroDigit 53016
#define sipName_zeroDigit &sipStrings_QtCore[53016]
#define sipNameNr_IsleOfMan 53026
#define sipName_IsleOfMan &sipStrings_QtCore[53026]
#define sipNameNr_Venezuela 53036
#define sipName_Venezuela &sipStrings_QtCore[53036]
#define sipNameNr_Swaziland 53046
#define sipName_Swaziland &sipStrings_QtCore[53046]
#define sipNameNr_Singapore 53056
#define sipName_Singapore &sipStrings_QtCore[53056]
#define sipNameNr_SanMarino 53066
#define sipName_SanMarino &sipStrings_QtCore[53066]
#define sipNameNr_Nicaragua 53076
#define sipName_Nicaragua &sipStrings_QtCore[53076]
#define sipNameNr_Mauritius 53086
#define sipName_Mauritius &sipStrings_QtCore[53086]
#define sipNameNr_Macedonia 53096
#define sipName_Macedonia &sipStrings_QtCore[53096]
#define sipNameNr_Lithuania 53106
#define sipName_Lithuania &sipStrings_QtCore[53106]
#define sipNameNr_Indonesia 53116
#define sipName_Indonesia &sipStrings_QtCore[53116]
#define sipNameNr_Guatemala 53126
#define sipName_Guatemala &sipStrings_QtCore[53126]
#define sipNameNr_Greenland 53136
#define sipName_Greenland &sipStrings_QtCore[53136]
#define sipNameNr_Gibraltar 53146
#define sipName_Gibraltar &sipStrings_QtCore[53146]
#define sipNameNr_EastTimor 53156
#define sipName_EastTimor &sipStrings_QtCore[53156]
#define sipNameNr_CostaRica 53166
#define sipName_CostaRica &sipStrings_QtCore[53166]
#define sipNameNr_CapeVerde 53176
#define sipName_CapeVerde &sipStrings_QtCore[53176]
#define sipNameNr_Australia 53186
#define sipName_Australia &sipStrings_QtCore[53186]
#define sipNameNr_Argentina 53196
#define sipName_Argentina &sipStrings_QtCore[53196]
#define sipNameNr_Chickasaw 53206
#define sipName_Chickasaw &sipStrings_QtCore[53206]
#define sipNameNr_Cantonese 53216
#define sipName_Cantonese &sipStrings_QtCore[53216]
#define sipNameNr_TedimChin 53226
#define sipName_TedimChin &sipStrings_QtCore[53226]
#define sipNameNr_HmongNjua 53236
#define sipName_HmongNjua &sipStrings_QtCore[53236]
#define sipNameNr_SkoltSami 53246
#define sipName_SkoltSami &sipStrings_QtCore[53246]
#define sipNameNr_InariSami 53256
#define sipName_InariSami &sipStrings_QtCore[53256]
#define sipNameNr_Samaritan 53266
#define sipName_Samaritan &sipStrings_QtCore[53266]
#define sipNameNr_BatakToba 53276
#define sipName_BatakToba &sipStrings_QtCore[53276]
#define sipNameNr_Aragonese 53286
#define sipName_Aragonese &sipStrings_QtCore[53286]
#define sipNameNr_Ngiemboon 53296
#define sipName_Ngiemboon &sipStrings_QtCore[53296]
#define sipNameNr_Sardinian 53306
#define sipName_Sardinian &sipStrings_QtCore[53306]
#define sipNameNr_JolaFonyi 53316
#define sipName_JolaFonyi &sipStrings_QtCore[53316]
#define sipNameNr_Colognian 53326
#define sipName_Colognian &sipStrings_QtCore[53326]
#define sipNameNr_Tachelhit 53336
#define sipName_Tachelhit &sipStrings_QtCore[53336]
#define sipNameNr_LowGerman 53346
#define sipName_LowGerman &sipStrings_QtCore[53346]
#define sipNameNr_SichuanYi 53356
#define sipName_SichuanYi &sipStrings_QtCore[53356]
#define sipNameNr_Ukrainian 53366
#define sipName_Ukrainian &sipStrings_QtCore[53366]
#define sipNameNr_Sundanese 53376
#define sipName_Sundanese &sipStrings_QtCore[53376]
#define sipNameNr_Slovenian 53386
#define sipName_Slovenian &sipStrings_QtCore[53386]
#define sipNameNr_Norwegian 53396
#define sipName_Norwegian &sipStrings_QtCore[53396]
#define sipNameNr_Mongolian 53406
#define sipName_Mongolian &sipStrings_QtCore[53406]
#define sipNameNr_Moldavian 53416
#define sipName_Moldavian &sipStrings_QtCore[53416]
#define sipNameNr_Malayalam 53426
#define sipName_Malayalam &sipStrings_QtCore[53426]
#define sipNameNr_Inuktitut 53436
#define sipName_Inuktitut &sipStrings_QtCore[53436]
#define sipNameNr_Icelandic 53446
#define sipName_Icelandic &sipStrings_QtCore[53446]
#define sipNameNr_Hungarian 53456
#define sipName_Hungarian &sipStrings_QtCore[53456]
#define sipNameNr_Esperanto 53466
#define sipName_Esperanto &sipStrings_QtCore[53466]
#define sipNameNr_Cambodian 53476
#define sipName_Cambodian &sipStrings_QtCore[53476]
#define sipNameNr_Bulgarian 53486
#define sipName_Bulgarian &sipStrings_QtCore[53486]
#define sipNameNr_Afrikaans 53496
#define sipName_Afrikaans &sipStrings_QtCore[53496]
#define sipNameNr_Abkhazian 53506
#define sipName_Abkhazian &sipStrings_QtCore[53506]
#define sipNameNr_fromPolar 53516
#define sipName_fromPolar &sipStrings_QtCore[53516]
#define sipNameNr_setLength 53526
#define sipName_setLength &sipStrings_QtCore[53526]
#define sipNameNr_intersect 53536
#define sipName_intersect &sipStrings_QtCore[53536]
#define sipNameNr_setPoints 53546
#define sipName_setPoints &sipStrings_QtCore[53546]
#define sipNameNr_buildDate 53556
#define sipName_buildDate &sipStrings_QtCore[53556]
#define sipNameNr_TestsPath 53566
#define sipName_TestsPath &sipStrings_QtCore[53566]
#define sipNameNr_isLibrary 53576
#define sipName_isLibrary &sipStrings_QtCore[53576]
#define sipNameNr_loadHints 53586
#define sipName_loadHints &sipStrings_QtCore[53586]
#define sipNameNr_LoadHints 16209
#define sipName_LoadHints &sipStrings_QtCore[16209]
#define sipNameNr_setObject 53596
#define sipName_setObject &sipStrings_QtCore[53596]
#define sipNameNr_toVariant 53606
#define sipName_toVariant &sipStrings_QtCore[53606]
#define sipNameNr_takeFirst 53616
#define sipName_takeFirst &sipStrings_QtCore[53616]
#define sipNameNr_removeAll 53626
#define sipName_removeAll &sipStrings_QtCore[53626]
#define sipNameNr_readyRead 53636
#define sipName_readyRead &sipStrings_QtCore[53636]
#define sipNameNr_ungetChar 53646
#define sipName_ungetChar &sipStrings_QtCore[53646]
#define sipNameNr_ReadWrite 53656
#define sipName_ReadWrite &sipStrings_QtCore[53656]
#define sipNameNr_WriteOnly 53666
#define sipName_WriteOnly &sipStrings_QtCore[53666]
#define sipNameNr_birthTime 53676
#define sipName_birthTime &sipStrings_QtCore[53676]
#define sipNameNr_isSymLink 53686
#define sipName_isSymLink &sipStrings_QtCore[53686]
#define sipNameNr_QFileInfo 53696
#define sipName_QFileInfo &sipStrings_QtCore[53696]
#define sipNameNr_NoOptions 53706
#define sipName_NoOptions &sipStrings_QtCore[53706]
#define sipNameNr_ReadOther 53716
#define sipName_ReadOther &sipStrings_QtCore[53716]
#define sipNameNr_ReadGroup 53726
#define sipName_ReadGroup &sipStrings_QtCore[53726]
#define sipNameNr_WriteUser 53736
#define sipName_WriteUser &sipStrings_QtCore[53736]
#define sipNameNr_ReadOwner 53746
#define sipName_ReadOwner &sipStrings_QtCore[53746]
#define sipNameNr_CopyError 53756
#define sipName_CopyError &sipStrings_QtCore[53756]
#define sipNameNr_OpenError 53766
#define sipName_OpenError &sipStrings_QtCore[53766]
#define sipNameNr_ReadError 53776
#define sipName_ReadError &sipStrings_QtCore[53776]
#define sipNameNr_FileError 10221
#define sipName_FileError &sipStrings_QtCore[10221]
#define sipNameNr_isRunning 53786
#define sipName_isRunning &sipStrings_QtCore[53786]
#define sipNameNr_AllEvents 53796
#define sipName_AllEvents &sipStrings_QtCore[53796]
#define sipNameNr_clockType 53806
#define sipName_clockType &sipStrings_QtCore[53806]
#define sipNameNr_ClockType 7222
#define sipName_ClockType &sipStrings_QtCore[7222]
#define sipNameNr_overshoot 53816
#define sipName_overshoot &sipStrings_QtCore[53816]
#define sipNameNr_setPeriod 53826
#define sipName_setPeriod &sipStrings_QtCore[53826]
#define sipNameNr_amplitude 53836
#define sipName_amplitude &sipStrings_QtCore[53836]
#define sipNameNr_TCBSpline 53846
#define sipName_TCBSpline &sipStrings_QtCore[53846]
#define sipNameNr_SineCurve 53856
#define sipName_SineCurve &sipStrings_QtCore[53856]
#define sipNameNr_OutBounce 46217
#define sipName_OutBounce &sipStrings_QtCore[46217]
#define sipNameNr_OutInBack 53866
#define sipName_OutInBack &sipStrings_QtCore[53866]
#define sipNameNr_InOutBack 53876
#define sipName_InOutBack &sipStrings_QtCore[53876]
#define sipNameNr_InElastic 42140
#define sipName_InElastic &sipStrings_QtCore[42140]
#define sipNameNr_OutInCirc 53886
#define sipName_OutInCirc &sipStrings_QtCore[53886]
#define sipNameNr_InOutCirc 53896
#define sipName_InOutCirc &sipStrings_QtCore[53896]
#define sipNameNr_OutInExpo 53906
#define sipName_OutInExpo &sipStrings_QtCore[53906]
#define sipNameNr_InOutExpo 53916
#define sipName_InOutExpo &sipStrings_QtCore[53916]
#define sipNameNr_OutInSine 53926
#define sipName_OutInSine &sipStrings_QtCore[53926]
#define sipNameNr_InOutSine 53936
#define sipName_InOutSine &sipStrings_QtCore[53936]
#define sipNameNr_OutInQuad 53946
#define sipName_OutInQuad &sipStrings_QtCore[53946]
#define sipNameNr_InOutQuad 53956
#define sipName_InOutQuad &sipStrings_QtCore[53956]
#define sipNameNr_cleanPath 53966
#define sipName_cleanPath &sipStrings_QtCore[53966]
#define sipNameNr_entryList 53976
#define sipName_entryList &sipStrings_QtCore[53976]
#define sipNameNr_setFilter 53986
#define sipName_setFilter &sipStrings_QtCore[53986]
#define sipNameNr_SortFlags 29428
#define sipName_SortFlags &sipStrings_QtCore[29428]
#define sipNameNr_DirsFirst 53996
#define sipName_DirsFirst &sipStrings_QtCore[53996]
#define sipNameNr_isForever 54006
#define sipName_isForever &sipStrings_QtCore[54006]
#define sipNameNr_YearRange 14191
#define sipName_YearRange &sipStrings_QtCore[14191]
#define sipNameNr_setTime_t 54016
#define sipName_setTime_t &sipStrings_QtCore[54016]
#define sipNameNr_QDateTime 54026
#define sipName_QDateTime &sipStrings_QtCore[54026]
#define sipNameNr_addMonths 54036
#define sipName_addMonths &sipStrings_QtCore[54036]
#define sipNameNr_dayOfYear 54046
#define sipName_dayOfYear &sipStrings_QtCore[54046]
#define sipNameNr_readBytes 54056
#define sipName_readBytes &sipStrings_QtCore[54056]
#define sipNameNr_writeBool 54066
#define sipName_writeBool &sipStrings_QtCore[54066]
#define sipNameNr_writeInt8 54076
#define sipName_writeInt8 &sipStrings_QtCore[54076]
#define sipNameNr_readFloat 54086
#define sipName_readFloat &sipStrings_QtCore[54086]
#define sipNameNr_readInt64 54096
#define sipName_readInt64 &sipStrings_QtCore[54096]
#define sipNameNr_readInt32 54106
#define sipName_readInt32 &sipStrings_QtCore[54106]
#define sipNameNr_readInt16 54116
#define sipName_readInt16 &sipStrings_QtCore[54116]
#define sipNameNr_readUInt8 54126
#define sipName_readUInt8 &sipStrings_QtCore[54126]
#define sipNameNr_byteOrder 54136
#define sipName_byteOrder &sipStrings_QtCore[54136]
#define sipNameNr_setStatus 46445
#define sipName_setStatus &sipStrings_QtCore[46445]
#define sipNameNr_BigEndian 54146
#define sipName_BigEndian &sipStrings_QtCore[54146]
#define sipNameNr_ByteOrder 10336
#define sipName_ByteOrder &sipStrings_QtCore[10336]
#define sipNameNr_Algorithm 3016
#define sipName_Algorithm &sipStrings_QtCore[3016]
#define sipNameNr_GrabMouse 54156
#define sipName_GrabMouse &sipStrings_QtCore[54156]
#define sipNameNr_HoverMove 10451
#define sipName_HoverMove &sipStrings_QtCore[10451]
#define sipNameNr_StatusTip 54166
#define sipName_StatusTip &sipStrings_QtCore[54166]
#define sipNameNr_WhatsThis 20951
#define sipName_WhatsThis &sipStrings_QtCore[20951]
#define sipNameNr_OkRequest 54176
#define sipName_OkRequest &sipStrings_QtCore[54176]
#define sipNameNr_DragLeave 10405
#define sipName_DragLeave &sipStrings_QtCore[10405]
#define sipNameNr_DragEnter 10428
#define sipName_DragEnter &sipStrings_QtCore[10428]
#define sipNameNr_Clipboard 54186
#define sipName_Clipboard &sipStrings_QtCore[54186]
#define sipNameNr_MouseMove 10382
#define sipName_MouseMove &sipStrings_QtCore[10382]
#define sipNameNr___enter__ 54196
#define sipName___enter__ &sipStrings_QtCore[54196]
#define sipNameNr_translate 54206
#define sipName_translate &sipStrings_QtCore[54206]
#define sipNameNr_postEvent 54216
#define sipName_postEvent &sipStrings_QtCore[54216]
#define sipNameNr_sendEvent 54226
#define sipName_sendEvent &sipStrings_QtCore[54226]
#define sipNameNr_errorText 54236
#define sipName_errorText &sipStrings_QtCore[54236]
#define sipNameNr_arguments 54246
#define sipName_arguments &sipStrings_QtCore[54246]
#define sipNameNr_addOption 54256
#define sipName_addOption &sipStrings_QtCore[54256]
#define sipNameNr_setHidden 54266
#define sipName_setHidden &sipStrings_QtCore[54266]
#define sipNameNr_valueName 54276
#define sipName_valueName &sipStrings_QtCore[54276]
#define sipNameNr_setLocale 54286
#define sipName_setLocale &sipStrings_QtCore[54286]
#define sipNameNr_QCollator 54296
#define sipName_QCollator &sipStrings_QtCore[54296]
#define sipNameNr_toInteger 54306
#define sipName_toInteger &sipStrings_QtCore[54306]
#define sipNameNr_isInvalid 54316
#define sipName_isInvalid &sipStrings_QtCore[54316]
#define sipNameNr_isFloat16 54326
#define sipName_isFloat16 &sipStrings_QtCore[54326]
#define sipNameNr_isInteger 54336
#define sipName_isInteger &sipStrings_QtCore[54336]
#define sipNameNr_lastError 54346
#define sipName_lastError &sipStrings_QtCore[54346]
#define sipNameNr_HalfFloat 54356
#define sipName_HalfFloat &sipStrings_QtCore[54356]
#define sipNameNr_ByteArray 37799
#define sipName_ByteArray &sipStrings_QtCore[37799]
#define sipNameNr_setDevice 54366
#define sipName_setDevice &sipStrings_QtCore[54366]
#define sipNameNr_Signature 15989
#define sipName_Signature &sipStrings_QtCore[15989]
#define sipNameNr_COSE_Sign 54376
#define sipName_COSE_Sign &sipStrings_QtCore[54376]
#define sipNameNr_Base64url 22934
#define sipName_Base64url &sipStrings_QtCore[22934]
#define sipNameNr_COSE_Mac0 54386
#define sipName_COSE_Mac0 &sipStrings_QtCore[54386]
#define sipNameNr_EndOfFile 54396
#define sipName_EndOfFile &sipStrings_QtCore[54396]
#define sipNameNr_Undefined 8934
#define sipName_Undefined &sipStrings_QtCore[8934]
#define sipNameNr_monthName 54406
#define sipName_monthName &sipStrings_QtCore[54406]
#define sipNameNr_dayOfWeek 54416
#define sipName_dayOfWeek &sipStrings_QtCore[54416]
#define sipNameNr_Gregorian 46877
#define sipName_Gregorian &sipStrings_QtCore[46877]
#define sipNameNr_QCalendar 54426
#define sipName_QCalendar &sipStrings_QtCore[54426]
#define sipNameNr_qChecksum 54436
#define sipName_qChecksum &sipStrings_QtCore[54436]
#define sipNameNr_qCompress 54446
#define sipName_qCompress &sipStrings_QtCore[54446]
#define sipNameNr_separator 54456
#define sipName_separator &sipStrings_QtCore[54456]
#define sipNameNr_push_back 54466
#define sipName_push_back &sipStrings_QtCore[54466]
#define sipNameNr_precision 54476
#define sipName_precision &sipStrings_QtCore[54476]
#define sipNameNr_writeData 54486
#define sipName_writeData &sipStrings_QtCore[54486]
#define sipNameNr_setBuffer 54496
#define sipName_setBuffer &sipStrings_QtCore[54496]
#define sipNameNr_QIODevice 54506
#define sipName_QIODevice &sipStrings_QtCore[54506]
#define sipNameNr_toggleBit 54516
#define sipName_toggleBit &sipStrings_QtCore[54516]
#define sipNameNr_QBitArray 54526
#define sipName_QBitArray &sipStrings_QtCore[54526]
#define sipNameNr_eventTest 54536
#define sipName_eventTest &sipStrings_QtCore[54536]
#define sipNameNr_triggered 54546
#define sipName_triggered &sipStrings_QtCore[54546]
#define sipNameNr_selection 54556
#define sipName_selection &sipStrings_QtCore[54556]
#define sipNameNr_rowsMoved 54566
#define sipName_rowsMoved &sipStrings_QtCore[54566]
#define sipNameNr_roleNames 54576
#define sipName_roleNames &sipStrings_QtCore[54576]
#define sipNameNr_removeRow 54586
#define sipName_removeRow &sipStrings_QtCore[54586]
#define sipNameNr_insertRow 54596
#define sipName_insertRow &sipStrings_QtCore[54596]
#define sipNameNr_fetchMore 54606
#define sipName_fetchMore &sipStrings_QtCore[54606]
#define sipNameNr_mimeTypes 54616
#define sipName_mimeTypes &sipStrings_QtCore[54616]
#define sipNameNr_eventType 54626
#define sipName_eventType &sipStrings_QtCore[54626]
#define sipNameNr_interrupt 54636
#define sipName_interrupt &sipStrings_QtCore[54636]
#define sipNameNr_timerType 54646
#define sipName_timerType &sipStrings_QtCore[54646]
#define sipNameNr_TimerInfo 1099
#define sipName_TimerInfo &sipStrings_QtCore[1099]
#define sipNameNr_setPaused 54656
#define sipName_setPaused &sipStrings_QtCore[54656]
#define sipNameNr_loopCount 54666
#define sipName_loopCount &sipStrings_QtCore[54666]
#define sipNameNr_direction 54676
#define sipName_direction &sipStrings_QtCore[54676]
#define sipNameNr_Direction 3106
#define sipName_Direction &sipStrings_QtCore[3106]
#define sipNameNr_Qt__Edges 54686
#define sipName_Qt__Edges &sipStrings_QtCore[54686]
#define sipNameNr_ScrollEnd 54696
#define sipName_ScrollEnd &sipStrings_QtCore[54696]
#define sipNameNr_RightEdge 54706
#define sipName_RightEdge &sipStrings_QtCore[54706]
#define sipNameNr_AnchorTop 54716
#define sipName_AnchorTop &sipStrings_QtCore[54716]
#define sipNameNr_RoundTile 54726
#define sipName_RoundTile &sipStrings_QtCore[54726]
#define sipNameNr_NoSection 54736
#define sipName_NoSection &sipStrings_QtCore[54736]
#define sipNameNr_MatchWrap 54746
#define sipName_MatchWrap &sipStrings_QtCore[54746]
#define sipNameNr_MatchFlag 38275
#define sipName_MatchFlag &sipStrings_QtCore[38275]
#define sipNameNr_ItemFlags 38289
#define sipName_ItemFlags &sipStrings_QtCore[38289]
#define sipNameNr_Unchecked 54756
#define sipName_Unchecked &sipStrings_QtCore[54756]
#define sipNameNr_ImEnabled 54766
#define sipName_ImEnabled &sipStrings_QtCore[54766]
#define sipNameNr_Wednesday 54776
#define sipName_Wednesday &sipStrings_QtCore[54776]
#define sipNameNr_DayOfWeek 32524
#define sipName_DayOfWeek &sipStrings_QtCore[32524]
#define sipNameNr_LocalTime 46289
#define sipName_LocalTime &sipStrings_QtCore[46289]
#define sipNameNr_LocalDate 54786
#define sipName_LocalDate &sipStrings_QtCore[54786]
#define sipNameNr_TimerType 38471
#define sipName_TimerType &sipStrings_QtCore[38471]
#define sipNameNr_PlainText 54796
#define sipName_PlainText &sipStrings_QtCore[54796]
#define sipNameNr_RoundJoin 54806
#define sipName_RoundJoin &sipStrings_QtCore[54806]
#define sipNameNr_BevelJoin 54816
#define sipName_BevelJoin &sipStrings_QtCore[54816]
#define sipNameNr_MiterJoin 43323
#define sipName_MiterJoin &sipStrings_QtCore[43323]
#define sipNameNr_SquareCap 54826
#define sipName_SquareCap &sipStrings_QtCore[54826]
#define sipNameNr_MPenStyle 54836
#define sipName_MPenStyle &sipStrings_QtCore[54836]
#define sipNameNr_SolidLine 54846
#define sipName_SolidLine &sipStrings_QtCore[54846]
#define sipNameNr_LeftArrow 54856
#define sipName_LeftArrow &sipStrings_QtCore[54856]
#define sipNameNr_DownArrow 54866
#define sipName_DownArrow &sipStrings_QtCore[54866]
#define sipNameNr_ArrowType 38653
#define sipName_ArrowType &sipStrings_QtCore[38653]
#define sipNameNr_Key_Guide 54876
#define sipName_Key_Guide &sipStrings_QtCore[54876]
#define sipNameNr_Key_Green 54886
#define sipName_Key_Green &sipStrings_QtCore[54886]
#define sipNameNr_Key_Music 54896
#define sipName_Key_Music &sipStrings_QtCore[54896]
#define sipNameNr_Key_Video 54906
#define sipName_Key_Video &sipStrings_QtCore[54906]
#define sipNameNr_Key_Tools 54916
#define sipName_Key_Tools &sipStrings_QtCore[54916]
#define sipNameNr_Key_Spell 54926
#define sipName_Key_Spell &sipStrings_QtCore[54926]
#define sipNameNr_Key_Reply 54936
#define sipName_Key_Reply &sipStrings_QtCore[54936]
#define sipNameNr_Key_Phone 54946
#define sipName_Key_Phone &sipStrings_QtCore[54946]
#define sipNameNr_Key_Paste 54956
#define sipName_Key_Paste &sipStrings_QtCore[54956]
#define sipNameNr_Key_Excel 54966
#define sipName_Key_Excel &sipStrings_QtCore[54966]
#define sipNameNr_Key_Close 54976
#define sipName_Key_Close &sipStrings_QtCore[54976]
#define sipNameNr_Key_Eject 54986
#define sipName_Key_Eject &sipStrings_QtCore[54986]
#define sipNameNr_Key_Sleep 54996
#define sipName_Key_Sleep &sipStrings_QtCore[54996]
#define sipNameNr_Key_Kanji 55006
#define sipName_Key_Kanji &sipStrings_QtCore[55006]
#define sipNameNr_Key_AltGr 55016
#define sipName_Key_AltGr &sipStrings_QtCore[55016]
#define sipNameNr_Key_THORN 55026
#define sipName_Key_THORN &sipStrings_QtCore[55026]
#define sipNameNr_Key_Aring 55036
#define sipName_Key_Aring &sipStrings_QtCore[55036]
#define sipNameNr_Key_acute 55046
#define sipName_Key_acute &sipStrings_QtCore[55046]
#define sipNameNr_Key_Equal 55056
#define sipName_Key_Equal &sipStrings_QtCore[55056]
#define sipNameNr_Key_Colon 55066
#define sipName_Key_Colon &sipStrings_QtCore[55066]
#define sipNameNr_Key_Slash 55076
#define sipName_Key_Slash &sipStrings_QtCore[55076]
#define sipNameNr_Key_Minus 55086
#define sipName_Key_Minus &sipStrings_QtCore[55086]
#define sipNameNr_Key_Comma 55096
#define sipName_Key_Comma &sipStrings_QtCore[55096]
#define sipNameNr_Key_Space 55106
#define sipName_Key_Space &sipStrings_QtCore[55106]
#define sipNameNr_Key_Shift 55116
#define sipName_Key_Shift &sipStrings_QtCore[55116]
#define sipNameNr_Key_Right 55126
#define sipName_Key_Right &sipStrings_QtCore[55126]
#define sipNameNr_Key_Clear 55136
#define sipName_Key_Clear &sipStrings_QtCore[55136]
#define sipNameNr_Key_Print 55146
#define sipName_Key_Print &sipStrings_QtCore[55146]
#define sipNameNr_Key_Pause 55156
#define sipName_Key_Pause &sipStrings_QtCore[55156]
#define sipNameNr_Key_Enter 55166
#define sipName_Key_Enter &sipStrings_QtCore[55166]
#define sipNameNr_ColorOnly 55176
#define sipName_ColorOnly &sipStrings_QtCore[55176]
#define sipNameNr_AutoColor 55186
#define sipName_AutoColor &sipStrings_QtCore[55186]
#define sipNameNr_WA_Mapped 55196
#define sipName_WA_Mapped &sipStrings_QtCore[55196]
#define sipNameNr_SubWindow 55206
#define sipName_SubWindow &sipStrings_QtCore[55206]
#define sipNameNr_ElideNone 55216
#define sipName_ElideNone &sipStrings_QtCore[55216]
#define sipNameNr_ElideLeft 55226
#define sipName_ElideLeft &sipStrings_QtCore[55226]
#define sipNameNr_Alignment 4059
#define sipName_Alignment &sipStrings_QtCore[4059]
#define sipNameNr_AlignLeft 55236
#define sipName_AlignLeft &sipStrings_QtCore[55236]
#define sipNameNr_SortOrder 39325
#define sipName_SortOrder &sipStrings_QtCore[39325]
#define sipNameNr_MidButton 55246
#define sipName_MidButton &sipStrings_QtCore[55246]
#define sipNameNr_darkGreen 55256
#define sipName_darkGreen &sipStrings_QtCore[55256]
#define sipNameNr_lightGray 55266
#define sipName_lightGray &sipStrings_QtCore[55266]
#define sipNameNr___index__ 55276
#define sipName___index__ &sipStrings_QtCore[55276]
#define sipNameNr_buildAbi 55286
#define sipName_buildAbi &sipStrings_QtCore[55286]
#define sipNameNr_WordSize 55295
#define sipName_WordSize &sipStrings_QtCore[55295]
#define sipNameNr_QSysInfo 55304
#define sipName_QSysInfo &sipStrings_QtCore[55304]
#define sipNameNr_writeDTD 55313
#define sipName_writeDTD &sipStrings_QtCore[55313]
#define sipNameNr_hasError 55322
#define sipName_hasError &sipStrings_QtCore[55322]
#define sipNameNr_readNext 55331
#define sipName_readNext &sipStrings_QtCore[55331]
#define sipNameNr_publicId 55340
#define sipName_publicId &sipStrings_QtCore[55340]
#define sipNameNr_systemId 55349
#define sipName_systemId &sipStrings_QtCore[55349]
#define sipNameNr_segments 55358
#define sipName_segments &sipStrings_QtCore[55358]
#define sipNameNr_endValue 55367
#define sipName_endValue &sipStrings_QtCore[55367]
#define sipNameNr_UserType 55376
#define sipName_UserType &sipStrings_QtCore[55376]
#define sipNameNr_PolygonF 52797
#define sipName_PolygonF &sipStrings_QtCore[52797]
#define sipNameNr_Vector4D 52807
#define sipName_Vector4D &sipStrings_QtCore[52807]
#define sipNameNr_Vector3D 52817
#define sipName_Vector3D &sipStrings_QtCore[52817]
#define sipNameNr_Vector2D 52827
#define sipName_Vector2D &sipStrings_QtCore[52827]
#define sipNameNr_DateTime 29461
#define sipName_DateTime &sipStrings_QtCore[29461]
#define sipNameNr_BitArray 54527
#define sipName_BitArray &sipStrings_QtCore[54527]
#define sipNameNr_Reserved 31460
#define sipName_Reserved &sipStrings_QtCore[31460]
#define sipNameNr_setQuery 55385
#define sipName_setQuery &sipStrings_QtCore[55385]
#define sipNameNr_hasQuery 55394
#define sipName_hasQuery &sipStrings_QtCore[55394]
#define sipNameNr_resolved 55403
#define sipName_resolved &sipStrings_QtCore[55403]
#define sipNameNr_fragment 55412
#define sipName_fragment &sipStrings_QtCore[55412]
#define sipNameNr_password 55421
#define sipName_password &sipStrings_QtCore[55421]
#define sipNameNr_userName 55430
#define sipName_userName &sipStrings_QtCore[55430]
#define sipNameNr_userInfo 55439
#define sipName_userInfo &sipStrings_QtCore[55439]
#define sipNameNr_nameType 55448
#define sipName_nameType &sipStrings_QtCore[55448]
#define sipNameNr_LongName 55457
#define sipName_LongName &sipStrings_QtCore[55457]
#define sipNameNr_NameType 14255
#define sipName_NameType &sipStrings_QtCore[14255]
#define sipNameNr_TimeType 15570
#define sipName_TimeType &sipStrings_QtCore[15570]
#define sipNameNr_endFrame 55466
#define sipName_endFrame &sipStrings_QtCore[55466]
#define sipNameNr_tryStart 55475
#define sipName_tryStart &sipStrings_QtCore[55475]
#define sipNameNr_Priority 3283
#define sipName_Priority &sipStrings_QtCore[3283]
#define sipNameNr_showbase 48589
#define sipName_showbase &sipStrings_QtCore[48589]
#define sipNameNr_setCodec 55484
#define sipName_setCodec &sipStrings_QtCore[55484]
#define sipNameNr_ShowBase 55493
#define sipName_ShowBase &sipStrings_QtCore[55493]
#define sipNameNr_position 55502
#define sipName_position &sipStrings_QtCore[55502]
#define sipNameNr_Sentence 55511
#define sipName_Sentence &sipStrings_QtCore[55511]
#define sipNameNr_Grapheme 55520
#define sipName_Grapheme &sipStrings_QtCore[55520]
#define sipNameNr_addState 55529
#define sipName_addState &sipStrings_QtCore[55529]
#define sipNameNr_sortRole 55538
#define sipName_sortRole &sipStrings_QtCore[55538]
#define sipNameNr_lessThan 55547
#define sipName_lessThan &sipStrings_QtCore[55547]
#define sipNameNr_shrunkBy 55556
#define sipName_shrunkBy &sipStrings_QtCore[55556]
#define sipNameNr_NotFound 55565
#define sipName_NotFound &sipStrings_QtCore[55565]
#define sipNameNr_KeyError 55574
#define sipName_KeyError &sipStrings_QtCore[55574]
#define sipNameNr_iniCodec 55583
#define sipName_iniCodec &sipStrings_QtCore[55583]
#define sipNameNr_setValue 55592
#define sipName_setValue &sipStrings_QtCore[55592]
#define sipNameNr_endGroup 55601
#define sipName_endGroup &sipStrings_QtCore[55601]
#define sipNameNr_addPause 55610
#define sipName_addPause &sipStrings_QtCore[55610]
#define sipNameNr_peekNext 55619
#define sipName_peekNext &sipStrings_QtCore[55619]
#define sipNameNr_captured 55628
#define sipName_captured &sipStrings_QtCore[55628]
#define sipNameNr_hasMatch 55637
#define sipName_hasMatch &sipStrings_QtCore[55637]
#define sipNameNr_optimize 55646
#define sipName_optimize &sipStrings_QtCore[55646]
#define sipNameNr_Wildcard 21549
#define sipName_Wildcard &sipStrings_QtCore[21549]
#define sipNameNr_setWidth 55655
#define sipName_setWidth &sipStrings_QtCore[55655]
#define sipNameNr_adjusted 55664
#define sipName_adjusted &sipStrings_QtCore[55664]
#define sipNameNr_moveLeft 55673
#define sipName_moveLeft &sipStrings_QtCore[55673]
#define sipNameNr_topRight 55682
#define sipName_topRight &sipStrings_QtCore[55682]
#define sipNameNr_generate 55691
#define sipName_generate &sipStrings_QtCore[55691]
#define sipNameNr_Starting 55700
#define sipName_Starting &sipStrings_QtCore[55700]
#define sipNameNr_Timedout 55709
#define sipName_Timedout &sipStrings_QtCore[55709]
#define sipNameNr_QProcess 55718
#define sipName_QProcess &sipStrings_QtCore[55718]
#define sipNameNr_Windows8 55727
#define sipName_Windows8 &sipStrings_QtCore[55727]
#define sipNameNr_Windows7 55736
#define sipName_Windows7 &sipStrings_QtCore[55736]
#define sipNameNr_pyqtSlot 55745
#define sipName_pyqtSlot &sipStrings_QtCore[55745]
#define sipNameNr_property 55754
#define sipName_property &sipStrings_QtCore[55754]
#define sipNameNr_children 55763
#define sipName_children &sipStrings_QtCore[55763]
#define sipNameNr_inherits 55772
#define sipName_inherits &sipStrings_QtCore[55772]
#define sipNameNr_suffixes 55781
#define sipName_suffixes &sipStrings_QtCore[55781]
#define sipNameNr_iconName 55790
#define sipName_iconName &sipStrings_QtCore[55790]
#define sipNameNr_hasColor 55799
#define sipName_hasColor &sipStrings_QtCore[55799]
#define sipNameNr_hasImage 55808
#define sipName_hasImage &sipStrings_QtCore[55808]
#define sipNameNr_TypeFlag 16010
#define sipName_TypeFlag &sipStrings_QtCore[16010]
#define sipNameNr_QCborMap 55817
#define sipName_QCborMap &sipStrings_QtCore[55817]
#define sipNameNr_QVariant 37548
#define sipName_QVariant &sipStrings_QtCore[37548]
#define sipNameNr_VoidStar 55826
#define sipName_VoidStar &sipStrings_QtCore[55826]
#define sipNameNr_QPolygon 55835
#define sipName_QPolygon &sipStrings_QtCore[55835]
#define sipNameNr_QPalette 55844
#define sipName_QPalette &sipStrings_QtCore[55844]
#define sipNameNr_LongLong 46950
#define sipName_LongLong &sipStrings_QtCore[46950]
#define sipNameNr_userType 55853
#define sipName_userType &sipStrings_QtCore[55853]
#define sipNameNr_isStored 55862
#define sipName_isStored &sipStrings_QtCore[55862]
#define sipNameNr_enumName 55871
#define sipName_enumName &sipStrings_QtCore[55871]
#define sipNameNr_isScoped 55880
#define sipName_isScoped &sipStrings_QtCore[55880]
#define sipNameNr_keyCount 55889
#define sipName_keyCount &sipStrings_QtCore[55889]
#define sipNameNr_typeName 55898
#define sipName_typeName &sipStrings_QtCore[55898]
#define sipNameNr___idiv__ 55907
#define sipName___idiv__ &sipStrings_QtCore[55907]
#define sipNameNr_setRight 55916
#define sipName_setRight &sipStrings_QtCore[55916]
#define sipNameNr_QMargins 55925
#define sipName_QMargins &sipStrings_QtCore[55925]
#define sipNameNr___call__ 55934
#define sipName___call__ &sipStrings_QtCore[55934]
#define sipNameNr_qWarning 55943
#define sipName_qWarning &sipStrings_QtCore[55943]
#define sipNameNr_critical 55952
#define sipName_critical &sipStrings_QtCore[55952]
#define sipNameNr_category 55961
#define sipName_category &sipStrings_QtCore[55961]
#define sipNameNr_function 55970
#define sipName_function &sipStrings_QtCore[55970]
#define sipNameNr_isLocked 55979
#define sipName_isLocked &sipStrings_QtCore[55979]
#define sipNameNr_weekdays 55988
#define sipName_weekdays &sipStrings_QtCore[55988]
#define sipNameNr_YiScript 55997
#define sipName_YiScript &sipStrings_QtCore[55997]
#define sipNameNr_language 56006
#define sipName_language &sipStrings_QtCore[56006]
#define sipNameNr_Guernsey 56015
#define sipName_Guernsey &sipStrings_QtCore[56015]
#define sipNameNr_Zimbabwe 56024
#define sipName_Zimbabwe &sipStrings_QtCore[56024]
#define sipNameNr_Thailand 56033
#define sipName_Thailand &sipStrings_QtCore[56033]
#define sipNameNr_Tanzania 56042
#define sipName_Tanzania &sipStrings_QtCore[56042]
#define sipNameNr_Suriname 56051
#define sipName_Suriname &sipStrings_QtCore[56051]
#define sipNameNr_SriLanka 56060
#define sipName_SriLanka &sipStrings_QtCore[56060]
#define sipNameNr_Slovenia 56069
#define sipName_Slovenia &sipStrings_QtCore[56069]
#define sipNameNr_Slovakia 56078
#define sipName_Slovakia &sipStrings_QtCore[56078]
#define sipNameNr_Portugal 56087
#define sipName_Portugal &sipStrings_QtCore[56087]
#define sipNameNr_Pitcairn 56096
#define sipName_Pitcairn &sipStrings_QtCore[56096]
#define sipNameNr_Paraguay 56105
#define sipName_Paraguay &sipStrings_QtCore[56105]
#define sipNameNr_Pakistan 56114
#define sipName_Pakistan &sipStrings_QtCore[56114]
#define sipNameNr_Mongolia 56123
#define sipName_Mongolia &sipStrings_QtCore[56123]
#define sipNameNr_Maldives 56132
#define sipName_Maldives &sipStrings_QtCore[56132]
#define sipNameNr_Malaysia 56141
#define sipName_Malaysia &sipStrings_QtCore[56141]
#define sipNameNr_Kiribati 56150
#define sipName_Kiribati &sipStrings_QtCore[56150]
#define sipNameNr_HongKong 56159
#define sipName_HongKong &sipStrings_QtCore[56159]
#define sipNameNr_Honduras 56168
#define sipName_Honduras &sipStrings_QtCore[56168]
#define sipNameNr_Ethiopia 56177
#define sipName_Ethiopia &sipStrings_QtCore[56177]
#define sipNameNr_Dominica 56186
#define sipName_Dominica &sipStrings_QtCore[56186]
#define sipNameNr_Djibouti 56195
#define sipName_Djibouti &sipStrings_QtCore[56195]
#define sipNameNr_Colombia 56204
#define sipName_Colombia &sipStrings_QtCore[56204]
#define sipNameNr_Cameroon 56213
#define sipName_Cameroon &sipStrings_QtCore[56213]
#define sipNameNr_Cambodia 56222
#define sipName_Cambodia &sipStrings_QtCore[56222]
#define sipNameNr_Bulgaria 56231
#define sipName_Bulgaria &sipStrings_QtCore[56231]
#define sipNameNr_Botswana 56240
#define sipName_Botswana &sipStrings_QtCore[56240]
#define sipNameNr_Barbados 56249
#define sipName_Barbados &sipStrings_QtCore[56249]
#define sipNameNr_Anguilla 56258
#define sipName_Anguilla &sipStrings_QtCore[56258]
#define sipNameNr_Silesian 56267
#define sipName_Silesian &sipStrings_QtCore[56267]
#define sipNameNr_Muscogee 56276
#define sipName_Muscogee &sipStrings_QtCore[56276]
#define sipNameNr_Sicilian 56285
#define sipName_Sicilian &sipStrings_QtCore[56285]
#define sipNameNr_TokPisin 56294
#define sipName_TokPisin &sipStrings_QtCore[56294]
#define sipNameNr_Bhojpuri 56303
#define sipName_Bhojpuri &sipStrings_QtCore[56303]
#define sipNameNr_Maithili 56312
#define sipName_Maithili &sipStrings_QtCore[56312]
#define sipNameNr_Lezghian 56321
#define sipName_Lezghian &sipStrings_QtCore[56321]
#define sipNameNr_Warlpiri 56330
#define sipName_Warlpiri &sipStrings_QtCore[56330]
#define sipNameNr_LuleSami 56339
#define sipName_LuleSami &sipStrings_QtCore[56339]
#define sipNameNr_Prussian 56348
#define sipName_Prussian &sipStrings_QtCore[56348]
#define sipNameNr_Ugaritic 56357
#define sipName_Ugaritic &sipStrings_QtCore[56357]
#define sipNameNr_Tagbanwa 56366
#define sipName_Tagbanwa &sipStrings_QtCore[56366]
#define sipNameNr_Parthian 56375
#define sipName_Parthian &sipStrings_QtCore[56375]
#define sipNameNr_OldNorse 56384
#define sipName_OldNorse &sipStrings_QtCore[56384]
#define sipNameNr_OldIrish 56393
#define sipName_OldIrish &sipStrings_QtCore[56393]
#define sipNameNr_Meroitic 56402
#define sipName_Meroitic &sipStrings_QtCore[56402]
#define sipNameNr_Manipuri 56411
#define sipName_Manipuri &sipStrings_QtCore[56411]
#define sipNameNr_Mandingo 56420
#define sipName_Mandingo &sipStrings_QtCore[56420]
#define sipNameNr_Etruscan 56429
#define sipName_Etruscan &sipStrings_QtCore[56429]
#define sipNameNr_Buginese 56438
#define sipName_Buginese &sipStrings_QtCore[56438]
#define sipNameNr_Balinese 56447
#define sipName_Balinese &sipStrings_QtCore[56447]
#define sipNameNr_Akkadian 56456
#define sipName_Akkadian &sipStrings_QtCore[56456]
#define sipNameNr_Asturian 56465
#define sipName_Asturian &sipStrings_QtCore[56465]
#define sipNameNr_Kwanyama 56474
#define sipName_Kwanyama &sipStrings_QtCore[56474]
#define sipNameNr_HiriMotu 56483
#define sipName_HiriMotu &sipStrings_QtCore[56483]
#define sipNameNr_Chamorro 56492
#define sipName_Chamorro &sipStrings_QtCore[56492]
#define sipNameNr_Tahitian 56501
#define sipName_Tahitian &sipStrings_QtCore[56501]
#define sipNameNr_Dzongkha 56510
#define sipName_Dzongkha &sipStrings_QtCore[56510]
#define sipNameNr_Shambala 56519
#define sipName_Shambala &sipStrings_QtCore[56519]
#define sipNameNr_Kalenjin 56528
#define sipName_Kalenjin &sipStrings_QtCore[56528]
#define sipNameNr_Morisyen 56537
#define sipName_Morisyen &sipStrings_QtCore[56537]
#define sipNameNr_Cherokee 56546
#define sipName_Cherokee &sipStrings_QtCore[56546]
#define sipNameNr_Nyankole 56555
#define sipName_Nyankole &sipStrings_QtCore[56555]
#define sipNameNr_Filipino 56564
#define sipName_Filipino &sipStrings_QtCore[56564]
#define sipNameNr_Hawaiian 56573
#define sipName_Hawaiian &sipStrings_QtCore[56573]
#define sipNameNr_Friulian 56582
#define sipName_Friulian &sipStrings_QtCore[56582]
#define sipNameNr_Tigrinya 56591
#define sipName_Tigrinya &sipStrings_QtCore[56591]
#define sipNameNr_Sanskrit 56600
#define sipName_Sanskrit &sipStrings_QtCore[56600]
#define sipNameNr_Romanian 56609
#define sipName_Romanian &sipStrings_QtCore[56609]
#define sipNameNr_Malagasy 56618
#define sipName_Malagasy &sipStrings_QtCore[56618]
#define sipNameNr_Kashmiri 56627
#define sipName_Kashmiri &sipStrings_QtCore[56627]
#define sipNameNr_Javanese 56636
#define sipName_Javanese &sipStrings_QtCore[56636]
#define sipNameNr_Japanese 56645
#define sipName_Japanese &sipStrings_QtCore[56645]
#define sipNameNr_Gujarati 56654
#define sipName_Gujarati &sipStrings_QtCore[56654]
#define sipNameNr_Georgian 56663
#define sipName_Georgian &sipStrings_QtCore[56663]
#define sipNameNr_Galician 56672
#define sipName_Galician &sipStrings_QtCore[56672]
#define sipNameNr_Estonian 56681
#define sipName_Estonian &sipStrings_QtCore[56681]
#define sipNameNr_Croatian 37142
#define sipName_Croatian &sipStrings_QtCore[37142]
#define sipNameNr_Corsican 56690
#define sipName_Corsican &sipStrings_QtCore[56690]
#define sipNameNr_Assamese 56699
#define sipName_Assamese &sipStrings_QtCore[56699]
#define sipNameNr_Armenian 56708
#define sipName_Armenian &sipStrings_QtCore[56708]
#define sipNameNr_Albanian 56717
#define sipName_Albanian &sipStrings_QtCore[56717]
#define sipNameNr_Language 14024
#define sipName_Language &sipStrings_QtCore[14024]
#define sipNameNr_setAngle 56726
#define sipName_setAngle &sipStrings_QtCore[56726]
#define sipNameNr_location 56735
#define sipName_location &sipStrings_QtCore[56735]
#define sipNameNr_DataPath 41751
#define sipName_DataPath &sipStrings_QtCore[41751]
#define sipNameNr_licensee 56744
#define sipName_licensee &sipStrings_QtCore[56744]
#define sipNameNr_isLoaded 56753
#define sipName_isLoaded &sipStrings_QtCore[56753]
#define sipNameNr_LoadHint 18938
#define sipName_LoadHint &sipStrings_QtCore[18938]
#define sipNameNr_QLibrary 56762
#define sipName_QLibrary &sipStrings_QtCore[56762]
#define sipNameNr_toObject 56771
#define sipName_toObject &sipStrings_QtCore[56771]
#define sipNameNr_setArray 56780
#define sipName_setArray &sipStrings_QtCore[56780]
#define sipNameNr_isObject 56789
#define sipName_isObject &sipStrings_QtCore[56789]
#define sipNameNr_fromJson 56798
#define sipName_fromJson &sipStrings_QtCore[56798]
#define sipNameNr_Indented 56807
#define sipName_Indented &sipStrings_QtCore[56807]
#define sipNameNr_Validate 56816
#define sipName_Validate &sipStrings_QtCore[56816]
#define sipNameNr_takeLast 56825
#define sipName_takeLast &sipStrings_QtCore[56825]
#define sipNameNr_removeAt 56834
#define sipName_removeAt &sipStrings_QtCore[56834]
#define sipNameNr_setModel 29877
#define sipName_setModel &sipStrings_QtCore[29877]
#define sipNameNr_Deselect 56843
#define sipName_Deselect &sipStrings_QtCore[56843]
#define sipNameNr_NoUpdate 56852
#define sipName_NoUpdate &sipStrings_QtCore[56852]
#define sipNameNr_readLine 56861
#define sipName_readLine &sipStrings_QtCore[56861]
#define sipNameNr_OpenMode 16370
#define sipName_OpenMode &sipStrings_QtCore[16370]
#define sipNameNr_Truncate 56870
#define sipName_Truncate &sipStrings_QtCore[56870]
#define sipNameNr_ReadOnly 48688
#define sipName_ReadOnly &sipStrings_QtCore[48688]
#define sipNameNr_addPaths 56879
#define sipName_addPaths &sipStrings_QtCore[56879]
#define sipNameNr_isBundle 56888
#define sipName_isBundle &sipStrings_QtCore[56888]
#define sipNameNr_lastRead 56897
#define sipName_lastRead &sipStrings_QtCore[56897]
#define sipNameNr_baseName 56906
#define sipName_baseName &sipStrings_QtCore[56906]
#define sipNameNr_fileTime 56915
#define sipName_fileTime &sipStrings_QtCore[56915]
#define sipNameNr_FileTime 12108
#define sipName_FileTime &sipStrings_QtCore[12108]
#define sipNameNr_ExeOther 56924
#define sipName_ExeOther &sipStrings_QtCore[56924]
#define sipNameNr_ExeGroup 56933
#define sipName_ExeGroup &sipStrings_QtCore[56933]
#define sipNameNr_ReadUser 56942
#define sipName_ReadUser &sipStrings_QtCore[56942]
#define sipNameNr_ExeOwner 56951
#define sipName_ExeOwner &sipStrings_QtCore[56951]
#define sipNameNr_OutCurve 31625
#define sipName_OutCurve &sipStrings_QtCore[31625]
#define sipNameNr_InBounce 46206
#define sipName_InBounce &sipStrings_QtCore[46206]
#define sipNameNr_OutQuint 50184
#define sipName_OutQuint &sipStrings_QtCore[50184]
#define sipNameNr_OutQuart 50206
#define sipName_OutQuart &sipStrings_QtCore[50206]
#define sipNameNr_OutCubic 50228
#define sipName_OutCubic &sipStrings_QtCore[50228]
#define sipNameNr_fileInfo 56960
#define sipName_fileInfo &sipStrings_QtCore[56960]
#define sipNameNr_tempPath 56969
#define sipName_tempPath &sipStrings_QtCore[56969]
#define sipNameNr_rootPath 56978
#define sipName_rootPath &sipStrings_QtCore[56978]
#define sipNameNr_homePath 56987
#define sipName_homePath &sipStrings_QtCore[56987]
#define sipNameNr_filePath 56996
#define sipName_filePath &sipStrings_QtCore[56996]
#define sipNameNr_fileName 57005
#define sipName_fileName &sipStrings_QtCore[57005]
#define sipNameNr_DirsLast 57014
#define sipName_DirsLast &sipStrings_QtCore[57014]
#define sipNameNr_Reversed 57023
#define sipName_Reversed &sipStrings_QtCore[57023]
#define sipNameNr_Unsorted 57032
#define sipName_Unsorted &sipStrings_QtCore[57032]
#define sipNameNr_SortFlag 33395
#define sipName_SortFlag &sipStrings_QtCore[33395]
#define sipNameNr_NoDotDot 57041
#define sipName_NoDotDot &sipStrings_QtCore[57041]
#define sipNameNr_NoFilter 57050
#define sipName_NoFilter &sipStrings_QtCore[57050]
#define sipNameNr_Modified 23997
#define sipName_Modified &sipStrings_QtCore[23997]
#define sipNameNr_Writable 50008
#define sipName_Writable &sipStrings_QtCore[50008]
#define sipNameNr_Readable 50272
#define sipName_Readable &sipStrings_QtCore[50272]
#define sipNameNr_TypeMask 57059
#define sipName_TypeMask &sipStrings_QtCore[57059]
#define sipNameNr___isub__ 57068
#define sipName___isub__ &sipStrings_QtCore[57068]
#define sipNameNr_addNSecs 57077
#define sipName_addNSecs &sipStrings_QtCore[57077]
#define sipNameNr_deadline 57086
#define sipName_deadline &sipStrings_QtCore[57086]
#define sipNameNr_timeZone 57095
#define sipName_timeZone &sipStrings_QtCore[57095]
#define sipNameNr_toTime_t 57104
#define sipName_toTime_t &sipStrings_QtCore[57104]
#define sipNameNr_timeSpec 57113
#define sipName_timeSpec &sipStrings_QtCore[57113]
#define sipNameNr_addMSecs 57122
#define sipName_addMSecs &sipStrings_QtCore[57122]
#define sipNameNr_toPyTime 57131
#define sipName_toPyTime &sipStrings_QtCore[57131]
#define sipNameNr_endOfDay 57140
#define sipName_endOfDay &sipStrings_QtCore[57140]
#define sipNameNr_addYears 57149
#define sipName_addYears &sipStrings_QtCore[57149]
#define sipNameNr_toPyDate 57158
#define sipName_toPyDate &sipStrings_QtCore[57158]
#define sipNameNr_writeInt 57167
#define sipName_writeInt &sipStrings_QtCore[57167]
#define sipNameNr_readBool 57176
#define sipName_readBool &sipStrings_QtCore[57176]
#define sipNameNr_readInt8 57185
#define sipName_readInt8 &sipStrings_QtCore[57185]
#define sipNameNr_Sha3_512 57194
#define sipName_Sha3_512 &sipStrings_QtCore[57194]
#define sipNameNr_Sha3_384 57203
#define sipName_Sha3_384 &sipStrings_QtCore[57203]
#define sipNameNr_Sha3_256 57212
#define sipName_Sha3_256 &sipStrings_QtCore[57212]
#define sipNameNr_Sha3_224 57221
#define sipName_Sha3_224 &sipStrings_QtCore[57221]
#define sipNameNr_polished 57230
#define sipName_polished &sipStrings_QtCore[57230]
#define sipNameNr_TouchEnd 57239
#define sipName_TouchEnd &sipStrings_QtCore[57239]
#define sipNameNr_Shortcut 5514
#define sipName_Shortcut &sipStrings_QtCore[5514]
#define sipNameNr_FileOpen 57248
#define sipName_FileOpen &sipStrings_QtCore[57248]
#define sipNameNr_IconDrag 57257
#define sipName_IconDrag &sipStrings_QtCore[57257]
#define sipNameNr_DragMove 12218
#define sipName_DragMove &sipStrings_QtCore[12218]
#define sipNameNr_MetaCall 57266
#define sipName_MetaCall &sipStrings_QtCore[57266]
#define sipNameNr_FocusOut 57275
#define sipName_FocusOut &sipStrings_QtCore[57275]
#define sipNameNr_KeyPress 57284
#define sipName_KeyPress &sipStrings_QtCore[57284]
#define sipNameNr___exit__ 57293
#define sipName___exit__ &sipStrings_QtCore[57293]
#define sipNameNr_priority 57302
#define sipName_priority &sipStrings_QtCore[57302]
#define sipNameNr_receiver 57311
#define sipName_receiver &sipStrings_QtCore[57311]
#define sipNameNr_helpText 57320
#define sipName_helpText &sipStrings_QtCore[57320]
#define sipNameNr_showHelp 57329
#define sipName_showHelp &sipStrings_QtCore[57329]
#define sipNameNr_exitCode 57338
#define sipName_exitCode &sipStrings_QtCore[57338]
#define sipNameNr_setFlags 57347
#define sipName_setFlags &sipStrings_QtCore[57347]
#define sipNameNr_isHidden 57356
#define sipName_isHidden &sipStrings_QtCore[57356]
#define sipNameNr_isDouble 57365
#define sipName_isDouble &sipStrings_QtCore[57365]
#define sipNameNr_isString 57374
#define sipName_isString &sipStrings_QtCore[57374]
#define sipNameNr_startMap 57383
#define sipName_startMap &sipStrings_QtCore[57383]
#define sipNameNr_endArray 57392
#define sipName_endArray &sipStrings_QtCore[57392]
#define sipNameNr_COSE_Mac 57401
#define sipName_COSE_Mac &sipStrings_QtCore[57401]
#define sipNameNr_Bigfloat 57410
#define sipName_Bigfloat &sipStrings_QtCore[57410]
#define sipNameNr_toString 57419
#define sipName_toString &sipStrings_QtCore[57419]
#define sipNameNr_repeated 57428
#define sipName_repeated &sipStrings_QtCore[57428]
#define sipNameNr_contains 57437
#define sipName_contains &sipStrings_QtCore[57437]
#define sipNameNr_capacity 57446
#define sipName_capacity &sipStrings_QtCore[57446]
#define sipNameNr___imul__ 57455
#define sipName___imul__ &sipStrings_QtCore[57455]
#define sipNameNr___repr__ 57464
#define sipName___repr__ &sipStrings_QtCore[57464]
#define sipNameNr_toBase64 57473
#define sipName_toBase64 &sipStrings_QtCore[57473]
#define sipNameNr_toDouble 57482
#define sipName_toDouble &sipStrings_QtCore[57482]
#define sipNameNr_toUShort 57491
#define sipName_toUShort &sipStrings_QtCore[57491]
#define sipNameNr___iadd__ 57500
#define sipName___iadd__ &sipStrings_QtCore[57500]
#define sipNameNr_endsWith 57509
#define sipName_endsWith &sipStrings_QtCore[57509]
#define sipNameNr_readData 57518
#define sipName_readData &sipStrings_QtCore[57518]
#define sipNameNr_openMode 57527
#define sipName_openMode &sipStrings_QtCore[57527]
#define sipNameNr_fromBits 57536
#define sipName_fromBits &sipStrings_QtCore[57536]
#define sipNameNr_clearBit 57545
#define sipName_clearBit &sipStrings_QtCore[57545]
#define sipNameNr_truncate 57554
#define sipName_truncate &sipStrings_QtCore[57554]
#define sipNameNr_isActive 57563
#define sipName_isActive &sipStrings_QtCore[57563]
#define sipNameNr_NoOption 57572
#define sipName_NoOption &sipStrings_QtCore[57572]
#define sipNameNr_moveRows 29893
#define sipName_moveRows &sipStrings_QtCore[29893]
#define sipNameNr_mimeData 57581
#define sipName_mimeData &sipStrings_QtCore[57581]
#define sipNameNr_itemData 57590
#define sipName_itemData &sipStrings_QtCore[57590]
#define sipNameNr_rowCount 57599
#define sipName_rowCount &sipStrings_QtCore[57599]
#define sipNameNr_hasIndex 57608
#define sipName_hasIndex &sipStrings_QtCore[57608]
#define sipNameNr_instance 57617
#define sipName_instance &sipStrings_QtCore[57617]
#define sipNameNr_interval 57626
#define sipName_interval &sipStrings_QtCore[57626]
#define sipNameNr_finished 57635
#define sipName_finished &sipStrings_QtCore[57635]
#define sipNameNr_duration 57644
#define sipName_duration &sipStrings_QtCore[57644]
#define sipNameNr_Backward 57653
#define sipName_Backward &sipStrings_QtCore[57653]
#define sipNameNr_LeftEdge 57662
#define sipName_LeftEdge &sipStrings_QtCore[57662]
#define sipNameNr_Qt__Edge 57671
#define sipName_Qt__Edge &sipStrings_QtCore[57671]
#define sipNameNr_FuzzyHit 57680
#define sipName_FuzzyHit &sipStrings_QtCore[57680]
#define sipNameNr_ExactHit 57689
#define sipName_ExactHit &sipStrings_QtCore[57689]
#define sipNameNr_TileRule 42973
#define sipName_TileRule &sipStrings_QtCore[42973]
#define sipNameNr_SizeHint 42999
#define sipName_SizeHint &sipStrings_QtCore[42999]
#define sipNameNr_SizeMode 43038
#define sipName_SizeMode &sipStrings_QtCore[43038]
#define sipNameNr_Qt__Axis 57698
#define sipName_Qt__Axis &sipStrings_QtCore[57698]
#define sipNameNr_MaskMode 43064
#define sipName_MaskMode &sipStrings_QtCore[43064]
#define sipNameNr_NonModal 57707
#define sipName_NonModal &sipStrings_QtCore[57707]
#define sipNameNr_ItemFlag 43103
#define sipName_ItemFlag &sipStrings_QtCore[43103]
#define sipNameNr_UserRole 57716
#define sipName_UserRole &sipStrings_QtCore[57716]
#define sipNameNr_FontRole 57725
#define sipName_FontRole &sipStrings_QtCore[57725]
#define sipNameNr_EditRole 57734
#define sipName_EditRole &sipStrings_QtCore[57734]
#define sipNameNr_FillRule 43168
#define sipName_FillRule &sipStrings_QtCore[43168]
#define sipNameNr_Saturday 57743
#define sipName_Saturday &sipStrings_QtCore[57743]
#define sipNameNr_Thursday 57752
#define sipName_Thursday &sipStrings_QtCore[57752]
#define sipNameNr_TimeZone 31550
#define sipName_TimeZone &sipStrings_QtCore[31550]
#define sipNameNr_TimeSpec 43181
#define sipName_TimeSpec &sipStrings_QtCore[43181]
#define sipNameNr_TextDate 57761
#define sipName_TextDate &sipStrings_QtCore[57761]
#define sipNameNr_AutoText 57770
#define sipName_AutoText &sipStrings_QtCore[57770]
#define sipNameNr_RichText 57779
#define sipName_RichText &sipStrings_QtCore[57779]
#define sipNameNr_UIEffect 43272
#define sipName_UIEffect &sipStrings_QtCore[43272]
#define sipNameNr_RoundCap 57788
#define sipName_RoundCap &sipStrings_QtCore[57788]
#define sipNameNr_DashLine 34670
#define sipName_DashLine &sipStrings_QtCore[34670]
#define sipNameNr_PenStyle 43350
#define sipName_PenStyle &sipStrings_QtCore[43350]
#define sipNameNr_Key_Redo 57797
#define sipName_Key_Redo &sipStrings_QtCore[57797]
#define sipNameNr_Key_Undo 57806
#define sipName_Key_Undo &sipStrings_QtCore[57806]
#define sipNameNr_Key_Find 57815
#define sipName_Key_Find &sipStrings_QtCore[57815]
#define sipNameNr_Key_Open 57824
#define sipName_Key_Open &sipStrings_QtCore[57824]
#define sipNameNr_Key_Exit 57833
#define sipName_Key_Exit &sipStrings_QtCore[57833]
#define sipNameNr_Key_Info 57842
#define sipName_Key_Info &sipStrings_QtCore[57842]
#define sipNameNr_Key_Blue 57851
#define sipName_Key_Blue &sipStrings_QtCore[57851]
#define sipNameNr_Key_View 57860
#define sipName_Key_View &sipStrings_QtCore[57860]
#define sipNameNr_Key_Time 57869
#define sipName_Key_Time &sipStrings_QtCore[57869]
#define sipNameNr_Key_WLAN 57878
#define sipName_Key_WLAN &sipStrings_QtCore[57878]
#define sipNameNr_Key_Away 57887
#define sipName_Key_Away &sipStrings_QtCore[57887]
#define sipNameNr_Key_Xfer 57896
#define sipName_Key_Xfer &sipStrings_QtCore[57896]
#define sipNameNr_Key_Word 57905
#define sipName_Key_Word &sipStrings_QtCore[57905]
#define sipNameNr_Key_Send 57914
#define sipName_Key_Send &sipStrings_QtCore[57914]
#define sipNameNr_Key_Save 57923
#define sipName_Key_Save &sipStrings_QtCore[57923]
#define sipNameNr_Key_News 57932
#define sipName_Key_News &sipStrings_QtCore[57932]
#define sipNameNr_Key_Game 57941
#define sipName_Key_Game &sipStrings_QtCore[57941]
#define sipNameNr_Key_Copy 57950
#define sipName_Key_Copy &sipStrings_QtCore[57950]
#define sipNameNr_Key_Book 57959
#define sipName_Key_Book &sipStrings_QtCore[57959]
#define sipNameNr_Key_Shop 57968
#define sipName_Key_Shop &sipStrings_QtCore[57968]
#define sipNameNr_Key_Memo 57977
#define sipName_Key_Memo &sipStrings_QtCore[57977]
#define sipNameNr_Key_Zoom 57986
#define sipName_Key_Zoom &sipStrings_QtCore[57986]
#define sipNameNr_Key_Play 57995
#define sipName_Key_Play &sipStrings_QtCore[57995]
#define sipNameNr_Key_Flip 58004
#define sipName_Key_Flip &sipStrings_QtCore[58004]
#define sipNameNr_Key_Call 58013
#define sipName_Key_Call &sipStrings_QtCore[58013]
#define sipNameNr_Key_Stop 58022
#define sipName_Key_Stop &sipStrings_QtCore[58022]
#define sipNameNr_Key_Back 58031
#define sipName_Key_Back &sipStrings_QtCore[58031]
#define sipNameNr_Key_cent 58040
#define sipName_Key_cent &sipStrings_QtCore[58040]
#define sipNameNr_Key_Less 58049
#define sipName_Key_Less &sipStrings_QtCore[58049]
#define sipNameNr_Key_Plus 58058
#define sipName_Key_Plus &sipStrings_QtCore[58058]
#define sipNameNr_Key_Help 58067
#define sipName_Key_Help &sipStrings_QtCore[58067]
#define sipNameNr_Key_Menu 58076
#define sipName_Key_Menu &sipStrings_QtCore[58076]
#define sipNameNr_Key_Meta 58085
#define sipName_Key_Meta &sipStrings_QtCore[58085]
#define sipNameNr_Key_Down 58094
#define sipName_Key_Down &sipStrings_QtCore[58094]
#define sipNameNr_Key_Left 58103
#define sipName_Key_Left &sipStrings_QtCore[58103]
#define sipNameNr_Key_Home 58112
#define sipName_Key_Home &sipStrings_QtCore[58112]
#define sipNameNr_MonoOnly 58121
#define sipName_MonoOnly &sipStrings_QtCore[58121]
#define sipNameNr_WA_Hover 58130
#define sipName_WA_Hover &sipStrings_QtCore[58130]
#define sipNameNr_WA_Moved 58139
#define sipName_WA_Moved &sipStrings_QtCore[58139]
#define sipNameNr_TextFlag 43870
#define sipName_TextFlag &sipStrings_QtCore[43870]
#define sipNameNr_AlignTop 58148
#define sipName_AlignTop &sipStrings_QtCore[58148]
#define sipNameNr_TabFocus 51042
#define sipName_TabFocus &sipStrings_QtCore[51042]
#define sipNameNr_Vertical 58157
#define sipName_Vertical &sipStrings_QtCore[58157]
#define sipNameNr_XButton2 58166
#define sipName_XButton2 &sipStrings_QtCore[58166]
#define sipNameNr_XButton1 58175
#define sipName_XButton1 &sipStrings_QtCore[58175]
#define sipNameNr_NoButton 58184
#define sipName_NoButton &sipStrings_QtCore[58184]
#define sipNameNr_Modifier 15389
#define sipName_Modifier &sipStrings_QtCore[15389]
#define sipNameNr_darkCyan 58193
#define sipName_darkCyan &sipStrings_QtCore[58193]
#define sipNameNr_darkBlue 58202
#define sipName_darkBlue &sipStrings_QtCore[58202]
#define sipNameNr_darkGray 58211
#define sipName_darkGray &sipStrings_QtCore[58211]
#define sipNameNr_quintptr 58220
#define sipName_quintptr &sipStrings_QtCore[58220]
#define sipNameNr___hash__ 58229
#define sipName___hash__ &sipStrings_QtCore[58229]
#define sipNameNr___bool__ 58238
#define sipName___bool__ &sipStrings_QtCore[58238]
#define sipNameNr___ixor__ 58247
#define sipName___ixor__ &sipStrings_QtCore[58247]
#define sipNameNr___iand__ 58256
#define sipName___iand__ &sipStrings_QtCore[58256]
#define sipNameNr_qVersion 58265
#define sipName_qVersion &sipStrings_QtCore[58265]
#define sipNameNr_qRound64 58274
#define sipName_qRound64 &sipStrings_QtCore[58274]
#define sipNameNr_dtdName 58283
#define sipName_dtdName &sipStrings_QtCore[58283]
#define sipNameNr_isCDATA 58291
#define sipName_isCDATA &sipStrings_QtCore[58291]
#define sipNameNr_Comment 39646
#define sipName_Comment &sipStrings_QtCore[39646]
#define sipNameNr_NoToken 58299
#define sipName_NoToken &sipStrings_QtCore[58299]
#define sipNameNr_wakeAll 58307
#define sipName_wakeAll &sipStrings_QtCore[58307]
#define sipNameNr_wakeOne 58315
#define sipName_wakeOne &sipStrings_QtCore[58315]
#define sipNameNr_convert 58323
#define sipName_convert &sipStrings_QtCore[58323]
#define sipNameNr_Polygon 55836
#define sipName_Polygon &sipStrings_QtCore[55836]
#define sipNameNr_Palette 38221
#define sipName_Palette &sipStrings_QtCore[38221]
#define sipNameNr_Variant 31401
#define sipName_Variant &sipStrings_QtCore[31401]
#define sipNameNr_matches 58331
#define sipName_matches &sipStrings_QtCore[58331]
#define sipNameNr_fromAce 58339
#define sipName_fromAce &sipStrings_QtCore[58339]
#define sipNameNr_setPort 58347
#define sipName_setPort &sipStrings_QtCore[58347]
#define sipNameNr_setHost 58355
#define sipName_setHost &sipStrings_QtCore[58355]
#define sipNameNr_tryTake 58363
#define sipName_tryTake &sipStrings_QtCore[58363]
#define sipNameNr_QThread 58371
#define sipName_QThread &sipStrings_QtCore[58371]
#define sipNameNr_padChar 58379
#define sipName_padChar &sipStrings_QtCore[58379]
#define sipNameNr_mibEnum 58387
#define sipName_mibEnum &sipStrings_QtCore[58387]
#define sipNameNr_toStart 58395
#define sipName_toStart &sipStrings_QtCore[58395]
#define sipNameNr_isReady 58403
#define sipName_isReady &sipStrings_QtCore[58403]
#define sipNameNr_stopped 58411
#define sipName_stopped &sipStrings_QtCore[58411]
#define sipNameNr_grownBy 58419
#define sipName_grownBy &sipStrings_QtCore[58419]
#define sipNameNr_mapping 58427
#define sipName_mapping &sipStrings_QtCore[58427]
#define sipNameNr_QWidget 58435
#define sipName_QWidget &sipStrings_QtCore[58435]
#define sipNameNr_allKeys 58443
#define sipName_allKeys &sipStrings_QtCore[58443]
#define sipNameNr_release 58451
#define sipName_release &sipStrings_QtCore[58451]
#define sipNameNr_acquire 58459
#define sipName_acquire &sipStrings_QtCore[58459]
#define sipNameNr_mapRoot 58467
#define sipName_mapRoot &sipStrings_QtCore[58467]
#define sipNameNr_NoMatch 58475
#define sipName_NoMatch &sipStrings_QtCore[58475]
#define sipNameNr_RegExp2 58483
#define sipName_RegExp2 &sipStrings_QtCore[58483]
#define sipNameNr_setSize 58491
#define sipName_setSize &sipStrings_QtCore[58491]
#define sipNameNr_setRect 58499
#define sipName_setRect &sipStrings_QtCore[58499]
#define sipNameNr_getRect 9296
#define sipName_getRect &sipStrings_QtCore[9296]
#define sipNameNr_moveTop 58507
#define sipName_moveTop &sipStrings_QtCore[58507]
#define sipNameNr_global_ 58515
#define sipName_global_ &sipStrings_QtCore[58515]
#define sipNameNr_discard 58523
#define sipName_discard &sipStrings_QtCore[58523]
#define sipNameNr_bounded 58531
#define sipName_bounded &sipStrings_QtCore[58531]
#define sipNameNr_started 58539
#define sipName_started &sipStrings_QtCore[58539]
#define sipNameNr_execute 58547
#define sipName_execute &sipStrings_QtCore[58547]
#define sipNameNr_program 58555
#define sipName_program &sipStrings_QtCore[58555]
#define sipNameNr_Crashed 58563
#define sipName_Crashed &sipStrings_QtCore[58563]
#define sipNameNr_toPoint 58571
#define sipName_toPoint &sipStrings_QtCore[58571]
#define sipNameNr_Android 58579
#define sipName_Android &sipStrings_QtCore[58579]
#define sipNameNr_WatchOS 58587
#define sipName_WatchOS &sipStrings_QtCore[58587]
#define sipNameNr_Windows 23728
#define sipName_Windows &sipStrings_QtCore[23728]
#define sipNameNr_Unknown 48436
#define sipName_Unknown &sipStrings_QtCore[48436]
#define sipNameNr_unblock 58595
#define sipName_unblock &sipStrings_QtCore[58595]
#define sipNameNr_reblock 58603
#define sipName_reblock &sipStrings_QtCore[58603]
#define sipNameNr_Q_FLAGS 58611
#define sipName_Q_FLAGS &sipStrings_QtCore[58611]
#define sipNameNr_Q_ENUMS 58619
#define sipName_Q_ENUMS &sipStrings_QtCore[58619]
#define sipNameNr_aliases 58627
#define sipName_aliases &sipStrings_QtCore[58627]
#define sipNameNr_comment 58635
#define sipName_comment &sipStrings_QtCore[58635]
#define sipNameNr_formats 58643
#define sipName_formats &sipStrings_QtCore[58643]
#define sipNameNr_hasHtml 58651
#define sipName_hasHtml &sipStrings_QtCore[58651]
#define sipNameNr_setHtml 58659
#define sipName_setHtml &sipStrings_QtCore[58659]
#define sipNameNr_hasText 58667
#define sipName_hasText &sipStrings_QtCore[58667]
#define sipNameNr_setText 58675
#define sipName_setText &sipStrings_QtCore[58675]
#define sipNameNr_hasUrls 58683
#define sipName_hasUrls &sipStrings_QtCore[58683]
#define sipNameNr_setUrls 58691
#define sipName_setUrls &sipStrings_QtCore[58691]
#define sipNameNr_QMatrix 58699
#define sipName_QMatrix &sipStrings_QtCore[58699]
#define sipNameNr_QCursor 58707
#define sipName_QCursor &sipStrings_QtCore[58707]
#define sipNameNr_QBitmap 58715
#define sipName_QBitmap &sipStrings_QtCore[58715]
#define sipNameNr_QRegion 58723
#define sipName_QRegion &sipStrings_QtCore[58723]
#define sipNameNr_QPixmap 58731
#define sipName_QPixmap &sipStrings_QtCore[58731]
#define sipNameNr_QRegExp 58739
#define sipName_QRegExp &sipStrings_QtCore[58739]
#define sipNameNr_QPointF 58747
#define sipName_QPointF &sipStrings_QtCore[58747]
#define sipNameNr_QString 42298
#define sipName_QString &sipStrings_QtCore[42298]
#define sipNameNr_isFinal 58755
#define sipName_isFinal &sipStrings_QtCore[58755]
#define sipNameNr_Private 58763
#define sipName_Private &sipStrings_QtCore[58763]
#define sipNameNr___pos__ 58771
#define sipName___pos__ &sipStrings_QtCore[58771]
#define sipNameNr___neg__ 58779
#define sipName___neg__ &sipStrings_QtCore[58779]
#define sipNameNr___div__ 58787
#define sipName___div__ &sipStrings_QtCore[58787]
#define sipNameNr_setLeft 58795
#define sipName_setLeft &sipStrings_QtCore[58795]
#define sipNameNr_warning 58803
#define sipName_warning &sipStrings_QtCore[58803]
#define sipNameNr_tryLock 58811
#define sipName_tryLock &sipStrings_QtCore[58811]
#define sipNameNr_dayName 58819
#define sipName_dayName &sipStrings_QtCore[58819]
#define sipNameNr_country 58827
#define sipName_country &sipStrings_QtCore[58827]
#define sipNameNr_Bonaire 58835
#define sipName_Bonaire &sipStrings_QtCore[58835]
#define sipNameNr_Vietnam 58843
#define sipName_Vietnam &sipStrings_QtCore[58843]
#define sipNameNr_CuraSao 58851
#define sipName_CuraSao &sipStrings_QtCore[58851]
#define sipNameNr_Vanuatu 58859
#define sipName_Vanuatu &sipStrings_QtCore[58859]
#define sipNameNr_Uruguay 58867
#define sipName_Uruguay &sipStrings_QtCore[58867]
#define sipNameNr_Ukraine 58875
#define sipName_Ukraine &sipStrings_QtCore[58875]
#define sipNameNr_Tunisia 58883
#define sipName_Tunisia &sipStrings_QtCore[58883]
#define sipNameNr_Tokelau 58891
#define sipName_Tokelau &sipStrings_QtCore[58891]
#define sipNameNr_Somalia 58899
#define sipName_Somalia &sipStrings_QtCore[58899]
#define sipNameNr_Senegal 58907
#define sipName_Senegal &sipStrings_QtCore[58907]
#define sipNameNr_Romania 58915
#define sipName_Romania &sipStrings_QtCore[58915]
#define sipNameNr_Reunion 58923
#define sipName_Reunion &sipStrings_QtCore[58923]
#define sipNameNr_Nigeria 58931
#define sipName_Nigeria &sipStrings_QtCore[58931]
#define sipNameNr_Namibia 58939
#define sipName_Namibia &sipStrings_QtCore[58939]
#define sipNameNr_Myanmar 58947
#define sipName_Myanmar &sipStrings_QtCore[58947]
#define sipNameNr_Morocco 58955
#define sipName_Morocco &sipStrings_QtCore[58955]
#define sipNameNr_Moldova 58963
#define sipName_Moldova &sipStrings_QtCore[58963]
#define sipNameNr_Mayotte 58971
#define sipName_Mayotte &sipStrings_QtCore[58971]
#define sipNameNr_Liberia 58979
#define sipName_Liberia &sipStrings_QtCore[58979]
#define sipNameNr_Lesotho 58987
#define sipName_Lesotho &sipStrings_QtCore[58987]
#define sipNameNr_Lebanon 58995
#define sipName_Lebanon &sipStrings_QtCore[58995]
#define sipNameNr_Jamaica 59003
#define sipName_Jamaica &sipStrings_QtCore[59003]
#define sipNameNr_Ireland 59011
#define sipName_Ireland &sipStrings_QtCore[59011]
#define sipNameNr_Iceland 59019
#define sipName_Iceland &sipStrings_QtCore[59019]
#define sipNameNr_Hungary 59027
#define sipName_Hungary &sipStrings_QtCore[59027]
#define sipNameNr_Grenada 59035
#define sipName_Grenada &sipStrings_QtCore[59035]
#define sipNameNr_Germany 59043
#define sipName_Germany &sipStrings_QtCore[59043]
#define sipNameNr_Georgia 59051
#define sipName_Georgia &sipStrings_QtCore[59051]
#define sipNameNr_Finland 59059
#define sipName_Finland &sipStrings_QtCore[59059]
#define sipNameNr_Estonia 59067
#define sipName_Estonia &sipStrings_QtCore[59067]
#define sipNameNr_Eritrea 59075
#define sipName_Eritrea &sipStrings_QtCore[59075]
#define sipNameNr_Ecuador 59083
#define sipName_Ecuador &sipStrings_QtCore[59083]
#define sipNameNr_Denmark 59091
#define sipName_Denmark &sipStrings_QtCore[59091]
#define sipNameNr_Croatia 59099
#define sipName_Croatia &sipStrings_QtCore[59099]
#define sipNameNr_Comoros 59107
#define sipName_Comoros &sipStrings_QtCore[59107]
#define sipNameNr_Burundi 59115
#define sipName_Burundi &sipStrings_QtCore[59115]
#define sipNameNr_Bolivia 59123
#define sipName_Bolivia &sipStrings_QtCore[59123]
#define sipNameNr_Bermuda 59131
#define sipName_Bermuda &sipStrings_QtCore[59131]
#define sipNameNr_Belgium 59139
#define sipName_Belgium &sipStrings_QtCore[59139]
#define sipNameNr_Belarus 59147
#define sipName_Belarus &sipStrings_QtCore[59147]
#define sipNameNr_Bahrain 59155
#define sipName_Bahrain &sipStrings_QtCore[59155]
#define sipNameNr_Bahamas 59163
#define sipName_Bahamas &sipStrings_QtCore[59163]
#define sipNameNr_Austria 59171
#define sipName_Austria &sipStrings_QtCore[59171]
#define sipNameNr_Armenia 59179
#define sipName_Armenia &sipStrings_QtCore[59179]
#define sipNameNr_Andorra 59187
#define sipName_Andorra &sipStrings_QtCore[59187]
#define sipNameNr_Algeria 59195
#define sipName_Algeria &sipStrings_QtCore[59195]
#define sipNameNr_Albania 59203
#define sipName_Albania &sipStrings_QtCore[59203]
#define sipNameNr_Country 25330
#define sipName_Country &sipStrings_QtCore[25330]
#define sipNameNr_Cebuano 59211
#define sipName_Cebuano &sipStrings_QtCore[59211]
#define sipNameNr_Saraiki 59219
#define sipName_Saraiki &sipStrings_QtCore[59219]
#define sipNameNr_Palauan 59227
#define sipName_Palauan &sipStrings_QtCore[59227]
#define sipNameNr_LinearA 59235
#define sipName_LinearA &sipStrings_QtCore[59235]
#define sipNameNr_Kenyang 59243
#define sipName_Kenyang &sipStrings_QtCore[59243]
#define sipNameNr_Mapuche 59251
#define sipName_Mapuche &sipStrings_QtCore[59251]
#define sipNameNr_Sylheti 59259
#define sipName_Sylheti &sipStrings_QtCore[59259]
#define sipNameNr_Santali 59267
#define sipName_Santali &sipStrings_QtCore[59267]
#define sipNameNr_Sabaean 59275
#define sipName_Sabaean &sipStrings_QtCore[59275]
#define sipNameNr_Pahlavi 59283
#define sipName_Pahlavi &sipStrings_QtCore[59283]
#define sipNameNr_Hanunoo 59291
#define sipName_Hanunoo &sipStrings_QtCore[59291]
#define sipNameNr_Aramaic 59299
#define sipName_Aramaic &sipStrings_QtCore[59299]
#define sipNameNr_Avestan 59307
#define sipName_Avestan &sipStrings_QtCore[59307]
#define sipNameNr_Walloon 59315
#define sipName_Walloon &sipStrings_QtCore[59315]
#define sipNameNr_Haitian 59323
#define sipName_Haitian &sipStrings_QtCore[59323]
#define sipNameNr_Chuvash 59331
#define sipName_Chuvash &sipStrings_QtCore[59331]
#define sipNameNr_Chechen 59339
#define sipName_Chechen &sipStrings_QtCore[59339]
#define sipNameNr_Sinhala 59347
#define sipName_Sinhala &sipStrings_QtCore[59347]
#define sipNameNr_Ossetic 59355
#define sipName_Ossetic &sipStrings_QtCore[59355]
#define sipNameNr_Romansh 59363
#define sipName_Romansh &sipStrings_QtCore[59363]
#define sipNameNr_Yangben 59371
#define sipName_Yangben &sipStrings_QtCore[59371]
#define sipNameNr_Tasawaq 59379
#define sipName_Tasawaq &sipStrings_QtCore[59379]
#define sipNameNr_Mundang 59387
#define sipName_Mundang &sipStrings_QtCore[59387]
#define sipNameNr_Machame 59395
#define sipName_Machame &sipStrings_QtCore[59395]
#define sipNameNr_Makonde 59403
#define sipName_Makonde &sipStrings_QtCore[59403]
#define sipNameNr_Bambara 59411
#define sipName_Bambara &sipStrings_QtCore[59411]
#define sipNameNr_Samburu 59419
#define sipName_Samburu &sipStrings_QtCore[59419]
#define sipNameNr_Konkani 59427
#define sipName_Konkani &sipStrings_QtCore[59427]
#define sipNameNr_Cornish 59435
#define sipName_Cornish &sipStrings_QtCore[59435]
#define sipNameNr_Bosnian 59443
#define sipName_Bosnian &sipStrings_QtCore[59443]
#define sipNameNr_Yiddish 59451
#define sipName_Yiddish &sipStrings_QtCore[59451]
#define sipNameNr_Volapuk 59459
#define sipName_Volapuk &sipStrings_QtCore[59459]
#define sipNameNr_Turkmen 59467
#define sipName_Turkmen &sipStrings_QtCore[59467]
#define sipNameNr_Turkish 49756
#define sipName_Turkish &sipStrings_QtCore[49756]
#define sipNameNr_Tibetan 59475
#define sipName_Tibetan &sipStrings_QtCore[59475]
#define sipNameNr_Tagalog 59483
#define sipName_Tagalog &sipStrings_QtCore[59483]
#define sipNameNr_Swedish 59491
#define sipName_Swedish &sipStrings_QtCore[59491]
#define sipNameNr_Swahili 41635
#define sipName_Swahili &sipStrings_QtCore[41635]
#define sipNameNr_Spanish 59499
#define sipName_Spanish &sipStrings_QtCore[59499]
#define sipNameNr_Serbian 59507
#define sipName_Serbian &sipStrings_QtCore[59507]
#define sipNameNr_Russian 59515
#define sipName_Russian &sipStrings_QtCore[59515]
#define sipNameNr_Quechua 59523
#define sipName_Quechua &sipStrings_QtCore[59523]
#define sipNameNr_Punjabi 59531
#define sipName_Punjabi &sipStrings_QtCore[59531]
#define sipNameNr_Persian 8624
#define sipName_Persian &sipStrings_QtCore[8624]
#define sipNameNr_Occitan 59539
#define sipName_Occitan &sipStrings_QtCore[59539]
#define sipNameNr_Marathi 59547
#define sipName_Marathi &sipStrings_QtCore[59547]
#define sipNameNr_Maltese 59555
#define sipName_Maltese &sipStrings_QtCore[59555]
#define sipNameNr_Lingala 59563
#define sipName_Lingala &sipStrings_QtCore[59563]
#define sipNameNr_Latvian 59571
#define sipName_Latvian &sipStrings_QtCore[59571]
#define sipNameNr_Kurundi 59579
#define sipName_Kurundi &sipStrings_QtCore[59579]
#define sipNameNr_Kurdish 29190
#define sipName_Kurdish &sipStrings_QtCore[29190]
#define sipNameNr_Kirghiz 59587
#define sipName_Kirghiz &sipStrings_QtCore[59587]
#define sipNameNr_Kannada 59595
#define sipName_Kannada &sipStrings_QtCore[59595]
#define sipNameNr_Italian 59603
#define sipName_Italian &sipStrings_QtCore[59603]
#define sipNameNr_Inupiak 59611
#define sipName_Inupiak &sipStrings_QtCore[59611]
#define sipNameNr_Guarani 59619
#define sipName_Guarani &sipStrings_QtCore[59619]
#define sipNameNr_Frisian 33021
#define sipName_Frisian &sipStrings_QtCore[33021]
#define sipNameNr_Finnish 59627
#define sipName_Finnish &sipStrings_QtCore[59627]
#define sipNameNr_Faroese 59635
#define sipName_Faroese &sipStrings_QtCore[59635]
#define sipNameNr_English 59643
#define sipName_English &sipStrings_QtCore[59643]
#define sipNameNr_Chinese 29222
#define sipName_Chinese &sipStrings_QtCore[29222]
#define sipNameNr_Catalan 59651
#define sipName_Catalan &sipStrings_QtCore[59651]
#define sipNameNr_Burmese 59659
#define sipName_Burmese &sipStrings_QtCore[59659]
#define sipNameNr_Bislama 59667
#define sipName_Bislama &sipStrings_QtCore[59667]
#define sipNameNr_Bhutani 59675
#define sipName_Bhutani &sipStrings_QtCore[59675]
#define sipNameNr_Bengali 59683
#define sipName_Bengali &sipStrings_QtCore[59683]
#define sipNameNr_Bashkir 59691
#define sipName_Bashkir &sipStrings_QtCore[59691]
#define sipNameNr_Amharic 59699
#define sipName_Amharic &sipStrings_QtCore[59699]
#define sipNameNr_QLocale 59707
#define sipName_QLocale &sipStrings_QtCore[59707]
#define sipNameNr_angleTo 59715
#define sipName_angleTo &sipStrings_QtCore[59715]
#define sipNameNr_pointAt 59723
#define sipName_pointAt &sipStrings_QtCore[59723]
#define sipNameNr_setLine 59731
#define sipName_setLine &sipStrings_QtCore[59731]
#define sipNameNr_resolve 59739
#define sipName_resolve &sipStrings_QtCore[59739]
#define sipNameNr_toArray 59747
#define sipName_toArray &sipStrings_QtCore[59747]
#define sipNameNr_Compact 59755
#define sipName_Compact &sipStrings_QtCore[59755]
#define sipNameNr_variant 59763
#define sipName_variant &sipStrings_QtCore[59763]
#define sipNameNr_rawData 59771
#define sipName_rawData &sipStrings_QtCore[59771]
#define sipNameNr_Columns 19870
#define sipName_Columns &sipStrings_QtCore[19870]
#define sipNameNr_Current 37241
#define sipName_Current &sipStrings_QtCore[37241]
#define sipNameNr_getChar 53648
#define sipName_getChar &sipStrings_QtCore[53648]
#define sipNameNr_putChar 59779
#define sipName_putChar &sipStrings_QtCore[59779]
#define sipNameNr_readAll 59787
#define sipName_readAll &sipStrings_QtCore[59787]
#define sipNameNr_NewOnly 59795
#define sipName_NewOnly &sipStrings_QtCore[59795]
#define sipNameNr_NotOpen 59803
#define sipName_NotOpen &sipStrings_QtCore[59803]
#define sipNameNr_addPath 59811
#define sipName_addPath &sipStrings_QtCore[59811]
#define sipNameNr_caching 59819
#define sipName_caching &sipStrings_QtCore[59819]
#define sipNameNr_created 59827
#define sipName_created &sipStrings_QtCore[59827]
#define sipNameNr_groupId 59835
#define sipName_groupId &sipStrings_QtCore[59835]
#define sipNameNr_ownerId 59843
#define sipName_ownerId &sipStrings_QtCore[59843]
#define sipNameNr_setFile 59851
#define sipName_setFile &sipStrings_QtCore[59851]
#define sipNameNr_ExeUser 59859
#define sipName_ExeUser &sipStrings_QtCore[59859]
#define sipNameNr_timeout 59867
#define sipName_timeout &sipStrings_QtCore[59867]
#define sipNameNr_setType 59875
#define sipName_setType &sipStrings_QtCore[59875]
#define sipNameNr_InCurve 44479
#define sipName_InCurve &sipStrings_QtCore[44479]
#define sipNameNr_OutBack 53878
#define sipName_OutBack &sipStrings_QtCore[53878]
#define sipNameNr_OutCirc 53898
#define sipName_OutCirc &sipStrings_QtCore[53898]
#define sipNameNr_OutExpo 53918
#define sipName_OutExpo &sipStrings_QtCore[53918]
#define sipNameNr_OutSine 53938
#define sipName_OutSine &sipStrings_QtCore[53938]
#define sipNameNr_InQuint 50174
#define sipName_InQuint &sipStrings_QtCore[50174]
#define sipNameNr_InQuart 50196
#define sipName_InQuart &sipStrings_QtCore[50196]
#define sipNameNr_InCubic 50218
#define sipName_InCubic &sipStrings_QtCore[50218]
#define sipNameNr_OutQuad 53958
#define sipName_OutQuad &sipStrings_QtCore[53958]
#define sipNameNr_refresh 59883
#define sipName_refresh &sipStrings_QtCore[59883]
#define sipNameNr_sorting 59891
#define sipName_sorting &sipStrings_QtCore[59891]
#define sipNameNr_dirName 59899
#define sipName_dirName &sipStrings_QtCore[59899]
#define sipNameNr_setPath 59907
#define sipName_setPath &sipStrings_QtCore[59907]
#define sipNameNr_filters 59915
#define sipName_filters &sipStrings_QtCore[59915]
#define sipNameNr_Filters 33381
#define sipName_Filters &sipStrings_QtCore[33381]
#define sipNameNr_AllDirs 59923
#define sipName_AllDirs &sipStrings_QtCore[59923]
#define sipNameNr___sub__ 59931
#define sipName___sub__ &sipStrings_QtCore[59931]
#define sipNameNr_current 59939
#define sipName_current &sipStrings_QtCore[59939]
#define sipNameNr_Forever 54008
#define sipName_Forever &sipStrings_QtCore[54008]
#define sipNameNr_setTime 59947
#define sipName_setTime &sipStrings_QtCore[59947]
#define sipNameNr_elapsed 59955
#define sipName_elapsed &sipStrings_QtCore[59955]
#define sipNameNr_restart 59963
#define sipName_restart &sipStrings_QtCore[59963]
#define sipNameNr_msecsTo 59971
#define sipName_msecsTo &sipStrings_QtCore[59971]
#define sipNameNr_addSecs 59979
#define sipName_addSecs &sipStrings_QtCore[59979]
#define sipNameNr_getDate 59987
#define sipName_getDate &sipStrings_QtCore[59987]
#define sipNameNr_setDate 59995
#define sipName_setDate &sipStrings_QtCore[59995]
#define sipNameNr_addDays 60003
#define sipName_addDays &sipStrings_QtCore[60003]
#define sipNameNr_readInt 60011
#define sipName_readInt &sipStrings_QtCore[60011]
#define sipNameNr_Qt_5_15 60019
#define sipName_Qt_5_15 &sipStrings_QtCore[60019]
#define sipNameNr_Qt_5_14 60027
#define sipName_Qt_5_14 &sipStrings_QtCore[60027]
#define sipNameNr_Qt_5_13 60035
#define sipName_Qt_5_13 &sipStrings_QtCore[60035]
#define sipNameNr_Qt_5_12 60043
#define sipName_Qt_5_12 &sipStrings_QtCore[60043]
#define sipNameNr_Qt_5_11 60051
#define sipName_Qt_5_11 &sipStrings_QtCore[60051]
#define sipNameNr_Qt_5_10 60059
#define sipName_Qt_5_10 &sipStrings_QtCore[60059]
#define sipNameNr_Version 8432
#define sipName_Version &sipStrings_QtCore[8432]
#define sipNameNr_removed 60067
#define sipName_removed &sipStrings_QtCore[60067]
#define sipNameNr_MaxUser 60075
#define sipName_MaxUser &sipStrings_QtCore[60075]
#define sipNameNr_Gesture 10591
#define sipName_Gesture &sipStrings_QtCore[10591]
#define sipNameNr_SockAct 60083
#define sipName_SockAct &sipStrings_QtCore[60083]
#define sipNameNr_FocusIn 60091
#define sipName_FocusIn &sipStrings_QtCore[60091]
#define sipNameNr_enabled 60099
#define sipName_enabled &sipStrings_QtCore[60099]
#define sipNameNr_version 20820
#define sipName_version &sipStrings_QtCore[20820]
#define sipNameNr_process 60107
#define sipName_process &sipStrings_QtCore[60107]
#define sipNameNr_sortKey 60115
#define sipName_sortKey &sipStrings_QtCore[60115]
#define sipNameNr_isFalse 60123
#define sipName_isFalse &sipStrings_QtCore[60123]
#define sipNameNr_isFloat 60131
#define sipName_isFloat &sipStrings_QtCore[60131]
#define sipNameNr_isArray 60139
#define sipName_isArray &sipStrings_QtCore[60139]
#define sipNameNr_hasNext 60147
#define sipName_hasNext &sipStrings_QtCore[60147]
#define sipNameNr_reparse 60155
#define sipName_reparse &sipStrings_QtCore[60155]
#define sipNameNr_addData 60163
#define sipName_addData &sipStrings_QtCore[60163]
#define sipNameNr_Invalid 29846
#define sipName_Invalid &sipStrings_QtCore[29846]
#define sipNameNr_Float16 54328
#define sipName_Float16 &sipStrings_QtCore[54328]
#define sipNameNr_Decimal 60171
#define sipName_Decimal &sipStrings_QtCore[60171]
#define sipNameNr_NoError 60179
#define sipName_NoError &sipStrings_QtCore[60179]
#define sipNameNr_isSolar 60187
#define sipName_isSolar &sipStrings_QtCore[60187]
#define sipNameNr_isLunar 60195
#define sipName_isLunar &sipStrings_QtCore[60195]
#define sipNameNr_indexIn 60203
#define sipName_indexIn &sipStrings_QtCore[60203]
#define sipNameNr_pattern 60211
#define sipName_pattern &sipStrings_QtCore[60211]
#define sipNameNr___add__ 60219
#define sipName___add__ &sipStrings_QtCore[60219]
#define sipNameNr_decoded 60227
#define sipName_decoded &sipStrings_QtCore[60227]
#define sipNameNr_isLower 60235
#define sipName_isLower &sipStrings_QtCore[60235]
#define sipNameNr_isUpper 60243
#define sipName_isUpper &sipStrings_QtCore[60243]
#define sipNameNr_compare 60251
#define sipName_compare &sipStrings_QtCore[60251]
#define sipNameNr_chopped 60259
#define sipName_chopped &sipStrings_QtCore[60259]
#define sipNameNr_percent 60267
#define sipName_percent &sipStrings_QtCore[60267]
#define sipNameNr_include 60275
#define sipName_include &sipStrings_QtCore[60275]
#define sipNameNr_exclude 60283
#define sipName_exclude &sipStrings_QtCore[60283]
#define sipNameNr_squeeze 60291
#define sipName_squeeze &sipStrings_QtCore[60291]
#define sipNameNr_reserve 60299
#define sipName_reserve &sipStrings_QtCore[60299]
#define sipNameNr___mul__ 60307
#define sipName___mul__ &sipStrings_QtCore[60307]
#define sipNameNr___str__ 60315
#define sipName___str__ &sipStrings_QtCore[60315]
#define sipNameNr_fromHex 60323
#define sipName_fromHex &sipStrings_QtCore[60323]
#define sipNameNr_toFloat 60331
#define sipName_toFloat &sipStrings_QtCore[60331]
#define sipNameNr_toULong 60339
#define sipName_toULong &sipStrings_QtCore[60339]
#define sipNameNr_toShort 60347
#define sipName_toShort &sipStrings_QtCore[60347]
#define sipNameNr_replace 60355
#define sipName_replace &sipStrings_QtCore[60355]
#define sipNameNr_prepend 60363
#define sipName_prepend &sipStrings_QtCore[60363]
#define sipNameNr_trimmed 60371
#define sipName_trimmed &sipStrings_QtCore[60371]
#define sipNameNr_toUpper 60379
#define sipName_toUpper &sipStrings_QtCore[60379]
#define sipNameNr_toLower 60387
#define sipName_toLower &sipStrings_QtCore[60387]
#define sipNameNr_indexOf 60395
#define sipName_indexOf &sipStrings_QtCore[60395]
#define sipNameNr_QBuffer 60403
#define sipName_QBuffer &sipStrings_QtCore[60403]
#define sipNameNr_testBit 60411
#define sipName_testBit &sipStrings_QtCore[60411]
#define sipNameNr_isEmpty 60419
#define sipName_isEmpty &sipStrings_QtCore[60419]
#define sipNameNr___len__ 60427
#define sipName___len__ &sipStrings_QtCore[60427]
#define sipNameNr_onEntry 60435
#define sipName_onEntry &sipStrings_QtCore[60435]
#define sipNameNr_entered 20801
#define sipName_entered &sipStrings_QtCore[20801]
#define sipNameNr_machine 60443
#define sipName_machine &sipStrings_QtCore[60443]
#define sipNameNr_options 60451
#define sipName_options &sipStrings_QtCore[60451]
#define sipNameNr_moveRow 54588
#define sipName_moveRow &sipStrings_QtCore[54588]
#define sipNameNr_parents 60459
#define sipName_parents &sipStrings_QtCore[60459]
#define sipNameNr_topLeft 60467
#define sipName_topLeft &sipStrings_QtCore[60467]
#define sipNameNr_indexes 60475
#define sipName_indexes &sipStrings_QtCore[60475]
#define sipNameNr_setData 11251
#define sipName_setData &sipStrings_QtCore[11251]
#define sipNameNr_sibling 60483
#define sipName_sibling &sipStrings_QtCore[60483]
#define sipNameNr_isValid 60491
#define sipName_isValid &sipStrings_QtCore[60491]
#define sipNameNr_message 60499
#define sipName_message &sipStrings_QtCore[60499]
#define sipNameNr_timerId 60507
#define sipName_timerId &sipStrings_QtCore[60507]
#define sipNameNr_Running 48711
#define sipName_Running &sipStrings_QtCore[48711]
#define sipNameNr_Stopped 23170
#define sipName_Stopped &sipStrings_QtCore[23170]
#define sipNameNr_Forward 27149
#define sipName_Forward &sipStrings_QtCore[27149]
#define sipNameNr_QObject 24956
#define sipName_QObject &sipStrings_QtCore[24956]
#define sipNameNr_TopEdge 60515
#define sipName_TopEdge &sipStrings_QtCore[60515]
#define sipNameNr_ImhTime 60523
#define sipName_ImhTime &sipStrings_QtCore[60523]
#define sipNameNr_ImhDate 60531
#define sipName_ImhDate &sipStrings_QtCore[60531]
#define sipNameNr_ImhNone 60539
#define sipName_ImhNone &sipStrings_QtCore[60539]
#define sipNameNr_Checked 26826
#define sipName_Checked &sipStrings_QtCore[26826]
#define sipNameNr_ImHints 60547
#define sipName_ImHints &sipStrings_QtCore[60547]
#define sipNameNr_Tuesday 60555
#define sipName_Tuesday &sipStrings_QtCore[60555]
#define sipNameNr_ISODate 60563
#define sipName_ISODate &sipStrings_QtCore[60563]
#define sipNameNr_NoBrush 60571
#define sipName_NoBrush &sipStrings_QtCore[60571]
#define sipNameNr_FlatCap 60579
#define sipName_FlatCap &sipStrings_QtCore[60579]
#define sipNameNr_DotLine 34686
#define sipName_DotLine &sipStrings_QtCore[34686]
#define sipNameNr_UpArrow 60587
#define sipName_UpArrow &sipStrings_QtCore[60587]
#define sipNameNr_NoArrow 60595
#define sipName_NoArrow &sipStrings_QtCore[60595]
#define sipNameNr_Key_New 60603
#define sipName_Key_New &sipStrings_QtCore[60603]
#define sipNameNr_Key_Red 60611
#define sipName_Key_Red &sipStrings_QtCore[60611]
#define sipNameNr_Key_UWB 60619
#define sipName_Key_UWB &sipStrings_QtCore[60619]
#define sipNameNr_Key_DOS 60627
#define sipName_Key_DOS &sipStrings_QtCore[60627]
#define sipNameNr_Key_Cut 60635
#define sipName_Key_Cut &sipStrings_QtCore[60635]
#define sipNameNr_Key_WWW 60643
#define sipName_Key_WWW &sipStrings_QtCore[60643]
#define sipNameNr_Key_Yes 60651
#define sipName_Key_Yes &sipStrings_QtCore[60651]
#define sipNameNr_Key_ETH 60659
#define sipName_Key_ETH &sipStrings_QtCore[60659]
#define sipNameNr_Key_yen 60667
#define sipName_Key_yen &sipStrings_QtCore[60667]
#define sipNameNr_Key_Bar 60675
#define sipName_Key_Bar &sipStrings_QtCore[60675]
#define sipNameNr_Key_Any 60683
#define sipName_Key_Any &sipStrings_QtCore[60683]
#define sipNameNr_Key_F35 60691
#define sipName_Key_F35 &sipStrings_QtCore[60691]
#define sipNameNr_Key_F34 60699
#define sipName_Key_F34 &sipStrings_QtCore[60699]
#define sipNameNr_Key_F33 60707
#define sipName_Key_F33 &sipStrings_QtCore[60707]
#define sipNameNr_Key_F32 60715
#define sipName_Key_F32 &sipStrings_QtCore[60715]
#define sipNameNr_Key_F31 60723
#define sipName_Key_F31 &sipStrings_QtCore[60723]
#define sipNameNr_Key_F30 60731
#define sipName_Key_F30 &sipStrings_QtCore[60731]
#define sipNameNr_Key_F29 60739
#define sipName_Key_F29 &sipStrings_QtCore[60739]
#define sipNameNr_Key_F28 60747
#define sipName_Key_F28 &sipStrings_QtCore[60747]
#define sipNameNr_Key_F27 60755
#define sipName_Key_F27 &sipStrings_QtCore[60755]
#define sipNameNr_Key_F26 60763
#define sipName_Key_F26 &sipStrings_QtCore[60763]
#define sipNameNr_Key_F25 60771
#define sipName_Key_F25 &sipStrings_QtCore[60771]
#define sipNameNr_Key_F24 60779
#define sipName_Key_F24 &sipStrings_QtCore[60779]
#define sipNameNr_Key_F23 60787
#define sipName_Key_F23 &sipStrings_QtCore[60787]
#define sipNameNr_Key_F22 60795
#define sipName_Key_F22 &sipStrings_QtCore[60795]
#define sipNameNr_Key_F21 60803
#define sipName_Key_F21 &sipStrings_QtCore[60803]
#define sipNameNr_Key_F20 60811
#define sipName_Key_F20 &sipStrings_QtCore[60811]
#define sipNameNr_Key_F19 60819
#define sipName_Key_F19 &sipStrings_QtCore[60819]
#define sipNameNr_Key_F18 60827
#define sipName_Key_F18 &sipStrings_QtCore[60827]
#define sipNameNr_Key_F17 60835
#define sipName_Key_F17 &sipStrings_QtCore[60835]
#define sipNameNr_Key_F16 60843
#define sipName_Key_F16 &sipStrings_QtCore[60843]
#define sipNameNr_Key_F15 60851
#define sipName_Key_F15 &sipStrings_QtCore[60851]
#define sipNameNr_Key_F14 60859
#define sipName_Key_F14 &sipStrings_QtCore[60859]
#define sipNameNr_Key_F13 60867
#define sipName_Key_F13 &sipStrings_QtCore[60867]
#define sipNameNr_Key_F12 60875
#define sipName_Key_F12 &sipStrings_QtCore[60875]
#define sipNameNr_Key_F11 60883
#define sipName_Key_F11 &sipStrings_QtCore[60883]
#define sipNameNr_Key_F10 60891
#define sipName_Key_F10 &sipStrings_QtCore[60891]
#define sipNameNr_Key_Alt 60899
#define sipName_Key_Alt &sipStrings_QtCore[60899]
#define sipNameNr_Key_End 60907
#define sipName_Key_End &sipStrings_QtCore[60907]
#define sipNameNr_Key_Tab 60915
#define sipName_Key_Tab &sipStrings_QtCore[60915]
#define sipNameNr_Qt__Key 60923
#define sipName_Qt__Key &sipStrings_QtCore[60923]
#define sipNameNr_Desktop 3777
#define sipName_Desktop &sipStrings_QtCore[3777]
#define sipNameNr_ToolTip 3690
#define sipName_ToolTip &sipStrings_QtCore[3690]
#define sipNameNr_NoFocus 60931
#define sipName_NoFocus &sipStrings_QtCore[60931]
#define sipNameNr_darkRed 60939
#define sipName_darkRed &sipStrings_QtCore[60939]
#define sipNameNr_magenta 60947
#define sipName_magenta &sipStrings_QtCore[60947]
#define sipNameNr_qintptr 60955
#define sipName_qintptr &sipStrings_QtCore[60955]
#define sipNameNr_qIsNull 60963
#define sipName_qIsNull &sipStrings_QtCore[60963]
#define sipNameNr___xor__ 60971
#define sipName___xor__ &sipStrings_QtCore[60971]
#define sipNameNr___ior__ 60979
#define sipName___ior__ &sipStrings_QtCore[60979]
#define sipNameNr___and__ 60987
#define sipName___and__ &sipStrings_QtCore[60987]
#define sipNameNr___int__ 60995
#define sipName___int__ &sipStrings_QtCore[60995]
#define sipNameNr_Endian 24192
#define sipName_Endian &sipStrings_QtCore[24192]
#define sipNameNr_Matrix 58700
#define sipName_Matrix &sipStrings_QtCore[58700]
#define sipNameNr_Cursor 20384
#define sipName_Cursor &sipStrings_QtCore[20384]
#define sipNameNr_Bitmap 58716
#define sipName_Bitmap &sipStrings_QtCore[58716]
#define sipNameNr_Region 58724
#define sipName_Region &sipStrings_QtCore[58724]
#define sipNameNr_Pixmap 58732
#define sipName_Pixmap &sipStrings_QtCore[58732]
#define sipNameNr_PointF 58748
#define sipName_PointF &sipStrings_QtCore[58748]
#define sipNameNr_Locale 21371
#define sipName_Locale &sipStrings_QtCore[21371]
#define sipNameNr_Random 61003
#define sipName_Random &sipStrings_QtCore[61003]
#define sipNameNr_scheme 61010
#define sipName_scheme &sipStrings_QtCore[61010]
#define sipNameNr_setUrl 61017
#define sipName_setUrl &sipStrings_QtCore[61017]
#define sipNameNr_QTimer 61024
#define sipName_QTimer &sipStrings_QtCore[61024]
#define sipNameNr_usleep 61031
#define sipName_usleep &sipStrings_QtCore[61031]
#define sipNameNr_msleep 61038
#define sipName_msleep &sipStrings_QtCore[61038]
#define sipNameNr_Create 61045
#define sipName_Create &sipStrings_QtCore[61045]
#define sipNameNr_QState 61052
#define sipName_QState &sipStrings_QtCore[61052]
#define sipNameNr_locate 61059
#define sipName_locate &sipStrings_QtCore[61059]
#define sipNameNr_socket 61066
#define sipName_socket &sipStrings_QtCore[61066]
#define sipNameNr_toSize 61073
#define sipName_toSize &sipStrings_QtCore[61073]
#define sipNameNr_scaled 61080
#define sipName_scaled &sipStrings_QtCore[61080]
#define sipNameNr_mapped 61087
#define sipName_mapped &sipStrings_QtCore[61087]
#define sipNameNr_attach 61094
#define sipName_attach &sipStrings_QtCore[61094]
#define sipNameNr_Format 2869
#define sipName_Format &sipStrings_QtCore[2869]
#define sipNameNr_cancel 61101
#define sipName_cancel &sipStrings_QtCore[61101]
#define sipNameNr_commit 61108
#define sipName_commit &sipStrings_QtCore[61108]
#define sipNameNr_create 61115
#define sipName_create &sipStrings_QtCore[61115]
#define sipNameNr_escape 61122
#define sipName_escape &sipStrings_QtCore[61122]
#define sipNameNr_RegExp 28167
#define sipName_RegExp &sipStrings_QtCore[28167]
#define sipNameNr_toRect 61129
#define sipName_toRect &sipStrings_QtCore[61129]
#define sipNameNr_united 61136
#define sipName_united &sipStrings_QtCore[61136]
#define sipNameNr_adjust 61143
#define sipName_adjust &sipStrings_QtCore[61143]
#define sipNameNr_moveTo 61150
#define sipName_moveTo &sipStrings_QtCore[61150]
#define sipNameNr_proper 61157
#define sipName_proper &sipStrings_QtCore[61157]
#define sipNameNr_vmicro 61164
#define sipName_vmicro &sipStrings_QtCore[61164]
#define sipNameNr_vminor 61171
#define sipName_vminor &sipStrings_QtCore[61171]
#define sipNameNr_OSType 2375
#define sipName_OSType &sipStrings_QtCore[2375]
#define sipNameNr_Q_FLAG 61178
#define sipName_Q_FLAG &sipStrings_QtCore[61178]
#define sipNameNr_Q_ENUM 61185
#define sipName_Q_ENUM &sipStrings_QtCore[61185]
#define sipNameNr_signal 61192
#define sipName_signal &sipStrings_QtCore[61192]
#define sipNameNr_sender 61199
#define sipName_sender &sipStrings_QtCore[61199]
#define sipNameNr_qIsNaN 61206
#define sipName_qIsNaN &sipStrings_QtCore[61206]
#define sipNameNr_qIsInf 61213
#define sipName_qIsInf &sipStrings_QtCore[61213]
#define sipNameNr_QMutex 61220
#define sipName_QMutex &sipStrings_QtCore[61220]
#define sipNameNr_relock 61227
#define sipName_relock &sipStrings_QtCore[61227]
#define sipNameNr_UShort 57493
#define sipName_UShort &sipStrings_QtCore[57493]
#define sipNameNr_QImage 61234
#define sipName_QImage &sipStrings_QtCore[61234]
#define sipNameNr_QColor 61241
#define sipName_QColor &sipStrings_QtCore[61241]
#define sipNameNr_QBrush 61248
#define sipName_QBrush &sipStrings_QtCore[61248]
#define sipNameNr_QPoint 61255
#define sipName_QPoint &sipStrings_QtCore[61255]
#define sipNameNr_QSizeF 61262
#define sipName_QSizeF &sipStrings_QtCore[61262]
#define sipNameNr_QRectF 61269
#define sipName_QRectF &sipStrings_QtCore[61269]
#define sipNameNr_isUser 61276
#define sipName_isUser &sipStrings_QtCore[61276]
#define sipNameNr_isFlag 61283
#define sipName_isFlag &sipStrings_QtCore[61283]
#define sipNameNr_invoke 61290
#define sipName_invoke &sipStrings_QtCore[61290]
#define sipNameNr_value9 61297
#define sipName_value9 &sipStrings_QtCore[61297]
#define sipNameNr_value8 61304
#define sipName_value8 &sipStrings_QtCore[61304]
#define sipNameNr_value7 61311
#define sipName_value7 &sipStrings_QtCore[61311]
#define sipNameNr_value6 61318
#define sipName_value6 &sipStrings_QtCore[61318]
#define sipNameNr_value5 61325
#define sipName_value5 &sipStrings_QtCore[61325]
#define sipNameNr_value4 61332
#define sipName_value4 &sipStrings_QtCore[61332]
#define sipNameNr_value3 61339
#define sipName_value3 &sipStrings_QtCore[61339]
#define sipNameNr_value2 61346
#define sipName_value2 &sipStrings_QtCore[61346]
#define sipNameNr_value1 61353
#define sipName_value1 &sipStrings_QtCore[61353]
#define sipNameNr_value0 61360
#define sipName_value0 &sipStrings_QtCore[61360]
#define sipNameNr_Signal 19282
#define sipName_Signal &sipStrings_QtCore[19282]
#define sipNameNr_Method 36360
#define sipName_Method &sipStrings_QtCore[36360]
#define sipNameNr_access 61367
#define sipName_access &sipStrings_QtCore[61367]
#define sipNameNr_Public 61374
#define sipName_Public &sipStrings_QtCore[61374]
#define sipNameNr_Access 16032
#define sipName_Access &sipStrings_QtCore[16032]
#define sipNameNr_setKey 61381
#define sipName_setKey &sipStrings_QtCore[61381]
#define sipNameNr_setTop 61388
#define sipName_setTop &sipStrings_QtCore[61388]
#define sipNameNr_qFatal 61395
#define sipName_qFatal &sipStrings_QtCore[61395]
#define sipNameNr_qDebug 61402
#define sipName_qDebug &sipStrings_QtCore[61402]
#define sipNameNr_unlock 61409
#define sipName_unlock &sipStrings_QtCore[61409]
#define sipNameNr_script 61416
#define sipName_script &sipStrings_QtCore[61416]
#define sipNameNr_Script 4230
#define sipName_Script &sipStrings_QtCore[4230]
#define sipNameNr_pmText 61423
#define sipName_pmText &sipStrings_QtCore[61423]
#define sipNameNr_amText 61430
#define sipName_amText &sipStrings_QtCore[61430]
#define sipNameNr_toTime 61437
#define sipName_toTime &sipStrings_QtCore[61437]
#define sipNameNr_toDate 61444
#define sipName_toDate &sipStrings_QtCore[61444]
#define sipNameNr_Europe 61451
#define sipName_Europe &sipStrings_QtCore[61451]
#define sipNameNr_Kosovo 61458
#define sipName_Kosovo &sipStrings_QtCore[61458]
#define sipNameNr_Jersey 61465
#define sipName_Jersey &sipStrings_QtCore[61465]
#define sipNameNr_Russia 61472
#define sipName_Russia &sipStrings_QtCore[61472]
#define sipNameNr_Brunei 61479
#define sipName_Brunei &sipStrings_QtCore[61479]
#define sipNameNr_Serbia 61486
#define sipName_Serbia &sipStrings_QtCore[61486]
#define sipNameNr_Zambia 61493
#define sipName_Zambia &sipStrings_QtCore[61493]
#define sipNameNr_Uganda 61500
#define sipName_Uganda &sipStrings_QtCore[61500]
#define sipNameNr_Tuvalu 61507
#define sipName_Tuvalu &sipStrings_QtCore[61507]
#define sipNameNr_Turkey 61514
#define sipName_Turkey &sipStrings_QtCore[61514]
#define sipNameNr_Taiwan 61521
#define sipName_Taiwan &sipStrings_QtCore[61521]
#define sipNameNr_Sweden 61528
#define sipName_Sweden &sipStrings_QtCore[61528]
#define sipNameNr_Rwanda 61535
#define sipName_Rwanda &sipStrings_QtCore[61535]
#define sipNameNr_Poland 61542
#define sipName_Poland &sipStrings_QtCore[61542]
#define sipNameNr_Panama 61549
#define sipName_Panama &sipStrings_QtCore[61549]
#define sipNameNr_Norway 61556
#define sipName_Norway &sipStrings_QtCore[61556]
#define sipNameNr_Monaco 61563
#define sipName_Monaco &sipStrings_QtCore[61563]
#define sipNameNr_Mexico 61570
#define sipName_Mexico &sipStrings_QtCore[61570]
#define sipNameNr_Malawi 61577
#define sipName_Malawi &sipStrings_QtCore[61577]
#define sipNameNr_Latvia 61584
#define sipName_Latvia &sipStrings_QtCore[61584]
#define sipNameNr_Kuwait 61591
#define sipName_Kuwait &sipStrings_QtCore[61591]
#define sipNameNr_Jordan 61598
#define sipName_Jordan &sipStrings_QtCore[61598]
#define sipNameNr_Israel 61605
#define sipName_Israel &sipStrings_QtCore[61605]
#define sipNameNr_Guyana 61612
#define sipName_Guyana &sipStrings_QtCore[61612]
#define sipNameNr_Guinea 25314
#define sipName_Guinea &sipStrings_QtCore[25314]
#define sipNameNr_Greece 61619
#define sipName_Greece &sipStrings_QtCore[61619]
#define sipNameNr_Gambia 61626
#define sipName_Gambia &sipStrings_QtCore[61626]
#define sipNameNr_France 61633
#define sipName_France &sipStrings_QtCore[61633]
#define sipNameNr_Cyprus 61640
#define sipName_Cyprus &sipStrings_QtCore[61640]
#define sipNameNr_Canada 61647
#define sipName_Canada &sipStrings_QtCore[61647]
#define sipNameNr_Brazil 61654
#define sipName_Brazil &sipStrings_QtCore[61654]
#define sipNameNr_Bhutan 61661
#define sipName_Bhutan &sipStrings_QtCore[61661]
#define sipNameNr_Belize 61668
#define sipName_Belize &sipStrings_QtCore[61668]
#define sipNameNr_Angola 61675
#define sipName_Angola &sipStrings_QtCore[61675]
#define sipNameNr_Lojban 61682
#define sipName_Lojban &sipStrings_QtCore[61682]
#define sipNameNr_Tangut 61689
#define sipName_Tangut &sipStrings_QtCore[61689]
#define sipNameNr_Newari 61696
#define sipName_Newari &sipStrings_QtCore[61696]
#define sipNameNr_Mohawk 61703
#define sipName_Mohawk &sipStrings_QtCore[61703]
#define sipNameNr_Lakota 61710
#define sipName_Lakota &sipStrings_QtCore[61710]
#define sipNameNr_Akoose 61717
#define sipName_Akoose &sipStrings_QtCore[61717]
#define sipNameNr_TaiNua 61724
#define sipName_TaiNua &sipStrings_QtCore[61724]
#define sipNameNr_TaiDam 61731
#define sipName_TaiDam &sipStrings_QtCore[61731]
#define sipNameNr_Rejang 61738
#define sipName_Rejang &sipStrings_QtCore[61738]
#define sipNameNr_Lydian 61745
#define sipName_Lydian &sipStrings_QtCore[61745]
#define sipNameNr_Lycian 61752
#define sipName_Lycian &sipStrings_QtCore[61752]
#define sipNameNr_Lepcha 61759
#define sipName_Lepcha &sipStrings_QtCore[61759]
#define sipNameNr_Ingush 61766
#define sipName_Ingush &sipStrings_QtCore[61766]
#define sipNameNr_Gothic 61773
#define sipName_Gothic &sipStrings_QtCore[61773]
#define sipNameNr_Coptic 61780
#define sipName_Coptic &sipStrings_QtCore[61780]
#define sipNameNr_Chakma 61787
#define sipName_Chakma &sipStrings_QtCore[61787]
#define sipNameNr_Carian 61794
#define sipName_Carian &sipStrings_QtCore[61794]
#define sipNameNr_Uighur 61801
#define sipName_Uighur &sipStrings_QtCore[61801]
#define sipNameNr_Ngomba 61808
#define sipName_Ngomba &sipStrings_QtCore[61808]
#define sipNameNr_Ojibwa 61815
#define sipName_Ojibwa &sipStrings_QtCore[61815]
#define sipNameNr_Ndonga 61822
#define sipName_Ndonga &sipStrings_QtCore[61822]
#define sipNameNr_Navaho 61829
#define sipName_Navaho &sipStrings_QtCore[61829]
#define sipNameNr_Kanuri 61836
#define sipName_Kanuri &sipStrings_QtCore[61836]
#define sipNameNr_Herero 61843
#define sipName_Herero &sipStrings_QtCore[61843]
#define sipNameNr_Church 61850
#define sipName_Church &sipStrings_QtCore[61850]
#define sipNameNr_Avaric 61857
#define sipName_Avaric &sipStrings_QtCore[61857]
#define sipNameNr_Nyanja 61864
#define sipName_Nyanja &sipStrings_QtCore[61864]
#define sipNameNr_Tongan 61871
#define sipName_Tongan &sipStrings_QtCore[61871]
#define sipNameNr_Tswana 61878
#define sipName_Tswana &sipStrings_QtCore[61878]
#define sipNameNr_Fijian 61885
#define sipName_Fijian &sipStrings_QtCore[61885]
#define sipNameNr_Walser 61892
#define sipName_Walser &sipStrings_QtCore[61892]
#define sipNameNr_Kwasio 61899
#define sipName_Kwasio &sipStrings_QtCore[61899]
#define sipNameNr_Ewondo 61906
#define sipName_Ewondo &sipStrings_QtCore[61906]
#define sipNameNr_Kabyle 61913
#define sipName_Kabyle &sipStrings_QtCore[61913]
#define sipNameNr_Kikuyu 61920
#define sipName_Kikuyu &sipStrings_QtCore[61920]
#define sipNameNr_Taroko 61927
#define sipName_Taroko &sipStrings_QtCore[61927]
#define sipNameNr_Kpelle 61934
#define sipName_Kpelle &sipStrings_QtCore[61934]
#define sipNameNr_Walamo 61941
#define sipName_Walamo &sipStrings_QtCore[61941]
#define sipNameNr_Sidamo 61948
#define sipName_Sidamo &sipStrings_QtCore[61948]
#define sipNameNr_Syriac 61955
#define sipName_Syriac &sipStrings_QtCore[61955]
#define sipNameNr_Divehi 61962
#define sipName_Divehi &sipStrings_QtCore[61962]
#define sipNameNr_Zhuang 61969
#define sipName_Zhuang &sipStrings_QtCore[61969]
#define sipNameNr_Yoruba 61976
#define sipName_Yoruba &sipStrings_QtCore[61976]
#define sipNameNr_Tsonga 61983
#define sipName_Tsonga &sipStrings_QtCore[61983]
#define sipNameNr_Telugu 61990
#define sipName_Telugu &sipStrings_QtCore[61990]
#define sipNameNr_Somali 61997
#define sipName_Somali &sipStrings_QtCore[61997]
#define sipNameNr_Slovak 62004
#define sipName_Slovak &sipStrings_QtCore[62004]
#define sipNameNr_Sindhi 62011
#define sipName_Sindhi &sipStrings_QtCore[62011]
#define sipNameNr_Samoan 62018
#define sipName_Samoan &sipStrings_QtCore[62018]
#define sipNameNr_Pashto 62025
#define sipName_Pashto &sipStrings_QtCore[62025]
#define sipNameNr_Nepali 62032
#define sipName_Nepali &sipStrings_QtCore[62032]
#define sipNameNr_Korean 62039
#define sipName_Korean &sipStrings_QtCore[62039]
#define sipNameNr_Kazakh 62046
#define sipName_Kazakh &sipStrings_QtCore[62046]
#define sipNameNr_Hebrew 62053
#define sipName_Hebrew &sipStrings_QtCore[62053]
#define sipNameNr_German 45788
#define sipName_German &sipStrings_QtCore[45788]
#define sipNameNr_Gaelic 62060
#define sipName_Gaelic &sipStrings_QtCore[62060]
#define sipNameNr_French 62067
#define sipName_French &sipStrings_QtCore[62067]
#define sipNameNr_Danish 62074
#define sipName_Danish &sipStrings_QtCore[62074]
#define sipNameNr_Breton 62081
#define sipName_Breton &sipStrings_QtCore[62081]
#define sipNameNr_Bihari 62088
#define sipName_Bihari &sipStrings_QtCore[62088]
#define sipNameNr_Basque 62095
#define sipName_Basque &sipStrings_QtCore[62095]
#define sipNameNr_Aymara 62102
#define sipName_Aymara &sipStrings_QtCore[62102]
#define sipNameNr_Arabic 62109
#define sipName_Arabic &sipStrings_QtCore[62109]
#define sipNameNr_toLine 62116
#define sipName_toLine &sipStrings_QtCore[62116]
#define sipNameNr_QLineF 62123
#define sipName_QLineF &sipStrings_QtCore[62123]
#define sipNameNr_center 62130
#define sipName_center &sipStrings_QtCore[62130]
#define sipNameNr_unload 62137
#define sipName_unload &sipStrings_QtCore[62137]
#define sipNameNr_symbol 62144
#define sipName_symbol &sipStrings_QtCore[62144]
#define sipNameNr_Object 18978
#define sipName_Object &sipStrings_QtCore[18978]
#define sipNameNr_toJson 62151
#define sipName_toJson &sipStrings_QtCore[62151]
#define sipNameNr_takeAt 62158
#define sipName_takeAt &sipStrings_QtCore[62158]
#define sipNameNr_Toggle 20688
#define sipName_Toggle &sipStrings_QtCore[20688]
#define sipNameNr_Select 33127
#define sipName_Select &sipStrings_QtCore[33127]
#define sipNameNr_height 62165
#define sipName_height &sipStrings_QtCore[62165]
#define sipNameNr_bottom 62172
#define sipName_bottom &sipStrings_QtCore[62172]
#define sipNameNr_isOpen 62179
#define sipName_isOpen &sipStrings_QtCore[62179]
#define sipNameNr_Append 62186
#define sipName_Append &sipStrings_QtCore[62186]
#define sipNameNr_select 56845
#define sipName_select &sipStrings_QtCore[56845]
#define sipNameNr_isFile 62193
#define sipName_isFile &sipStrings_QtCore[62193]
#define sipNameNr_suffix 62200
#define sipName_suffix &sipStrings_QtCore[62200]
#define sipNameNr_offset 62207
#define sipName_offset &sipStrings_QtCore[62207]
#define sipNameNr_handle 62214
#define sipName_handle &sipStrings_QtCore[62214]
#define sipNameNr_period 62221
#define sipName_period &sipStrings_QtCore[62221]
#define sipNameNr_Custom 62228
#define sipName_Custom &sipStrings_QtCore[62228]
#define sipNameNr_InBack 53869
#define sipName_InBack &sipStrings_QtCore[53869]
#define sipNameNr_InCirc 53889
#define sipName_InCirc &sipStrings_QtCore[53889]
#define sipNameNr_InExpo 53909
#define sipName_InExpo &sipStrings_QtCore[53909]
#define sipNameNr_InSine 53929
#define sipName_InSine &sipStrings_QtCore[53929]
#define sipNameNr_InQuad 53949
#define sipName_InQuad &sipStrings_QtCore[53949]
#define sipNameNr_Linear 62235
#define sipName_Linear &sipStrings_QtCore[62235]
#define sipNameNr_prefix 62242
#define sipName_prefix &sipStrings_QtCore[62242]
#define sipNameNr_drives 62249
#define sipName_drives &sipStrings_QtCore[62249]
#define sipNameNr_rename 62256
#define sipName_rename &sipStrings_QtCore[62256]
#define sipNameNr_isRoot 62263
#define sipName_isRoot &sipStrings_QtCore[62263]
#define sipNameNr_exists 62270
#define sipName_exists &sipStrings_QtCore[62270]
#define sipNameNr_rmpath 62277
#define sipName_rmpath &sipStrings_QtCore[62277]
#define sipNameNr_mkpath 62284
#define sipName_mkpath &sipStrings_QtCore[62284]
#define sipNameNr_filter 62291
#define sipName_filter &sipStrings_QtCore[62291]
#define sipNameNr_NoSort 62298
#define sipName_NoSort &sipStrings_QtCore[62298]
#define sipNameNr_Hidden 23207
#define sipName_Hidden &sipStrings_QtCore[23207]
#define sipNameNr_Drives 62305
#define sipName_Drives &sipStrings_QtCore[62305]
#define sipNameNr_Filter 5381
#define sipName_Filter &sipStrings_QtCore[5381]
#define sipNameNr_secsTo 59972
#define sipName_secsTo &sipStrings_QtCore[59972]
#define sipNameNr_setHMS 62312
#define sipName_setHMS &sipStrings_QtCore[62312]
#define sipNameNr_minute 62319
#define sipName_minute &sipStrings_QtCore[62319]
#define sipNameNr_second 62326
#define sipName_second &sipStrings_QtCore[62326]
#define sipNameNr_daysTo 62333
#define sipName_daysTo &sipStrings_QtCore[62333]
#define sipNameNr_status 62340
#define sipName_status &sipStrings_QtCore[62340]
#define sipNameNr_Status 2020
#define sipName_Status &sipStrings_QtCore[2020]
#define sipNameNr_Qt_5_9 62347
#define sipName_Qt_5_9 &sipStrings_QtCore[62347]
#define sipNameNr_Qt_5_8 62354
#define sipName_Qt_5_8 &sipStrings_QtCore[62354]
#define sipNameNr_Qt_5_7 62361
#define sipName_Qt_5_7 &sipStrings_QtCore[62361]
#define sipNameNr_Qt_5_6 62368
#define sipName_Qt_5_6 &sipStrings_QtCore[62368]
#define sipNameNr_Qt_5_5 62375
#define sipName_Qt_5_5 &sipStrings_QtCore[62375]
#define sipNameNr_Qt_5_4 62382
#define sipName_Qt_5_4 &sipStrings_QtCore[62382]
#define sipNameNr_Qt_5_3 62389
#define sipName_Qt_5_3 &sipStrings_QtCore[62389]
#define sipNameNr_Qt_5_2 62396
#define sipName_Qt_5_2 &sipStrings_QtCore[62396]
#define sipNameNr_Qt_5_1 62403
#define sipName_Qt_5_1 &sipStrings_QtCore[62403]
#define sipNameNr_Qt_5_0 62410
#define sipName_Qt_5_0 &sipStrings_QtCore[62410]
#define sipNameNr_Qt_4_9 62417
#define sipName_Qt_4_9 &sipStrings_QtCore[62417]
#define sipNameNr_Qt_4_8 62424
#define sipName_Qt_4_8 &sipStrings_QtCore[62424]
#define sipNameNr_Qt_4_7 62431
#define sipName_Qt_4_7 &sipStrings_QtCore[62431]
#define sipNameNr_Qt_4_6 62438
#define sipName_Qt_4_6 &sipStrings_QtCore[62438]
#define sipNameNr_Qt_4_5 62445
#define sipName_Qt_4_5 &sipStrings_QtCore[62445]
#define sipNameNr_Qt_4_4 62452
#define sipName_Qt_4_4 &sipStrings_QtCore[62452]
#define sipNameNr_Qt_4_3 62459
#define sipName_Qt_4_3 &sipStrings_QtCore[62459]
#define sipNameNr_Qt_4_2 62466
#define sipName_Qt_4_2 &sipStrings_QtCore[62466]
#define sipNameNr_Qt_4_1 62473
#define sipName_Qt_4_1 &sipStrings_QtCore[62473]
#define sipNameNr_Qt_4_0 62480
#define sipName_Qt_4_0 &sipStrings_QtCore[62480]
#define sipNameNr_Qt_3_3 62487
#define sipName_Qt_3_3 &sipStrings_QtCore[62487]
#define sipNameNr_Qt_3_1 62494
#define sipName_Qt_3_1 &sipStrings_QtCore[62494]
#define sipNameNr_Qt_3_0 62501
#define sipName_Qt_3_0 &sipStrings_QtCore[62501]
#define sipNameNr_Qt_2_1 62508
#define sipName_Qt_2_1 &sipStrings_QtCore[62508]
#define sipNameNr_Qt_2_0 62515
#define sipName_Qt_2_0 &sipStrings_QtCore[62515]
#define sipNameNr_Qt_1_0 62522
#define sipName_Qt_1_0 &sipStrings_QtCore[62522]
#define sipNameNr_method 62529
#define sipName_method &sipStrings_QtCore[62529]
#define sipNameNr_Sha512 62536
#define sipName_Sha512 &sipStrings_QtCore[62536]
#define sipNameNr_Sha384 62543
#define sipName_Sha384 &sipStrings_QtCore[62543]
#define sipNameNr_Sha256 62550
#define sipName_Sha256 &sipStrings_QtCore[62550]
#define sipNameNr_Sha224 62557
#define sipName_Sha224 &sipStrings_QtCore[62557]
#define sipNameNr_ignore 62564
#define sipName_ignore &sipStrings_QtCore[62564]
#define sipNameNr_accept 62571
#define sipName_accept &sipStrings_QtCore[62571]
#define sipNameNr_Expose 62578
#define sipName_Expose &sipStrings_QtCore[62578]
#define sipNameNr_Scroll 62585
#define sipName_Scroll &sipStrings_QtCore[62585]
#define sipNameNr_Polish 62592
#define sipName_Polish &sipStrings_QtCore[62592]
#define sipNameNr_Resize 16532
#define sipName_Resize &sipStrings_QtCore[16532]
#define sipNameNr_QEvent 62599
#define sipName_QEvent &sipStrings_QtCore[62599]
#define sipNameNr_notify 62606
#define sipName_notify &sipStrings_QtCore[62606]
#define sipNameNr_values 62613
#define sipName_values &sipStrings_QtCore[62613]
#define sipNameNr_syntax 62620
#define sipName_syntax &sipStrings_QtCore[62620]
#define sipNameNr_string 62627
#define sipName_string &sipStrings_QtCore[62627]
#define sipNameNr_toBool 62634
#define sipName_toBool &sipStrings_QtCore[62634]
#define sipNameNr_isBool 62641
#define sipName_isBool &sipStrings_QtCore[62641]
#define sipNameNr_isTrue 62648
#define sipName_isTrue &sipStrings_QtCore[62648]
#define sipNameNr_Double 32167
#define sipName_Double &sipStrings_QtCore[32167]
#define sipNameNr_String 12154
#define sipName_String &sipStrings_QtCore[12154]
#define sipNameNr_endMap 62655
#define sipName_endMap &sipStrings_QtCore[62655]
#define sipNameNr_device 62662
#define sipName_device &sipStrings_QtCore[62662]
#define sipNameNr_Base64 33802
#define sipName_Base64 &sipStrings_QtCore[33802]
#define sipNameNr_False_ 62669
#define sipName_False_ &sipStrings_QtCore[62669]
#define sipNameNr_locale 62676
#define sipName_locale &sipStrings_QtCore[62676]
#define sipNameNr_system 62683
#define sipName_system &sipStrings_QtCore[62683]
#define sipNameNr_Jalali 62690
#define sipName_Jalali &sipStrings_QtCore[62690]
#define sipNameNr_Julian 62697
#define sipName_Julian &sipStrings_QtCore[62697]
#define sipNameNr_System 3139
#define sipName_System &sipStrings_QtCore[3139]
#define sipNameNr_number 62704
#define sipName_number &sipStrings_QtCore[62704]
#define sipNameNr_setNum 62711
#define sipName_setNum &sipStrings_QtCore[62711]
#define sipNameNr_format 62718
#define sipName_format &sipStrings_QtCore[62718]
#define sipNameNr_toLong 62725
#define sipName_toLong &sipStrings_QtCore[62725]
#define sipNameNr_toUInt 62732
#define sipName_toUInt &sipStrings_QtCore[62732]
#define sipNameNr___ge__ 62739
#define sipName___ge__ &sipStrings_QtCore[62739]
#define sipNameNr___le__ 62746
#define sipName___le__ &sipStrings_QtCore[62746]
#define sipNameNr___gt__ 62753
#define sipName___gt__ &sipStrings_QtCore[62753]
#define sipNameNr_remove 62760
#define sipName_remove &sipStrings_QtCore[62760]
#define sipNameNr_insert 62767
#define sipName_insert &sipStrings_QtCore[62767]
#define sipNameNr_append 62774
#define sipName_append &sipStrings_QtCore[62774]
#define sipNameNr_length 62781
#define sipName_length &sipStrings_QtCore[62781]
#define sipNameNr_maxlen 62788
#define sipName_maxlen &sipStrings_QtCore[62788]
#define sipNameNr_buffer 62795
#define sipName_buffer &sipStrings_QtCore[62795]
#define sipNameNr_setBit 62802
#define sipName_setBit &sipStrings_QtCore[62802]
#define sipNameNr_detach 62809
#define sipName_detach &sipStrings_QtCore[62809]
#define sipNameNr_resize 62816
#define sipName_resize &sipStrings_QtCore[62816]
#define sipNameNr_isNull 62823
#define sipName_isNull &sipStrings_QtCore[62823]
#define sipNameNr_onExit 62830
#define sipName_onExit &sipStrings_QtCore[62830]
#define sipNameNr_exited 62837
#define sipName_exited &sipStrings_QtCore[62837]
#define sipNameNr_active 16952
#define sipName_active &sipStrings_QtCore[16952]
#define sipNameNr_revert 62844
#define sipName_revert &sipStrings_QtCore[62844]
#define sipNameNr_submit 62851
#define sipName_submit &sipStrings_QtCore[62851]
#define sipNameNr___lt__ 62858
#define sipName___lt__ &sipStrings_QtCore[62858]
#define sipNameNr_column 62865
#define sipName_column &sipStrings_QtCore[62865]
#define sipNameNr_result 62872
#define sipName_result &sipStrings_QtCore[62872]
#define sipNameNr_wakeUp 62879
#define sipName_wakeUp &sipStrings_QtCore[62879]
#define sipNameNr_object 62886
#define sipName_object &sipStrings_QtCore[62886]
#define sipNameNr_thread 62893
#define sipName_thread &sipStrings_QtCore[62893]
#define sipNameNr_resume 62900
#define sipName_resume &sipStrings_QtCore[62900]
#define sipNameNr_policy 62907
#define sipName_policy &sipStrings_QtCore[62907]
#define sipNameNr_parent 6696
#define sipName_parent &sipStrings_QtCore[6696]
#define sipNameNr_Paused 54659
#define sipName_Paused &sipStrings_QtCore[54659]
#define sipNameNr_ImFont 62914
#define sipName_ImFont &sipStrings_QtCore[62914]
#define sipNameNr_NoClip 62921
#define sipName_NoClip &sipStrings_QtCore[62921]
#define sipNameNr_Corner 23549
#define sipName_Corner &sipStrings_QtCore[23549]
#define sipNameNr_Sunday 62928
#define sipName_Sunday &sipStrings_QtCore[62928]
#define sipNameNr_Friday 62935
#define sipName_Friday &sipStrings_QtCore[62935]
#define sipNameNr_Monday 62942
#define sipName_Monday &sipStrings_QtCore[62942]
#define sipNameNr_Key_Go 62949
#define sipName_Key_Go &sipStrings_QtCore[62949]
#define sipNameNr_Key_CD 62956
#define sipName_Key_CD &sipStrings_QtCore[62956]
#define sipNameNr_Key_No 62963
#define sipName_Key_No &sipStrings_QtCore[62963]
#define sipNameNr_Key_AE 62970
#define sipName_Key_AE &sipStrings_QtCore[62970]
#define sipNameNr_Key_mu 62977
#define sipName_Key_mu &sipStrings_QtCore[62977]
#define sipNameNr_Key_At 62984
#define sipName_Key_At &sipStrings_QtCore[62984]
#define sipNameNr_Key_F9 62991
#define sipName_Key_F9 &sipStrings_QtCore[62991]
#define sipNameNr_Key_F8 62998
#define sipName_Key_F8 &sipStrings_QtCore[62998]
#define sipNameNr_Key_F7 63005
#define sipName_Key_F7 &sipStrings_QtCore[63005]
#define sipNameNr_Key_F6 63012
#define sipName_Key_F6 &sipStrings_QtCore[63012]
#define sipNameNr_Key_F5 63019
#define sipName_Key_F5 &sipStrings_QtCore[63019]
#define sipNameNr_Key_F4 63026
#define sipName_Key_F4 &sipStrings_QtCore[63026]
#define sipNameNr_Key_F3 63033
#define sipName_Key_F3 &sipStrings_QtCore[63033]
#define sipNameNr_Key_F2 63040
#define sipName_Key_F2 &sipStrings_QtCore[63040]
#define sipNameNr_Key_F1 63047
#define sipName_Key_F1 &sipStrings_QtCore[63047]
#define sipNameNr_Key_Up 63054
#define sipName_Key_Up &sipStrings_QtCore[63054]
#define sipNameNr_BGMode 51913
#define sipName_BGMode &sipStrings_QtCore[51913]
#define sipNameNr_Drawer 63061
#define sipName_Drawer &sipStrings_QtCore[63061]
#define sipNameNr_Dialog 4650
#define sipName_Dialog &sipStrings_QtCore[4650]
#define sipNameNr_Window 5678
#define sipName_Window &sipStrings_QtCore[5678]
#define sipNameNr_Widget 6774
#define sipName_Widget &sipStrings_QtCore[6774]
#define sipNameNr_yellow 63068
#define sipName_yellow &sipStrings_QtCore[63068]
#define sipNameNr_color1 63075
#define sipName_color1 &sipStrings_QtCore[63075]
#define sipNameNr_color0 63082
#define sipName_color0 &sipStrings_QtCore[63082]
#define sipNameNr_qsrand 63089
#define sipName_qsrand &sipStrings_QtCore[63089]
#define sipNameNr___ne__ 63096
#define sipName___ne__ &sipStrings_QtCore[63096]
#define sipNameNr___eq__ 63103
#define sipName___eq__ &sipStrings_QtCore[63103]
#define sipNameNr___or__ 63110
#define sipName___or__ &sipStrings_QtCore[63110]
#define sipNameNr_QFlags 63117
#define sipName_QFlags &sipStrings_QtCore[63117]
#define sipNameNr_qRound 63124
#define sipName_qRound &sipStrings_QtCore[63124]
#define sipNameNr_Sizes 27640
#define sipName_Sizes &sipStrings_QtCore[27640]
#define sipNameNr_isDTD 63131
#define sipName_isDTD &sipStrings_QtCore[63131]
#define sipNameNr_Image 55811
#define sipName_Image &sipStrings_QtCore[55811]
#define sipNameNr_Color 31208
#define sipName_Color &sipStrings_QtCore[31208]
#define sipNameNr_Brush 60573
#define sipName_Brush &sipStrings_QtCore[60573]
#define sipNameNr_Point 30184
#define sipName_Point &sipStrings_QtCore[30184]
#define sipNameNr_LineF 62124
#define sipName_LineF &sipStrings_QtCore[62124]
#define sipNameNr_SizeF 61263
#define sipName_SizeF &sipStrings_QtCore[61263]
#define sipNameNr_RectF 61270
#define sipName_RectF &sipStrings_QtCore[61270]
#define sipNameNr_Id128 63137
#define sipName_Id128 &sipStrings_QtCore[63137]
#define sipNameNr_query 63143
#define sipName_query &sipStrings_QtCore[63143]
#define sipNameNr_toAce 63149
#define sipName_toAce &sipStrings_QtCore[63149]
#define sipNameNr_atUtc 63155
#define sipName_atUtc &sipStrings_QtCore[63155]
#define sipNameNr_sleep 61032
#define sipName_sleep &sipStrings_QtCore[61032]
#define sipNameNr_fixed 63161
#define sipName_fixed &sipStrings_QtCore[63161]
#define sipNameNr_toEnd 63167
#define sipName_toEnd &sipStrings_QtCore[63167]
#define sipNameNr_Write 28360
#define sipName_Write &sipStrings_QtCore[28360]
#define sipNameNr_scale 63173
#define sipName_scale &sipStrings_QtCore[63173]
#define sipNameNr_codec 63179
#define sipName_codec &sipStrings_QtCore[63179]
#define sipNameNr_Scope 24669
#define sipName_Scope &sipStrings_QtCore[24669]
#define sipNameNr_MacOS 63185
#define sipName_MacOS &sipStrings_QtCore[63185]
#define sipNameNr_Q_ARG 63191
#define sipName_Q_ARG &sipStrings_QtCore[63191]
#define sipNameNr_qQNaN 63197
#define sipName_qQNaN &sipStrings_QtCore[63197]
#define sipNameNr_qSNaN 63203
#define sipName_qSNaN &sipStrings_QtCore[63203]
#define sipNameNr_mutex 63209
#define sipName_mutex &sipStrings_QtCore[63209]
#define sipNameNr_SChar 63215
#define sipName_SChar &sipStrings_QtCore[63215]
#define sipNameNr_QUuid 63221
#define sipName_QUuid &sipStrings_QtCore[63221]
#define sipNameNr_UChar 63227
#define sipName_UChar &sipStrings_QtCore[63227]
#define sipNameNr_ULong 60341
#define sipName_ULong &sipStrings_QtCore[60341]
#define sipNameNr_Short 57494
#define sipName_Short &sipStrings_QtCore[57494]
#define sipNameNr_QIcon 63233
#define sipName_QIcon &sipStrings_QtCore[63233]
#define sipNameNr_QFont 63239
#define sipName_QFont &sipStrings_QtCore[63239]
#define sipNameNr_QSize 63245
#define sipName_QSize &sipStrings_QtCore[63245]
#define sipNameNr_QRect 63251
#define sipName_QRect &sipStrings_QtCore[63251]
#define sipNameNr_scope 63257
#define sipName_scope &sipStrings_QtCore[63257]
#define sipNameNr_qInfo 63263
#define sipName_qInfo &sipStrings_QtCore[63263]
#define sipNameNr_fatal 63269
#define sipName_fatal &sipStrings_QtCore[63269]
#define sipNameNr_debug 63275
#define sipName_debug &sipStrings_QtCore[63275]
#define sipNameNr_style 63281
#define sipName_style &sipStrings_QtCore[63281]
#define sipNameNr_World 63287
#define sipName_World &sipStrings_QtCore[63287]
#define sipNameNr_Tonga 63293
#define sipName_Tonga &sipStrings_QtCore[63293]
#define sipNameNr_Syria 63299
#define sipName_Syria &sipStrings_QtCore[63299]
#define sipNameNr_Libya 63305
#define sipName_Libya &sipStrings_QtCore[63305]
#define sipNameNr_Yemen 63311
#define sipName_Yemen &sipStrings_QtCore[63311]
#define sipNameNr_Sudan 49439
#define sipName_Sudan &sipStrings_QtCore[49439]
#define sipNameNr_Spain 63317
#define sipName_Spain &sipStrings_QtCore[63317]
#define sipNameNr_Samoa 37075
#define sipName_Samoa &sipStrings_QtCore[37075]
#define sipNameNr_Qatar 63323
#define sipName_Qatar &sipStrings_QtCore[63323]
#define sipNameNr_Palau 63329
#define sipName_Palau &sipStrings_QtCore[63329]
#define sipNameNr_Niger 63335
#define sipName_Niger &sipStrings_QtCore[63335]
#define sipNameNr_Nepal 63341
#define sipName_Nepal &sipStrings_QtCore[63341]
#define sipNameNr_Malta 63347
#define sipName_Malta &sipStrings_QtCore[63347]
#define sipNameNr_Macau 63353
#define sipName_Macau &sipStrings_QtCore[63353]
#define sipNameNr_Kenya 63359
#define sipName_Kenya &sipStrings_QtCore[63359]
#define sipNameNr_Japan 63365
#define sipName_Japan &sipStrings_QtCore[63365]
#define sipNameNr_Italy 63371
#define sipName_Italy &sipStrings_QtCore[63371]
#define sipNameNr_India 63377
#define sipName_India &sipStrings_QtCore[63377]
#define sipNameNr_Haiti 63383
#define sipName_Haiti &sipStrings_QtCore[63383]
#define sipNameNr_Ghana 63389
#define sipName_Ghana &sipStrings_QtCore[63389]
#define sipNameNr_Gabon 63395
#define sipName_Gabon &sipStrings_QtCore[63395]
#define sipNameNr_Egypt 63401
#define sipName_Egypt &sipStrings_QtCore[63401]
#define sipNameNr_China 63407
#define sipName_China &sipStrings_QtCore[63407]
#define sipNameNr_Chile 63413
#define sipName_Chile &sipStrings_QtCore[63413]
#define sipNameNr_Benin 63419
#define sipName_Benin &sipStrings_QtCore[63419]
#define sipNameNr_Aruba 63425
#define sipName_Aruba &sipStrings_QtCore[63425]
#define sipNameNr_Erzya 63431
#define sipName_Erzya &sipStrings_QtCore[63431]
#define sipNameNr_Osage 63437
#define sipName_Osage &sipStrings_QtCore[63437]
#define sipNameNr_Bassa 63443
#define sipName_Bassa &sipStrings_QtCore[63443]
#define sipNameNr_Mende 63449
#define sipName_Mende &sipStrings_QtCore[63449]
#define sipNameNr_Kiche 63455
#define sipName_Kiche &sipStrings_QtCore[63455]
#define sipNameNr_Limbu 63461
#define sipName_Limbu &sipStrings_QtCore[63461]
#define sipNameNr_Dogri 63467
#define sipName_Dogri &sipStrings_QtCore[63467]
#define sipNameNr_Buhid 63473
#define sipName_Buhid &sipStrings_QtCore[63473]
#define sipNameNr_Bamun 63479
#define sipName_Bamun &sipStrings_QtCore[63479]
#define sipNameNr_Kongo 63485
#define sipName_Kongo &sipStrings_QtCore[63485]
#define sipNameNr_Swati 63491
#define sipName_Swati &sipStrings_QtCore[63491]
#define sipNameNr_Sango 63497
#define sipName_Sango &sipStrings_QtCore[63497]
#define sipNameNr_Khmer 63503
#define sipName_Khmer &sipStrings_QtCore[63503]
#define sipNameNr_Oromo 63509
#define sipName_Oromo &sipStrings_QtCore[63509]
#define sipNameNr_Sangu 63515
#define sipName_Sangu &sipStrings_QtCore[63515]
#define sipNameNr_Sakha 63521
#define sipName_Sakha &sipStrings_QtCore[63521]
#define sipNameNr_Bafia 63527
#define sipName_Bafia &sipStrings_QtCore[63527]
#define sipNameNr_Duala 63533
#define sipName_Duala &sipStrings_QtCore[63533]
#define sipNameNr_Zarma 63539
#define sipName_Zarma &sipStrings_QtCore[63539]
#define sipNameNr_Basaa 63545
#define sipName_Basaa &sipStrings_QtCore[63545]
#define sipNameNr_Aghem 63551
#define sipName_Aghem &sipStrings_QtCore[63551]
#define sipNameNr_Rundi 63557
#define sipName_Rundi &sipStrings_QtCore[63557]
#define sipNameNr_Chiga 63563
#define sipName_Chiga &sipStrings_QtCore[63563]
#define sipNameNr_Luyia 63569
#define sipName_Luyia &sipStrings_QtCore[63569]
#define sipNameNr_Masai 63575
#define sipName_Masai &sipStrings_QtCore[63575]
#define sipNameNr_Bemba 63581
#define sipName_Bemba &sipStrings_QtCore[63581]
#define sipNameNr_Ganda 63587
#define sipName_Ganda &sipStrings_QtCore[63587]
#define sipNameNr_Langi 63593
#define sipName_Langi &sipStrings_QtCore[63593]
#define sipNameNr_Vunjo 63599
#define sipName_Vunjo &sipStrings_QtCore[63599]
#define sipNameNr_Rombo 63605
#define sipName_Rombo &sipStrings_QtCore[63605]
#define sipNameNr_Fulah 63611
#define sipName_Fulah &sipStrings_QtCore[63611]
#define sipNameNr_Taita 63617
#define sipName_Taita &sipStrings_QtCore[63617]
#define sipNameNr_Gusii 63623
#define sipName_Gusii &sipStrings_QtCore[63623]
#define sipNameNr_Chewa 63629
#define sipName_Chewa &sipStrings_QtCore[63629]
#define sipNameNr_Venda 63635
#define sipName_Venda &sipStrings_QtCore[63635]
#define sipNameNr_Tigre 63641
#define sipName_Tigre &sipStrings_QtCore[63641]
#define sipNameNr_Atsam 63647
#define sipName_Atsam &sipStrings_QtCore[63647]
#define sipNameNr_Kamba 63653
#define sipName_Kamba &sipStrings_QtCore[63653]
#define sipNameNr_Xhosa 63659
#define sipName_Xhosa &sipStrings_QtCore[63659]
#define sipNameNr_Wolof 63665
#define sipName_Wolof &sipStrings_QtCore[63665]
#define sipNameNr_Welsh 63671
#define sipName_Welsh &sipStrings_QtCore[63671]
#define sipNameNr_Uzbek 63677
#define sipName_Uzbek &sipStrings_QtCore[63677]
#define sipNameNr_Uigur 63683
#define sipName_Uigur &sipStrings_QtCore[63683]
#define sipNameNr_Tatar 63689
#define sipName_Tatar &sipStrings_QtCore[63689]
#define sipNameNr_Tamil 63695
#define sipName_Tamil &sipStrings_QtCore[63695]
#define sipNameNr_Tajik 63701
#define sipName_Tajik &sipStrings_QtCore[63701]
#define sipNameNr_Shona 63707
#define sipName_Shona &sipStrings_QtCore[63707]
#define sipNameNr_Oriya 63713
#define sipName_Oriya &sipStrings_QtCore[63713]
#define sipNameNr_Maori 63719
#define sipName_Maori &sipStrings_QtCore[63719]
#define sipNameNr_Malay 63725
#define sipName_Malay &sipStrings_QtCore[63725]
#define sipNameNr_Latin 34193
#define sipName_Latin &sipStrings_QtCore[34193]
#define sipNameNr_Irish 56396
#define sipName_Irish &sipStrings_QtCore[56396]
#define sipNameNr_Hindi 63731
#define sipName_Hindi &sipStrings_QtCore[63731]
#define sipNameNr_Hausa 63737
#define sipName_Hausa &sipStrings_QtCore[63737]
#define sipNameNr_Greek 34703
#define sipName_Greek &sipStrings_QtCore[34703]
#define sipNameNr_Dutch 63743
#define sipName_Dutch &sipStrings_QtCore[63743]
#define sipNameNr_Czech 63749
#define sipName_Czech &sipStrings_QtCore[63749]
#define sipNameNr_angle 7726
#define sipName_angle &sipStrings_QtCore[7726]
#define sipNameNr_setP2 63755
#define sipName_setP2 &sipStrings_QtCore[63755]
#define sipNameNr_setP1 63761
#define sipName_setP1 &sipStrings_QtCore[63761]
#define sipNameNr_QLine 63767
#define sipName_QLine &sipStrings_QtCore[63767]
#define sipNameNr_array 63773
#define sipName_array &sipStrings_QtCore[63773]
#define sipNameNr_merge 63779
#define sipName_merge &sipStrings_QtCore[63779]
#define sipNameNr_Clear 55140
#define sipName_Clear &sipStrings_QtCore[55140]
#define sipNameNr_write 63785
#define sipName_write &sipStrings_QtCore[63785]
#define sipNameNr_files 63791
#define sipName_files &sipStrings_QtCore[63791]
#define sipNameNr_paths 63797
#define sipName_paths &sipStrings_QtCore[63797]
#define sipNameNr_owner 63803
#define sipName_owner &sipStrings_QtCore[63803]
#define sipNameNr_isDir 63809
#define sipName_isDir &sipStrings_QtCore[63809]
#define sipNameNr_unmap 63815
#define sipName_unmap &sipStrings_QtCore[63815]
#define sipNameNr_error 63821
#define sipName_error &sipStrings_QtCore[63821]
#define sipNameNr_QFile 63827
#define sipName_QFile &sipStrings_QtCore[63827]
#define sipNameNr_rmdir 63833
#define sipName_rmdir &sipStrings_QtCore[63833]
#define sipNameNr_mkdir 63839
#define sipName_mkdir &sipStrings_QtCore[63839]
#define sipNameNr_NoDot 63845
#define sipName_NoDot &sipStrings_QtCore[63845]
#define sipNameNr_Files 63851
#define sipName_Files &sipStrings_QtCore[63851]
#define sipNameNr_nsecs 63857
#define sipName_nsecs &sipStrings_QtCore[63857]
#define sipNameNr_First 53620
#define sipName_First &sipStrings_QtCore[53620]
#define sipNameNr_toUTC 63863
#define sipName_toUTC &sipStrings_QtCore[63863]
#define sipNameNr_QTime 63869
#define sipName_QTime &sipStrings_QtCore[63869]
#define sipNameNr_QDate 63875
#define sipName_QDate &sipStrings_QtCore[63875]
#define sipNameNr_added 63881
#define sipName_added &sipStrings_QtCore[63881]
#define sipNameNr_Wheel 19321
#define sipName_Wheel &sipStrings_QtCore[19321]
#define sipNameNr_Close 27304
#define sipName_Close &sipStrings_QtCore[27304]
#define sipNameNr_Paint 63887
#define sipName_Paint &sipStrings_QtCore[63887]
#define sipNameNr_Leave 8770
#define sipName_Leave &sipStrings_QtCore[8770]
#define sipNameNr_Enter 8794
#define sipName_Enter &sipStrings_QtCore[8794]
#define sipNameNr_Timer 29976
#define sipName_Timer &sipStrings_QtCore[29976]
#define sipNameNr_None_ 63893
#define sipName_None_ &sipStrings_QtCore[63893]
#define sipNameNr_exec_ 63899
#define sipName_exec_ &sipStrings_QtCore[63899]
#define sipNameNr_isSet 63905
#define sipName_isSet &sipStrings_QtCore[63905]
#define sipNameNr_parse 60157
#define sipName_parse &sipStrings_QtCore[60157]
#define sipNameNr_Flags 959
#define sipName_Flags &sipStrings_QtCore[959]
#define sipNameNr_names 63911
#define sipName_names &sipStrings_QtCore[63911]
#define sipNameNr_QChar 63917
#define sipName_QChar &sipStrings_QtCore[63917]
#define sipNameNr_isTag 63923
#define sipName_isTag &sipStrings_QtCore[63923]
#define sipNameNr_isMap 63929
#define sipName_isMap &sipStrings_QtCore[63929]
#define sipNameNr_reset 63935
#define sipName_reset &sipStrings_QtCore[63935]
#define sipNameNr_Error 430
#define sipName_Error &sipStrings_QtCore[430]
#define sipNameNr_Float 50451
#define sipName_Float &sipStrings_QtCore[50451]
#define sipNameNr_Array 22362
#define sipName_Array &sipStrings_QtCore[22362]
#define sipNameNr_True_ 63941
#define sipName_True_ &sipStrings_QtCore[63941]
#define sipNameNr_month 63947
#define sipName_month &sipStrings_QtCore[63947]
#define sipNameNr_toHex 63953
#define sipName_toHex &sipStrings_QtCore[63953]
#define sipNameNr_toInt 63959
#define sipName_toInt &sipStrings_QtCore[63959]
#define sipNameNr_split 63965
#define sipName_split &sipStrings_QtCore[63965]
#define sipNameNr_width 63971
#define sipName_width &sipStrings_QtCore[63971]
#define sipNameNr_right 20784
#define sipName_right &sipStrings_QtCore[20784]
#define sipNameNr_atEnd 63977
#define sipName_atEnd &sipStrings_QtCore[63977]
#define sipNameNr_close 63983
#define sipName_close &sipStrings_QtCore[63983]
#define sipNameNr_clear 63989
#define sipName_clear &sipStrings_QtCore[63989]
#define sipNameNr_first 63995
#define sipName_first &sipStrings_QtCore[63995]
#define sipNameNr_match 64001
#define sipName_match &sipStrings_QtCore[64001]
#define sipNameNr_buddy 64007
#define sipName_buddy &sipStrings_QtCore[64007]
#define sipNameNr_order 64013
#define sipName_order &sipStrings_QtCore[64013]
#define sipNameNr_count 64019
#define sipName_count &sipStrings_QtCore[64019]
#define sipNameNr_roles 64025
#define sipName_roles &sipStrings_QtCore[64025]
#define sipNameNr_value 64031
#define sipName_value &sipStrings_QtCore[64031]
#define sipNameNr_index 64037
#define sipName_index &sipStrings_QtCore[64037]
#define sipNameNr_model 64043
#define sipName_model &sipStrings_QtCore[64043]
#define sipNameNr_child 64049
#define sipName_child &sipStrings_QtCore[64049]
#define sipNameNr_awake 64055
#define sipName_awake &sipStrings_QtCore[64055]
#define sipNameNr_flush 64061
#define sipName_flush &sipStrings_QtCore[64061]
#define sipNameNr_flags 64067
#define sipName_flags &sipStrings_QtCore[64067]
#define sipNameNr_event 64073
#define sipName_event &sipStrings_QtCore[64073]
#define sipNameNr_msecs 64079
#define sipName_msecs &sipStrings_QtCore[64079]
#define sipNameNr_pause 64085
#define sipName_pause &sipStrings_QtCore[64085]
#define sipNameNr_start 59965
#define sipName_start &sipStrings_QtCore[59965]
#define sipNameNr_group 64091
#define sipName_group &sipStrings_QtCore[64091]
#define sipNameNr_state 20290
#define sipName_state &sipStrings_QtCore[20290]
#define sipNameNr_State 4842
#define sipName_State &sipStrings_QtCore[4842]
#define sipNameNr_Floor 26437
#define sipName_Floor &sipStrings_QtCore[26437]
#define sipNameNr_Round 63125
#define sipName_Round &sipStrings_QtCore[63125]
#define sipNameNr_Edges 54690
#define sipName_Edges &sipStrings_QtCore[54690]
#define sipNameNr_ZAxis 64097
#define sipName_ZAxis &sipStrings_QtCore[64097]
#define sipNameNr_YAxis 64103
#define sipName_YAxis &sipStrings_QtCore[64103]
#define sipNameNr_XAxis 64109
#define sipName_XAxis &sipStrings_QtCore[64109]
#define sipNameNr_NoPen 64115
#define sipName_NoPen &sipStrings_QtCore[64115]
#define sipNameNr_Key_Z 64121
#define sipName_Key_Z &sipStrings_QtCore[64121]
#define sipNameNr_Key_Y 64127
#define sipName_Key_Y &sipStrings_QtCore[64127]
#define sipNameNr_Key_X 64133
#define sipName_Key_X &sipStrings_QtCore[64133]
#define sipNameNr_Key_W 64139
#define sipName_Key_W &sipStrings_QtCore[64139]
#define sipNameNr_Key_V 64145
#define sipName_Key_V &sipStrings_QtCore[64145]
#define sipNameNr_Key_U 64151
#define sipName_Key_U &sipStrings_QtCore[64151]
#define sipNameNr_Key_T 64157
#define sipName_Key_T &sipStrings_QtCore[64157]
#define sipNameNr_Key_S 64163
#define sipName_Key_S &sipStrings_QtCore[64163]
#define sipNameNr_Key_R 64169
#define sipName_Key_R &sipStrings_QtCore[64169]
#define sipNameNr_Key_Q 64175
#define sipName_Key_Q &sipStrings_QtCore[64175]
#define sipNameNr_Key_P 64181
#define sipName_Key_P &sipStrings_QtCore[64181]
#define sipNameNr_Key_O 64187
#define sipName_Key_O &sipStrings_QtCore[64187]
#define sipNameNr_Key_N 64193
#define sipName_Key_N &sipStrings_QtCore[64193]
#define sipNameNr_Key_M 64199
#define sipName_Key_M &sipStrings_QtCore[64199]
#define sipNameNr_Key_L 64205
#define sipName_Key_L &sipStrings_QtCore[64205]
#define sipNameNr_Key_K 64211
#define sipName_Key_K &sipStrings_QtCore[64211]
#define sipNameNr_Key_J 64217
#define sipName_Key_J &sipStrings_QtCore[64217]
#define sipNameNr_Key_I 64223
#define sipName_Key_I &sipStrings_QtCore[64223]
#define sipNameNr_Key_H 64229
#define sipName_Key_H &sipStrings_QtCore[64229]
#define sipNameNr_Key_G 64235
#define sipName_Key_G &sipStrings_QtCore[64235]
#define sipNameNr_Key_F 64241
#define sipName_Key_F &sipStrings_QtCore[64241]
#define sipNameNr_Key_E 64247
#define sipName_Key_E &sipStrings_QtCore[64247]
#define sipNameNr_Key_D 64253
#define sipName_Key_D &sipStrings_QtCore[64253]
#define sipNameNr_Key_C 64259
#define sipName_Key_C &sipStrings_QtCore[64259]
#define sipNameNr_Key_B 64265
#define sipName_Key_B &sipStrings_QtCore[64265]
#define sipNameNr_Key_A 64271
#define sipName_Key_A &sipStrings_QtCore[64271]
#define sipNameNr_Key_9 64277
#define sipName_Key_9 &sipStrings_QtCore[64277]
#define sipNameNr_Key_8 64283
#define sipName_Key_8 &sipStrings_QtCore[64283]
#define sipNameNr_Key_7 64289
#define sipName_Key_7 &sipStrings_QtCore[64289]
#define sipNameNr_Key_6 64295
#define sipName_Key_6 &sipStrings_QtCore[64295]
#define sipNameNr_Key_5 64301
#define sipName_Key_5 &sipStrings_QtCore[64301]
#define sipNameNr_Key_4 64307
#define sipName_Key_4 &sipStrings_QtCore[64307]
#define sipNameNr_Key_3 64313
#define sipName_Key_3 &sipStrings_QtCore[64313]
#define sipNameNr_Key_2 64319
#define sipName_Key_2 &sipStrings_QtCore[64319]
#define sipNameNr_Key_1 64325
#define sipName_Key_1 &sipStrings_QtCore[64325]
#define sipNameNr_Key_0 64331
#define sipName_Key_0 &sipStrings_QtCore[64331]
#define sipNameNr_Popup 64337
#define sipName_Popup &sipStrings_QtCore[64337]
#define sipNameNr_Sheet 39189
#define sipName_Sheet &sipStrings_QtCore[39189]
#define sipNameNr_SHIFT 64343
#define sipName_SHIFT &sipStrings_QtCore[64343]
#define sipNameNr_green 64349
#define sipName_green &sipStrings_QtCore[64349]
#define sipNameNr_white 64355
#define sipName_white &sipStrings_QtCore[64355]
#define sipNameNr_black 64361
#define sipName_black &sipStrings_QtCore[64361]
#define sipNameNr_qrand 64367
#define sipName_qrand &sipStrings_QtCore[64367]
#define sipNameNr_save 64373
#define sipName_save &sipStrings_QtCore[64373]
#define sipNameNr_Hash 19246
#define sipName_Hash &sipStrings_QtCore[19246]
#define sipNameNr_Icon 7702
#define sipName_Icon &sipStrings_QtCore[7702]
#define sipNameNr_Font 51948
#define sipName_Font &sipStrings_QtCore[51948]
#define sipNameNr_Rect 5464
#define sipName_Rect &sipStrings_QtCore[5464]
#define sipNameNr_Date 10893
#define sipName_Date &sipStrings_QtCore[10893]
#define sipNameNr_List 6412
#define sipName_List &sipStrings_QtCore[6412]
#define sipNameNr_port 47602
#define sipName_port &sipStrings_QtCore[47602]
#define sipNameNr_host 64378
#define sipName_host &sipStrings_QtCore[64378]
#define sipNameNr_wait 61593
#define sipName_wait &sipStrings_QtCore[61593]
#define sipNameNr_endl 64383
#define sipName_endl &sipStrings_QtCore[64383]
#define sipNameNr_hex_ 64388
#define sipName_hex_ &sipStrings_QtCore[64388]
#define sipNameNr_oct_ 64393
#define sipName_oct_ &sipStrings_QtCore[64393]
#define sipNameNr_bin_ 64398
#define sipName_bin_ &sipStrings_QtCore[64398]
#define sipNameNr_Line 34674
#define sipName_Line &sipStrings_QtCore[34674]
#define sipNameNr_Word 57909
#define sipName_Word &sipStrings_QtCore[57909]
#define sipNameNr_Open 57252
#define sipName_Open &sipStrings_QtCore[57252]
#define sipNameNr_Read 25537
#define sipName_Read &sipStrings_QtCore[25537]
#define sipNameNr_sync 64403
#define sipName_sync &sipStrings_QtCore[64403]
#define sipNameNr_kill 64408
#define sipName_kill &sipStrings_QtCore[64408]
#define sipNameNr_setY 64413
#define sipName_setY &sipStrings_QtCore[64413]
#define sipNameNr_setX 64418
#define sipName_setX &sipStrings_QtCore[64418]
#define sipNameNr_TvOS 64423
#define sipName_TvOS &sipStrings_QtCore[64423]
#define sipNameNr_qInf 64428
#define sipName_qInf &sipStrings_QtCore[64428]
#define sipNameNr_html 64433
#define sipName_html &sipStrings_QtCore[64433]
#define sipNameNr_text 17334
#define sipName_text &sipStrings_QtCore[17334]
#define sipNameNr_urls 64438
#define sipName_urls &sipStrings_QtCore[64438]
#define sipNameNr_Char 44542
#define sipName_Char &sipStrings_QtCore[44542]
#define sipNameNr_Long 46954
#define sipName_Long &sipStrings_QtCore[46954]
#define sipNameNr_QPen 64443
#define sipName_QPen &sipStrings_QtCore[64443]
#define sipNameNr_QUrl 64448
#define sipName_QUrl &sipStrings_QtCore[64448]
#define sipNameNr_UInt 62734
#define sipName_UInt &sipStrings_QtCore[62734]
#define sipNameNr_Void 64453
#define sipName_Void &sipStrings_QtCore[64453]
#define sipNameNr_keys 64458
#define sipName_keys &sipStrings_QtCore[64458]
#define sipNameNr_Slot 45022
#define sipName_Slot &sipStrings_QtCore[45022]
#define sipNameNr_info 64463
#define sipName_info &sipStrings_QtCore[64463]
#define sipNameNr_lock 33294
#define sipName_lock &sipStrings_QtCore[33294]
#define sipNameNr_Laos 64468
#define sipName_Laos &sipStrings_QtCore[64468]
#define sipNameNr_Fiji 64473
#define sipName_Fiji &sipStrings_QtCore[64473]
#define sipNameNr_Togo 64478
#define sipName_Togo &sipStrings_QtCore[64478]
#define sipNameNr_Peru 64483
#define sipName_Peru &sipStrings_QtCore[64483]
#define sipNameNr_Oman 64488
#define sipName_Oman &sipStrings_QtCore[64488]
#define sipNameNr_Niue 64493
#define sipName_Niue &sipStrings_QtCore[64493]
#define sipNameNr_Mali 64498
#define sipName_Mali &sipStrings_QtCore[64498]
#define sipNameNr_Iraq 64503
#define sipName_Iraq &sipStrings_QtCore[64503]
#define sipNameNr_Iran 64508
#define sipName_Iran &sipStrings_QtCore[64508]
#define sipNameNr_Guam 64513
#define sipName_Guam &sipStrings_QtCore[64513]
#define sipNameNr_Cuba 64518
#define sipName_Cuba &sipStrings_QtCore[64518]
#define sipNameNr_Chad 64523
#define sipName_Chad &sipStrings_QtCore[64523]
#define sipNameNr_Ahom 64528
#define sipName_Ahom &sipStrings_QtCore[64528]
#define sipNameNr_Mono 64533
#define sipName_Mono &sipStrings_QtCore[64533]
#define sipNameNr_Sora 64538
#define sipName_Sora &sipStrings_QtCore[64538]
#define sipNameNr_Lisu 64543
#define sipName_Lisu &sipStrings_QtCore[64543]
#define sipNameNr_Meta 6568
#define sipName_Meta &sipStrings_QtCore[6568]
#define sipNameNr_Kako 64548
#define sipName_Kako &sipStrings_QtCore[64548]
#define sipNameNr_Pali 64553
#define sipName_Pali &sipStrings_QtCore[64553]
#define sipNameNr_Komi 64558
#define sipName_Komi &sipStrings_QtCore[64558]
#define sipNameNr_Cree 64563
#define sipName_Cree &sipStrings_QtCore[64563]
#define sipNameNr_Nuer 64568
#define sipName_Nuer &sipStrings_QtCore[64568]
#define sipNameNr_Bodo 64573
#define sipName_Bodo &sipStrings_QtCore[64573]
#define sipNameNr_Saho 64578
#define sipName_Saho &sipStrings_QtCore[64578]
#define sipNameNr_Teso 64583
#define sipName_Teso &sipStrings_QtCore[64583]
#define sipNameNr_Soga 64588
#define sipName_Soga &sipStrings_QtCore[64588]
#define sipNameNr_Nama 64593
#define sipName_Nama &sipStrings_QtCore[64593]
#define sipNameNr_Meru 64598
#define sipName_Meru &sipStrings_QtCore[64598]
#define sipNameNr_Embu 64603
#define sipName_Embu &sipStrings_QtCore[64603]
#define sipNameNr_Bena 64608
#define sipName_Bena &sipStrings_QtCore[64608]
#define sipNameNr_Sena 64613
#define sipName_Sena &sipStrings_QtCore[64613]
#define sipNameNr_Tyap 64618
#define sipName_Tyap &sipStrings_QtCore[64618]
#define sipNameNr_Koro 64623
#define sipName_Koro &sipStrings_QtCore[64623]
#define sipNameNr_Geez 64628
#define sipName_Geez &sipStrings_QtCore[64628]
#define sipNameNr_Blin 64633
#define sipName_Blin &sipStrings_QtCore[64633]
#define sipNameNr_Igbo 64638
#define sipName_Igbo &sipStrings_QtCore[64638]
#define sipNameNr_Akan 64643
#define sipName_Akan &sipStrings_QtCore[64643]
#define sipNameNr_Manx 64648
#define sipName_Manx &sipStrings_QtCore[64648]
#define sipNameNr_Zulu 64653
#define sipName_Zulu &sipStrings_QtCore[64653]
#define sipNameNr_Urdu 64658
#define sipName_Urdu &sipStrings_QtCore[64658]
#define sipNameNr_Thai 41599
#define sipName_Thai &sipStrings_QtCore[41599]
#define sipNameNr_Afar 64663
#define sipName_Afar &sipStrings_QtCore[64663]
#define sipNameNr_Afan 64668
#define sipName_Afan &sipStrings_QtCore[64668]
#define sipNameNr_line 5572
#define sipName_line &sipStrings_QtCore[5572]
#define sipNameNr_load 51420
#define sipName_load &sipStrings_QtCore[51420]
#define sipNameNr_Bool 54071
#define sipName_Bool &sipStrings_QtCore[54071]
#define sipNameNr_move 35830
#define sipName_move &sipStrings_QtCore[35830]
#define sipNameNr_Rows 29897
#define sipName_Rows &sipStrings_QtCore[29897]
#define sipNameNr_skip 64673
#define sipName_skip &sipStrings_QtCore[64673]
#define sipNameNr_peek 64678
#define sipName_peek &sipStrings_QtCore[64678]
#define sipNameNr_read 18239
#define sipName_read &sipStrings_QtCore[18239]
#define sipNameNr_Text 17054
#define sipName_Text &sipStrings_QtCore[17054]
#define sipNameNr_file 64683
#define sipName_file &sipStrings_QtCore[64683]
#define sipNameNr_copy 64688
#define sipName_copy &sipStrings_QtCore[64688]
#define sipNameNr_link 64693
#define sipName_link &sipStrings_QtCore[64693]
#define sipNameNr_temp 64698
#define sipName_temp &sipStrings_QtCore[64698]
#define sipNameNr_root 64703
#define sipName_root &sipStrings_QtCore[64703]
#define sipNameNr_home 64708
#define sipName_home &sipStrings_QtCore[64708]
#define sipNameNr_cdUp 64713
#define sipName_cdUp &sipStrings_QtCore[64713]
#define sipNameNr_path 62279
#define sipName_path &sipStrings_QtCore[62279]
#define sipNameNr_Size 20880
#define sipName_Size &sipStrings_QtCore[20880]
#define sipNameNr_Time 8723
#define sipName_Time &sipStrings_QtCore[8723]
#define sipNameNr_Name 12354
#define sipName_Name &sipStrings_QtCore[12354]
#define sipNameNr_Dirs 59926
#define sipName_Dirs &sipStrings_QtCore[59926]
#define sipNameNr_QDir 64718
#define sipName_QDir &sipStrings_QtCore[64718]
#define sipNameNr_Last 38812
#define sipName_Last &sipStrings_QtCore[38812]
#define sipNameNr_time 64723
#define sipName_time &sipStrings_QtCore[64723]
#define sipNameNr_hour 64728
#define sipName_hour &sipStrings_QtCore[64728]
#define sipNameNr_spec 64733
#define sipName_spec &sipStrings_QtCore[64733]
#define sipNameNr_hash 64738
#define sipName_hash &sipStrings_QtCore[64738]
#define sipNameNr_Sha1 64743
#define sipName_Sha1 &sipStrings_QtCore[64743]
#define sipNameNr_User 53741
#define sipName_User &sipStrings_QtCore[53741]
#define sipNameNr_Drop 22687
#define sipName_Drop &sipStrings_QtCore[22687]
#define sipNameNr_Hide 5707
#define sipName_Hide &sipStrings_QtCore[5707]
#define sipNameNr_Show 64748
#define sipName_Show &sipStrings_QtCore[64748]
#define sipNameNr_Move 10387
#define sipName_Move &sipStrings_QtCore[10387]
#define sipNameNr_quit 64753
#define sipName_quit &sipStrings_QtCore[64753]
#define sipNameNr_exit 64758
#define sipName_exit &sipStrings_QtCore[64758]
#define sipNameNr_exec 64763
#define sipName_exec &sipStrings_QtCore[64763]
#define sipNameNr_mode 64768
#define sipName_mode &sipStrings_QtCore[64768]
#define sipNameNr_Flag 1245
#define sipName_Flag &sipStrings_QtCore[1245]
#define sipNameNr_next 64773
#define sipName_next &sipStrings_QtCore[64773]
#define sipNameNr_Type 1068
#define sipName_Type &sipStrings_QtCore[1068]
#define sipNameNr_Uuid 48417
#define sipName_Uuid &sipStrings_QtCore[48417]
#define sipNameNr_code 13461
#define sipName_code &sipStrings_QtCore[13461]
#define sipNameNr_Code 1032
#define sipName_Code &sipStrings_QtCore[1032]
#define sipNameNr_Null 13503
#define sipName_Null &sipStrings_QtCore[13503]
#define sipNameNr_date 12838
#define sipName_date &sipStrings_QtCore[12838]
#define sipNameNr_name 31494
#define sipName_name &sipStrings_QtCore[31494]
#define sipNameNr_year 64778
#define sipName_year &sipStrings_QtCore[64778]
#define sipNameNr_base 35718
#define sipName_base &sipStrings_QtCore[35718]
#define sipNameNr_chop 64783
#define sipName_chop &sipStrings_QtCore[64783]
#define sipNameNr_left 23875
#define sipName_left &sipStrings_QtCore[23875]
#define sipNameNr_seek 64788
#define sipName_seek &sipStrings_QtCore[64788]
#define sipNameNr_open 64793
#define sipName_open &sipStrings_QtCore[64793]
#define sipNameNr_bits 64798
#define sipName_bits &sipStrings_QtCore[64798]
#define sipNameNr_fill 64803
#define sipName_fill &sipStrings_QtCore[64803]
#define sipNameNr_size 16534
#define sipName_size &sipStrings_QtCore[16534]
#define sipNameNr_msec 64808
#define sipName_msec &sipStrings_QtCore[64808]
#define sipNameNr_type 64813
#define sipName_type &sipStrings_QtCore[64813]
#define sipNameNr_from 64818
#define sipName_from &sipStrings_QtCore[64818]
#define sipNameNr_hint 64823
#define sipName_hint &sipStrings_QtCore[64823]
#define sipNameNr_last 64828
#define sipName_last &sipStrings_QtCore[64828]
#define sipNameNr_span 64833
#define sipName_span &sipStrings_QtCore[64833]
#define sipNameNr_hits 64838
#define sipName_hits &sipStrings_QtCore[64838]
#define sipNameNr_sort 64843
#define sipName_sort &sipStrings_QtCore[64843]
#define sipNameNr_swap 64848
#define sipName_swap &sipStrings_QtCore[64848]
#define sipNameNr_data 64853
#define sipName_data &sipStrings_QtCore[64853]
#define sipNameNr_role 64858
#define sipName_role &sipStrings_QtCore[64858]
#define sipNameNr_stop 64863
#define sipName_stop &sipStrings_QtCore[64863]
#define sipNameNr_Ceil 64868
#define sipName_Ceil &sipStrings_QtCore[64868]
#define sipNameNr_Edge 51057
#define sipName_Edge &sipStrings_QtCore[51057]
#define sipNameNr_Axis 57702
#define sipName_Axis &sipStrings_QtCore[57702]
#define sipNameNr_Tool 64873
#define sipName_Tool &sipStrings_QtCore[64873]
#define sipNameNr_CTRL 64878
#define sipName_CTRL &sipStrings_QtCore[64878]
#define sipNameNr_META 64883
#define sipName_META &sipStrings_QtCore[64883]
#define sipNameNr_cyan 64888
#define sipName_cyan &sipStrings_QtCore[64888]
#define sipNameNr_blue 64893
#define sipName_blue &sipStrings_QtCore[64893]
#define sipNameNr_gray 64898
#define sipName_gray &sipStrings_QtCore[64898]
#define sipNameNr_seed 64903
#define sipName_seed &sipStrings_QtCore[64903]
#define sipNameNr_qAbs 64908
#define sipName_qAbs &sipStrings_QtCore[64908]
#define sipNameNr_DTD 55318
#define sipName_DTD &sipStrings_QtCore[55318]
#define sipNameNr_Pen 64117
#define sipName_Pen &sipStrings_QtCore[64117]
#define sipNameNr_DCE 64913
#define sipName_DCE &sipStrings_QtCore[64913]
#define sipNameNr_NCS 64917
#define sipName_NCS &sipStrings_QtCore[64917]
#define sipNameNr_utc 64921
#define sipName_utc &sipStrings_QtCore[64921]
#define sipNameNr_bom 64925
#define sipName_bom &sipStrings_QtCore[64925]
#define sipNameNr_dec 44747
#define sipName_dec &sipStrings_QtCore[44747]
#define sipNameNr_run 64929
#define sipName_run &sipStrings_QtCore[64929]
#define sipNameNr_cap 64933
#define sipName_cap &sipStrings_QtCore[64933]
#define sipNameNr_nth 19646
#define sipName_nth &sipStrings_QtCore[19646]
#define sipNameNr_max 64937
#define sipName_max &sipStrings_QtCore[64937]
#define sipNameNr_min 64941
#define sipName_min &sipStrings_QtCore[64941]
#define sipNameNr_IOS 64945
#define sipName_IOS &sipStrings_QtCore[64945]
#define sipNameNr_add 64949
#define sipName_add &sipStrings_QtCore[64949]
#define sipNameNr_url 22940
#define sipName_url &sipStrings_QtCore[22940]
#define sipNameNr_Int 52422
#define sipName_Int &sipStrings_QtCore[52422]
#define sipNameNr_pid 64953
#define sipName_pid &sipStrings_QtCore[64953]
#define sipNameNr_Ido 64957
#define sipName_Ido &sipStrings_QtCore[64957]
#define sipNameNr_Mru 64961
#define sipName_Mru &sipStrings_QtCore[64961]
#define sipNameNr_Nko 64965
#define sipName_Nko &sipStrings_QtCore[64965]
#define sipNameNr_Lao 64969
#define sipName_Lao &sipStrings_QtCore[64969]
#define sipNameNr_Vai 64973
#define sipName_Vai &sipStrings_QtCore[64973]
#define sipNameNr_Luo 64977
#define sipName_Luo &sipStrings_QtCore[64977]
#define sipNameNr_Rwa 64981
#define sipName_Rwa &sipStrings_QtCore[64981]
#define sipNameNr_Asu 64985
#define sipName_Asu &sipStrings_QtCore[64985]
#define sipNameNr_Ewe 64989
#define sipName_Ewe &sipStrings_QtCore[64989]
#define sipNameNr_Jju 64993
#define sipName_Jju &sipStrings_QtCore[64993]
#define sipNameNr_Twi 64997
#define sipName_Twi &sipStrings_QtCore[64997]
#define sipNameNr_top 3781
#define sipName_top &sipStrings_QtCore[3781]
#define sipNameNr_map 58719
#define sipName_map &sipStrings_QtCore[58719]
#define sipNameNr_dir 63835
#define sipName_dir &sipStrings_QtCore[63835]
#define sipNameNr_Md5 65001
#define sipName_Md5 &sipStrings_QtCore[65001]
#define sipNameNr_Md4 65005
#define sipName_Md4 &sipStrings_QtCore[65005]
#define sipNameNr_key 38967
#define sipName_key &sipStrings_QtCore[38967]
#define sipNameNr_Tag 63925
#define sipName_Tag &sipStrings_QtCore[63925]
#define sipNameNr_Map 25912
#define sipName_Map &sipStrings_QtCore[25912]
#define sipNameNr_tag 65009
#define sipName_tag &sipStrings_QtCore[65009]
#define sipNameNr_Url 32350
#define sipName_Url &sipStrings_QtCore[32350]
#define sipNameNr_day 54782
#define sipName_day &sipStrings_QtCore[54782]
#define sipNameNr_mid 65013
#define sipName_mid &sipStrings_QtCore[65013]
#define sipNameNr_pos 65017
#define sipName_pos &sipStrings_QtCore[65017]
#define sipNameNr_row 51245
#define sipName_row &sipStrings_QtCore[51245]
#define sipNameNr_UTC 38435
#define sipName_UTC &sipStrings_QtCore[38435]
#define sipNameNr_Key 26167
#define sipName_Key &sipStrings_QtCore[26167]
#define sipNameNr_ALT 65021
#define sipName_ALT &sipStrings_QtCore[65021]
#define sipNameNr_red 11497
#define sipName_red &sipStrings_QtCore[11497]
#define sipNameNr_ws 23733
#define sipName_ws &sipStrings_QtCore[23733]
#define sipNameNr_tr 58226
#define sipName_tr &sipStrings_QtCore[58226]
#define sipNameNr_Ho 65025
#define sipName_Ho &sipStrings_QtCore[65025]
#define sipNameNr_Lu 65028
#define sipName_Lu &sipStrings_QtCore[65028]
#define sipNameNr_Ga 65031
#define sipName_Ga &sipStrings_QtCore[65031]
#define sipNameNr_dy 58408
#define sipName_dy &sipStrings_QtCore[58408]
#define sipNameNr_dx 65034
#define sipName_dx &sipStrings_QtCore[65034]
#define sipNameNr_y2 65037
#define sipName_y2 &sipStrings_QtCore[65037]
#define sipNameNr_x2 65040
#define sipName_x2 &sipStrings_QtCore[65040]
#define sipNameNr_y1 65043
#define sipName_y1 &sipStrings_QtCore[65043]
#define sipNameNr_x1 65046
#define sipName_x1 &sipStrings_QtCore[65046]
#define sipNameNr_cd 65049
#define sipName_cd &sipStrings_QtCore[65049]
#define sipNameNr_Ok 65052
#define sipName_Ok &sipStrings_QtCore[65052]
#define sipNameNr_cs 19172
#define sipName_cs &sipStrings_QtCore[19172]
#define sipNameNr_ok 14408
#define sipName_ok &sipStrings_QtCore[14408]
#define sipNameNr_at 2873
#define sipName_at &sipStrings_QtCore[2873]
#define sipNameNr_on 667
#define sipName_on &sipStrings_QtCore[667]
#define sipNameNr_id 29851
#define sipName_id &sipStrings_QtCore[29851]
#define sipNameNr_Qt 6466
#define sipName_Qt &sipStrings_QtCore[6466]
#define sipNameNr_p2 58488
#define sipName_p2 &sipStrings_QtCore[58488]
#define sipNameNr_p1 65055
#define sipName_p1 &sipStrings_QtCore[65055]
#define sipNameNr_x 7780
#define sipName_x &sipStrings_QtCore[7780]
#define sipNameNr_C 35352
#define sipName_C &sipStrings_QtCore[35352]
#define sipNameNr_y 474
#define sipName_y &sipStrings_QtCore[474]
#define sipNameNr_n 668
#define sipName_n &sipStrings_QtCore[668]
#define sipNameNr_c 10114
#define sipName_c &sipStrings_QtCore[10114]

#define sipMalloc                   sipAPI_QtCore->api_malloc
#define sipFree                     sipAPI_QtCore->api_free
#define sipBuildResult              sipAPI_QtCore->api_build_result
#define sipCallMethod               sipAPI_QtCore->api_call_method
#define sipCallProcedureMethod      sipAPI_QtCore->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtCore->api_call_error_handler
#define sipParseResultEx            sipAPI_QtCore->api_parse_result_ex
#define sipParseResult              sipAPI_QtCore->api_parse_result
#define sipParseArgs                sipAPI_QtCore->api_parse_args
#define sipParseKwdArgs             sipAPI_QtCore->api_parse_kwd_args
#define sipParsePair                sipAPI_QtCore->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtCore->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtCore->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtCore->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtCore->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtCore->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtCore->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtCore->api_add_exception
#define sipNoFunction               sipAPI_QtCore->api_no_function
#define sipNoMethod                 sipAPI_QtCore->api_no_method
#define sipAbstractMethod           sipAPI_QtCore->api_abstract_method
#define sipBadClass                 sipAPI_QtCore->api_bad_class
#define sipBadCatcherResult         sipAPI_QtCore->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtCore->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtCore->api_bad_operator_arg
#define sipTrace                    sipAPI_QtCore->api_trace
#define sipTransferBack             sipAPI_QtCore->api_transfer_back
#define sipTransferTo               sipAPI_QtCore->api_transfer_to
#define sipTransferBreak            sipAPI_QtCore->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtCore->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtCore->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtCore->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtCore->api_voidptr_type
#define sipGetPyObject              sipAPI_QtCore->api_get_pyobject
#define sipGetAddress               sipAPI_QtCore->api_get_address
#define sipGetMixinAddress          sipAPI_QtCore->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtCore->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtCore->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtCore->api_is_py_method
#define sipCallHook                 sipAPI_QtCore->api_call_hook
#define sipEndThread                sipAPI_QtCore->api_end_thread
#define sipConnectRx                sipAPI_QtCore->api_connect_rx
#define sipDisconnectRx             sipAPI_QtCore->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtCore->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtCore->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtCore->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtCore->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtCore->api_free_sipslot
#define sipSameSlot                 sipAPI_QtCore->api_same_slot
#define sipPySlotExtend             sipAPI_QtCore->api_pyslot_extend
#define sipConvertRx                sipAPI_QtCore->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtCore->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtCore->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtCore->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtCore->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtCore->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtCore->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtCore->api_convert_to_bool
#define sipReleaseType              sipAPI_QtCore->api_release_type
#define sipConvertFromType          sipAPI_QtCore->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtCore->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtCore->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtCore->api_convert_from_enum
#define sipGetState                 sipAPI_QtCore->api_get_state
#define sipExportSymbol             sipAPI_QtCore->api_export_symbol
#define sipImportSymbol             sipAPI_QtCore->api_import_symbol
#define sipFindType                 sipAPI_QtCore->api_find_type
#define sipFindNamedEnum            sipAPI_QtCore->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtCore->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtCore->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtCore->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtCore->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtCore->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtCore->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtCore->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtCore->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtCore->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtCore->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtCore->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtCore->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtCore->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtCore->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtCore->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtCore->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtCore->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtCore->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtCore->api_deprecated
#define sipGetReference             sipAPI_QtCore->api_get_reference
#define sipKeepReference            sipAPI_QtCore->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtCore->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtCore->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtCore->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtCore->api_type_scope
#define sipResolveTypedef           sipAPI_QtCore->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtCore->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtCore->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtCore->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtCore->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtCore->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtCore->api_init_mixin
#define sipExportModule             sipAPI_QtCore->api_export_module
#define sipInitModule               sipAPI_QtCore->api_init_module
#define sipGetInterpreter           sipAPI_QtCore->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtCore->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtCore->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtCore->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtCore->api_py_type_dict
#define sipPyTypeName               sipAPI_QtCore->api_py_type_name
#define sipGetCFunction             sipAPI_QtCore->api_get_c_function
#define sipGetMethod                sipAPI_QtCore->api_get_method
#define sipFromMethod               sipAPI_QtCore->api_from_method
#define sipGetDate                  sipAPI_QtCore->api_get_date
#define sipFromDate                 sipAPI_QtCore->api_from_date
#define sipGetDateTime              sipAPI_QtCore->api_get_datetime
#define sipFromDateTime             sipAPI_QtCore->api_from_datetime
#define sipGetTime                  sipAPI_QtCore->api_get_time
#define sipFromTime                 sipAPI_QtCore->api_from_time
#define sipIsUserType               sipAPI_QtCore->api_is_user_type
#define sipGetFrame                 sipAPI_QtCore->api_get_frame
#define sipCheckPluginForType       sipAPI_QtCore->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtCore->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtCore->api_unicode_write
#define sipUnicodeData              sipAPI_QtCore->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtCore->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtCore->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtCore->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtCore->api_is_derived_class
#define sipGetUserObject            sipAPI_QtCore->api_get_user_object
#define sipSetUserObject            sipAPI_QtCore->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtCore->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtCore->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtCore->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtCore->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtCore->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtCore->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtCore->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtCore->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtCore->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtCore->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtCore->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtCore->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtCore->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtCore->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtCore->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtCore->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtCore->api_map_int_to_class
#define sipFindClass                sipAPI_QtCore->api_find_class
#define sipFindMappedType           sipAPI_QtCore->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtCore->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtCore->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtCore->api_enable_gc
#define sipPrintObject              sipAPI_QtCore->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtCore->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtCore[];

#define sipType_Qt sipExportedTypes_QtCore[350]
#define sipClass_Qt sipExportedTypes_QtCore[350]->u.td_wrapper_type

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipExportedTypes_QtCore[392]
#define sipEnum_Qt_HighDpiScaleFactorRoundingPolicy sipExportedTypes_QtCore[392]->u.td_py_type

#define sipType_Qt_ChecksumType sipExportedTypes_QtCore[364]
#define sipEnum_Qt_ChecksumType sipExportedTypes_QtCore[364]->u.td_py_type

#define sipType_Qt_EnterKeyType sipExportedTypes_QtCore[380]
#define sipEnum_Qt_EnterKeyType sipExportedTypes_QtCore[380]->u.td_py_type

#define sipType_Qt_ItemSelectionOperation sipExportedTypes_QtCore[404]
#define sipEnum_Qt_ItemSelectionOperation sipExportedTypes_QtCore[404]->u.td_py_type

#define sipType_Qt_TabFocusBehavior sipExportedTypes_QtCore[433]
#define sipEnum_Qt_TabFocusBehavior sipExportedTypes_QtCore[433]->u.td_py_type

#define sipType_Qt_MouseEventFlag sipExportedTypes_QtCore[415]
#define sipEnum_Qt_MouseEventFlag sipExportedTypes_QtCore[415]->u.td_py_type

#define sipType_Qt_MouseEventSource sipExportedTypes_QtCore[417]
#define sipEnum_Qt_MouseEventSource sipExportedTypes_QtCore[417]->u.td_py_type

#define sipType_Qt_ScrollPhase sipExportedTypes_QtCore[428]
#define sipEnum_Qt_ScrollPhase sipExportedTypes_QtCore[428]->u.td_py_type

#define sipType_Qt_NativeGestureType sipExportedTypes_QtCore[418]
#define sipEnum_Qt_NativeGestureType sipExportedTypes_QtCore[418]->u.td_py_type

#define sipType_Qt_Edge sipExportedTypes_QtCore[378]
#define sipEnum_Qt_Edge sipExportedTypes_QtCore[378]->u.td_py_type

#define sipType_Qt_ApplicationState sipExportedTypes_QtCore[355]
#define sipEnum_Qt_ApplicationState sipExportedTypes_QtCore[355]->u.td_py_type

#define sipType_Qt_HitTestAccuracy sipExportedTypes_QtCore[393]
#define sipEnum_Qt_HitTestAccuracy sipExportedTypes_QtCore[393]->u.td_py_type

#define sipType_Qt_WhiteSpaceMode sipExportedTypes_QtCore[449]
#define sipEnum_Qt_WhiteSpaceMode sipExportedTypes_QtCore[449]->u.td_py_type

#define sipType_Qt_FindChildOption sipExportedTypes_QtCore[383]
#define sipEnum_Qt_FindChildOption sipExportedTypes_QtCore[383]->u.td_py_type

#define sipType_Qt_ScreenOrientation sipExportedTypes_QtCore[425]
#define sipEnum_Qt_ScreenOrientation sipExportedTypes_QtCore[425]->u.td_py_type

#define sipType_Qt_CursorMoveStyle sipExportedTypes_QtCore[370]
#define sipEnum_Qt_CursorMoveStyle sipExportedTypes_QtCore[370]->u.td_py_type

#define sipType_Qt_NavigationMode sipExportedTypes_QtCore[419]
#define sipEnum_Qt_NavigationMode sipExportedTypes_QtCore[419]->u.td_py_type

#define sipType_Qt_GestureFlag sipExportedTypes_QtCore[387]
#define sipEnum_Qt_GestureFlag sipExportedTypes_QtCore[387]->u.td_py_type

#define sipType_Qt_GestureType sipExportedTypes_QtCore[390]
#define sipEnum_Qt_GestureType sipExportedTypes_QtCore[390]->u.td_py_type

#define sipType_Qt_GestureState sipExportedTypes_QtCore[389]
#define sipEnum_Qt_GestureState sipExportedTypes_QtCore[389]->u.td_py_type

#define sipType_Qt_TouchPointState sipExportedTypes_QtCore[445]
#define sipEnum_Qt_TouchPointState sipExportedTypes_QtCore[445]->u.td_py_type

#define sipType_Qt_CoordinateSystem sipExportedTypes_QtCore[368]
#define sipEnum_Qt_CoordinateSystem sipExportedTypes_QtCore[368]->u.td_py_type

#define sipType_Qt_AnchorPoint sipExportedTypes_QtCore[353]
#define sipEnum_Qt_AnchorPoint sipExportedTypes_QtCore[353]->u.td_py_type

#define sipType_Qt_InputMethodHint sipExportedTypes_QtCore[396]
#define sipEnum_Qt_InputMethodHint sipExportedTypes_QtCore[396]->u.td_py_type

#define sipType_Qt_TileRule sipExportedTypes_QtCore[439]
#define sipEnum_Qt_TileRule sipExportedTypes_QtCore[439]->u.td_py_type

#define sipType_Qt_WindowFrameSection sipExportedTypes_QtCore[452]
#define sipEnum_Qt_WindowFrameSection sipExportedTypes_QtCore[452]->u.td_py_type

#define sipType_Qt_SizeHint sipExportedTypes_QtCore[430]
#define sipEnum_Qt_SizeHint sipExportedTypes_QtCore[430]->u.td_py_type

#define sipType_Qt_SizeMode sipExportedTypes_QtCore[431]
#define sipEnum_Qt_SizeMode sipExportedTypes_QtCore[431]->u.td_py_type

#define sipType_Qt_EventPriority sipExportedTypes_QtCore[381]
#define sipEnum_Qt_EventPriority sipExportedTypes_QtCore[381]->u.td_py_type

#define sipType_Qt_Axis sipExportedTypes_QtCore[359]
#define sipEnum_Qt_Axis sipExportedTypes_QtCore[359]->u.td_py_type

#define sipType_Qt_MaskMode sipExportedTypes_QtCore[409]
#define sipEnum_Qt_MaskMode sipExportedTypes_QtCore[409]->u.td_py_type

#define sipType_Qt_TextInteractionFlag sipExportedTypes_QtCore[437]
#define sipEnum_Qt_TextInteractionFlag sipExportedTypes_QtCore[437]->u.td_py_type

#define sipType_Qt_ItemSelectionMode sipExportedTypes_QtCore[403]
#define sipEnum_Qt_ItemSelectionMode sipExportedTypes_QtCore[403]->u.td_py_type

#define sipType_Qt_ApplicationAttribute sipExportedTypes_QtCore[354]
#define sipEnum_Qt_ApplicationAttribute sipExportedTypes_QtCore[354]->u.td_py_type

#define sipType_Qt_WindowModality sipExportedTypes_QtCore[453]
#define sipEnum_Qt_WindowModality sipExportedTypes_QtCore[453]->u.td_py_type

#define sipType_Qt_MatchFlag sipExportedTypes_QtCore[410]
#define sipEnum_Qt_MatchFlag sipExportedTypes_QtCore[410]->u.td_py_type

#define sipType_Qt_ItemFlag sipExportedTypes_QtCore[401]
#define sipEnum_Qt_ItemFlag sipExportedTypes_QtCore[401]->u.td_py_type

#define sipType_Qt_ItemDataRole sipExportedTypes_QtCore[400]
#define sipEnum_Qt_ItemDataRole sipExportedTypes_QtCore[400]->u.td_py_type

#define sipType_Qt_CheckState sipExportedTypes_QtCore[363]
#define sipEnum_Qt_CheckState sipExportedTypes_QtCore[363]->u.td_py_type

#define sipType_Qt_DropAction sipExportedTypes_QtCore[376]
#define sipEnum_Qt_DropAction sipExportedTypes_QtCore[376]->u.td_py_type

#define sipType_Qt_LayoutDirection sipExportedTypes_QtCore[408]
#define sipEnum_Qt_LayoutDirection sipExportedTypes_QtCore[408]->u.td_py_type

#define sipType_Qt_ToolButtonStyle sipExportedTypes_QtCore[444]
#define sipEnum_Qt_ToolButtonStyle sipExportedTypes_QtCore[444]->u.td_py_type

#define sipType_Qt_InputMethodQuery sipExportedTypes_QtCore[399]
#define sipEnum_Qt_InputMethodQuery sipExportedTypes_QtCore[399]->u.td_py_type

#define sipType_Qt_ContextMenuPolicy sipExportedTypes_QtCore[367]
#define sipEnum_Qt_ContextMenuPolicy sipExportedTypes_QtCore[367]->u.td_py_type

#define sipType_Qt_FocusReason sipExportedTypes_QtCore[386]
#define sipEnum_Qt_FocusReason sipExportedTypes_QtCore[386]->u.td_py_type

#define sipType_Qt_TransformationMode sipExportedTypes_QtCore[447]
#define sipEnum_Qt_TransformationMode sipExportedTypes_QtCore[447]->u.td_py_type

#define sipType_Qt_ClipOperation sipExportedTypes_QtCore[365]
#define sipEnum_Qt_ClipOperation sipExportedTypes_QtCore[365]->u.td_py_type

#define sipType_Qt_FillRule sipExportedTypes_QtCore[382]
#define sipEnum_Qt_FillRule sipExportedTypes_QtCore[382]->u.td_py_type

#define sipType_Qt_ShortcutContext sipExportedTypes_QtCore[429]
#define sipEnum_Qt_ShortcutContext sipExportedTypes_QtCore[429]->u.td_py_type

#define sipType_Qt_ConnectionType sipExportedTypes_QtCore[366]
#define sipEnum_Qt_ConnectionType sipExportedTypes_QtCore[366]->u.td_py_type

#define sipType_Qt_Corner sipExportedTypes_QtCore[369]
#define sipEnum_Qt_Corner sipExportedTypes_QtCore[369]->u.td_py_type

#define sipType_Qt_CaseSensitivity sipExportedTypes_QtCore[362]
#define sipEnum_Qt_CaseSensitivity sipExportedTypes_QtCore[362]->u.td_py_type

#define sipType_Qt_ScrollBarPolicy sipExportedTypes_QtCore[427]
#define sipEnum_Qt_ScrollBarPolicy sipExportedTypes_QtCore[427]->u.td_py_type

#define sipType_Qt_DayOfWeek sipExportedTypes_QtCore[373]
#define sipEnum_Qt_DayOfWeek sipExportedTypes_QtCore[373]->u.td_py_type

#define sipType_Qt_TimeSpec sipExportedTypes_QtCore[440]
#define sipEnum_Qt_TimeSpec sipExportedTypes_QtCore[440]->u.td_py_type

#define sipType_Qt_DateFormat sipExportedTypes_QtCore[372]
#define sipEnum_Qt_DateFormat sipExportedTypes_QtCore[372]->u.td_py_type

#define sipType_Qt_ToolBarArea sipExportedTypes_QtCore[442]
#define sipEnum_Qt_ToolBarArea sipExportedTypes_QtCore[442]->u.td_py_type

#define sipType_Qt_TimerType sipExportedTypes_QtCore[441]
#define sipEnum_Qt_TimerType sipExportedTypes_QtCore[441]->u.td_py_type

#define sipType_Qt_DockWidgetArea sipExportedTypes_QtCore[374]
#define sipEnum_Qt_DockWidgetArea sipExportedTypes_QtCore[374]->u.td_py_type

#define sipType_Qt_AspectRatioMode sipExportedTypes_QtCore[358]
#define sipEnum_Qt_AspectRatioMode sipExportedTypes_QtCore[358]->u.td_py_type

#define sipType_Qt_TextFormat sipExportedTypes_QtCore[436]
#define sipEnum_Qt_TextFormat sipExportedTypes_QtCore[436]->u.td_py_type

#define sipType_Qt_CursorShape sipExportedTypes_QtCore[371]
#define sipEnum_Qt_CursorShape sipExportedTypes_QtCore[371]->u.td_py_type

#define sipType_Qt_UIEffect sipExportedTypes_QtCore[448]
#define sipEnum_Qt_UIEffect sipExportedTypes_QtCore[448]->u.td_py_type

#define sipType_Qt_BrushStyle sipExportedTypes_QtCore[361]
#define sipEnum_Qt_BrushStyle sipExportedTypes_QtCore[361]->u.td_py_type

#define sipType_Qt_PenJoinStyle sipExportedTypes_QtCore[423]
#define sipEnum_Qt_PenJoinStyle sipExportedTypes_QtCore[423]->u.td_py_type

#define sipType_Qt_PenCapStyle sipExportedTypes_QtCore[422]
#define sipEnum_Qt_PenCapStyle sipExportedTypes_QtCore[422]->u.td_py_type

#define sipType_Qt_PenStyle sipExportedTypes_QtCore[424]
#define sipEnum_Qt_PenStyle sipExportedTypes_QtCore[424]->u.td_py_type

#define sipType_Qt_ArrowType sipExportedTypes_QtCore[357]
#define sipEnum_Qt_ArrowType sipExportedTypes_QtCore[357]->u.td_py_type

#define sipType_Qt_Key sipExportedTypes_QtCore[405]
#define sipEnum_Qt_Key sipExportedTypes_QtCore[405]->u.td_py_type

#define sipType_Qt_BGMode sipExportedTypes_QtCore[360]
#define sipEnum_Qt_BGMode sipExportedTypes_QtCore[360]->u.td_py_type

#define sipType_Qt_ImageConversionFlag sipExportedTypes_QtCore[394]
#define sipEnum_Qt_ImageConversionFlag sipExportedTypes_QtCore[394]->u.td_py_type

#define sipType_Qt_WidgetAttribute sipExportedTypes_QtCore[450]
#define sipEnum_Qt_WidgetAttribute sipExportedTypes_QtCore[450]->u.td_py_type

#define sipType_Qt_WindowState sipExportedTypes_QtCore[454]
#define sipEnum_Qt_WindowState sipExportedTypes_QtCore[454]->u.td_py_type

#define sipType_Qt_WindowType sipExportedTypes_QtCore[456]
#define sipEnum_Qt_WindowType sipExportedTypes_QtCore[456]->u.td_py_type

#define sipType_Qt_TextElideMode sipExportedTypes_QtCore[434]
#define sipEnum_Qt_TextElideMode sipExportedTypes_QtCore[434]->u.td_py_type

#define sipType_Qt_TextFlag sipExportedTypes_QtCore[435]
#define sipEnum_Qt_TextFlag sipExportedTypes_QtCore[435]->u.td_py_type

#define sipType_Qt_AlignmentFlag sipExportedTypes_QtCore[352]
#define sipEnum_Qt_AlignmentFlag sipExportedTypes_QtCore[352]->u.td_py_type

#define sipType_Qt_SortOrder sipExportedTypes_QtCore[432]
#define sipEnum_Qt_SortOrder sipExportedTypes_QtCore[432]->u.td_py_type

#define sipType_Qt_FocusPolicy sipExportedTypes_QtCore[385]
#define sipEnum_Qt_FocusPolicy sipExportedTypes_QtCore[385]->u.td_py_type

#define sipType_Qt_Orientation sipExportedTypes_QtCore[420]
#define sipEnum_Qt_Orientation sipExportedTypes_QtCore[420]->u.td_py_type

#define sipType_Qt_MouseButton sipExportedTypes_QtCore[413]
#define sipEnum_Qt_MouseButton sipExportedTypes_QtCore[413]->u.td_py_type

#define sipType_Qt_Modifier sipExportedTypes_QtCore[412]
#define sipEnum_Qt_Modifier sipExportedTypes_QtCore[412]->u.td_py_type

#define sipType_Qt_KeyboardModifier sipExportedTypes_QtCore[406]
#define sipEnum_Qt_KeyboardModifier sipExportedTypes_QtCore[406]->u.td_py_type

#define sipType_Qt_GlobalColor sipExportedTypes_QtCore[391]
#define sipEnum_Qt_GlobalColor sipExportedTypes_QtCore[391]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt;

#define sipType_Qt_KeyboardModifiers sipExportedTypes_QtCore[407]
#define sipClass_Qt_KeyboardModifiers sipExportedTypes_QtCore[407]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_KeyboardModifiers;

#define sipType_Qt_MouseButtons sipExportedTypes_QtCore[414]
#define sipClass_Qt_MouseButtons sipExportedTypes_QtCore[414]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MouseButtons;

#define sipType_Qt_Orientations sipExportedTypes_QtCore[421]
#define sipClass_Qt_Orientations sipExportedTypes_QtCore[421]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Orientations;

#define sipType_Qt_Alignment sipExportedTypes_QtCore[351]
#define sipClass_Qt_Alignment sipExportedTypes_QtCore[351]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Alignment;

#define sipType_Qt_WindowFlags sipExportedTypes_QtCore[451]
#define sipClass_Qt_WindowFlags sipExportedTypes_QtCore[451]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_WindowFlags;

#define sipType_Qt_WindowStates sipExportedTypes_QtCore[455]
#define sipClass_Qt_WindowStates sipExportedTypes_QtCore[455]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_WindowStates;

#define sipType_Qt_ImageConversionFlags sipExportedTypes_QtCore[395]
#define sipClass_Qt_ImageConversionFlags sipExportedTypes_QtCore[395]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ImageConversionFlags;

#define sipType_Qt_DockWidgetAreas sipExportedTypes_QtCore[375]
#define sipClass_Qt_DockWidgetAreas sipExportedTypes_QtCore[375]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_DockWidgetAreas;

#define sipType_Qt_ToolBarAreas sipExportedTypes_QtCore[443]
#define sipClass_Qt_ToolBarAreas sipExportedTypes_QtCore[443]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ToolBarAreas;

#define sipType_Qt_InputMethodQueries sipExportedTypes_QtCore[398]
#define sipClass_Qt_InputMethodQueries sipExportedTypes_QtCore[398]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_InputMethodQueries;

#define sipType_Qt_DropActions sipExportedTypes_QtCore[377]
#define sipClass_Qt_DropActions sipExportedTypes_QtCore[377]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_DropActions;

#define sipType_Qt_ItemFlags sipExportedTypes_QtCore[402]
#define sipClass_Qt_ItemFlags sipExportedTypes_QtCore[402]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ItemFlags;

#define sipType_Qt_MatchFlags sipExportedTypes_QtCore[411]
#define sipClass_Qt_MatchFlags sipExportedTypes_QtCore[411]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MatchFlags;

#define sipType_Qt_TextInteractionFlags sipExportedTypes_QtCore[438]
#define sipClass_Qt_TextInteractionFlags sipExportedTypes_QtCore[438]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_TextInteractionFlags;

#define sipType_Qt_InputMethodHints sipExportedTypes_QtCore[397]
#define sipClass_Qt_InputMethodHints sipExportedTypes_QtCore[397]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_InputMethodHints;

#define sipType_Qt_TouchPointStates sipExportedTypes_QtCore[446]
#define sipClass_Qt_TouchPointStates sipExportedTypes_QtCore[446]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_TouchPointStates;

#define sipType_Qt_GestureFlags sipExportedTypes_QtCore[388]
#define sipClass_Qt_GestureFlags sipExportedTypes_QtCore[388]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_GestureFlags;

#define sipType_Qt_ScreenOrientations sipExportedTypes_QtCore[426]
#define sipClass_Qt_ScreenOrientations sipExportedTypes_QtCore[426]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ScreenOrientations;

#define sipType_Qt_FindChildOptions sipExportedTypes_QtCore[384]
#define sipClass_Qt_FindChildOptions sipExportedTypes_QtCore[384]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_FindChildOptions;

#define sipType_Qt_ApplicationStates sipExportedTypes_QtCore[356]
#define sipClass_Qt_ApplicationStates sipExportedTypes_QtCore[356]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_ApplicationStates;

#define sipType_Qt_Edges sipExportedTypes_QtCore[379]
#define sipClass_Qt_Edges sipExportedTypes_QtCore[379]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_Edges;

#define sipType_Qt_MouseEventFlags sipExportedTypes_QtCore[416]
#define sipClass_Qt_MouseEventFlags sipExportedTypes_QtCore[416]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_Qt_MouseEventFlags;

#define sipType_QObject sipExportedTypes_QtCore[191]
#define sipClass_QObject sipExportedTypes_QtCore[191]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QObject;

#define sipType_QAbstractAnimation sipExportedTypes_QtCore[0]
#define sipClass_QAbstractAnimation sipExportedTypes_QtCore[0]->u.td_wrapper_type

#define sipType_QAbstractAnimation_DeletionPolicy sipExportedTypes_QtCore[1]
#define sipEnum_QAbstractAnimation_DeletionPolicy sipExportedTypes_QtCore[1]->u.td_py_type

#define sipType_QAbstractAnimation_State sipExportedTypes_QtCore[3]
#define sipEnum_QAbstractAnimation_State sipExportedTypes_QtCore[3]->u.td_py_type

#define sipType_QAbstractAnimation_Direction sipExportedTypes_QtCore[2]
#define sipEnum_QAbstractAnimation_Direction sipExportedTypes_QtCore[2]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractAnimation;

#define sipType_QAbstractEventDispatcher sipExportedTypes_QtCore[4]
#define sipClass_QAbstractEventDispatcher sipExportedTypes_QtCore[4]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher;

#define sipType_QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[5]
#define sipClass_QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[5]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractEventDispatcher_TimerInfo;

#define sipType_QModelIndex sipExportedTypes_QtCore[187]
#define sipClass_QModelIndex sipExportedTypes_QtCore[187]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QModelIndex;

#define sipType_QPersistentModelIndex sipExportedTypes_QtCore[198]
#define sipClass_QPersistentModelIndex sipExportedTypes_QtCore[198]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPersistentModelIndex;

#define sipType_QAbstractItemModel sipExportedTypes_QtCore[6]
#define sipClass_QAbstractItemModel sipExportedTypes_QtCore[6]->u.td_wrapper_type

#define sipType_QAbstractItemModel_CheckIndexOption sipExportedTypes_QtCore[7]
#define sipEnum_QAbstractItemModel_CheckIndexOption sipExportedTypes_QtCore[7]->u.td_py_type

#define sipType_QAbstractItemModel_LayoutChangeHint sipExportedTypes_QtCore[9]
#define sipEnum_QAbstractItemModel_LayoutChangeHint sipExportedTypes_QtCore[9]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractItemModel;

#define sipType_QAbstractItemModel_CheckIndexOptions sipExportedTypes_QtCore[8]
#define sipClass_QAbstractItemModel_CheckIndexOptions sipExportedTypes_QtCore[8]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractItemModel_CheckIndexOptions;

#define sipType_QAbstractTableModel sipExportedTypes_QtCore[14]
#define sipClass_QAbstractTableModel sipExportedTypes_QtCore[14]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractTableModel;

#define sipType_QAbstractListModel sipExportedTypes_QtCore[10]
#define sipClass_QAbstractListModel sipExportedTypes_QtCore[10]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractListModel;

#define sipType_QAbstractNativeEventFilter sipExportedTypes_QtCore[11]
#define sipClass_QAbstractNativeEventFilter sipExportedTypes_QtCore[11]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractNativeEventFilter;

#define sipType_QAbstractProxyModel sipExportedTypes_QtCore[12]
#define sipClass_QAbstractProxyModel sipExportedTypes_QtCore[12]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractProxyModel;

#define sipType_QAbstractState sipExportedTypes_QtCore[13]
#define sipClass_QAbstractState sipExportedTypes_QtCore[13]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractState;

#define sipType_QAbstractTransition sipExportedTypes_QtCore[15]
#define sipClass_QAbstractTransition sipExportedTypes_QtCore[15]->u.td_wrapper_type

#define sipType_QAbstractTransition_TransitionType sipExportedTypes_QtCore[16]
#define sipEnum_QAbstractTransition_TransitionType sipExportedTypes_QtCore[16]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QAbstractTransition;

#define sipType_QAnimationGroup sipExportedTypes_QtCore[17]
#define sipClass_QAnimationGroup sipExportedTypes_QtCore[17]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QAnimationGroup;

#define sipType_QBasicTimer sipExportedTypes_QtCore[18]
#define sipClass_QBasicTimer sipExportedTypes_QtCore[18]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QBasicTimer;

#define sipType_QBitArray sipExportedTypes_QtCore[19]
#define sipClass_QBitArray sipExportedTypes_QtCore[19]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QBitArray;

#define sipType_QIODevice sipExportedTypes_QtCore[102]
#define sipClass_QIODevice sipExportedTypes_QtCore[102]->u.td_wrapper_type

#define sipType_QIODevice_OpenModeFlag sipExportedTypes_QtCore[104]
#define sipEnum_QIODevice_OpenModeFlag sipExportedTypes_QtCore[104]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QIODevice;

#define sipType_QBuffer sipExportedTypes_QtCore[20]
#define sipClass_QBuffer sipExportedTypes_QtCore[20]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QBuffer;

#define sipType_QByteArray sipExportedTypes_QtCore[21]
#define sipClass_QByteArray sipExportedTypes_QtCore[21]->u.td_wrapper_type

#define sipType_QByteArray_Base64DecodingStatus sipExportedTypes_QtCore[22]
#define sipEnum_QByteArray_Base64DecodingStatus sipExportedTypes_QtCore[22]->u.td_py_type

#define sipType_QByteArray_Base64Option sipExportedTypes_QtCore[23]
#define sipEnum_QByteArray_Base64Option sipExportedTypes_QtCore[23]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray;

#define sipType_QByteArray_Base64Options sipExportedTypes_QtCore[24]
#define sipClass_QByteArray_Base64Options sipExportedTypes_QtCore[24]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray_Base64Options;

#define sipType_QByteArray_FromBase64Result sipExportedTypes_QtCore[25]
#define sipClass_QByteArray_FromBase64Result sipExportedTypes_QtCore[25]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QByteArray_FromBase64Result;

#define sipType_QByteArrayMatcher sipExportedTypes_QtCore[26]
#define sipClass_QByteArrayMatcher sipExportedTypes_QtCore[26]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QByteArrayMatcher;

#define sipType_QCalendar sipExportedTypes_QtCore[27]
#define sipClass_QCalendar sipExportedTypes_QtCore[27]->u.td_wrapper_type

#define sipType_QCalendar_System sipExportedTypes_QtCore[28]
#define sipEnum_QCalendar_System sipExportedTypes_QtCore[28]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar;

#define sipType_QCalendar_YearMonthDay sipExportedTypes_QtCore[29]
#define sipClass_QCalendar_YearMonthDay sipExportedTypes_QtCore[29]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCalendar_YearMonthDay;

#define sipType_QCborError sipExportedTypes_QtCore[30]
#define sipClass_QCborError sipExportedTypes_QtCore[30]->u.td_wrapper_type

#define sipType_QCborError_Code sipExportedTypes_QtCore[31]
#define sipEnum_QCborError_Code sipExportedTypes_QtCore[31]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCborError;

#define sipType_QCborStreamWriter sipExportedTypes_QtCore[37]
#define sipClass_QCborStreamWriter sipExportedTypes_QtCore[37]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamWriter;

#define sipType_QCborStreamReader sipExportedTypes_QtCore[34]
#define sipClass_QCborStreamReader sipExportedTypes_QtCore[34]->u.td_wrapper_type

#define sipType_QCborStreamReader_StringResultCode sipExportedTypes_QtCore[35]
#define sipEnum_QCborStreamReader_StringResultCode sipExportedTypes_QtCore[35]->u.td_py_type

#define sipType_QCborStreamReader_Type sipExportedTypes_QtCore[36]
#define sipEnum_QCborStreamReader_Type sipExportedTypes_QtCore[36]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCborStreamReader;

#define sipType_QCollatorSortKey sipExportedTypes_QtCore[41]
#define sipClass_QCollatorSortKey sipExportedTypes_QtCore[41]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCollatorSortKey;

#define sipType_QCollator sipExportedTypes_QtCore[40]
#define sipClass_QCollator sipExportedTypes_QtCore[40]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCollator;

#define sipType_QCommandLineOption sipExportedTypes_QtCore[42]
#define sipClass_QCommandLineOption sipExportedTypes_QtCore[42]->u.td_wrapper_type

#define sipType_QCommandLineOption_Flag sipExportedTypes_QtCore[43]
#define sipEnum_QCommandLineOption_Flag sipExportedTypes_QtCore[43]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineOption;

#define sipType_QCommandLineOption_Flags sipExportedTypes_QtCore[44]
#define sipClass_QCommandLineOption_Flags sipExportedTypes_QtCore[44]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineOption_Flags;

#define sipType_QCommandLineParser sipExportedTypes_QtCore[45]
#define sipClass_QCommandLineParser sipExportedTypes_QtCore[45]->u.td_wrapper_type

#define sipType_QCommandLineParser_OptionsAfterPositionalArgumentsMode sipExportedTypes_QtCore[46]
#define sipEnum_QCommandLineParser_OptionsAfterPositionalArgumentsMode sipExportedTypes_QtCore[46]->u.td_py_type

#define sipType_QCommandLineParser_SingleDashWordOptionMode sipExportedTypes_QtCore[47]
#define sipEnum_QCommandLineParser_SingleDashWordOptionMode sipExportedTypes_QtCore[47]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCommandLineParser;

#define sipType_QConcatenateTablesProxyModel sipExportedTypes_QtCore[48]
#define sipClass_QConcatenateTablesProxyModel sipExportedTypes_QtCore[48]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QConcatenateTablesProxyModel;

#define sipType_QCoreApplication sipExportedTypes_QtCore[49]
#define sipClass_QCoreApplication sipExportedTypes_QtCore[49]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QCoreApplication;

#define sipType_QEvent sipExportedTypes_QtCore[76]
#define sipClass_QEvent sipExportedTypes_QtCore[76]->u.td_wrapper_type

#define sipType_QEvent_Type sipExportedTypes_QtCore[77]
#define sipEnum_QEvent_Type sipExportedTypes_QtCore[77]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QEvent;

#define sipType_QTimerEvent sipExportedTypes_QtCore[307]
#define sipClass_QTimerEvent sipExportedTypes_QtCore[307]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTimerEvent;

#define sipType_QChildEvent sipExportedTypes_QtCore[39]
#define sipClass_QChildEvent sipExportedTypes_QtCore[39]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QChildEvent;

#define sipType_QDynamicPropertyChangeEvent sipExportedTypes_QtCore[71]
#define sipClass_QDynamicPropertyChangeEvent sipExportedTypes_QtCore[71]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QDynamicPropertyChangeEvent;

#define sipType_QCryptographicHash sipExportedTypes_QtCore[50]
#define sipClass_QCryptographicHash sipExportedTypes_QtCore[50]->u.td_wrapper_type

#define sipType_QCryptographicHash_Algorithm sipExportedTypes_QtCore[51]
#define sipEnum_QCryptographicHash_Algorithm sipExportedTypes_QtCore[51]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QCryptographicHash;

#define sipType_QDataStream sipExportedTypes_QtCore[52]
#define sipClass_QDataStream sipExportedTypes_QtCore[52]->u.td_wrapper_type

#define sipType_QDataStream_FloatingPointPrecision sipExportedTypes_QtCore[54]
#define sipEnum_QDataStream_FloatingPointPrecision sipExportedTypes_QtCore[54]->u.td_py_type

#define sipType_QDataStream_Status sipExportedTypes_QtCore[55]
#define sipEnum_QDataStream_Status sipExportedTypes_QtCore[55]->u.td_py_type

#define sipType_QDataStream_ByteOrder sipExportedTypes_QtCore[53]
#define sipEnum_QDataStream_ByteOrder sipExportedTypes_QtCore[53]->u.td_py_type

#define sipType_QDataStream_Version sipExportedTypes_QtCore[56]
#define sipEnum_QDataStream_Version sipExportedTypes_QtCore[56]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDataStream;

#define sipType_QDate sipExportedTypes_QtCore[57]
#define sipClass_QDate sipExportedTypes_QtCore[57]->u.td_wrapper_type

#define sipType_QDate_MonthNameType sipExportedTypes_QtCore[58]
#define sipEnum_QDate_MonthNameType sipExportedTypes_QtCore[58]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDate;

#define sipType_QTime sipExportedTypes_QtCore[297]
#define sipClass_QTime sipExportedTypes_QtCore[297]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTime;

#define sipType_QDateTime sipExportedTypes_QtCore[59]
#define sipClass_QDateTime sipExportedTypes_QtCore[59]->u.td_wrapper_type

#define sipType_QDateTime_YearRange sipExportedTypes_QtCore[60]
#define sipEnum_QDateTime_YearRange sipExportedTypes_QtCore[60]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDateTime;

#define sipType_QDeadlineTimer sipExportedTypes_QtCore[61]
#define sipClass_QDeadlineTimer sipExportedTypes_QtCore[61]->u.td_wrapper_type

#define sipType_QDeadlineTimer_ForeverConstant sipExportedTypes_QtCore[62]
#define sipEnum_QDeadlineTimer_ForeverConstant sipExportedTypes_QtCore[62]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDeadlineTimer;

#define sipType_QDir sipExportedTypes_QtCore[63]
#define sipClass_QDir sipExportedTypes_QtCore[63]->u.td_wrapper_type

#define sipType_QDir_SortFlag sipExportedTypes_QtCore[66]
#define sipEnum_QDir_SortFlag sipExportedTypes_QtCore[66]->u.td_py_type

#define sipType_QDir_Filter sipExportedTypes_QtCore[64]
#define sipEnum_QDir_Filter sipExportedTypes_QtCore[64]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDir;

#define sipType_QDir_Filters sipExportedTypes_QtCore[65]
#define sipClass_QDir_Filters sipExportedTypes_QtCore[65]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QDir_Filters;

#define sipType_QDir_SortFlags sipExportedTypes_QtCore[67]
#define sipClass_QDir_SortFlags sipExportedTypes_QtCore[67]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QDir_SortFlags;

#define sipType_QDirIterator sipExportedTypes_QtCore[68]
#define sipClass_QDirIterator sipExportedTypes_QtCore[68]->u.td_wrapper_type

#define sipType_QDirIterator_IteratorFlag sipExportedTypes_QtCore[69]
#define sipEnum_QDirIterator_IteratorFlag sipExportedTypes_QtCore[69]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QDirIterator;

#define sipType_QDirIterator_IteratorFlags sipExportedTypes_QtCore[70]
#define sipClass_QDirIterator_IteratorFlags sipExportedTypes_QtCore[70]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QDirIterator_IteratorFlags;

#define sipType_QEasingCurve sipExportedTypes_QtCore[72]
#define sipClass_QEasingCurve sipExportedTypes_QtCore[72]->u.td_wrapper_type

#define sipType_QEasingCurve_Type sipExportedTypes_QtCore[73]
#define sipEnum_QEasingCurve_Type sipExportedTypes_QtCore[73]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QEasingCurve;

#define sipType_QElapsedTimer sipExportedTypes_QtCore[74]
#define sipClass_QElapsedTimer sipExportedTypes_QtCore[74]->u.td_wrapper_type

#define sipType_QElapsedTimer_ClockType sipExportedTypes_QtCore[75]
#define sipEnum_QElapsedTimer_ClockType sipExportedTypes_QtCore[75]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QElapsedTimer;

#define sipType_QEventLoop sipExportedTypes_QtCore[78]
#define sipClass_QEventLoop sipExportedTypes_QtCore[78]->u.td_wrapper_type

#define sipType_QEventLoop_ProcessEventsFlag sipExportedTypes_QtCore[79]
#define sipEnum_QEventLoop_ProcessEventsFlag sipExportedTypes_QtCore[79]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoop;

#define sipType_QEventLoop_ProcessEventsFlags sipExportedTypes_QtCore[80]
#define sipClass_QEventLoop_ProcessEventsFlags sipExportedTypes_QtCore[80]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoop_ProcessEventsFlags;

#define sipType_QEventLoopLocker sipExportedTypes_QtCore[81]
#define sipClass_QEventLoopLocker sipExportedTypes_QtCore[81]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QEventLoopLocker;

#define sipType_QEventTransition sipExportedTypes_QtCore[82]
#define sipClass_QEventTransition sipExportedTypes_QtCore[82]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QEventTransition;

#define sipType_QFileDevice sipExportedTypes_QtCore[84]
#define sipClass_QFileDevice sipExportedTypes_QtCore[84]->u.td_wrapper_type

#define sipType_QFileDevice_FileTime sipExportedTypes_QtCore[88]
#define sipEnum_QFileDevice_FileTime sipExportedTypes_QtCore[88]->u.td_py_type

#define sipType_QFileDevice_MemoryMapFlags sipExportedTypes_QtCore[89]
#define sipEnum_QFileDevice_MemoryMapFlags sipExportedTypes_QtCore[89]->u.td_py_type

#define sipType_QFileDevice_FileHandleFlag sipExportedTypes_QtCore[86]
#define sipEnum_QFileDevice_FileHandleFlag sipExportedTypes_QtCore[86]->u.td_py_type

#define sipType_QFileDevice_Permission sipExportedTypes_QtCore[90]
#define sipEnum_QFileDevice_Permission sipExportedTypes_QtCore[90]->u.td_py_type

#define sipType_QFileDevice_FileError sipExportedTypes_QtCore[85]
#define sipEnum_QFileDevice_FileError sipExportedTypes_QtCore[85]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice;

#define sipType_QFile sipExportedTypes_QtCore[83]
#define sipClass_QFile sipExportedTypes_QtCore[83]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFile;

#define sipType_QFileDevice_Permissions sipExportedTypes_QtCore[91]
#define sipClass_QFileDevice_Permissions sipExportedTypes_QtCore[91]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice_Permissions;

#define sipType_QFileDevice_FileHandleFlags sipExportedTypes_QtCore[87]
#define sipClass_QFileDevice_FileHandleFlags sipExportedTypes_QtCore[87]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileDevice_FileHandleFlags;

#define sipType_QFileInfo sipExportedTypes_QtCore[92]
#define sipClass_QFileInfo sipExportedTypes_QtCore[92]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileInfo;

#define sipType_QFileSelector sipExportedTypes_QtCore[93]
#define sipClass_QFileSelector sipExportedTypes_QtCore[93]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileSelector;

#define sipType_QFileSystemWatcher sipExportedTypes_QtCore[94]
#define sipClass_QFileSystemWatcher sipExportedTypes_QtCore[94]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFileSystemWatcher;

#define sipType_QFinalState sipExportedTypes_QtCore[95]
#define sipClass_QFinalState sipExportedTypes_QtCore[95]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QFinalState;

#define sipType_QHistoryState sipExportedTypes_QtCore[100]
#define sipClass_QHistoryState sipExportedTypes_QtCore[100]->u.td_wrapper_type

#define sipType_QHistoryState_HistoryType sipExportedTypes_QtCore[101]
#define sipEnum_QHistoryState_HistoryType sipExportedTypes_QtCore[101]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QHistoryState;

#define sipType_QIdentityProxyModel sipExportedTypes_QtCore[105]
#define sipClass_QIdentityProxyModel sipExportedTypes_QtCore[105]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QIdentityProxyModel;

#define sipType_QIODevice_OpenMode sipExportedTypes_QtCore[103]
#define sipClass_QIODevice_OpenMode sipExportedTypes_QtCore[103]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QIODevice_OpenMode;

#define sipType_QItemSelectionRange sipExportedTypes_QtCore[110]
#define sipClass_QItemSelectionRange sipExportedTypes_QtCore[110]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionRange;

#define sipType_QItemSelectionModel sipExportedTypes_QtCore[107]
#define sipClass_QItemSelectionModel sipExportedTypes_QtCore[107]->u.td_wrapper_type

#define sipType_QItemSelectionModel_SelectionFlag sipExportedTypes_QtCore[108]
#define sipEnum_QItemSelectionModel_SelectionFlag sipExportedTypes_QtCore[108]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionModel;

#define sipType_QItemSelectionModel_SelectionFlags sipExportedTypes_QtCore[109]
#define sipClass_QItemSelectionModel_SelectionFlags sipExportedTypes_QtCore[109]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelectionModel_SelectionFlags;

#define sipType_QItemSelection sipExportedTypes_QtCore[106]
#define sipClass_QItemSelection sipExportedTypes_QtCore[106]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QItemSelection;

#define sipType_QJsonParseError sipExportedTypes_QtCore[116]
#define sipClass_QJsonParseError sipExportedTypes_QtCore[116]->u.td_wrapper_type

#define sipType_QJsonParseError_ParseError sipExportedTypes_QtCore[117]
#define sipEnum_QJsonParseError_ParseError sipExportedTypes_QtCore[117]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QJsonParseError;

#define sipType_QJsonDocument sipExportedTypes_QtCore[112]
#define sipClass_QJsonDocument sipExportedTypes_QtCore[112]->u.td_wrapper_type

#define sipType_QJsonDocument_JsonFormat sipExportedTypes_QtCore[114]
#define sipEnum_QJsonDocument_JsonFormat sipExportedTypes_QtCore[114]->u.td_py_type

#define sipType_QJsonDocument_DataValidation sipExportedTypes_QtCore[113]
#define sipEnum_QJsonDocument_DataValidation sipExportedTypes_QtCore[113]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QJsonDocument;

#define sipType_QJsonValue sipExportedTypes_QtCore[118]
#define sipClass_QJsonValue sipExportedTypes_QtCore[118]->u.td_wrapper_type

#define sipType_QJsonValue_Type sipExportedTypes_QtCore[119]
#define sipEnum_QJsonValue_Type sipExportedTypes_QtCore[119]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QJsonValue;

#define sipType_QLibrary sipExportedTypes_QtCore[120]
#define sipClass_QLibrary sipExportedTypes_QtCore[120]->u.td_wrapper_type

#define sipType_QLibrary_LoadHint sipExportedTypes_QtCore[121]
#define sipEnum_QLibrary_LoadHint sipExportedTypes_QtCore[121]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QLibrary;

#define sipType_QLibrary_LoadHints sipExportedTypes_QtCore[122]
#define sipClass_QLibrary_LoadHints sipExportedTypes_QtCore[122]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QLibrary_LoadHints;

#define sipType_QLibraryInfo sipExportedTypes_QtCore[123]
#define sipClass_QLibraryInfo sipExportedTypes_QtCore[123]->u.td_wrapper_type

#define sipType_QLibraryInfo_LibraryLocation sipExportedTypes_QtCore[124]
#define sipEnum_QLibraryInfo_LibraryLocation sipExportedTypes_QtCore[124]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QLibraryInfo;

#define sipType_QLine sipExportedTypes_QtCore[125]
#define sipClass_QLine sipExportedTypes_QtCore[125]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QLine;

#define sipType_QLineF sipExportedTypes_QtCore[126]
#define sipClass_QLineF sipExportedTypes_QtCore[126]->u.td_wrapper_type

#define sipType_QLineF_IntersectType sipExportedTypes_QtCore[127]
#define sipEnum_QLineF_IntersectType sipExportedTypes_QtCore[127]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QLineF;

#define sipType_QLocale sipExportedTypes_QtCore[149]
#define sipClass_QLocale sipExportedTypes_QtCore[149]->u.td_wrapper_type

#define sipType_QLocale_DataSizeFormat sipExportedTypes_QtCore[152]
#define sipEnum_QLocale_DataSizeFormat sipExportedTypes_QtCore[152]->u.td_py_type

#define sipType_QLocale_FloatingPointPrecisionOption sipExportedTypes_QtCore[154]
#define sipEnum_QLocale_FloatingPointPrecisionOption sipExportedTypes_QtCore[154]->u.td_py_type

#define sipType_QLocale_QuotationStyle sipExportedTypes_QtCore[160]
#define sipEnum_QLocale_QuotationStyle sipExportedTypes_QtCore[160]->u.td_py_type

#define sipType_QLocale_CurrencySymbolFormat sipExportedTypes_QtCore[151]
#define sipEnum_QLocale_CurrencySymbolFormat sipExportedTypes_QtCore[151]->u.td_py_type

#define sipType_QLocale_Script sipExportedTypes_QtCore[161]
#define sipEnum_QLocale_Script sipExportedTypes_QtCore[161]->u.td_py_type

#define sipType_QLocale_MeasurementSystem sipExportedTypes_QtCore[157]
#define sipEnum_QLocale_MeasurementSystem sipExportedTypes_QtCore[157]->u.td_py_type

#define sipType_QLocale_FormatType sipExportedTypes_QtCore[155]
#define sipEnum_QLocale_FormatType sipExportedTypes_QtCore[155]->u.td_py_type

#define sipType_QLocale_NumberOption sipExportedTypes_QtCore[158]
#define sipEnum_QLocale_NumberOption sipExportedTypes_QtCore[158]->u.td_py_type

#define sipType_QLocale_Country sipExportedTypes_QtCore[150]
#define sipEnum_QLocale_Country sipExportedTypes_QtCore[150]->u.td_py_type

#define sipType_QLocale_Language sipExportedTypes_QtCore[156]
#define sipEnum_QLocale_Language sipExportedTypes_QtCore[156]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QLocale;

#define sipType_QLocale_NumberOptions sipExportedTypes_QtCore[159]
#define sipClass_QLocale_NumberOptions sipExportedTypes_QtCore[159]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QLocale_NumberOptions;

#define sipType_QLocale_DataSizeFormats sipExportedTypes_QtCore[153]
#define sipClass_QLocale_DataSizeFormats sipExportedTypes_QtCore[153]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QLocale_DataSizeFormats;

#define sipType_QLockFile sipExportedTypes_QtCore[162]
#define sipClass_QLockFile sipExportedTypes_QtCore[162]->u.td_wrapper_type

#define sipType_QLockFile_LockError sipExportedTypes_QtCore[163]
#define sipEnum_QLockFile_LockError sipExportedTypes_QtCore[163]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QLockFile;

#define sipType_QMessageLogContext sipExportedTypes_QtCore[169]
#define sipClass_QMessageLogContext sipExportedTypes_QtCore[169]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogContext;

#define sipType_QMessageLogger sipExportedTypes_QtCore[170]
#define sipClass_QMessageLogger sipExportedTypes_QtCore[170]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMessageLogger;

#define sipType_QLoggingCategory sipExportedTypes_QtCore[164]
#define sipClass_QLoggingCategory sipExportedTypes_QtCore[164]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QLoggingCategory;

#define sipType_QMargins sipExportedTypes_QtCore[166]
#define sipClass_QMargins sipExportedTypes_QtCore[166]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMargins;

#define sipType_QMarginsF sipExportedTypes_QtCore[167]
#define sipClass_QMarginsF sipExportedTypes_QtCore[167]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMarginsF;

#define sipType_QMessageAuthenticationCode sipExportedTypes_QtCore[168]
#define sipClass_QMessageAuthenticationCode sipExportedTypes_QtCore[168]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMessageAuthenticationCode;

#define sipType_QMetaMethod sipExportedTypes_QtCore[173]
#define sipClass_QMetaMethod sipExportedTypes_QtCore[173]->u.td_wrapper_type

#define sipType_QMetaMethod_MethodType sipExportedTypes_QtCore[175]
#define sipEnum_QMetaMethod_MethodType sipExportedTypes_QtCore[175]->u.td_py_type

#define sipType_QMetaMethod_Access sipExportedTypes_QtCore[174]
#define sipEnum_QMetaMethod_Access sipExportedTypes_QtCore[174]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaMethod;

#define sipType_QMetaEnum sipExportedTypes_QtCore[172]
#define sipClass_QMetaEnum sipExportedTypes_QtCore[172]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaEnum;

#define sipType_QMetaProperty sipExportedTypes_QtCore[178]
#define sipClass_QMetaProperty sipExportedTypes_QtCore[178]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaProperty;

#define sipType_QMetaClassInfo sipExportedTypes_QtCore[171]
#define sipClass_QMetaClassInfo sipExportedTypes_QtCore[171]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaClassInfo;

#define sipType_QMetaType sipExportedTypes_QtCore[179]
#define sipClass_QMetaType sipExportedTypes_QtCore[179]->u.td_wrapper_type

#define sipType_QMetaType_TypeFlag sipExportedTypes_QtCore[181]
#define sipEnum_QMetaType_TypeFlag sipExportedTypes_QtCore[181]->u.td_py_type

#define sipType_QMetaType_Type sipExportedTypes_QtCore[180]
#define sipEnum_QMetaType_Type sipExportedTypes_QtCore[180]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaType;

#define sipType_QMetaType_TypeFlags sipExportedTypes_QtCore[182]
#define sipClass_QMetaType_TypeFlags sipExportedTypes_QtCore[182]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaType_TypeFlags;

#define sipType_QMimeData sipExportedTypes_QtCore[183]
#define sipClass_QMimeData sipExportedTypes_QtCore[183]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMimeData;

#define sipType_QMimeDatabase sipExportedTypes_QtCore[184]
#define sipClass_QMimeDatabase sipExportedTypes_QtCore[184]->u.td_wrapper_type

#define sipType_QMimeDatabase_MatchMode sipExportedTypes_QtCore[185]
#define sipEnum_QMimeDatabase_MatchMode sipExportedTypes_QtCore[185]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QMimeDatabase;

#define sipType_QMimeType sipExportedTypes_QtCore[186]
#define sipClass_QMimeType sipExportedTypes_QtCore[186]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMimeType;

#define sipType_QMutexLocker sipExportedTypes_QtCore[190]
#define sipClass_QMutexLocker sipExportedTypes_QtCore[190]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMutexLocker;

#define sipType_QMutex sipExportedTypes_QtCore[188]
#define sipClass_QMutex sipExportedTypes_QtCore[188]->u.td_wrapper_type

#define sipType_QMutex_RecursionMode sipExportedTypes_QtCore[189]
#define sipEnum_QMutex_RecursionMode sipExportedTypes_QtCore[189]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QMutex;

#define sipType_QRecursiveMutex sipExportedTypes_QtCore[217]
#define sipClass_QRecursiveMutex sipExportedTypes_QtCore[217]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRecursiveMutex;

#define sipType_QSignalBlocker sipExportedTypes_QtCore[244]
#define sipClass_QSignalBlocker sipExportedTypes_QtCore[244]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSignalBlocker;

#define sipType_QObjectCleanupHandler sipExportedTypes_QtCore[192]
#define sipClass_QObjectCleanupHandler sipExportedTypes_QtCore[192]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QObjectCleanupHandler;

#define sipType_QMetaObject sipExportedTypes_QtCore[176]
#define sipClass_QMetaObject sipExportedTypes_QtCore[176]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject;

#define sipType_QMetaObject_Connection sipExportedTypes_QtCore[177]
#define sipClass_QMetaObject_Connection sipExportedTypes_QtCore[177]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QMetaObject_Connection;

#define sipType_QGenericArgument sipExportedTypes_QtCore[96]
#define sipClass_QGenericArgument sipExportedTypes_QtCore[96]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QGenericArgument;

#define sipType_QGenericReturnArgument sipExportedTypes_QtCore[97]
#define sipClass_QGenericReturnArgument sipExportedTypes_QtCore[97]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QGenericReturnArgument;

#define sipType_QOperatingSystemVersion sipExportedTypes_QtCore[193]
#define sipClass_QOperatingSystemVersion sipExportedTypes_QtCore[193]->u.td_wrapper_type

#define sipType_QOperatingSystemVersion_OSType sipExportedTypes_QtCore[194]
#define sipEnum_QOperatingSystemVersion_OSType sipExportedTypes_QtCore[194]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QOperatingSystemVersion;

#define sipType_QParallelAnimationGroup sipExportedTypes_QtCore[196]
#define sipClass_QParallelAnimationGroup sipExportedTypes_QtCore[196]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QParallelAnimationGroup;

#define sipType_QPauseAnimation sipExportedTypes_QtCore[197]
#define sipClass_QPauseAnimation sipExportedTypes_QtCore[197]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPauseAnimation;

#define sipType_QVariantAnimation sipExportedTypes_QtCore[325]
#define sipClass_QVariantAnimation sipExportedTypes_QtCore[325]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QVariantAnimation;

#define sipType_QPropertyAnimation sipExportedTypes_QtCore[210]
#define sipClass_QPropertyAnimation sipExportedTypes_QtCore[210]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPropertyAnimation;

#define sipType_QPluginLoader sipExportedTypes_QtCore[199]
#define sipClass_QPluginLoader sipExportedTypes_QtCore[199]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPluginLoader;

#define sipType_QPoint sipExportedTypes_QtCore[200]
#define sipClass_QPoint sipExportedTypes_QtCore[200]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPoint;

#define sipType_QPointF sipExportedTypes_QtCore[201]
#define sipClass_QPointF sipExportedTypes_QtCore[201]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QPointF;

#define sipType_QProcess sipExportedTypes_QtCore[202]
#define sipClass_QProcess sipExportedTypes_QtCore[202]->u.td_wrapper_type

#define sipType_QProcess_InputChannelMode sipExportedTypes_QtCore[204]
#define sipEnum_QProcess_InputChannelMode sipExportedTypes_QtCore[204]->u.td_py_type

#define sipType_QProcess_ProcessChannelMode sipExportedTypes_QtCore[206]
#define sipEnum_QProcess_ProcessChannelMode sipExportedTypes_QtCore[206]->u.td_py_type

#define sipType_QProcess_ProcessChannel sipExportedTypes_QtCore[205]
#define sipEnum_QProcess_ProcessChannel sipExportedTypes_QtCore[205]->u.td_py_type

#define sipType_QProcess_ProcessState sipExportedTypes_QtCore[208]
#define sipEnum_QProcess_ProcessState sipExportedTypes_QtCore[208]->u.td_py_type

#define sipType_QProcess_ProcessError sipExportedTypes_QtCore[207]
#define sipEnum_QProcess_ProcessError sipExportedTypes_QtCore[207]->u.td_py_type

#define sipType_QProcess_ExitStatus sipExportedTypes_QtCore[203]
#define sipEnum_QProcess_ExitStatus sipExportedTypes_QtCore[203]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QProcess;

#define sipType_QProcessEnvironment sipExportedTypes_QtCore[209]
#define sipClass_QProcessEnvironment sipExportedTypes_QtCore[209]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QProcessEnvironment;

#define sipType_QRandomGenerator sipExportedTypes_QtCore[211]
#define sipClass_QRandomGenerator sipExportedTypes_QtCore[211]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRandomGenerator;

#define sipType_QReadWriteLock sipExportedTypes_QtCore[213]
#define sipClass_QReadWriteLock sipExportedTypes_QtCore[213]->u.td_wrapper_type

#define sipType_QReadWriteLock_RecursionMode sipExportedTypes_QtCore[214]
#define sipEnum_QReadWriteLock_RecursionMode sipExportedTypes_QtCore[214]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QReadWriteLock;

#define sipType_QReadLocker sipExportedTypes_QtCore[212]
#define sipClass_QReadLocker sipExportedTypes_QtCore[212]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QReadLocker;

#define sipType_QWriteLocker sipExportedTypes_QtCore[338]
#define sipClass_QWriteLocker sipExportedTypes_QtCore[338]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QWriteLocker;

#define sipType_QRect sipExportedTypes_QtCore[215]
#define sipClass_QRect sipExportedTypes_QtCore[215]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRect;

#define sipType_QRectF sipExportedTypes_QtCore[216]
#define sipClass_QRectF sipExportedTypes_QtCore[216]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRectF;

#define sipType_QRegExp sipExportedTypes_QtCore[218]
#define sipClass_QRegExp sipExportedTypes_QtCore[218]->u.td_wrapper_type

#define sipType_QRegExp_CaretMode sipExportedTypes_QtCore[219]
#define sipEnum_QRegExp_CaretMode sipExportedTypes_QtCore[219]->u.td_py_type

#define sipType_QRegExp_PatternSyntax sipExportedTypes_QtCore[220]
#define sipEnum_QRegExp_PatternSyntax sipExportedTypes_QtCore[220]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegExp;

#define sipType_QRegularExpression sipExportedTypes_QtCore[221]
#define sipClass_QRegularExpression sipExportedTypes_QtCore[221]->u.td_wrapper_type

#define sipType_QRegularExpression_MatchOption sipExportedTypes_QtCore[222]
#define sipEnum_QRegularExpression_MatchOption sipExportedTypes_QtCore[222]->u.td_py_type

#define sipType_QRegularExpression_MatchType sipExportedTypes_QtCore[224]
#define sipEnum_QRegularExpression_MatchType sipExportedTypes_QtCore[224]->u.td_py_type

#define sipType_QRegularExpression_PatternOption sipExportedTypes_QtCore[225]
#define sipEnum_QRegularExpression_PatternOption sipExportedTypes_QtCore[225]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression;

#define sipType_QRegularExpression_PatternOptions sipExportedTypes_QtCore[226]
#define sipClass_QRegularExpression_PatternOptions sipExportedTypes_QtCore[226]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression_PatternOptions;

#define sipType_QRegularExpression_MatchOptions sipExportedTypes_QtCore[223]
#define sipClass_QRegularExpression_MatchOptions sipExportedTypes_QtCore[223]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpression_MatchOptions;

#define sipType_QRegularExpressionMatch sipExportedTypes_QtCore[227]
#define sipClass_QRegularExpressionMatch sipExportedTypes_QtCore[227]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatch;

#define sipType_QRegularExpressionMatchIterator sipExportedTypes_QtCore[228]
#define sipClass_QRegularExpressionMatchIterator sipExportedTypes_QtCore[228]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRegularExpressionMatchIterator;

#define sipType_QResource sipExportedTypes_QtCore[229]
#define sipClass_QResource sipExportedTypes_QtCore[229]->u.td_wrapper_type

#define sipType_QResource_Compression sipExportedTypes_QtCore[230]
#define sipEnum_QResource_Compression sipExportedTypes_QtCore[230]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QResource;

#define sipType_QRunnable sipExportedTypes_QtCore[231]
#define sipClass_QRunnable sipExportedTypes_QtCore[231]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QRunnable;

#define sipType_QSaveFile sipExportedTypes_QtCore[232]
#define sipClass_QSaveFile sipExportedTypes_QtCore[232]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSaveFile;

#define sipType_QSemaphore sipExportedTypes_QtCore[233]
#define sipClass_QSemaphore sipExportedTypes_QtCore[233]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphore;

#define sipType_QSemaphoreReleaser sipExportedTypes_QtCore[234]
#define sipClass_QSemaphoreReleaser sipExportedTypes_QtCore[234]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSemaphoreReleaser;

#define sipType_QSequentialAnimationGroup sipExportedTypes_QtCore[235]
#define sipClass_QSequentialAnimationGroup sipExportedTypes_QtCore[235]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSequentialAnimationGroup;

#define sipType_QSettings sipExportedTypes_QtCore[237]
#define sipClass_QSettings sipExportedTypes_QtCore[237]->u.td_wrapper_type

#define sipType_QSettings_Scope sipExportedTypes_QtCore[239]
#define sipEnum_QSettings_Scope sipExportedTypes_QtCore[239]->u.td_py_type

#define sipType_QSettings_Format sipExportedTypes_QtCore[238]
#define sipEnum_QSettings_Format sipExportedTypes_QtCore[238]->u.td_py_type

#define sipType_QSettings_Status sipExportedTypes_QtCore[240]
#define sipEnum_QSettings_Status sipExportedTypes_QtCore[240]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QSettings;

#define sipType_QSharedMemory sipExportedTypes_QtCore[241]
#define sipClass_QSharedMemory sipExportedTypes_QtCore[241]->u.td_wrapper_type

#define sipType_QSharedMemory_SharedMemoryError sipExportedTypes_QtCore[243]
#define sipEnum_QSharedMemory_SharedMemoryError sipExportedTypes_QtCore[243]->u.td_py_type

#define sipType_QSharedMemory_AccessMode sipExportedTypes_QtCore[242]
#define sipEnum_QSharedMemory_AccessMode sipExportedTypes_QtCore[242]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QSharedMemory;

#define sipType_QWidget sipExportedTypes_QtCore[337]
#define sipClass_QWidget sipExportedTypes_QtCore[337]->u.td_wrapper_type

#define sipType_QSignalMapper sipExportedTypes_QtCore[245]
#define sipClass_QSignalMapper sipExportedTypes_QtCore[245]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSignalMapper;

#define sipType_QSignalTransition sipExportedTypes_QtCore[246]
#define sipClass_QSignalTransition sipExportedTypes_QtCore[246]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSignalTransition;

#define sipType_QSize sipExportedTypes_QtCore[247]
#define sipClass_QSize sipExportedTypes_QtCore[247]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSize;

#define sipType_QSizeF sipExportedTypes_QtCore[248]
#define sipClass_QSizeF sipExportedTypes_QtCore[248]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSizeF;

#define sipType_QSocketNotifier sipExportedTypes_QtCore[249]
#define sipClass_QSocketNotifier sipExportedTypes_QtCore[249]->u.td_wrapper_type

#define sipType_QSocketNotifier_Type sipExportedTypes_QtCore[250]
#define sipEnum_QSocketNotifier_Type sipExportedTypes_QtCore[250]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QSocketNotifier;

#define sipType_QSortFilterProxyModel sipExportedTypes_QtCore[251]
#define sipClass_QSortFilterProxyModel sipExportedTypes_QtCore[251]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QSortFilterProxyModel;

#define sipType_QStandardPaths sipExportedTypes_QtCore[252]
#define sipClass_QStandardPaths sipExportedTypes_QtCore[252]->u.td_wrapper_type

#define sipType_QStandardPaths_LocateOption sipExportedTypes_QtCore[253]
#define sipEnum_QStandardPaths_LocateOption sipExportedTypes_QtCore[253]->u.td_py_type

#define sipType_QStandardPaths_StandardLocation sipExportedTypes_QtCore[255]
#define sipEnum_QStandardPaths_StandardLocation sipExportedTypes_QtCore[255]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QStandardPaths;

#define sipType_QStandardPaths_LocateOptions sipExportedTypes_QtCore[254]
#define sipClass_QStandardPaths_LocateOptions sipExportedTypes_QtCore[254]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QStandardPaths_LocateOptions;

#define sipType_QState sipExportedTypes_QtCore[256]
#define sipClass_QState sipExportedTypes_QtCore[256]->u.td_wrapper_type

#define sipType_QState_RestorePolicy sipExportedTypes_QtCore[258]
#define sipEnum_QState_RestorePolicy sipExportedTypes_QtCore[258]->u.td_py_type

#define sipType_QState_ChildMode sipExportedTypes_QtCore[257]
#define sipEnum_QState_ChildMode sipExportedTypes_QtCore[257]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QState;

#define sipType_QStateMachine sipExportedTypes_QtCore[259]
#define sipClass_QStateMachine sipExportedTypes_QtCore[259]->u.td_wrapper_type

#define sipType_QStateMachine_Error sipExportedTypes_QtCore[260]
#define sipEnum_QStateMachine_Error sipExportedTypes_QtCore[260]->u.td_py_type

#define sipType_QStateMachine_EventPriority sipExportedTypes_QtCore[261]
#define sipEnum_QStateMachine_EventPriority sipExportedTypes_QtCore[261]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine;

#define sipType_QStateMachine_SignalEvent sipExportedTypes_QtCore[262]
#define sipClass_QStateMachine_SignalEvent sipExportedTypes_QtCore[262]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine_SignalEvent;

#define sipType_QStateMachine_WrappedEvent sipExportedTypes_QtCore[263]
#define sipClass_QStateMachine_WrappedEvent sipExportedTypes_QtCore[263]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QStateMachine_WrappedEvent;

#define sipType_QStorageInfo sipExportedTypes_QtCore[264]
#define sipClass_QStorageInfo sipExportedTypes_QtCore[264]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QStorageInfo;

#define sipType_QStringListModel sipExportedTypes_QtCore[267]
#define sipClass_QStringListModel sipExportedTypes_QtCore[267]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QStringListModel;

#define sipType_QSystemSemaphore sipExportedTypes_QtCore[272]
#define sipClass_QSystemSemaphore sipExportedTypes_QtCore[272]->u.td_wrapper_type

#define sipType_QSystemSemaphore_SystemSemaphoreError sipExportedTypes_QtCore[274]
#define sipEnum_QSystemSemaphore_SystemSemaphoreError sipExportedTypes_QtCore[274]->u.td_py_type

#define sipType_QSystemSemaphore_AccessMode sipExportedTypes_QtCore[273]
#define sipEnum_QSystemSemaphore_AccessMode sipExportedTypes_QtCore[273]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QSystemSemaphore;

#define sipType_QTemporaryDir sipExportedTypes_QtCore[275]
#define sipClass_QTemporaryDir sipExportedTypes_QtCore[275]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryDir;

#define sipType_QTemporaryFile sipExportedTypes_QtCore[276]
#define sipClass_QTemporaryFile sipExportedTypes_QtCore[276]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTemporaryFile;

#define sipType_QTextBoundaryFinder sipExportedTypes_QtCore[277]
#define sipClass_QTextBoundaryFinder sipExportedTypes_QtCore[277]->u.td_wrapper_type

#define sipType_QTextBoundaryFinder_BoundaryType sipExportedTypes_QtCore[280]
#define sipEnum_QTextBoundaryFinder_BoundaryType sipExportedTypes_QtCore[280]->u.td_py_type

#define sipType_QTextBoundaryFinder_BoundaryReason sipExportedTypes_QtCore[278]
#define sipEnum_QTextBoundaryFinder_BoundaryReason sipExportedTypes_QtCore[278]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextBoundaryFinder;

#define sipType_QTextBoundaryFinder_BoundaryReasons sipExportedTypes_QtCore[279]
#define sipClass_QTextBoundaryFinder_BoundaryReasons sipExportedTypes_QtCore[279]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextBoundaryFinder_BoundaryReasons;

#define sipType_QTextCodec sipExportedTypes_QtCore[281]
#define sipClass_QTextCodec sipExportedTypes_QtCore[281]->u.td_wrapper_type

#define sipType_QTextCodec_ConversionFlag sipExportedTypes_QtCore[282]
#define sipEnum_QTextCodec_ConversionFlag sipExportedTypes_QtCore[282]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec;

#define sipType_QTextCodec_ConversionFlags sipExportedTypes_QtCore[283]
#define sipClass_QTextCodec_ConversionFlags sipExportedTypes_QtCore[283]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec_ConversionFlags;

#define sipType_QTextCodec_ConverterState sipExportedTypes_QtCore[284]
#define sipClass_QTextCodec_ConverterState sipExportedTypes_QtCore[284]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextCodec_ConverterState;

#define sipType_QTextEncoder sipExportedTypes_QtCore[286]
#define sipClass_QTextEncoder sipExportedTypes_QtCore[286]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextEncoder;

#define sipType_QTextDecoder sipExportedTypes_QtCore[285]
#define sipClass_QTextDecoder sipExportedTypes_QtCore[285]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextDecoder;

#define sipType_QTextStream sipExportedTypes_QtCore[287]
#define sipClass_QTextStream sipExportedTypes_QtCore[287]->u.td_wrapper_type

#define sipType_QTextStream_Status sipExportedTypes_QtCore[292]
#define sipEnum_QTextStream_Status sipExportedTypes_QtCore[292]->u.td_py_type

#define sipType_QTextStream_NumberFlag sipExportedTypes_QtCore[289]
#define sipEnum_QTextStream_NumberFlag sipExportedTypes_QtCore[289]->u.td_py_type

#define sipType_QTextStream_FieldAlignment sipExportedTypes_QtCore[288]
#define sipEnum_QTextStream_FieldAlignment sipExportedTypes_QtCore[288]->u.td_py_type

#define sipType_QTextStream_RealNumberNotation sipExportedTypes_QtCore[291]
#define sipEnum_QTextStream_RealNumberNotation sipExportedTypes_QtCore[291]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextStream;

#define sipType_QTextStream_NumberFlags sipExportedTypes_QtCore[290]
#define sipClass_QTextStream_NumberFlags sipExportedTypes_QtCore[290]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextStream_NumberFlags;

#define sipType_QTextStreamManipulator sipExportedTypes_QtCore[293]
#define sipClass_QTextStreamManipulator sipExportedTypes_QtCore[293]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTextStreamManipulator;

#define sipType_QThread sipExportedTypes_QtCore[294]
#define sipClass_QThread sipExportedTypes_QtCore[294]->u.td_wrapper_type

#define sipType_QThread_Priority sipExportedTypes_QtCore[295]
#define sipEnum_QThread_Priority sipExportedTypes_QtCore[295]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QThread;

#define sipType_QThreadPool sipExportedTypes_QtCore[296]
#define sipClass_QThreadPool sipExportedTypes_QtCore[296]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QThreadPool;

#define sipType_QTimeLine sipExportedTypes_QtCore[298]
#define sipClass_QTimeLine sipExportedTypes_QtCore[298]->u.td_wrapper_type

#define sipType_QTimeLine_State sipExportedTypes_QtCore[301]
#define sipEnum_QTimeLine_State sipExportedTypes_QtCore[301]->u.td_py_type

#define sipType_QTimeLine_Direction sipExportedTypes_QtCore[300]
#define sipEnum_QTimeLine_Direction sipExportedTypes_QtCore[300]->u.td_py_type

#define sipType_QTimeLine_CurveShape sipExportedTypes_QtCore[299]
#define sipEnum_QTimeLine_CurveShape sipExportedTypes_QtCore[299]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QTimeLine;

#define sipType_QTimer sipExportedTypes_QtCore[306]
#define sipClass_QTimer sipExportedTypes_QtCore[306]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTimer;

#define sipType_QTimeZone sipExportedTypes_QtCore[302]
#define sipClass_QTimeZone sipExportedTypes_QtCore[302]->u.td_wrapper_type

#define sipType_QTimeZone_NameType sipExportedTypes_QtCore[303]
#define sipEnum_QTimeZone_NameType sipExportedTypes_QtCore[303]->u.td_py_type

#define sipType_QTimeZone_TimeType sipExportedTypes_QtCore[305]
#define sipEnum_QTimeZone_TimeType sipExportedTypes_QtCore[305]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone;

#define sipType_QTimeZone_OffsetData sipExportedTypes_QtCore[304]
#define sipClass_QTimeZone_OffsetData sipExportedTypes_QtCore[304]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTimeZone_OffsetData;

#define sipType_QTranslator sipExportedTypes_QtCore[308]
#define sipClass_QTranslator sipExportedTypes_QtCore[308]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTranslator;

#define sipType_QTransposeProxyModel sipExportedTypes_QtCore[309]
#define sipClass_QTransposeProxyModel sipExportedTypes_QtCore[309]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QTransposeProxyModel;

#define sipType_QUrl sipExportedTypes_QtCore[310]
#define sipClass_QUrl sipExportedTypes_QtCore[310]->u.td_wrapper_type

#define sipType_QUrl_UserInputResolutionOption sipExportedTypes_QtCore[316]
#define sipEnum_QUrl_UserInputResolutionOption sipExportedTypes_QtCore[316]->u.td_py_type

#define sipType_QUrl_ComponentFormattingOption sipExportedTypes_QtCore[311]
#define sipEnum_QUrl_ComponentFormattingOption sipExportedTypes_QtCore[311]->u.td_py_type

#define sipType_QUrl_UrlFormattingOption sipExportedTypes_QtCore[315]
#define sipEnum_QUrl_UrlFormattingOption sipExportedTypes_QtCore[315]->u.td_py_type

#define sipType_QUrl_ParsingMode sipExportedTypes_QtCore[314]
#define sipEnum_QUrl_ParsingMode sipExportedTypes_QtCore[314]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QUrl;

#define sipType_QUrl_FormattingOptions sipExportedTypes_QtCore[313]
#define sipClass_QUrl_FormattingOptions sipExportedTypes_QtCore[313]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_FormattingOptions;

#define sipType_QUrl_ComponentFormattingOptions sipExportedTypes_QtCore[312]
#define sipClass_QUrl_ComponentFormattingOptions sipExportedTypes_QtCore[312]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_ComponentFormattingOptions;

#define sipType_QUrl_UserInputResolutionOptions sipExportedTypes_QtCore[317]
#define sipClass_QUrl_UserInputResolutionOptions sipExportedTypes_QtCore[317]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QUrl_UserInputResolutionOptions;

#define sipType_QUrlQuery sipExportedTypes_QtCore[318]
#define sipClass_QUrlQuery sipExportedTypes_QtCore[318]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QUrlQuery;

#define sipType_QUuid sipExportedTypes_QtCore[319]
#define sipClass_QUuid sipExportedTypes_QtCore[319]->u.td_wrapper_type

#define sipType_QUuid_StringFormat sipExportedTypes_QtCore[320]
#define sipEnum_QUuid_StringFormat sipExportedTypes_QtCore[320]->u.td_py_type

#define sipType_QUuid_Version sipExportedTypes_QtCore[322]
#define sipEnum_QUuid_Version sipExportedTypes_QtCore[322]->u.td_py_type

#define sipType_QUuid_Variant sipExportedTypes_QtCore[321]
#define sipEnum_QUuid_Variant sipExportedTypes_QtCore[321]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QUuid;

#define sipType_QVariant sipExportedTypes_QtCore[323]
#define sipClass_QVariant sipExportedTypes_QtCore[323]->u.td_wrapper_type

#define sipType_QVariant_Type sipExportedTypes_QtCore[324]
#define sipEnum_QVariant_Type sipExportedTypes_QtCore[324]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QVariant;

#define sipType_QVersionNumber sipExportedTypes_QtCore[335]
#define sipClass_QVersionNumber sipExportedTypes_QtCore[335]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QVersionNumber;

#define sipType_QWaitCondition sipExportedTypes_QtCore[336]
#define sipClass_QWaitCondition sipExportedTypes_QtCore[336]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QWaitCondition;

#define sipType_QXmlStreamAttribute sipExportedTypes_QtCore[339]
#define sipClass_QXmlStreamAttribute sipExportedTypes_QtCore[339]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttribute;

#define sipType_QXmlStreamAttributes sipExportedTypes_QtCore[340]
#define sipClass_QXmlStreamAttributes sipExportedTypes_QtCore[340]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamAttributes;

#define sipType_QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[343]
#define sipClass_QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[343]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNamespaceDeclaration;

#define sipType_QXmlStreamNotationDeclaration sipExportedTypes_QtCore[344]
#define sipClass_QXmlStreamNotationDeclaration sipExportedTypes_QtCore[344]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNotationDeclaration;

#define sipType_QXmlStreamEntityDeclaration sipExportedTypes_QtCore[341]
#define sipClass_QXmlStreamEntityDeclaration sipExportedTypes_QtCore[341]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityDeclaration;

#define sipType_QXmlStreamEntityResolver sipExportedTypes_QtCore[342]
#define sipClass_QXmlStreamEntityResolver sipExportedTypes_QtCore[342]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamEntityResolver;

#define sipType_QXmlStreamReader sipExportedTypes_QtCore[345]
#define sipClass_QXmlStreamReader sipExportedTypes_QtCore[345]->u.td_wrapper_type

#define sipType_QXmlStreamReader_Error sipExportedTypes_QtCore[346]
#define sipEnum_QXmlStreamReader_Error sipExportedTypes_QtCore[346]->u.td_py_type

#define sipType_QXmlStreamReader_ReadElementTextBehaviour sipExportedTypes_QtCore[347]
#define sipEnum_QXmlStreamReader_ReadElementTextBehaviour sipExportedTypes_QtCore[347]->u.td_py_type

#define sipType_QXmlStreamReader_TokenType sipExportedTypes_QtCore[348]
#define sipEnum_QXmlStreamReader_TokenType sipExportedTypes_QtCore[348]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamReader;

#define sipType_QXmlStreamWriter sipExportedTypes_QtCore[349]
#define sipClass_QXmlStreamWriter sipExportedTypes_QtCore[349]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtCore_QXmlStreamWriter;

#define sipType_QSysInfo sipExportedTypes_QtCore[269]
#define sipClass_QSysInfo sipExportedTypes_QtCore[269]->u.td_wrapper_type

#define sipType_QSysInfo_Endian sipExportedTypes_QtCore[270]
#define sipEnum_QSysInfo_Endian sipExportedTypes_QtCore[270]->u.td_py_type

#define sipType_QSysInfo_Sizes sipExportedTypes_QtCore[271]
#define sipEnum_QSysInfo_Sizes sipExportedTypes_QtCore[271]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtCore_QSysInfo;

#define sipType_QList_0600QPair_0100QString_0100QString sipExportedTypes_QtCore[140]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600QPair_0100QString_0100QString;

#define sipType_QList_0100QStorageInfo sipExportedTypes_QtCore[143]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QStorageInfo;

#define sipType_QSet_0101QAbstractState sipExportedTypes_QtCore[236]

extern sipMappedTypeDef sipTypeDef_QtCore_QSet_0101QAbstractState;

#define sipType_QList_0101QAbstractTransition sipExportedTypes_QtCore[132]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractTransition;

#define sipType_QList_0100QMimeType sipExportedTypes_QtCore[137]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QMimeType;

#define sipType_QList_0100QUrl sipExportedTypes_QtCore[144]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QUrl;

#define sipType_QList_0100QLocale sipExportedTypes_QtCore[136]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QLocale;

#define sipType_QVector_0100QPointF sipExportedTypes_QtCore[328]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QPointF;

#define sipType_QList_0101QAbstractItemModel sipExportedTypes_QtCore[130]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractItemModel;

#define sipType_QList_0100QCommandLineOption sipExportedTypes_QtCore[134]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QCommandLineOption;

#define sipType_QList_0101QAbstractAnimation sipExportedTypes_QtCore[128]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractAnimation;

#define sipType_QList_0101QAbstractState sipExportedTypes_QtCore[131]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QAbstractState;

#define sipType_QHash_1800_0100QByteArray sipExportedTypes_QtCore[99]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_1800_0100QByteArray;

#define sipType_QList_0100QPersistentModelIndex sipExportedTypes_QtCore[142]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QPersistentModelIndex;

#define sipType_QMap_1800_0100QVariant sipExportedTypes_QtCore[165]

extern sipMappedTypeDef sipTypeDef_QtCore_QMap_1800_0100QVariant;

#define sipType_QList_0100QAbstractEventDispatcher_TimerInfo sipExportedTypes_QtCore[129]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QAbstractEventDispatcher_TimerInfo;

#define sipType_QList_0100QByteArray sipExportedTypes_QtCore[133]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QByteArray;

#define sipType_QVector_0100QXmlStreamNotationDeclaration sipExportedTypes_QtCore[332]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamNotationDeclaration;

#define sipType_QVector_0100QXmlStreamNamespaceDeclaration sipExportedTypes_QtCore[331]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamNamespaceDeclaration;

#define sipType_QVector_0100QXmlStreamEntityDeclaration sipExportedTypes_QtCore[330]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QXmlStreamEntityDeclaration;

#define sipType_QList_0100QVariant sipExportedTypes_QtCore[145]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QVariant;

#define sipType_QHash_0100QString_0100QVariant sipExportedTypes_QtCore[98]

extern sipMappedTypeDef sipTypeDef_QtCore_QHash_0100QString_0100QVariant;

#define sipType_QVector_0600QPair_2400_0100QVariant sipExportedTypes_QtCore[327]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0600QPair_2400_0100QVariant;

#define sipType_QVector_0100QTimeZone_OffsetData sipExportedTypes_QtCore[329]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_0100QTimeZone_OffsetData;

#define sipType_QList_0101QObject sipExportedTypes_QtCore[139]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0101QObject;

#define sipType_QList_0100QModelIndex sipExportedTypes_QtCore[138]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QModelIndex;

#define sipType_QList_0100QFileInfo sipExportedTypes_QtCore[135]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100QFileInfo;

#define sipType_QVector_1600 sipExportedTypes_QtCore[334]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_1600;

#define sipType_QVector_1800 sipExportedTypes_QtCore[333]

extern sipMappedTypeDef sipTypeDef_QtCore_QVector_1800;

#define sipType_QPair_1800_1800 sipExportedTypes_QtCore[195]

extern sipMappedTypeDef sipTypeDef_QtCore_QPair_1800_1800;

#define sipType_QVariantMap sipExportedTypes_QtCore[326]

extern sipMappedTypeDef sipTypeDef_QtCore_QVariantMap;

#define sipType_QJsonArray sipExportedTypes_QtCore[111]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonArray;

#define sipType_QStringList sipExportedTypes_QtCore[266]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringList;

#define sipType_QList_0100Qt_DayOfWeek sipExportedTypes_QtCore[146]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0100Qt_DayOfWeek;

#define sipType_QList_2400 sipExportedTypes_QtCore[148]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_2400;

#define sipType_QList_1800 sipExportedTypes_QtCore[147]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_1800;

#define sipType_QList_0600QPair_1800_1800 sipExportedTypes_QtCore[141]

extern sipMappedTypeDef sipTypeDef_QtCore_QList_0600QPair_1800_1800;

#define sipType_QJsonObject sipExportedTypes_QtCore[115]

extern sipMappedTypeDef sipTypeDef_QtCore_QJsonObject;

#define sipType_QStringRef sipExportedTypes_QtCore[268]

extern sipMappedTypeDef sipTypeDef_QtCore_QStringRef;

#define sipType_QString sipExportedTypes_QtCore[265]

extern sipMappedTypeDef sipTypeDef_QtCore_QString;

#define sipType_QChar sipExportedTypes_QtCore[38]

extern sipMappedTypeDef sipTypeDef_QtCore_QChar;

#define sipType_quintptr sipExportedTypes_QtCore[459]

extern sipMappedTypeDef sipTypeDef_QtCore_quintptr;

#define sipType_qintptr sipExportedTypes_QtCore[458]

extern sipMappedTypeDef sipTypeDef_QtCore_qintptr;

#define sipType_QtMsgType sipExportedTypes_QtCore[457]
#define sipEnum_QtMsgType sipExportedTypes_QtCore[457]->u.td_py_type

#define sipType_QCborKnownTags sipExportedTypes_QtCore[32]
#define sipEnum_QCborKnownTags sipExportedTypes_QtCore[32]->u.td_py_type

#define sipType_QCborSimpleType sipExportedTypes_QtCore[33]
#define sipEnum_QCborSimpleType sipExportedTypes_QtCore[33]->u.td_py_type

void sipVEH_QtCore_PyQt5(sipSimpleWrapper *, sip_gilstate_t);

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtCore;
extern sipExportedModuleDef sipModuleAPI_QtCore;
extern sipTypeDef *sipExportedTypes_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtCore_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtCore_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtCore_qt_metacast;
#line 742 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtCore/qobject.sip"
#include "qpycore_api.h"
#line 12734 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtCore/sipAPIQtCore.h"

#endif
