/*
 * Module code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 123 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 32 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 40 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 726 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 733 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglbuffer.sip"
#include <qopenglbuffer.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglshaderprogram.sip"
#include <qopenglshaderprogram.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengltexture.sip"
#include <qopengltexture.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qrawfont.sip"
#include <qrawfont.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtouchdevice.sip"
#include <qtouchdevice.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 103 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 118 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 137 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 140 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 143 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 146 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 149 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 152 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 155 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimageiohandler.sip"
#include <qimageiohandler.h>
#line 158 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qsurface.sip"
#include <qsurface.h>
#line 161 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 795 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 425 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 412 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 384 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 460 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 471 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 363 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 205 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 253 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 726 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 302 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 398 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 197 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 200 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 374 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 205 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 174 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 208 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qline.sip"
#include <qline.h>
#line 211 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 95 "sip/QtCore/qline.sip"
#include <qline.h>
#line 214 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 217 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 220 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 223 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 226 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 229 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 275 "sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 232 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 235 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 238 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 241 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 244 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 247 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 36 "sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 250 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 146 "sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 253 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 103 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 256 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 259 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 96 "sip/QtCore/qurl.sip"
#include <qurl.h>
#line 262 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 265 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 268 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 271 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolorspace.sip"
#include <qcolorspace.h>
#line 274 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 277 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 280 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 283 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 286 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpen.sip"
#include <qpen.h>
#line 289 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpicture.sip"
#include <qpicture.h>
#line 292 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 34 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixelformat.sip"
#include <qpixelformat.h>
#line 295 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 329 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 298 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 301 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 304 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 307 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 34 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qrgba64.sip"
#include <qrgba64.h>
#line 310 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 313 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 316 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector2d.sip"
#include <qvector2d.h>
#line 319 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 322 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector4d.sip"
#include <qvector4d.h>
#line 325 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qabstracttextdocumentlayout.sip"
#include <qabstracttextdocumentlayout.h>
#line 330 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 333 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 372 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 336 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 393 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 339 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 424 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 342 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qcolortransform.sip"
#include <qcolortransform.h>
#line 345 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qdesktopservices.sip"
#include <qdesktopservices.h>
#line 348 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 238 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 351 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 438 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 354 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 449 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 357 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 482 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 360 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 509 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 363 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 509 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 525 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 368 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 556 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 371 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 570 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 374 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 592 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 377 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 608 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 380 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 619 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 383 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 630 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 386 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 647 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 389 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 659 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 392 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 675 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 395 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 701 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 398 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 726 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 733 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 403 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 807 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 406 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 825 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 409 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 849 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 412 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 872 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 415 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 901 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 418 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 922 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 421 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontdatabase.sip"
#include <qfontdatabase.h>
#line 424 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 427 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 430 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 433 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 27 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 436 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 179 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 439 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 331 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 442 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 483 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 445 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 632 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 448 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 781 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 451 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 927 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 454 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 1073 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qgenericmatrix.sip"
#include <qgenericmatrix.h>
#line 457 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qglyphrun.sip"
#include <qglyphrun.h>
#line 460 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qglyphrun.sip"
#include <qglyphrun.h>
#line 463 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 468 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 83 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qiconengine.sip"
#include <qiconengine.h>
#line 473 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimageiohandler.sip"
#include <qimageiohandler.h>
#line 476 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimagereader.sip"
#include <qimagereader.h>
#line 479 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimagewriter.sip"
#include <qimagewriter.h>
#line 482 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qmovie.sip"
#include <qmovie.h>
#line 485 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qoffscreensurface.sip"
#include <qoffscreensurface.h>
#line 488 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglbuffer.sip"
#include <qopenglbuffer.h>
#line 491 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 46 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglcontext.sip"
#include <qopenglcontext.h>
#line 494 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglcontext.sip"
#include <qopenglcontext.h>
#line 497 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 500 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 503 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 506 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengldebug.sip"
#include <qopengldebug.h>
#line 509 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 124 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglframebufferobject.sip"
#include <qopenglframebufferobject.h>
#line 512 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglpaintdevice.sip"
#include <qopenglpaintdevice.h>
#line 515 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglpixeltransferoptions.sip"
#include <qopenglpixeltransferoptions.h>
#line 518 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglshaderprogram.sip"
#include <qopenglshaderprogram.h>
#line 521 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 73 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglshaderprogram.sip"
#include <qopenglshaderprogram.h>
#line 524 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengltexture.sip"
#include <qopengltexture.h>
#line 527 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopengltextureblitter.sip"
#include <qopengltextureblitter.h>
#line 530 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglvertexarrayobject.sip"
#include <qopenglvertexarrayobject.h>
#line 533 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 536 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpagelayout.sip"
#include <qpagelayout.h>
#line 539 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpagesize.sip"
#include <qpagesize.h>
#line 542 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 545 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 496 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 550 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 553 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 556 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 559 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 562 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 160 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 565 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpicture.sip"
#include <qpicture.h>
#line 568 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 571 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixmapcache.sip"
#include <qpixmapcache.h>
#line 576 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qrawfont.sip"
#include <qrawfont.h>
#line 579 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 582 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qstatictext.sip"
#include <qstatictext.h>
#line 585 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 588 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextcursor.sip"
#include <qtextcursor.h>
#line 591 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 594 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextdocument.sip"
#include <qtextdocument.h>
#line 597 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextdocumentfragment.sip"
#include <qtextdocumentfragment.h>
#line 600 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextdocumentwriter.sip"
#include <qtextdocumentwriter.h>
#line 603 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 606 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 318 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 609 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 433 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 612 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 500 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 615 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 532 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 618 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 555 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 621 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 618 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 624 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 650 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextformat.sip"
#include <qtextformat.h>
#line 627 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 630 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 70 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 635 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 132 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextlayout.sip"
#include <qtextlayout.h>
#line 638 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 76 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 643 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 118 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 143 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 648 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 224 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 651 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 248 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
#include <qtextobject.h>
#line 654 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 657 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 662 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtexttable.sip"
#include <qtexttable.h>
#line 665 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtouchdevice.sip"
#include <qtouchdevice.h>
#line 668 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 671 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 71 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 674 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 100 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 677 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
#line 117 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 680 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtGui[] = {
    'Q', 'P', 'a', 'i', 'r', '<', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', ',', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'I', 'n', 'h', 'e', 'r', 'i', 't', 'a', 'n', 'c', 'e', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', ':', ':', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'R', 'e', 's', 't', 'o', 'r', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '>', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'P', 'a', 'i', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'Q', 'P', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'A', 'd', 'd', 'S', 'p', 'a', 'c', 'e', 'F', 'o', 'r', 'L', 'i', 'n', 'e', 'A', 'n', 'd', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', ':', ':', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', '>', 0,
    'm', 'o', 'u', 's', 'e', 'Q', 'u', 'i', 'c', 'k', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 's', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 'D', 'p', 'i', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'R', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'R', 'e', 's', 't', 'o', 'r', 'e', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'o', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', ':', ':', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', ':', ':', 'I', 'n', 'f', 'o', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 's', 0,
    'B', 'l', 'o', 'c', 'k', 'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'R', 'u', 'l', 'e', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 'n', 'e', 'r', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 's', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'O', 'u', 't', 'e', 'r', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'S', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 'A', 'r', 'g', 'u', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', ':', ':', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', ':', ':', 'I', 'n', 'f', 'o', 'F', 'l', 'a', 'g', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'A', 'n', 'd', 'H', 'o', 'l', 'd', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'T', 'y', 'p', 'e', 'I', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'X', 'o', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'V', 'e', 'r', 't', 'e', 'x', 'A', 'r', 'r', 'a', 'y', 'O', 'b', 'j', 'e', 'c', 't', ':', ':', 'B', 'i', 'n', 'd', 'e', 'r', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'M', 'o', 'd', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'S', 'w', 'i', 'z', 'z', 'l', 'e', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'U', 'n', 'i', 't', 'R', 'e', 's', 'e', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'M', 'i', 'p', 'M', 'a', 'p', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'C', 'a', 'c', 'h', 'e', 'a', 'b', 'l', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'F', 'r', 'o', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    'a', 'd', 'd', 'C', 'a', 'c', 'h', 'e', 'a', 'b', 'l', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 'F', 'r', 'o', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 'C', 'o', 'd', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', ':', ':', 'O', 'p', 'e', 'n', 'G', 'L', 'M', 'o', 'd', 'u', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', 0,
    'h', 'i', 'g', 'h', 'D', 'p', 'i', 'S', 'c', 'a', 'l', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'R', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'M', 'e', 't', 'r', 'i', 'c', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 't', 'o', 'p', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'O', 'v', 'e', 'r', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'L', 'o', 'g', 'g', 'e', 'r', ':', ':', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'i', 'e', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'R', 'a', 'n', 'g', 'e', 'A', 'c', 'c', 'e', 's', 's', 'F', 'l', 'a', 'g', 's', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 'A', 'n', 'd', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', ':', ':', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', '>', 0,
    'r', 'e', 'p', 'o', 'r', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'S', 'h', 'o', 'w', 'L', 'i', 'n', 'e', 'A', 'n', 'd', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'M', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'O', 'u', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'M', 'i', 'p', 'M', 'a', 'p', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'S', 'R', 'G', 'B', '8', '_', 'P', 'u', 'n', 'c', 'h', 'T', 'h', 'r', 'o', 'u', 'g', 'h', '_', 'A', 'l', 'p', 'h', 'a', '1', '_', 'E', 'T', 'C', '2', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 'n', 'e', 'r', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'O', 'u', 't', 'e', 'r', 'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'R', 'a', 'n', 'g', 'e', 'A', 'c', 'c', 'e', 's', 's', 'F', 'l', 'a', 'g', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'P', 'a', 'i', 'r', '<', 'q', 'r', 'e', 'a', 'l', ',', 'Q', 'C', 'o', 'l', 'o', 'r', '>', ' ', '>', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'D', 'r', 'a', 'w', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'H', 'i', 'n', 't', 's', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'X', 'o', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'n', 'd', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'I', 'n', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'U', 'p', 'd', 'a', 't', 'e', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'B', 'l', 'i', 't', 't', 'e', 'r', ':', ':', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'i', 's', 'A', 'u', 't', 'o', 'M', 'i', 'p', 'M', 'a', 'p', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'D', 'o', 'n', 't', 'R', 'e', 's', 't', 'o', 'r', 'e', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'q', 't', '_', 's', 'e', 't', '_', 's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '_', 'a', 'u', 't', 'o', '_', 'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'F', 'l', 'i', 'p', 'A', 'n', 'd', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '8', '8', '8', '8', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '4', '4', '4', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '8', '5', '5', '5', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '6', '6', '6', '6', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '8', '5', '6', '5', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 'F', 'o', 'n', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'F', 'l', 'a', 'g', 0,
    'W', 'r', 'a', 'p', 'A', 't', 'W', 'o', 'r', 'd', 'B', 'o', 'u', 'n', 'd', 'a', 'r', 'y', 'O', 'r', 'A', 'n', 'y', 'w', 'h', 'e', 'r', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'M', 'a', 'r', 'k', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'Q', 'u', 'i', 'c', 'k', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'I', 'n', 'p', 'u', 't', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', ':', ':', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'H', 'i', 'n', 't', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'S', 'w', 'i', 'z', 'z', 'l', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 'B', 'i', 't', 0,
    's', 'e', 't', 'L', 'e', 'a', 's', 't', 'S', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', 'B', 'y', 't', 'e', 'F', 'i', 'r', 's', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'S', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'I', 'm', 'a', 'g', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', '2', 'R', 'G', 'B', '3', '0', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', '2', 'B', 'G', 'R', '3', '0', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'N', 'a', 'm', 'e', 'd', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'Q', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'O', 'n', 'l', 'y', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'h', 'o', 'w', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', 'I', 'n', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 's', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'F', 'a', 'c', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'P', 'i', 'x', 'e', 'l', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'h', 'a', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'U', 's', 'a', 'g', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'M', 'a', 't', 'c', 'h', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '6', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', 'H', 'o', 'o', 'k', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', '>', 0,
    'Q', 'D', 'o', 'u', 'b', 'l', 'e', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', ':', ':', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'F', 'l', 'a', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'M', 'o', 'v', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'o', 'l', 'o', 'r', 'D', 'o', 'd', 'g', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 't', 'o', 'p', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'v', 'e', 'r', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'S', 'i', 'z', 'e', 'M', 'a', 't', 'c', 'h', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'O', 'p', 'e', 'r', 'a', 't', 'o', 'r', 's', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 0,
    'i', 's', 'L', 'e', 'a', 's', 't', 'S', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', 'B', 'i', 't', 'F', 'i', 'r', 's', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'D', 'e', 'c', 'i', 'd', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 'F', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'Q', 'T', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', ':', ':', 'T', 'a', 'b', 'l', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', ':', ':', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'D', 'i', 'a', 'l', 'e', 'c', 't', 'C', 'o', 'm', 'm', 'o', 'n', 'M', 'a', 'r', 'k', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'A', 'n', 'd', 'H', 'o', 'l', 'd', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 's', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', ':', ':', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'S', 'c', 'a', 'l', 'e', 'd', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'C', 'l', 'e', 'a', 'r', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'E', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'f', 't', 'L', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'H', 'a', 'r', 'd', 'L', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'o', 'l', 'o', 'r', 'B', 'u', 'r', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'O', 'u', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'O', 'E', 'S', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'F', 'l', 'o', 'a', 't', '3', '2', '_', 'D', '3', '2', '_', 'U', 'I', 'n', 't', '3', '2', '_', 'S', '8', '_', 'X', '2', '4', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'P', 'i', 'x', 'e', 'l', 'T', 'y', 'p', 'e', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'A', 'r', 'r', 'a', 'y', 0,
    'm', 'a', 'x', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'O', 'u', 't', 'p', 'u', 't', 'V', 'e', 'r', 't', 'i', 'c', 'e', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'R', 'e', 's', 't', 'o', 'r', 'e', 'F', 'r', 'a', 'm', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', ':', ':', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'K', 'e', 'y', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'Q', 'u', 'i', 't', 'O', 'n', 'L', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', ':', ':', 'S', 'y', 's', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 's', 0,
    'S', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'E', 'v', 'e', 'n', 't', ':', ':', 'S', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', ':', ':', 'R', 'e', 'a', 's', 'o', 'n', 0,
    'Q', 'T', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', ':', ':', 'P', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'D', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 's', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    't', 'a', 'k', 'e', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'U', 'p', 'd', 'a', 't', 'e', 'M', 'a', 's', 'k', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'A', 'l', 'p', 'h', 'a', 'U', 's', 'a', 'g', 'e', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 'I', 'n', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'V', 'e', 'r', 't', 'e', 'x', 'A', 'r', 'r', 'a', 'y', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'h', 'a', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'B', 'l', 'i', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'I', 'n', 's', 'e', 'r', 't', 'P', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'D', 'e', 't', 'e', 'c', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', '>', 0,
    'C', 'u', 'r', 's', 'o', 'r', 'B', 'e', 't', 'w', 'e', 'e', 'n', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'F', 'i', 'n', 'd', 'F', 'l', 'a', 'g', 0,
    's', 'e', 't', 'K', 'e', 'e', 'p', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'n', 'I', 'n', 's', 'e', 'r', 't', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'w', 'h', 'e', 'e', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'L', 'i', 'n', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'a', 'b', 'F', 'o', 'c', 'u', 's', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', ':', ':', 'I', 't', 'e', 'm', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'W', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 's', 0,
    'a', 'd', 'v', 'a', 'n', 'c', 'e', 's', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'B', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'Y', 'U', 'V', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'F', 'l', 'a', 'g', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'S', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'L', 'i', 'g', 'h', 't', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'O', 'v', 'e', 'r', 'l', 'a', 'y', 0,
    'H', 'i', 'g', 'h', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    's', 'e', 't', 'F', 'i', 'x', 'e', 'd', 'S', 'a', 'm', 'p', 'l', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '2', 'x', '1', '2', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '2', 'x', '1', '0', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '1', '0', 0,
    'h', 'a', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 's', 0,
    'a', 'd', 'd', 'S', 'h', 'a', 'd', 'e', 'r', 'F', 'r', 'o', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    'a', 'd', 'd', 'S', 'h', 'a', 'd', 'e', 'r', 'F', 'r', 'o', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 'C', 'o', 'd', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'W', 'r', 'i', 't', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 's', 'F', 'o', 'r', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'd', 'e', 'c', 'i', 'd', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '2', '7', '0', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '1', '8', '0', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'A', 'w', 'a', 'r', 'e', 0,
    'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', ':', ':', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 'F', 'l', 'a', 'g', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'Q', 'P', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'D', 'e', 'v', 'i', 'c', 'e', 'U', 'n', 'i', 'q', 'u', 'e', 'I', 'd', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', ':', ':', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', '*', '>', 0,
    's', 'e', 't', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'G', 'r', 'a', 'b', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'S', 'h', 'o', 'w', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'A', 'd', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'W', 'i', 'd', 't', 'h', 'C', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 'D', 'o', 't', 'D', 'a', 's', 'h', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'C', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'B', 'l', 'o', 'c', 'k', 'N', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'l', 'w', 'a', 'y', 's', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'l', 'a', 's', 's', 0,
    't', 'o', 'u', 'c', 'h', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'u', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'F', 'l', 'a', 's', 'h', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 'O', 'n', 'T', 'o', 'u', 'c', 'h', 'R', 'e', 'l', 'e', 'a', 's', 'e', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 'R', 'a', 't', 'e', 0,
    't', 'a', 'k', 'e', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'X', 'm', 'p', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    'P', 'a', 'i', 'n', 't', 'O', 'u', 't', 's', 'i', 'd', 'e', 'P', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 's', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', 'S', 'c', 'a', 'l', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'D', 'a', 'r', 'k', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'L', 'o', 's', 's', 'l', 'e', 's', 's', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'i', 's', 'F', 'i', 'x', 'e', 'd', 'S', 'a', 'm', 'p', 'l', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'M', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '8', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '6', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '5', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'E', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 0,
    'D', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', 'd', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'T', 'h', 'r', 'e', 'a', 'd', 'e', 'd', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'R', 'o', 't', 'a', 't', 'e', '9', '0', 0,
    's', 'e', 't', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    'q', 'u', 'i', 't', 'O', 'n', 'L', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'q', 'u', 'e', 'r', 'y', 'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'Q', 'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 'C', 'l', 'i', 'c', 'k', 'e', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', ':', ':', 'P', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', '*', '>', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'A', 'n', 'c', 'e', 's', 't', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 's', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 'S', 'p', 'a', 'c', 'e', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'f', 'o', 'n', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'l', 'w', 'a', 'y', 's', 'A', 'f', 't', 'e', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'D', 'i', 'a', 'l', 'e', 'c', 't', 'G', 'i', 't', 'H', 'u', 'b', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', ':', ':', 'S', 't', 'a', 'c', 'k', 's', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 'B', 'y', 'L', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'j', 'o', 'i', 'n', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', ':', ':', 'M', 'o', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'A', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'I', 'n', 'p', 'u', 't', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'U', 'p', 'd', 'a', 't', 'e', 'M', 'a', 's', 'k', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'L', 'a', 'y', 'o', 'u', 't', 'F', 'l', 'a', 'g', 's', 0,
    'g', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 'F', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', ':', ':', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'C', 'l', 'e', 'a', 'r', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    'Q', 't', '4', 'C', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'N', 'o', 'n', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'e', 'n', 0,
    'S', 'm', 'o', 'o', 't', 'h', 'P', 'i', 'x', 'm', 'a', 'p', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'F', 'u', 'z', 'z', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'c', 'h', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 'I', 'd', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'B', 'l', 'i', 't', 't', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '8', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '6', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '5', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '6', 'x', '6', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '6', 'x', '5', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '5', 'x', '5', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '5', 'x', '4', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'A', 'S', 'T', 'C', '_', '4', 'x', '4', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', '_', 'E', 'T', 'C', '2', '_', 'E', 'A', 'C', 0,
    'R', 'G', 'B', '_', 'B', 'P', '_', 'U', 'N', 'S', 'I', 'G', 'N', 'E', 'D', '_', 'F', 'L', 'O', 'A', 'T', 0,
    'd', 'i', 's', 'a', 'b', 'l', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'b', 'i', 'n', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'V', 'e', 'r', 's', 'i', 'o', 'n', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'R', 'a', 'n', 'g', 'e', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'a', 'u', 't', 'o', 'D', 'e', 't', 'e', 'c', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'o', 'u', 'c', 'h', 'D', 'e', 'v', 'i', 'c', 'e', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', '>', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'R', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', 'T', 'y', 'p', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', ':', ':', 'i', 't', 'e', 'r', 'a', 't', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', ':', ':', 'i', 't', 'e', 'r', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'A', 'd', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'N', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'V', 'e', 'c', 't', 'o', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'B', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'F', 'r', 'o', 'm', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'k', 'e', 'e', 'p', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'O', 'n', 'I', 'n', 's', 'e', 'r', 't', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'M', 'o', 'v', 'e', 'm', 'e', 'n', 't', 'X', 0,
    'm', 'e', 'r', 'g', 'e', 'B', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'Y', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'X', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', ':', ':', 'L', 'a', 'y', 'o', 'u', 't', 'F', 'l', 'a', 'g', 0,
    'S', 'u', 'b', 'P', 'i', 'x', 'e', 'l', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'P', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'v', 'i', 'e', 'w', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'P', 'l', 'u', 's', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'L', 'e', 'v', 'e', 'l', 'o', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'B', 'i', 'a', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'L', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'M', 'i', 'p', 'M', 'a', 'p', 'N', 'e', 'a', 'r', 'e', 's', 't', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'i', 'c', 'F', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 'A', 'r', 'r', 'a', 'y', 's', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'D', 'o', 'n', 't', 'R', 'e', 's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'U', 'n', 'i', 't', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', 'C', 'u', 'b', 'e', 'M', 'a', 'p', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '1', 'D', 'A', 'r', 'r', 'a', 'y', 0,
    's', 'e', 't', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 'V', 'a', 'l', 'u', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'C', 'o', 'm', 'b', 'i', 'n', 'e', 'd', 'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'M', 'e', 's', 's', 'a', 'g', 'e', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'm', 'p', 'i', 'l', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'W', 'r', 'i', 't', 'e', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', 'B', 'y', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    's', 'e', 't', 'F', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'c', 'r', 'e', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'A', 'w', 'a', 'r', 'e', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'S', 'm', 'a', 'l', 'l', 'e', 's', 't', 'R', 'e', 'a', 'd', 'a', 'b', 'l', 'e', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'P', 'r', 'o', 'p', 'o', 's', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'w', 'i', 't', 'h', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 's', ':', ':', 'S', 'v', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'a', 'g', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '>', 0,
    'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'M', 'o', 'u', 's', 'e', 'G', 'r', 'a', 'b', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'f', 'i', 'r', 's', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'r', 'i', 'g', 'h', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'i', 'n', 'e', 'F', 'o', 'r', 'T', 'e', 'x', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 'D', 'a', 's', 'h', 0,
    'S', 'p', 'e', 'l', 'l', 'C', 'h', 'e', 'c', 'k', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'C', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'T', 'a', 'b', 'l', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'H', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'c', 'l', 'e', 'a', 'r', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 's', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'U', 's', 'e', 'D', 'e', 's', 'i', 'g', 'n', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'F', 'i', 'n', 'd', 'C', 'a', 's', 'e', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', 0,
    's', 'e', 't', 'V', 'i', 's', 'u', 'a', 'l', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'C', 'o', 'm', 'p', 'l', 'e', 'x', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'D', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'Y', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 'X', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 0,
    'Q', 'R', 'e', 'g', 'i', 'o', 'n', ':', ':', 'R', 'e', 'g', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'C', 'u', 'r', 'r', 'e', 'n', 't', 'S', 'y', 's', 't', 'e', 'm', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'X', 'm', 'p', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'R', 'o', 'l', 'e', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 'S', 't', 'r', 'o', 'k', 'e', 'r', 0,
    'b', 'r', 'u', 's', 'h', 'N', 'e', 'e', 'd', 's', 'R', 'e', 's', 'o', 'l', 'v', 'i', 'n', 'g', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'C', 'o', 'n', 'i', 'c', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'P', 'd', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'N', 'a', 't', 'i', 'v', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', '_', 'X', 'o', 'r', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'R', 'e', 'f', 'T', 'o', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'G', 'r', 'e', 'a', 't', 'e', 'r', 'E', 'q', 'u', 'a', 'l', 0,
    'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'M', 'i', 'p', 'M', 'a', 'p', 'N', 'e', 'a', 'r', 'e', 's', 't', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 'M', 'i', 'p', 'M', 'a', 'p', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'M', 'o', 'd', 'e', 0,
    'R', 'G', 'B', '_', 'B', 'P', '_', 'S', 'I', 'G', 'N', 'E', 'D', '_', 'F', 'L', 'O', 'A', 'T', 0,
    'D', 'o', 'n', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'e', 't', 'P', 'a', 't', 'c', 'h', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    'T', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    's', 'e', 't', 'S', 'w', 'a', 'p', 'B', 'y', 't', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'A', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'R', 'a', 'n', 'g', 'e', 'U', 'n', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'e', 'd', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'T', 'y', 'p', 'e', 0,
    'I', 'n', 's', 'e', 'r', 't', 'L', 'i', 'n', 'e', 'S', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'p', 'p', 'l', 'y', 'C', 'o', 'l', 'o', 'r', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'A', 's', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'M', 'a', 's', 'k', 'F', 'r', 'o', 'm', 'C', 'o', 'l', 'o', 'r', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'H', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', 'M', 'a', 's', 'k', 0,
    'f', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    's', 'e', 't', 'T', 'h', 'e', 'm', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    'f', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'S', 'a', 'm', 'p', 'l', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    'F', 'o', 'r', 'c', 'e', 'I', 'n', 't', 'e', 'g', 'e', 'r', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'N', 'o', 'S', 'u', 'b', 'p', 'i', 'x', 'e', 'l', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'Q', 'N', 'a', 't', 'i', 'v', 'e', 'G', 'e', 's', 't', 'u', 'r', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'P', 'r', 'e', 'p', 'a', 'r', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'S', 't', 'r', 'e', 't', 'c', 'h', 'T', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', '*', '>', 0,
    'Q', 'P', 'a', 'i', 'r', '<', 'f', 'l', 'o', 'a', 't', ',', 'f', 'l', 'o', 'a', 't', '>', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'T', 'i', 't', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 's', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'a', 'b', 'S', 't', 'o', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'l', 'a', 's', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'L', 'e', 'a', 'd', 'i', 'n', 'g', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'd', 0,
    'l', 'e', 'f', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'n', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'O', 'u', 't', 's', 'e', 't', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'G', 'r', 'o', 'o', 'v', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'a', 's', 'h', 'e', 'd', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'D', 'o', 't', 't', 'e', 'd', 0,
    'L', 'i', 'n', 'e', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'P', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'f', 'o', 'n', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'I', 'm', 'a', 'g', 'e', 'U', 'r', 'l', 0,
    'F', 'u', 'l', 'l', 'W', 'i', 'd', 't', 'h', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'T', 'e', 'x', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'T', 'e', 'x', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'R', 'e', 'd', 'o', 'S', 't', 'e', 'p', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'U', 'n', 'd', 'o', 'S', 't', 'e', 'p', 's', 0,
    'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'M', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'B', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'y', 'n', 't', 'a', 'x', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'r', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'U', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 0,
    'f', 'o', 'n', 't', 'S', 'm', 'o', 'o', 't', 'h', 'i', 'n', 'g', 'G', 'a', 'm', 'm', 'a', 0,
    's', 'e', 't', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'H', 'e', 'a', 'd', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'o', 't', 's', 'P', 'e', 'r', 'I', 'n', 'c', 'h', 0,
    'f', 'r', 'o', 'm', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    't', 'y', 'p', 'e', 'I', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'u', 'r', 'v', 'e', 'T', 'o', 'D', 'a', 't', 'a', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'T', 'y', 'p', 'e', 0,
    'R', 'a', 'd', 'i', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'F', 'i', 'l', 'l', 0,
    'P', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'w', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', '_', 'N', 'o', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'G', 'e', 'r', 'm', 'a', 'n', 'L', 'e', 'g', 'a', 'l', 0,
    'P', 'a', 'r', 't', 'i', 'a', 'l', 'U', 'p', 'd', 'a', 't', 'e', 'B', 'l', 'e', 'n', 'd', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'v', 'e', 'l', 'O', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'R', 'a', 'n', 'g', 'e', 0,
    'm', 'i', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'M', 'i', 'p', 'M', 'a', 'p', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'M', 'u', 'l', 't', 'i', 's', 'a', 'm', 'p', 'l', 'e', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', 'B', '1', '0', 'A', '2', '_', 'R', 'e', 'v', 0,
    'i', 's', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'A', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'd', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'i', 's', 'S', 'w', 'a', 'p', 'B', 'y', 't', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'e', 'n', 's', 'u', 'r', 'e', 'A', 'c', 't', 'i', 'v', 'e', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'a', 'd', 'd', 'C', 'o', 'l', 'o', 'r', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'D', 'e', 'b', 'u', 'g', 'L', 'o', 'g', 'g', 'e', 'r', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'S', 'y', 's', 't', 'e', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'S', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'o', 'p', 'e', 'n', 'G', 'L', 'M', 'o', 'd', 'u', 'l', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'a', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'R', 'a', 'n', 'g', 'e', 'F', 'l', 'u', 's', 'h', 'E', 'x', 'p', 'l', 'i', 'c', 'i', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', ':', ':', 'M', 'o', 'v', 'i', 'e', 'S', 't', 'a', 't', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'P', 'a', 'g', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'W', 'o', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'i', 'n', 'p', 'u', 't', 'I', 't', 'e', 'm', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'F', 'l', 'i', 'p', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'N', 'o', 'n', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 'l', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', '1', '6', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', ':', ':', 'I', 'n', 'v', 'e', 'r', 't', 'M', 'o', 'd', 'e', 0,
    'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 's', 'H', 'o', 'o', 'k', 0,
    's', 'e', 't', 'D', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'n', 't', 0,
    'i', 's', 'S', 'm', 'o', 'o', 't', 'h', 'l', 'y', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'T', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'C', 'h', 'i', 'n', 'e', 's', 'e', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'S', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 'R', 'a', 'n', 'g', 'e', 0,
    'r', 'a', 'w', 'S', 'c', 'r', 'e', 'e', 'n', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    's', 't', 'a', 'r', 't', 'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 0,
    't', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'F', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', ':', ':', 'N', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'S', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', '>', 0,
    's', 't', 'a', 'r', 't', 'S', 'y', 's', 't', 'e', 'm', 'R', 'e', 's', 'i', 'z', 'e', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 's', 0,
    'E', 'x', 'c', 'l', 'u', 'd', 'e', 'T', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 's', 0,
    'Q', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'S', 'h', 'o', 'w', 'T', 'a', 'b', 's', 'A', 'n', 'd', 'S', 'p', 'a', 'c', 'e', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'F', 'l', 'a', 'g', 0,
    'C', 'u', 'r', 's', 'o', 'r', 'O', 'n', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'a', 'd', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'I', 'n', 's', 'e', 't', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'R', 'i', 'd', 'g', 'e', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'S', 'o', 'l', 'i', 'd', 0,
    'n', 'o', 'n', 'B', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', 'L', 'i', 'n', 'e', 's', 0,
    'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 'A', 'l', 'l', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'f', 'o', 'n', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    't', 'o', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'B', 'l', 'o', 'c', 'k', 'C', 'o', 'd', 'e', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'F', 'i', 'r', 's', 't', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    'B', 'l', 'o', 'c', 'k', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', ':', ':', 'T', 'y', 'p', 'e', 0,
    'U', 'n', 'd', 'o', 'A', 'n', 'd', 'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 's', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 'B', 'y', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'B', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'r', 'k', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'i', 's', 'U', 'n', 'd', 'o', 'R', 'e', 'd', 'o', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'M', 'o', 'v', 'e', 'm', 'e', 'n', 't', 'X', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'R', 'e', 's', 'e', 't', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 'M', 'a', 's', 'k', 'D', 'e', 'l', 'a', 'y', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'V', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'A', 'g', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    'i', 'n', 'v', 'i', 's', 'i', 'b', 'l', 'e', 'R', 'o', 'o', 't', 'I', 't', 'e', 'm', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 'C', 'a', 'c', 'h', 'e', ':', ':', 'K', 'e', 'y', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 'e', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'C', 'u', 'r', 'v', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    't', 'o', 'S', 'u', 'b', 'p', 'a', 't', 'h', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 's', 0,
    'p', 'e', 'n', 'N', 'e', 'e', 'd', 's', 'R', 'e', 's', 'o', 'l', 'v', 'i', 'n', 'g', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'F', 0,
    'e', 'n', 'd', 'N', 'a', 't', 'i', 'v', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'c', 'o', 'm', 'b', 'i', 'n', 'e', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'W', 'o', 'r', 'l', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'd', 'r', 'a', 'w', 'C', 'o', 'n', 'v', 'e', 'x', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', ':', ':', 'U', 'n', 'i', 't', 0,
    'E', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 0,
    'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'P', 'a', 'r', 't', 'i', 'a', 'l', 'U', 'p', 'd', 'a', 't', 'e', 'B', 'l', 'i', 't', 0,
    's', 'e', 't', 'R', 'e', 'd', 'B', 'l', 'u', 'e', 'S', 'w', 'i', 'z', 'z', 'l', 'e', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'l', 'e', 'v', 'e', 'l', 'o', 'f', 'D', 'e', 't', 'a', 'i', 'l', 'B', 'i', 'a', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 0,
    'N', 'P', 'O', 'T', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'R', 'e', 'p', 'e', 'a', 't', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', 'D', 'a', 't', 'a', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', '5', 'G', '6', 'B', '5', '_', 'R', 'e', 'v', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', 'G', 'B', '5', 'A', '1', '_', 'R', 'e', 'v', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'V', 'i', 'e', 'w', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'A', 'r', 'r', 'a', 'y', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'm', 'p', 'i', 'l', 'e', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    'c', 'o', 'm', 'p', 'i', 'l', 'e', 'S', 'o', 'u', 'r', 'c', 'e', 'C', 'o', 'd', 'e', 0,
    'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'i', 'x', 'e', 'l', 'U', 'n', 'p', 'a', 'c', 'k', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'O', 'f', 'f', 's', 'c', 'r', 'e', 'e', 'n', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', ':', ':', 'C', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'S', 't', 'a', 'r', 't', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'S', 't', 'a', 'r', 't', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'e', 'd', 'W', 'r', 'i', 't', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'I', 'm', 'a', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'F', 'i', 'l', 'e', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 's', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', '8', 0,
    'f', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'O', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 0,
    't', 'i', 'g', 'h', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 'N', 'a', 'm', 'e', 0,
    'S', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', 'C', 'h', 'i', 'n', 'e', 's', 'e', 0,
    'h', 'i', 'n', 't', 'i', 'n', 'g', 'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'F', 'u', 'l', 'l', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'l', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    'P', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'o', 'v', 'e', 'r', 's', 'h', 'o', 'o', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'l', 'a', 's', 't', 'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'P', 'r', 'e', 's', 'e', 't', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'p', 'r', 'i', 'n', 'g', 'g', 'r', 'e', 'e', 'n', 0,
    'h', 'a', 's', 'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'b', 'l', 'o', 'c', 'k', 'W', 'i', 't', 'h', 'M', 'a', 'r', 'k', 'e', 'r', 'A', 't', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'b', 'l', 'o', 'c', 'k', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'f', 'r', 'a', 'm', 'e', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'r', 'e', 'g', 'u', 'l', 'a', 'r', 'E', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'F', '>', 0,
    'Q', 'S', 'e', 't', '<', 'Q', 'B', 'y', 't', 'e', 'A', 'r', 'r', 'a', 'y', '>', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    'Q', 'R', 'e', 'g', 'E', 'x', 'p', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'o', 'u', 'b', 'l', 'e', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', ':', ':', 'T', 'a', 'b', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'n', 'a', 't', 'u', 'r', 'a', 'l', 'T', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', '_', 'N', 'o', 'n', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    't', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'R', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'S', 'u', 'p', 'e', 'r', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'L', 'i', 's', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    'L', 'i', 's', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    'L', 'a', 's', 't', 'F', 'o', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'F', 'r', 'a', 'm', 'e', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'B', 'l', 'o', 'c', 'k', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'P', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'u', 'n', 'd', 'o', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 'A', 'd', 'd', 'e', 'd', 0,
    'u', 's', 'e', 'D', 'e', 's', 'i', 'g', 'n', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'v', 'i', 's', 'u', 'a', 'l', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'e', 'r', 'g', 'e', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'B', 'l', 'o', 'c', 'k', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'r', 'e', 'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'B', 'l', 'o', 'c', 'k', 0,
    's', 'e', 't', 'R', 'e', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'w', 'h', 'e', 'e', 'l', 'S', 'c', 'r', 'o', 'l', 'l', 'L', 'i', 'n', 'e', 's', 0,
    't', 'a', 'b', 'F', 'o', 'c', 'u', 's', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'u', 's', 'e', 'R', 't', 'l', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    's', 'h', 'o', 'w', 'I', 's', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'R', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'P', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 'A', 't', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'S', 'e', 'p', 'a', 'r', 'a', 't', 'e', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 's', 0,
    'a', 'l', 'p', 'h', 'a', 'M', 'a', 'p', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 0,
    'a', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 'T', 'y', 'p', 'e', 0,
    't', 'o', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'F', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'm', 'y', 'k', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'R', 'g', 'b', 'a', 0,
    'N', 'o', 't', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'r', 'o', 'l', 'P', 'o', 'i', 'n', 't', 'R', 'e', 'c', 't', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'P', 'a', 't', 't', 'e', 'r', 'n', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'c', 'l', 'i', 'p', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'T', 'e', 'x', 't', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'e', 'r', 's', 'o', 'n', 'a', 'l', 0,
    'O', 'r', 'i', 'g', 'i', 'n', 'B', 'o', 't', 't', 'o', 'm', 'L', 'e', 'f', 't', 0,
    'C', 'o', 'm', 'm', 'p', 'a', 'r', 'e', 'N', 'o', 't', 'E', 'q', 'u', 'a', 'l', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'L', 'e', 's', 's', 'E', 'q', 'u', 'a', 'l', 0,
    's', 'e', 't', 'M', 'i', 'n', 'M', 'a', 'g', 'F', 'i', 'l', 't', 'e', 'r', 's', 0,
    'd', 'e', 'p', 't', 'h', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 'R', 'a', 'n', 'g', 'e', 0,
    'S', 't', 'e', 'n', 'c', 'i', 'l', 'T', 'e', 'x', 't', 'u', 'r', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', 'B', 'A', '8', '_', 'R', 'e', 'v', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', 'G', 'B', 'A', '4', '_', 'R', 'e', 'v', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'Z', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'Z', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'Y', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'Y', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'X', 0,
    'C', 'u', 'b', 'e', 'M', 'a', 'p', 'P', 'o', 's', 'i', 't', 'i', 'v', 'e', 'X', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'M', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'p', 'a', 't', 'c', 'h', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 's', 0,
    'h', 'a', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'o', 'p', 'e', 'n', 'G', 'L', 'M', 'o', 'd', 'u', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'B', 'l', 'o', 'c', 'k', 0,
    'a', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'u', 'e', 'r', 'y', 'F', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'c', 't', 0,
    'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'D', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'Y', 0,
    's', 'e', 't', 'D', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'X', 0,
    'S', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 'H', 'o', 'o', 'k', 0,
    't', 'h', 'e', 'm', 'e', 'S', 'e', 'a', 'r', 'c', 'h', 'P', 'a', 't', 'h', 's', 0,
    'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'l', 'a', 's', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'a', 'v', 'e', 'r', 'a', 'g', 'e', 'C', 'h', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'r', 0,
    'i', 's', 'B', 'i', 't', 'm', 'a', 'p', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'L', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'l', 'a', 's', 't', 'R', 'e', 's', 'o', 'r', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'E', 'v', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    't', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 'S', 't', 'a', 't', 'e', 's', 0,
    'e', 'l', 'l', 'i', 'p', 's', 'e', 'D', 'i', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 'S', 't', 'a', 'r', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'V', 'i', 'r', 't', 'u', 'a', 'l', 'K', 'e', 'y', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'D', 'e', 's', 'k', 't', 'o', 'p', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 's', 0,
    't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'o', 'n', 'i', 'c', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'E', 't', 'e', 'r', 'n', 'a', 'l', 'C', 'o', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'a', 'q', 'u', 'a', 'm', 'a', 'r', 'i', 'n', 'e', 0,
    'd', 'r', 'a', 'w', 'I', 'n', 'l', 'i', 'n', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'r', 'F', 'o', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'R', 'e', 'c', 't', 'F', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'P', 'o', 'i', 'n', 't', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'L', 'i', 'n', 'e', 'F', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'c', 'r', 'e', 'e', 'n', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'i', 'n', 'd', 'o', 'w', '*', '>', 0,
    's', 't', 'a', 'r', 't', 'S', 'y', 's', 't', 'e', 'm', 'M', 'o', 'v', 'e', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 's', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'd', 'a', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'A', 'c', 't', 'i', 'v', 'a', 't', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'C', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'f', 'i', 'r', 's', 't', 'L', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'c', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 'G', 'r', 'o', 'u', 'p', 0,
    'l', 'e', 'a', 'd', 'i', 'n', 'g', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'd', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', ':', ':', 'E', 'd', 'g', 'e', 0,
    'n', 'a', 't', 'u', 'r', 'a', 'l', 'T', 'e', 'x', 't', 'R', 'e', 'c', 't', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'M', 'o', 'v', 'e', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 'T', 'e', 'x', 't', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'T', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'p', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'f', 'o', 'n', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'B', 'l', 'o', 'c', 'k', 'Q', 'u', 'o', 't', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    'F', 'r', 'a', 'm', 'e', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'F', 'o', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'e', 't', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'i', 's', 'R', 'e', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'U', 'n', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'm', 'i', 'g', 'h', 't', 'B', 'e', 'R', 'i', 'c', 'h', 'T', 'e', 'x', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'I', 'n', 'B', 'l', 'o', 'c', 'k', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'e', 'r', 'g', 'e', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'L', 'i', 'n', 'e', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'W', 'o', 'r', 'd', 'U', 'n', 'd', 'e', 'r', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'S', 'w', 'a', 'p', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'a', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'g', 'r', 'e', 'e', 'n', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'd', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'G', 'L', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'u', 's', 'e', 'H', 'o', 'v', 'e', 'r', 'E', 'f', 'f', 'e', 'c', 't', 's', 0,
    's', 'h', 'o', 'w', 'I', 's', 'M', 'a', 'x', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'F', 'l', 'a', 's', 'h', 'T', 'i', 'm', 'e', 0,
    'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'M', 'o', 'd', 'e', 'r', 'a', 't', 'e', 'C', 'a', 'c', 'h', 'i', 'n', 'g', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'e', 'm', 'i', 't', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 's', 0,
    'u', 'n', 'p', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'f', 'r', 'o', 'm', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'g', 'e', 't', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'f', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'Y', 'u', 'v', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'H', 's', 'v', 0,
    'q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'H', 's', 'l', 0,
    'd', 'e', 'f', 'i', 'n', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'p', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 'T', 'e', 'x', 't', 0,
    'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'P', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 'T', 'e', 'x', 't', 0,
    'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    'p', 'e', 'r', 'c', 'e', 'n', 't', 'A', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'P', 'd', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'P', 'd', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'd', 'r', 'a', 'w', 'R', 'o', 'u', 'n', 'd', 'e', 'd', 'R', 'e', 'c', 't', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'd', 'r', 'a', 'w', 'T', 'i', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 'U', 'n', 'i', 't', 's', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', ':', ':', 'U', 'n', 'i', 't', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'I', 't', 'a', 'l', 'i', 'a', 'n', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'M', 'o', 'n', 'a', 'r', 'c', 'h', 0,
    'g', 'r', 'a', 'b', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 0,
    'N', 'o', 'P', 'a', 'r', 't', 'i', 'a', 'l', 'U', 'p', 'd', 'a', 't', 'e', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    't', 'a', 'r', 'g', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    's', 'e', 't', 'M', 'i', 'p', 'B', 'a', 's', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    'U', 'I', 'n', 't', '8', '_', 'R', 'G', '3', 'B', '2', '_', 'R', 'e', 'v', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', '1', '1', 'B', '1', '0', 'F', 0,
    'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '2', 'x', '1', '2', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '2', 'x', '1', '0', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '1', '0', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '5', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '3', 0,
    'S', 'R', 'G', 'B', '_', 'A', 'l', 'p', 'h', 'a', '_', 'D', 'X', 'T', '1', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '3', 'D', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '2', 'D', 0,
    'B', 'i', 'n', 'd', 'i', 'n', 'g', 'T', 'a', 'r', 'g', 'e', 't', '1', 'D', 0,
    's', 'e', 't', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 'V', 'a', 'l', 'u', 'e', 0,
    'u', 'n', 'i', 'f', 'o', 'r', 'm', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'i', 'n', 't', 'F', 'l', 'i', 'p', 'p', 'e', 'd', 0,
    'b', 'l', 'i', 't', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 0,
    'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', '_', 'f', 'o', 'r', 'm', 'a', 't', 0,
    'd', 'i', 's', 'a', 'b', 'l', 'e', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'P', 'o', 'r', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'T', 'y', 'p', 'e', 0,
    'i', 's', 'L', 'e', 'g', 'a', 'c', 'y', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'R', 'a', 'n', 'g', 'e', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 0,
    's', 'e', 't', 'U', 's', 'a', 'g', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'P', 'i', 'x', 'e', 'l', 'P', 'a', 'c', 'k', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'e', 't', 'N', 'a', 't', 'i', 'v', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'N', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'P', 'l', 'a', 'n', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'E', 'n', 'd', 'O', 'f', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'N', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'I', 'O', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'M', 'o', 'd', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 's', 'k', 0,
    'h', 'a', 's', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '8', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '8', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'n', 'd', 'e', 'x', 'e', 'd', '8', 0,
    'd', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    't', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    'Q', 'G', 'u', 'i', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'G', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    'm', 'i', 'n', 'R', 'i', 'g', 'h', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'i', 's', 'P', 'r', 'i', 'v', 'a', 't', 'e', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'N', 'o', 'H', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'c', 'a', 'c', 'h', 'e', 'S', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 's', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'N', 'o', 'S', 'h', 'a', 'p', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 'R', 'a', 'n', 'g', 'e', 0,
    'Q', 'S', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'D', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'D', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'o', 's', 's', 'i', 'b', 'l', 'e', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'C', 'o', 'm', 'm', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'u', 'n', 's', 'e', 't', 'U', 'r', 'l', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'C', 'e', 'n', 't', 'e', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'Q', 'R', 'a', 'd', 'i', 'a', 'l', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'Q', 'L', 'i', 'n', 'e', 'a', 'r', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'L', 'a', 'n', 'd', 'i', 'n', 'g', 'A', 'i', 'r', 'c', 'r', 'a', 'f', 't', 0,
    'C', 'h', 'e', 'e', 'r', 'f', 'u', 'l', 'C', 'a', 'r', 'a', 'm', 'e', 'l', 0,
    'S', 'a', 'i', 'n', 't', 'P', 'e', 't', 'e', 'r', 's', 'b', 'u', 'r', 'g', 0,
    'C', 'l', 'o', 'u', 'd', 'y', 'K', 'n', 'o', 'x', 'v', 'i', 'l', 'l', 'e', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', ':', ':', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'v', 'i', 'o', 'l', 'e', 't', 'r', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'l', 'a', 't', 'e', 'b', 'l', 'u', 'e', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 's', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'c', 'a', 'n', 'D', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'R', 'e', 'c', 't', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'L', 'i', 'n', 'e', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'S', 'i', 'z', 'e', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'q', 'r', 'e', 'a', 'l', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'f', 'l', 'o', 'a', 't', '>', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'h', 'o', 'w', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'T', 'o', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'u', 's', 'e', 'E', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 'C', 'e', 'l', 'l', 0,
    'S', 'u', 'p', 'p', 'r', 'e', 's', 's', 'C', 'o', 'l', 'o', 'r', 's', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'S', 'k', 'i', 'p', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 's', 0,
    's', 'e', 't', 'P', 'r', 'e', 'e', 'd', 'i', 't', 'A', 'r', 'e', 'a', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'l', 'a', 'p', 's', 'e', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'L', 'i', 's', 't', 'U', 'p', 'p', 'e', 'r', 'R', 'o', 'm', 'a', 'n', 0,
    'L', 'i', 's', 't', 'L', 'o', 'w', 'e', 'r', 'R', 'o', 'm', 'a', 'n', 0,
    'L', 'i', 's', 't', 'U', 'p', 'p', 'e', 'r', 'A', 'l', 'p', 'h', 'a', 0,
    'L', 'i', 's', 't', 'L', 'o', 'w', 'e', 'r', 'A', 'l', 'p', 'h', 'a', 0,
    'l', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'f', 'o', 'n', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'A', 'l', 'i', 'g', 'n', 'S', 'u', 'b', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 't', 'r', 'i', 'n', 'g', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'd', 'o', 'u', 'b', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'B', 'l', 'o', 'c', 'k', 'C', 'o', 'd', 'e', 'F', 'e', 'n', 'c', 'e', 0,
    'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'T', 'y', 'p', 'e', 0,
    'F', 'r', 'a', 'm', 'e', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'B', 'l', 'o', 'c', 'k', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'P', 'a', 'g', 'e', 'B', 'r', 'e', 'a', 'k', '_', 'A', 'u', 't', 'o', 0,
    'V', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 'N', 'o', 'H', 'T', 'M', 'L', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'n', 't', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'n', 't', 0,
    'F', 'i', 'n', 'd', 'W', 'h', 'o', 'l', 'e', 'W', 'o', 'r', 'd', 's', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'b', 'e', 'g', 'i', 'n', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'i', 'n', 's', 'e', 'r', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'S', 't', 'a', 'r', 't', 0,
    's', 'R', 'G', 'B', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'b', 'l', 'u', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'O', 'p', 'e', 'n', 'G', 'L', 0,
    'i', 's', 'U', 's', 'e', 'r', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'i', 's', 'A', 'u', 't', 'o', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'D', 'r', 'o', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'q', 'U', 'n', 'p', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'K', 'e', 'r', 'n', 'e', 'd', 'A', 'd', 'v', 'a', 'n', 'c', 'e', 's', 0,
    'g', 'e', 't', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'S', 'i', 'z', 'e', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'a', 's', 'h', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'c', 'u', 'r', 'v', 'e', 'T', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 0,
    'a', 'd', 'd', 'R', 'o', 'u', 'n', 'd', 'e', 'd', 'R', 'e', 'c', 't', 0,
    's', 'l', 'o', 'p', 'e', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    'a', 'n', 'g', 'l', 'e', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    'p', 'o', 'i', 'n', 't', 'A', 't', 'P', 'e', 'r', 'c', 'e', 'n', 't', 0,
    't', 'o', 'F', 'i', 'l', 'l', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 's', 0,
    'C', 'u', 'r', 'v', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'D', 'i', 'r', 't', 'y', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'p', 'a', 'i', 'n', 't', 'i', 'n', 'g', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'd', 'r', 'a', 'w', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', 0,
    't', 'e', 's', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    'w', 'o', 'r', 'l', 'd', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'r', 'e', 's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'B', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'M', 'o', 'd', 'e', 0,
    'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 'S', 'i', 'z', 'e', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'i', 's', 'E', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 't', 'T', 'o', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', '1', '_', '6', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', 'A', '1', 'b', 0,
    'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', '_', '1', '_', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'I', 'n', 'v', 'i', 't', 'e', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 'P', 'o', 's', 't', 'c', 'a', 'r', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'G', 'r', 'e', 'a', 't', 'e', 'r', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 'R', 'e', 'p', 'e', 'a', 't', 0,
    's', 'e', 't', 'S', 'w', 'i', 'z', 'z', 'l', 'e', 'M', 'a', 's', 'k', 0,
    'r', 'e', 's', 'e', 't', 'B', 'a', 's', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'M', 'i', 'p', 'M', 'a', 'x', 'L', 'e', 'v', 'e', 'l', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', 'B', '1', '0', 'A', '2', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', 'B', '9', '_', 'E', '5', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 0,
    'N', 'o', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '8', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '6', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '1', '0', 'x', '5', 0,
    'R', 'G', 'B', 'A', '8', '_', 'E', 'T', 'C', '2', '_', 'E', 'A', 'C', 0,
    'R', 'G', '1', '1', '_', 'E', 'A', 'C', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '1', '1', '_', 'E', 'A', 'C', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '_', 'A', 'T', 'I', '2', 'N', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '_', 'A', 'T', 'I', '2', 'N', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'b', 'o', 'u', 'n', 'd', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'o', 'g', 'g', 'e', 'd', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'M', 'e', 'd', 'i', 'u', 'm', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'g', 'e', 't', 'P', 'r', 'o', 'c', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'n', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 'D', 'e', 'l', 'a', 'y', 0,
    'l', 'i', 's', 't', 'F', 'r', 'o', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'P', 'a', 'g', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'P', 'a', 'g', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'W', 'o', 'r', 'd', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 0,
    'v', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'e', 'd', 'W', 'r', 'i', 't', 'e', 0,
    's', 'e', 't', 'C', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'n', 'e', 'x', 't', 'I', 'm', 'a', 'g', 'e', 'D', 'e', 'l', 'a', 'y', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'T', 'o', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'M', 'o', 'n', 'o', 'L', 'S', 'B', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', ':', ':', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 's', 0,
    'p', 'a', 'l', 'e', 't', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'T', 'o', 'L', 'e', 'f', 't', 0,
    'm', 'i', 'n', 'L', 'e', 'f', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 's', 0,
    'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'W', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'l', 'a', 's', 't', 'R', 'e', 's', 'o', 'r', 't', 'F', 'o', 'n', 't', 0,
    'E', 'x', 't', 'r', 'a', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'U', 'l', 't', 'r', 'a', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'S', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 't', 'a', 'r', 't', 'S', 'c', 'r', 'e', 'e', 'n', 'P', 'o', 's', 0,
    'Q', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'i', 'l', 'e', 'O', 'p', 'e', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'D', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'r', 'o', 'p', 'o', 's', 'e', 'd', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'c', 'o', 'n', 'D', 'r', 'a', 'g', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'S', 'c', 'a', 'n', 'C', 'o', 'd', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'o', 'i', 'n', 't', 'e', 'r', 0,
    'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'S', 't', 'y', 'l', 'u', 's', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'r', 'o', 'm', 'I', 'c', 'c', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'o', 'w', 'n', 's', 'F', 'i', 'n', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'e', 't', 'F', 'o', 'c', 'a', 'l', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'M', 'o', 'd', 'e', 0,
    'S', 't', 'r', 'i', 'c', 't', 'N', 'o', 'v', 'e', 'm', 'b', 'e', 'r', 0,
    'S', 'l', 'e', 'e', 'p', 'l', 'e', 's', 's', 'N', 'i', 'g', 'h', 't', 0,
    'M', 'i', 'l', 'l', 'e', 'n', 'n', 'i', 'u', 'm', 'P', 'i', 'n', 'e', 0,
    'C', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'C', 'l', 'o', 'u', 'd', 0,
    'O', 'c', 't', 'o', 'b', 'e', 'r', 'S', 'i', 'l', 'e', 'n', 'c', 'e', 0,
    'P', 'u', 'r', 'p', 'l', 'e', 'D', 'i', 'v', 'i', 's', 'i', 'o', 'n', 0,
    'E', 'v', 'e', 'r', 'l', 'a', 's', 't', 'i', 'n', 'g', 'S', 'k', 'y', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'g', 'h', 't', 's', 't', 'e', 'e', 'l', 'b', 'l', 'u', 'e', 0,
    'l', 'i', 'g', 'h', 't', 's', 'l', 'a', 't', 'e', 'g', 'r', 'e', 'y', 0,
    'l', 'i', 'g', 'h', 't', 's', 'l', 'a', 't', 'e', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 'o', 'l', 'i', 'v', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'c', 'o', 'r', 'n', 'f', 'l', 'o', 'w', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'b', 'l', 'a', 'n', 'c', 'h', 'e', 'd', 'a', 'l', 'm', 'o', 'n', 'd', 0,
    'h', 's', 'l', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    'h', 's', 'v', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    's', 't', 'a', 't', 'i', 'c', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'D', 'a', 's', 'h', 'D', 'o', 't', 'D', 'o', 't', 'L', 'i', 'n', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'u', 'i', 'n', 't', '>', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'U', 'p', 'd', 'a', 't', 'e', 0,
    's', 'h', 'o', 'w', 'M', 'a', 'x', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'M', 'i', 'n', 'i', 'm', 'i', 'z', 'e', 'd', 0,
    'm', 'a', 'p', 'F', 'r', 'o', 'm', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'f', 'r', 'a', 'm', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'f', 'r', 'a', 'm', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'i', 'z', 'e', 'I', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'Q', 'I', 'n', 't', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'f', 'r', 'o', 'm', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'i', 's', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'n', 'g', 0,
    'r', 'o', 't', 'a', 't', 'e', 'R', 'a', 'd', 'i', 'a', 'n', 's', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'f', 'i', 'r', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'b', 'l', 'o', 'c', 'k', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    's', 'e', 't', 'N', 'u', 'm', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'b', 'o', 't', 't', 'o', 'm', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'T', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'o', 'n', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    'W', 'a', 'v', 'e', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'D', 'a', 's', 'h', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 'H', 'r', 'e', 'f', 0,
    'f', 'o', 'n', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    'f', 'o', 'n', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'f', 'o', 'n', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 0,
    't', 'o', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'T', 'a', 'b', 'l', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'F', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'B', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'r', 'u', 's', 'h', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'o', 'l', 'o', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'l', 'e', 'a', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'F', 'o', 'n', 't', 'P', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    'f', 'r', 'o', 'm', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'u', 'n', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'r', 'e', 'd', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'I', 'm', 'a', 'g', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'T', 'i', 't', 'l', 'e', 0,
    'Q', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'N', 'e', 'x', 't', 'C', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'B', 'l', 'o', 'c', 'k', 0,
    'r', 'e', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'S', 't', 'e', 'r', 'e', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'V', 'u', 'l', 'k', 'a', 'n', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'O', 'p', 'e', 'n', 'V', 'G', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'R', 'a', 's', 't', 'e', 'r', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 't', 'a', 'r', 't', 'D', 'r', 'a', 'g', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'h', 'e', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'F', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'i', 's', 'D', 'r', 'o', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'D', 'r', 'a', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', 0,
    't', 'e', 'x', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'Q', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'I', 't', 'e', 'm', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'i', 't', 'e', 'm', 'P', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'F', 'r', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'i', 't', 'e', 'm', 'F', 'r', 'o', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    'i', 's', 'T', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 't', 0,
    'l', 'i', 'n', 'e', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 0,
    'Q', 'R', 'a', 's', 't', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    't', 'o', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'f', 'r', 'o', 'm', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'r', 'o', 't', 'a', 't', 'e', 'd', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'S', 'q', 'u', 'a', 'r', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'L', 'i', 'm', 'i', 't', 0,
    'a', 'l', 'p', 'h', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'S', 'i', 'z', 'e', 0,
    'F', 'l', 'o', 'a', 't', 'i', 'n', 'g', 'P', 'o', 'i', 'n', 't', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'S', 'h', 'o', 'r', 't', 0,
    'o', 'u', 't', 'p', 'u', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'p', 'i', 'c', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'B', 'a', 's', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'B', 'a', 's', 'e', 0,
    's', 'e', 't', 'D', 'a', 's', 'h', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'M', 'i', 't', 'e', 'r', 'L', 'i', 'm', 'i', 't', 0,
    't', 'o', 'F', 'i', 'l', 'l', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'L', 'i', 'n', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'i', 's', 'C', 'l', 'i', 'p', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'c', 'l', 'i', 'p', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'y', 's', 't', 'e', 'm', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    'R', 'a', 's', 't', 'e', 'r', 'O', 'p', 'M', 'o', 'd', 'e', 's', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'L', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 'M', 'M', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '1', '0', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'K', 'a', 'k', 'u', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'K', 'a', 'k', 'u', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', 'h', 'o', 'u', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', 'h', 'o', 'u', '3', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'G', 'e', 'r', 'm', 'a', 'n', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '5', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '2', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '4', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '3', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '1', '0', 'x', '1', '1', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'O', 'r', 'i', 'g', 'i', 'n', 'T', 'o', 'p', 'L', 'e', 'f', 't', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'A', 'l', 'w', 'a', 'y', 's', 0,
    'C', 'l', 'a', 'm', 'p', 'T', 'o', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'm', 'i', 'n', 'M', 'a', 'g', 'F', 'i', 'l', 't', 'e', 'r', 's', 0,
    'm', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 'R', 'a', 'n', 'g', 'e', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'A', 'r', 'r', 'a', 'y', 's', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', '5', 'G', '6', 'B', '5', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', 'G', 'B', '5', 'A', '1', 0,
    'i', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'V', 'i', 'e', 'w', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '8', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '6', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '8', 'x', '5', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '6', 'x', '6', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '6', 'x', '5', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '5', 'x', '5', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '5', 'x', '4', 0,
    'R', 'G', 'B', 'A', '_', 'A', 'S', 'T', 'C', '_', '4', 'x', '4', 0,
    'R', '1', '1', '_', 'E', 'A', 'C', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '1', '1', '_', 'E', 'A', 'C', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'S', 'R', 'G', 'B', '_', 'B', 'P', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', '_', 'A', 'T', 'I', '1', 'N', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '_', 'A', 'T', 'I', '1', 'N', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'S', 'k', 'i', 'p', 'P', 'i', 'x', 'e', 'l', 's', 0,
    's', 'e', 't', 'S', 'k', 'i', 'p', 'I', 'm', 'a', 'g', 'e', 's', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'T', 'a', 'r', 'g', 'e', 't', 0,
    's', 'e', 't', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'm', 'e', 's', 's', 'a', 'g', 'e', 'L', 'o', 'g', 'g', 'e', 'd', 0,
    'G', 'r', 'o', 'u', 'p', 'P', 'u', 's', 'h', 'T', 'y', 'p', 'e', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'O', 'p', 'e', 'n', 'G', 'L', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'h', 'i', 'l', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 't', 'o', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    't', 'o', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'i', 't', 'P', 'l', 'a', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'Y', 0,
    'd', 'o', 't', 's', 'P', 'e', 'r', 'M', 'e', 't', 'e', 'r', 'X', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'T', 'o', 'W', 'i', 'd', 't', 'h', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    'c', 'o', 'n', 's', 't', 'S', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'A', '6', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', 'X', '6', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'l', 'p', 'h', 'a', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '4', '4', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '8', '8', '8', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '5', '5', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '6', '6', '6', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'I', 'c', 'o', 'n', 0,
    'i', 's', 'L', 'e', 'f', 't', 'T', 'o', 'R', 'i', 'g', 'h', 't', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'i', 's', 'R', 'i', 'g', 'h', 't', 'T', 'o', 'L', 'e', 'f', 't', 0,
    'S', 'p', 'l', 'i', 't', 'L', 'i', 'g', 'a', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'T', 'o', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    'Q', 'F', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 'F', 0,
    'w', 'r', 'i', 't', 'i', 'n', 'g', 'S', 'y', 's', 't', 'e', 'm', 0,
    's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'i', 'z', 'e', 's', 0,
    'Q', 'F', 'o', 'n', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'l', 'e', 't', 't', 'e', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', 0,
    's', 't', 'y', 'l', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 'F', 0,
    'U', 'l', 't', 'r', 'a', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'E', 'x', 't', 'r', 'a', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'S', 'e', 'm', 'i', 'C', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'N', 'o', 'F', 'o', 'n', 't', 'M', 'e', 'r', 'g', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'f', 'r', 'o', 'm', 'N', 'u', 'm', 'e', 'r', 'i', 'c', 'I', 'd', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'P', 'o', 's', 0,
    'l', 'a', 's', 't', 'S', 'c', 'r', 'e', 'e', 'n', 'P', 'o', 's', 0,
    's', 't', 'a', 'r', 't', 'S', 'c', 'e', 'n', 'e', 'P', 'o', 's', 0,
    's', 'e', 't', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 'e', 'd', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    't', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'r', 'a', 'g', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'o', 'w', 'n', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'o', 'w', 'n', 's', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    's', 'e', 't', 'F', 'o', 'c', 'a', 'l', 'P', 'o', 'i', 'n', 't', 0,
    'S', 'u', 'g', 'a', 'r', 'L', 'o', 'l', 'l', 'i', 'p', 'o', 'p', 0,
    'C', 'o', 'l', 'o', 'r', 'f', 'u', 'l', 'P', 'e', 'a', 'c', 'h', 0,
    'M', 'i', 'd', 'n', 'i', 'g', 'h', 't', 'B', 'l', 'o', 'o', 'm', 0,
    'H', 'a', 'p', 'p', 'y', 'M', 'e', 'm', 'o', 'r', 'i', 'e', 's', 0,
    'V', 'i', 'c', 'i', 'o', 'u', 's', 'S', 't', 'a', 'n', 'c', 'e', 0,
    'R', 'i', 's', 'k', 'y', 'C', 'o', 'n', 'c', 'r', 'e', 't', 'e', 0,
    'P', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'B', 'e', 'd', 0,
    'B', 'u', 'r', 'n', 'i', 'n', 'g', 'S', 'p', 'r', 'i', 'n', 'g', 0,
    'I', 't', 'm', 'e', 'o', 'B', 'r', 'a', 'n', 'd', 'i', 'n', 'g', 0,
    'S', 'h', 'a', 'r', 'p', 'e', 'y', 'e', 'E', 'a', 'g', 'l', 'e', 0,
    'T', 'e', 'm', 'p', 't', 'i', 'n', 'g', 'A', 'z', 'u', 'r', 'e', 0,
    'R', 'a', 'i', 'n', 'y', 'A', 's', 'h', 'v', 'i', 'l', 'l', 'e', 0,
    'R', 'e', 'f', 'l', 'e', 'c', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'p', 'a', 'l', 'e', 'v', 'i', 'o', 'l', 'e', 't', 'r', 'e', 'd', 0,
    'p', 'a', 'l', 'e', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'p', 'a', 'l', 'e', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 0,
    'l', 'i', 'g', 'h', 't', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'a', 'v', 'e', 'n', 'd', 'e', 'r', 'b', 'l', 'u', 's', 'h', 0,
    'd', 'a', 'r', 'k', 't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'g', 'r', 'e', 'y', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 's', 'l', 'a', 't', 'e', 'b', 'l', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 'g', 'o', 'l', 'd', 'e', 'n', 'r', 'o', 'd', 0,
    't', 'o', 'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'R', 'g', 'b', 0,
    'h', 's', 'l', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'h', 's', 'v', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 'B', 'a', 'c', 'k', 'i', 'n', 'g', 'S', 't', 'o', 'r', 'e', 0,
    'i', 'n', 't', 'r', 'i', 'n', 's', 'i', 'c', 'S', 'i', 'z', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'C', 'o', 'u', 'n', 't', 0,
    't', 'e', 'x', 't', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'A', 'l', 'i', 'g', 'n', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 0,
    'q', 'F', 'u', 'z', 'z', 'y', 'C', 'o', 'm', 'p', 'a', 'r', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'i', 'z', 'e', '>', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 's', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'i', 's', 'A', 'n', 'c', 'e', 's', 't', 'o', 'r', 'O', 'f', 0,
    'c', 'r', 'o', 's', 's', 'P', 'r', 'o', 'd', 'u', 'c', 't', 0,
    'I', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 't', 'e', 0,
    'i', 's', 'I', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', 0,
    'm', 'a', 'p', 'T', 'o', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 'S', 'q', 'u', 'a', 'r', 'e', 0,
    's', 'q', 'u', 'a', 'r', 'e', 'T', 'o', 'Q', 'u', 'a', 'd', 0,
    'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', 0,
    'R', 'a', 'w', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'D', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 'T', 'a', 'b', 0,
    'W', 'r', 'a', 'p', 'A', 'n', 'y', 'w', 'h', 'e', 'r', 'e', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'l', 'a', 's', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'b', 'l', 'o', 'c', 'k', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'l', 'e', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'a', 'c', 'h', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    't', 'e', 'x', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'b', 'o', 't', 't', 'o', 'm', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'T', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'r', 'i', 'g', 'h', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'S', 'u', 'f', 'f', 'i', 'x', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 'P', 'r', 'e', 'f', 'i', 'x', 0,
    'h', 'e', 'a', 'd', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    't', 'a', 'b', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'f', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'f', 'o', 'n', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    't', 'o', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'L', 'i', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'C', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'o', 'o', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'U', 's', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'I', 'm', 'a', 'g', 'e', 'A', 'l', 't', 'T', 'e', 'x', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'T', 'a', 'b', 'l', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'F', 'r', 'a', 'm', 'e', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'd', 'r', 'a', 'w', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'l', 'o', 'a', 'd', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'U', 's', 'e', 'r', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'H', 't', 'm', 'l', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'F', 'i', 'n', 'd', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    's', 'e', 't', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'e', 'n', 'd', 'E', 'd', 'i', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'a', 't', 'B', 'l', 'o', 'c', 'k', 'S', 't', 'a', 'r', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'T', 'e', 'x', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'd', 0,
    'm', 'o', 'v', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'C', 'e', 'l', 'l', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'B', 'l', 'o', 'c', 'k', 0,
    's', 'w', 'a', 'p', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'w', 'a', 'p', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'T', 'r', 'i', 'p', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'D', 'e', 'b', 'u', 'g', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'l', 'a', 's', 's', 0,
    'M', 'e', 't', 'a', 'l', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 0,
    's', 'o', 'r', 't', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    's', 'e', 't', 'C', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'S', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    's', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', 0,
    'a', 'n', 'g', 'l', 'e', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'q', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', 0,
    'l', 'o', 'a', 'd', 'F', 'r', 'o', 'm', 'F', 'i', 'l', 'e', 0,
    'm', 'a', 'x', 'C', 'h', 'a', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'p', 'a', 't', 'h', 'F', 'o', 'r', 'G', 'l', 'y', 'p', 'h', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 'C', 'a', 'c', 'h', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'D', 'e', 'p', 't', 'h', 0,
    'b', 'i', 't', 's', 'P', 'e', 'r', 'P', 'i', 'x', 'e', 'l', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'B', 'y', 't', 'e', 0,
    'I', 'g', 'n', 'o', 'r', 'e', 's', 'A', 'l', 'p', 'h', 'a', 0,
    'Q', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 'n', 'p', 'u', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'N', 'C', 'o', 'l', 'o', 'r', 'G', 'r', 'o', 'u', 'p', 's', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'S', 't', 'r', 'o', 'k', 'e', 0,
    's', 'e', 't', 'J', 'o', 'i', 'n', 'S', 't', 'y', 'l', 'e', 0,
    'e', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'S', 'u', 'b', 'p', 'a', 't', 'h', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 0,
    'C', 'o', 'r', 'e', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 0,
    'd', 'r', 'a', 'w', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', 0,
    'P', 'o', 'l', 'y', 'l', 'i', 'n', 'e', 'M', 'o', 'd', 'e', 0,
    'D', 'i', 'r', 't', 'y', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'P', 'a', 'i', 'n', 't', 'e', 'r', 'P', 'a', 't', 'h', 's', 0,
    'P', 'a', 't', 't', 'e', 'r', 'n', 'B', 'r', 'u', 's', 'h', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'P', 'd', 'm', 'N', 'u', 'm', 'C', 'o', 'l', 'o', 'r', 's', 0,
    'd', 'r', 'a', 'w', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'l', 'y', 'l', 'i', 'n', 'e', 0,
    'b', 'o', 't', 't', 'o', 'm', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'T', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'F', 'u', 'l', 'l', 'P', 'a', 'g', 'e', 'M', 'o', 'd', 'e', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'M', 'o', 'd', 'e', 0,
    'L', 'a', 's', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'Y', 'o', 'u', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '9', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '8', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '7', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '5', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'P', 'r', 'c', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '9', 'x', '1', '2', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '9', 'x', '1', '1', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '8', 'x', '1', '0', 0,
    'T', 'a', 'b', 'l', 'o', 'i', 'd', 'E', 'x', 't', 'r', 'a', 0,
    'p', 'a', 'i', 'n', 't', 'U', 'n', 'd', 'e', 'r', 'G', 'L', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'G', 'L', 0,
    'f', 'r', 'a', 'm', 'e', 'S', 'w', 'a', 'p', 'p', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'N', 'e', 'v', 'e', 'r', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'E', 'q', 'u', 'a', 'l', 0,
    'S', 'w', 'i', 'z', 'z', 'l', 'e', 'A', 'l', 'p', 'h', 'a', 0,
    'S', 'w', 'i', 'z', 'z', 'l', 'e', 'G', 'r', 'e', 'e', 'n', 0,
    'm', 'i', 'p', 'B', 'a', 's', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    'N', 'P', 'O', 'T', 'T', 'e', 'x', 't', 'u', 'r', 'e', 's', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'D', '2', '4', 'S', '8', 0,
    'U', 'I', 'n', 't', '3', '2', '_', 'R', 'G', 'B', 'A', '8', 0,
    'U', 'I', 'n', 't', '1', '6', '_', 'R', 'G', 'B', 'A', '4', 0,
    'B', 'G', 'R', 'A', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'R', 'G', 'B', 'A', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    's', 'e', 't', 'M', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'S', 'R', 'G', 'B', '8', '_', 'A', 'l', 'p', 'h', 'a', '8', 0,
    'R', 'G', 'B', 'A', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'R', 'o', 'w', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'A', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'F', 'l', 'i', 'p', 'p', 'e', 'd', 0,
    'N', 'o', 'A', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    's', 't', 'a', 'r', 't', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 0,
    'H', 'i', 'g', 'h', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'G', 'r', 'o', 'u', 'p', 'P', 'o', 'p', 'T', 'y', 'p', 'e', 0,
    'h', 'a', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    's', 'h', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'u', 's', 'a', 'g', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'V', 'e', 'r', 't', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    's', 'e', 't', 'C', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'l', 'i', 's', 't', 'T', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'F', 'i', 'n', 'd', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'H', 'e', 'l', 'p', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'P', 'a', 'r', 't', 'i', 'a', 'l', 'M', 'a', 't', 'c', 'h', 0,
    'P', 'o', 'r', 't', 'a', 'b', 'l', 'e', 'T', 'e', 'x', 't', 0,
    'i', 'n', 'v', 'o', 'k', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 'a', 'd', 'e', 'r', 0,
    's', 'm', 'o', 'o', 't', 'h', 'S', 'c', 'a', 'l', 'e', 'd', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'b', 'y', 't', 'e', 's', 'P', 'e', 'r', 'L', 'i', 'n', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '3', '0', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '3', '0', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '1', '6', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '3', '2', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'I', 'c', 'o', 'n', 'N', 'a', 'm', 'e', 'H', 'o', 'o', 'k', 0,
    's', 'e', 't', 'T', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    'h', 'a', 's', 'T', 'h', 'e', 'm', 'e', 'I', 'c', 'o', 'n', 0,
    'Q', 'I', 'c', 'o', 'n', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'p', 'l', 'a', 't', 'f', 'o', 'r', 'm', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'g', 'l', 'y', 'p', 'h', 'I', 'n', 'd', 'e', 'x', 'e', 's', 0,
    's', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 'P', 'o', 's', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'Q', 'F', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'i', 's', 'F', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'A', 'l', 'l', 'L', 'o', 'w', 'e', 'r', 'c', 'a', 's', 'e', 0,
    'A', 'l', 'l', 'U', 'p', 'p', 'e', 'r', 'c', 'a', 's', 'e', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'S', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    's', 'e', 't', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'S', 'e', 'm', 'i', 'E', 'x', 'p', 'a', 'n', 'd', 'e', 'd', 0,
    'S', 't', 'y', 'l', 'e', 'O', 'b', 'l', 'i', 'q', 'u', 'e', 0,
    'Q', 'F', 'o', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 0,
    'F', 'o', 'r', 'c', 'e', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'B', 'i', 't', 'm', 'a', 'p', 0,
    'Q', 'S', 'c', 'r', 'o', 'l', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 'i', 'z', 'e', 0,
    'Q', 'E', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 's', 't', 'S', 'c', 'e', 'n', 'e', 'P', 'o', 's', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'c', 'o', 'm', 'm', 'i', 't', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'Q', 'R', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'A', 'u', 't', 'o', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'h', 'i', 'R', 'e', 's', 'G', 'l', 'o', 'b', 'a', 'l', 'Y', 0,
    'h', 'i', 'R', 'e', 's', 'G', 'l', 'o', 'b', 'a', 'l', 'X', 0,
    'Q', 'T', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'c', 'e', 'n', 't', 'e', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'F', 'i', 'n', 'a', 'l', 'S', 't', 'o', 'p', 0,
    'F', 'a', 'b', 'l', 'e', 'd', 'S', 'u', 'n', 's', 'e', 't', 0,
    'S', 'w', 'e', 'e', 't', 'D', 'e', 's', 's', 'e', 'r', 't', 0,
    'M', 'o', 'r', 'n', 'i', 'n', 'g', 'S', 'a', 'l', 'a', 'd', 0,
    'P', 'e', 'r', 'f', 'e', 'c', 't', 'W', 'h', 'i', 't', 'e', 0,
    'S', 'a', 'l', 't', 'M', 'o', 'u', 'n', 't', 'a', 'i', 'n', 0,
    'S', 'o', 'f', 't', 'L', 'i', 'p', 's', 't', 'i', 'c', 'k', 0,
    'C', 'r', 'y', 's', 't', 'a', 'l', 'R', 'i', 'v', 'e', 'r', 0,
    'G', 'r', 'a', 's', 's', 'S', 'h', 'a', 'm', 'p', 'o', 'o', 0,
    'A', 'q', 'u', 'a', 'G', 'u', 'i', 'd', 'a', 'n', 'c', 'e', 0,
    'N', 'o', 'r', 't', 'h', 'M', 'i', 'r', 'a', 'c', 'l', 'e', 0,
    'A', 'f', 'r', 'i', 'c', 'a', 'n', 'F', 'i', 'e', 'l', 'd', 0,
    'H', 'a', 'p', 'p', 'y', 'U', 'n', 'i', 'c', 'o', 'r', 'n', 0,
    'H', 'i', 'd', 'd', 'e', 'n', 'J', 'a', 'g', 'u', 'a', 'r', 0,
    'N', 'e', 'w', 'R', 'e', 't', 'r', 'o', 'w', 'a', 'v', 'e', 0,
    'H', 'e', 'a', 'l', 't', 'h', 'y', 'W', 'a', 't', 'e', 'r', 0,
    'P', 'r', 'e', 'm', 'i', 'u', 'm', 'W', 'h', 'i', 't', 'e', 0,
    'A', 'l', 'c', 'h', 'e', 'm', 'i', 's', 't', 'L', 'a', 'b', 0,
    'F', 'a', 'r', 'a', 'w', 'a', 'y', 'R', 'i', 'v', 'e', 'r', 0,
    'P', 'h', 'o', 'e', 'n', 'i', 'x', 'S', 't', 'a', 'r', 't', 0,
    'M', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'R', 'o', 'c', 'k', 0,
    'R', 'e', 'd', 'S', 'a', 'l', 'v', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'o', 'l', 'i', 't', 'e', 'R', 'u', 'm', 'o', 'r', 's', 0,
    'T', 'e', 'e', 'n', 'N', 'o', 't', 'e', 'b', 'o', 'o', 'k', 0,
    'L', 'a', 'd', 'o', 'g', 'a', 'B', 'o', 't', 't', 'o', 'm', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'D', 'r', 'e', 'a', 'm', 's', 0,
    'S', 'u', 'n', 'n', 'y', 'M', 'o', 'r', 'n', 'i', 'n', 'g', 0,
    'Y', 'o', 'u', 'n', 'g', 'P', 'a', 's', 's', 'i', 'o', 'n', 0,
    'S', 'p', 'r', 'i', 'n', 'g', 'W', 'a', 'r', 'm', 't', 'h', 0,
    'R', 'e', 'p', 'e', 'a', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    'm', 'i', 'd', 'n', 'i', 'g', 'h', 't', 'b', 'l', 'u', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'p', 'u', 'r', 'p', 'l', 'e', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'o', 'r', 'c', 'h', 'i', 'd', 0,
    'l', 'i', 'g', 'h', 't', 's', 'k', 'y', 'b', 'l', 'u', 'e', 0,
    'l', 'e', 'm', 'o', 'n', 'c', 'h', 'i', 'f', 'f', 'o', 'n', 0,
    'd', 'a', 'r', 'k', 's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', 0,
    'a', 'n', 't', 'i', 'q', 'u', 'e', 'w', 'h', 'i', 't', 'e', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', ':', ':', 'S', 'p', 'e', 'c', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'l', 'o', 'a', 'd', 'F', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'm', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'm', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'Q', 'K', 'e', 'y', 'S', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 0,
    'h', 'a', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'L', 'i', 't', 't', 'l', 'e', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'c', 'o', 'n', 't', 'a', 'i', 'n', 's', '_', '_', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'c', 'a', 'n', 'F', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'd', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    's', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'u', 'n', 's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'm', 'a', 'p', 'T', 'o', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'S', 'i', 'z', 'e', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'M', 'o', 'd', 'a', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'N', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'e', 'c', 'i', 'm', 'a', 'l', 's', 0,
    'T', 'x', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'T', 'o', 'u', 'c', 'h', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'T', 'a', 'b', 'A', 'r', 'r', 'a', 'y', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'e', 't', 'R', 'e', 'v', 'i', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'f', 'r', 'a', 'm', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'b', 'e', 'g', 'i', 'n', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'r', 'i', 'g', 'h', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'l', 'e', 'f', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'c', 'e', 'l', 'l', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'c', 'e', 'l', 'l', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'B', 'r', 'u', 's', 'h', 0,
    'L', 'i', 's', 't', 'D', 'e', 'c', 'i', 'm', 'a', 'l', 0,
    'F', 'i', 'x', 'e', 'd', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'f', 'o', 'n', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'f', 'o', 'n', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'N', 'o', 'U', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    't', 'e', 'x', 't', 'O', 'u', 't', 'l', 'i', 'n', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'M', 'i', 'd', 'd', 'l', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'p', 'e', 'n', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'h', 'a', 's', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'B', 'l', 'o', 'c', 'k', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'T', 'e', 'x', 't', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    'F', 'r', 'a', 'm', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'F', 'r', 'a', 'm', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'F', 'r', 'a', 'm', 'e', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'B', 'l', 'o', 'c', 'k', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'T', 'a', 'b', 'l', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'I', 'm', 'a', 'g', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'F', 'i', 'x', 'e', 'd', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'A', 't', 0,
    'i', 'n', 'd', 'e', 'n', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'a', 'd', 'd', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'n', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'I', 'n', 'd', 'e', 'x', 0,
    't', 'o', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'U', 'r', 'l', 0,
    'b', 'l', 'o', 'c', 'k', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'i', 'n', 's', 'e', 'r', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'L', 'i', 's', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'b', 'l', 'o', 'c', 'k', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'R', 'o', 'w', 0,
    'Q', 'T', 'e', 'x', 't', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'r', 'e', 'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'C', 'o', 'r', 'e', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'Q', 'S', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 's', 0,
    'Q', 'S', 't', 'a', 't', 'i', 'c', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    's', 'e', 't', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'i', 's', 'C', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'R', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'R', 'a', 't', 'e', 0,
    'i', 's', 'L', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'm', 'a', 'g', 'e', 'n', 't', 'a', 'S', 'i', 'z', 'e', 0,
    'A', 't', 'B', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 0,
    's', 'e', 't', 'I', 'O', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 'T', 'e', 'x', 't', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 'B', 'a', 's', 'e', 0,
    'l', 'i', 'n', 'k', 'V', 'i', 's', 'i', 't', 'e', 'd', 0,
    'N', 'C', 'o', 'l', 'o', 'r', 'R', 'o', 'l', 'e', 's', 0,
    'T', 'o', 'o', 'l', 'T', 'i', 'p', 'T', 'e', 'x', 't', 0,
    'T', 'o', 'o', 'l', 'T', 'i', 'p', 'B', 'a', 's', 'e', 0,
    'L', 'i', 'n', 'k', 'V', 'i', 's', 'i', 't', 'e', 'd', 0,
    'd', 'a', 's', 'h', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'C', 'a', 'p', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'F', 'i', 'l', 'l', 'R', 'u', 'l', 'e', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'P', 'a', 't', 'h', 0,
    'P', 'a', 'i', 'n', 't', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'W', 'i', 'n', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'O', 'd', 'd', 'E', 'v', 'e', 'n', 'M', 'o', 'd', 'e', 0,
    'A', 'l', 'l', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'M', 'a', 's', 'k', 'e', 'd', 'B', 'r', 'u', 's', 'h', 0,
    'B', 'r', 'u', 's', 'h', 'S', 't', 'r', 'o', 'k', 'e', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'F', 'l', 'a', 'g', 's', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'Y', 0,
    'l', 'o', 'g', 'i', 'c', 'a', 'l', 'D', 'p', 'i', 'X', 0,
    'P', 'd', 'm', 'H', 'e', 'i', 'g', 'h', 't', 'M', 'M', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'H', 'i', 'n', 't', 's', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'c', 't', 'u', 'r', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'd', 'r', 'a', 'w', 'E', 'l', 'l', 'i', 'p', 's', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'h', 'a', 's', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    'b', 'r', 'u', 's', 'h', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'f', 'o', 'n', 't', 'M', 'e', 't', 'r', 'i', 'c', 's', 0,
    'm', 'a', 't', 'c', 'h', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'r', 'i', 'g', 'h', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '6', '5', 0,
    'I', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '7', 'x', '9', 0,
    'L', 'e', 't', 't', 'e', 'r', 'S', 'm', 'a', 'l', 'l', 0,
    'L', 'e', 't', 't', 'e', 'r', 'E', 'x', 't', 'r', 'a', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'O', 'v', 'e', 'r', 'G', 'L', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'N', 'o', 'n', 'e', 0,
    'C', 'o', 'm', 'p', 'a', 'r', 'e', 'L', 'e', 's', 's', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'C', 'l', 'a', 'm', 'p', 'T', 'o', 'E', 'd', 'g', 'e', 0,
    's', 'w', 'i', 'z', 'z', 'l', 'e', 'M', 'a', 's', 'k', 0,
    'S', 'w', 'i', 'z', 'z', 'l', 'e', 'B', 'l', 'u', 'e', 0,
    'm', 'i', 'p', 'M', 'a', 'x', 'L', 'e', 'v', 'e', 'l', 0,
    'U', 'I', 'n', 't', '8', '_', 'R', 'G', '3', 'B', '2', 0,
    'N', 'o', 'P', 'i', 'x', 'e', 'l', 'T', 'y', 'p', 'e', 0,
    'B', 'G', 'R', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'R', 'G', 'B', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'R', 'e', 'd', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'D', 'e', 'p', 't', 'h', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'G', 'B', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', 'A', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'i', 'm', 'a', 'g', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'S', 'k', 'i', 'p', 'R', 'o', 'w', 's', 0,
    't', 'a', 'k', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'b', 'i', 'n', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    's', 't', 'o', 'p', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 0,
    'l', 'o', 'g', 'g', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'A', 'n', 'y', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'L', 'o', 'w', 'S', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'T', 'y', 'p', 'e', 0,
    'O', 't', 'h', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'h', 'a', 's', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 's', 0,
    's', 'w', 'a', 'p', 'B', 'u', 'f', 'f', 'e', 'r', 's', 0,
    'd', 'o', 'n', 'e', 'C', 'u', 'r', 'r', 'e', 'n', 't', 0,
    'm', 'a', 'k', 'e', 'C', 'u', 'r', 'r', 'e', 'n', 't', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'C', 'o', 'p', 'y', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'R', 'e', 'a', 'd', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'D', 'r', 'a', 'w', 0,
    'I', 'n', 'd', 'e', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'F', 'r', 'a', 'm', 'e', 0,
    '_', '_', 'i', 'm', 'a', 't', 'm', 'u', 'l', '_', '_', 0,
    'p', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 0,
    'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', 0,
    'k', 'e', 'y', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 's', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', 0,
    'i', 's', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', 0,
    'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 0,
    'i', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'j', 'u', 'm', 'p', 'T', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'i', 'z', 'e', 'I', 'n', 'B', 'y', 't', 'e', 's', 0,
    'p', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'i', 's', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'M', 'o', 'n', 'o', 0,
    'Q', 'I', 'c', 'o', 'n', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'I', 'c', 'o', 'n', ':', ':', 'M', 'o', 'd', 'e', 0,
    'f', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'm', 'o', 'd', 'a', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'A', 'd', 'd', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'f', 'o', 'c', 'u', 's', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'o', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 'P', 'o', 's', 0,
    'l', 'e', 'f', 't', 'B', 'e', 'a', 'r', 'i', 'n', 'g', 0,
    'l', 'i', 'n', 'e', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'G', 'e', 'n', 'e', 'r', 'a', 'l', 'F', 'o', 'n', 't', 0,
    's', 't', 'y', 'l', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'm', 'o', 'o', 't', 'h', 'S', 'i', 'z', 'e', 's', 0,
    's', 'e', 't', 'F', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'w', 'o', 'r', 'd', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 's', 0,
    's', 'e', 't', 'O', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'U', 'n', 's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'd', 0,
    'S', 't', 'y', 'l', 'e', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'S', 't', 'y', 'l', 'e', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'N', 'o', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'M', 'a', 't', 'c', 'h', 0,
    'g', 'e', 's', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    's', 'c', 'r', 'o', 'l', 'l', 'S', 't', 'a', 't', 'e', 0,
    't', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 's', 0,
    'Q', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'A', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 0,
    'Q', 'C', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'F', 'o', 'c', 'u', 's', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'o', 'i', 'n', 't', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'X', 'F', 'r', 'e', 'e', 'E', 'r', 'a', 's', 'e', 'r', 0,
    'Q', 'W', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'H', 'o', 'v', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'I', 'n', 'p', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'P', 'r', 'o', 'P', 'h', 'o', 't', 'o', 'R', 'g', 'b', 0,
    's', 'e', 't', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'f', 'o', 'c', 'a', 'l', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'P', 'e', 'r', 'f', 'e', 'c', 't', 'B', 'l', 'u', 'e', 0,
    'G', 'a', 'g', 'a', 'r', 'i', 'n', 'V', 'i', 'e', 'w', 0,
    'N', 'o', 'r', 's', 'e', 'B', 'e', 'a', 'u', 't', 'y', 0,
    'S', 'm', 'a', 'r', 't', 'I', 'n', 'd', 'i', 'g', 'o', 0,
    'R', 'o', 'y', 'a', 'l', 'G', 'a', 'r', 'd', 'e', 'n', 0,
    'O', 'r', 'a', 'n', 'g', 'e', 'J', 'u', 'i', 'c', 'e', 0,
    'A', 'b', 'o', 'v', 'e', 'T', 'h', 'e', 'S', 'k', 'y', 0,
    'F', 'l', 'y', 'i', 'n', 'g', 'L', 'e', 'm', 'o', 'n', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'B', 'e', 'r', 'r', 'y', 0,
    'C', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 'n', 'e', 0,
    'S', 't', 'r', 'o', 'n', 'g', 'S', 't', 'i', 'c', 'k', 0,
    'C', 'l', 'o', 'u', 'd', 'y', 'A', 'p', 'p', 'l', 'e', 0,
    'S', 'm', 'i', 'l', 'i', 'n', 'g', 'R', 'a', 'i', 'n', 0,
    'S', 'u', 'm', 'm', 'e', 'r', 'G', 'a', 'm', 'e', 's', 0,
    'C', 'o', 'c', 'h', 'i', 't', 'i', 'L', 'a', 'k', 'e', 0,
    'C', 'o', 'l', 'd', 'E', 'v', 'e', 'n', 'i', 'n', 'g', 0,
    'P', 'r', 'e', 'm', 'i', 'u', 'm', 'D', 'a', 'r', 'k', 0,
    'C', 'l', 'e', 'a', 'n', 'M', 'i', 'r', 'r', 'o', 'r', 0,
    'H', 'e', 'a', 'v', 'e', 'n', 'P', 'e', 'a', 'c', 'h', 0,
    'S', 'o', 'f', 't', 'C', 'h', 'e', 'r', 'i', 's', 'h', 0,
    'S', 'w', 'e', 'e', 't', 'P', 'e', 'r', 'i', 'o', 'd', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'e', 'a', 'u', 't', 'y', 0,
    'F', 'e', 'b', 'r', 'u', 'a', 'r', 'y', 'I', 'n', 'k', 0,
    'S', 't', 'r', 'o', 'n', 'g', 'B', 'l', 'i', 's', 's', 0,
    'A', 'w', 'e', 's', 'o', 'm', 'e', 'P', 'i', 'n', 'e', 0,
    'Z', 'e', 'u', 's', 'M', 'i', 'r', 'a', 'c', 'l', 'e', 0,
    'H', 'a', 'p', 'p', 'y', 'F', 'i', 's', 'h', 'e', 'r', 0,
    'M', 'o', 'r', 'p', 'h', 'e', 'u', 's', 'D', 'e', 'n', 0,
    'M', 'a', 'l', 'i', 'b', 'u', 'B', 'e', 'a', 'c', 'h', 0,
    'R', 'i', 'p', 'e', 'M', 'a', 'l', 'i', 'n', 'k', 'a', 0,
    'L', 'o', 'g', 'i', 'c', 'a', 'l', 'M', 'o', 'd', 'e', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'g', 'r', 'e', 'e', 'n', 0,
    's', 'a', 'd', 'd', 'l', 'e', 'b', 'r', 'o', 'w', 'n', 0,
    'n', 'a', 'v', 'a', 'j', 'o', 'w', 'h', 'i', 't', 'e', 0,
    'l', 'i', 'g', 'h', 't', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'l', 'i', 'g', 'h', 't', 's', 'a', 'l', 'm', 'o', 'n', 0,
    'g', 'r', 'e', 'e', 'n', 'y', 'e', 'l', 'l', 'o', 'w', 0,
    'f', 'o', 'r', 'e', 's', 't', 'g', 'r', 'e', 'e', 'n', 0,
    'f', 'l', 'o', 'r', 'a', 'l', 'w', 'h', 'i', 't', 'e', 0,
    'd', 'e', 'e', 'p', 's', 'k', 'y', 'b', 'l', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 'm', 'a', 'g', 'e', 'n', 't', 'a', 0,
    'D', 'a', 'r', 'k', 'M', 'a', 'g', 'e', 'n', 't', 'a', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'B', 'l', 'o', 'c', 'k', 0,
    'p', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'o', 'r', 't', 'R', 'o', 'l', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'Q', 'Q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    '_', '_', 'd', 'e', 'l', 'i', 't', 'e', 'm', '_', '_', 0,
    '_', '_', 's', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'e', 'd', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'C', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'l', 'a', 's', 't', 'I', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    'd', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'h', 'a', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'S', 't', 'a', 't', 'e', 0,
    'D', 'a', 's', 'h', 'D', 'o', 't', 'L', 'i', 'n', 'e', 0,
    'A', 'l', 'i', 'g', 'n', 'B', 'o', 't', 't', 'o', 'm', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'G', 'u', 'i', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 0,
    't', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    's', 'h', 'o', 'w', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'i', 's', 'T', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 0,
    'A', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e', 0,
    'Q', 'V', 'a', 'l', 'i', 'd', 'a', 't', 'o', 'r', 0,
    'i', 's', 'R', 'o', 't', 'a', 't', 'i', 'n', 'g', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 'Q', 'u', 'a', 'd', 0,
    'm', 'e', 'r', 'g', 'e', 'C', 'e', 'l', 'l', 's', 0,
    'Q', 'T', 'e', 'x', 't', 'T', 'a', 'b', 'l', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'S', 'p', 'a', 'n', 0,
    's', 'e', 't', 'T', 'a', 'b', 'S', 't', 'o', 'p', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 'W', 'r', 'a', 'p', 0,
    'Q', 'T', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'Q', 'T', 'e', 'x', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 't', 'e', 'm', 0,
    'i', 't', 'e', 'm', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    't', 'e', 'x', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'd', 'r', 'a', 'w', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'L', 'i', 'n', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'e', 'n', 't', 0,
    'l', 'e', 'f', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    't', 'o', 'p', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'P', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    'F', 'l', 'o', 'a', 't', 'R', 'i', 'g', 'h', 't', 0,
    'L', 'i', 's', 't', 'S', 'q', 'u', 'a', 'r', 'e', 0,
    'L', 'i', 's', 't', 'C', 'i', 'r', 'c', 'l', 'e', 0,
    'l', 'i', 'n', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    't', 'e', 'x', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'H', 'r', 'e', 'f', 0,
    'f', 'o', 'n', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    'f', 'o', 'n', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'f', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    'I', 'm', 'a', 'g', 'e', 'T', 'i', 't', 'l', 'e', 0,
    'I', 'm', 'a', 'g', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'F', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'L', 'i', 's', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    'A', 'n', 'c', 'h', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'O', 'u', 't', 'l', 'i', 'n', 'e', 'P', 'e', 'n', 0,
    'U', 's', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'U', 's', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'o', 'M', 'a', 'r', 'k', 'd', 'o', 'w', 'n', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'U', 'r', 'l', 0,
    'f', 'i', 'r', 's', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'b', 'l', 'o', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'a', 'd', 'j', 'u', 's', 't', 'S', 'i', 'z', 'e', 0,
    'i', 'd', 'e', 'a', 'l', 'W', 'i', 'd', 't', 'h', 0,
    'a', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'i', 's', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'H', 't', 'm', 'l', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'L', 'i', 's', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'L', 'i', 's', 't', 0,
    'a', 't', 'B', 'l', 'o', 'c', 'k', 'E', 'n', 'd', 0,
    'c', 'h', 'a', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'C', 'h', 'a', 'r', 0,
    'i', 'n', 's', 'e', 'r', 't', 'T', 'e', 'x', 't', 0,
    'K', 'e', 'e', 'p', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'M', 'o', 'v', 'e', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    't', 'e', 's', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'e', 'x', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'e', 'x', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'R', 'o', 'w', 's', 0,
    's', 'e', 't', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    'i', 's', 'T', 'r', 'i', 's', 't', 'a', 't', 'e', 0,
    'i', 's', 'E', 'd', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'c', 'h', 'e', 'c', 'k', 'S', 't', 'a', 't', 'e', 0,
    't', 'a', 'k', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'g', 'r', 'a', 'b', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'i', 's', 'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 0,
    'm', 'a', 'p', 'B', 'e', 't', 'w', 'e', 'e', 'n', 0,
    'f', 'r', 'o', 'm', 'A', 'r', 'g', 'b', '3', '2', 0,
    'u', 'n', 'i', 't', 's', 'P', 'e', 'r', 'E', 'm', 0,
    'f', 'a', 'm', 'i', 'l', 'y', 'N', 'a', 'm', 'e', 0,
    'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'T', 'o', 0,
    't', 'o', 'V', 'e', 'c', 't', 'o', 'r', '4', 'D', 0,
    'c', 'a', 'c', 'h', 'e', 'L', 'i', 'm', 'i', 't', 0,
    'a', 'l', 'p', 'h', 'a', 'U', 's', 'a', 'g', 'e', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'e', 't', 'P', 'i', 'c', 't', 'u', 'r', 'e', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    'Q', 'P', 'i', 'c', 't', 'u', 'r', 'e', 'I', 'O', 0,
    'i', 's', 'C', 'o', 's', 'm', 'e', 't', 'i', 'c', 0,
    'p', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'Q', 'P', 'd', 'f', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'i', 's', 'B', 'r', 'u', 's', 'h', 'S', 'e', 't', 0,
    'b', 'u', 't', 't', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'T', 'e', 'x', 't', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'T', 'e', 'x', 't', 0,
    'B', 'u', 't', 't', 'o', 'n', 'T', 'e', 'x', 't', 0,
    'B', 'r', 'i', 'g', 'h', 't', 'T', 'e', 'x', 't', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'T', 'e', 'x', 't', 0,
    'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'd', 'a', 's', 'h', 'O', 'f', 'f', 's', 'e', 't', 0,
    'm', 'i', 't', 'e', 'r', 'L', 'i', 'm', 'i', 't', 0,
    's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'e', 'd', 0,
    't', 'o', 'R', 'e', 'v', 'e', 'r', 's', 'e', 'd', 0,
    'a', 'd', 'd', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'a', 'd', 'd', 'E', 'l', 'l', 'i', 'p', 's', 'e', 0,
    'P', 'o', 's', 't', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'M', 'a', 'c', 'P', 'r', 'i', 'n', 't', 'e', 'r', 0,
    'C', 'o', 'n', 'v', 'e', 'x', 'M', 'o', 'd', 'e', 0,
    'D', 'i', 'r', 't', 'y', 'H', 'i', 'n', 't', 's', 0,
    'D', 'i', 'r', 't', 'y', 'B', 'r', 'u', 's', 'h', 0,
    'B', 'l', 'e', 'n', 'd', 'M', 'o', 'd', 'e', 's', 0,
    'P', 'o', 'r', 't', 'e', 'r', 'D', 'u', 'f', 'f', 0,
    'A', 'l', 'p', 'h', 'a', 'B', 'l', 'e', 'n', 'd', 0,
    'P', 'd', 'm', 'W', 'i', 'd', 't', 'h', 'M', 'M', 0,
    'O', 'p', 'a', 'q', 'u', 'e', 'H', 'i', 'n', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'L', 'e', 'f', 't', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 't', 'r', 'o', 'k', 'e', 'P', 'a', 't', 'h', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 0,
    'r', 'e', 'c', 't', 'P', 'i', 'x', 'e', 'l', 's', 0,
    'r', 'e', 'c', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    's', 'i', 'z', 'e', 'P', 'i', 'x', 'e', 'l', 's', 0,
    's', 'i', 'z', 'e', 'P', 'o', 'i', 'n', 't', 's', 0,
    'F', 'u', 'z', 'z', 'y', 'M', 'a', 't', 'c', 'h', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'l', 'e', 'f', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'm', 'i', 'n', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'M', 'i', 'l', 'l', 'i', 'm', 'e', 't', 'e', 'r', 0,
    'p', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'p', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 'M', 'M', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '0', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'D', 'L', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '5', 0,
    'N', 'P', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '1', '1', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '7', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '4', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '3', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '2', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '1', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'C', '0', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '6', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '5', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'B', '4', 0,
    'L', 'e', 't', 't', 'e', 'r', 'P', 'l', 'u', 's', 0,
    'L', 'e', 'g', 'a', 'l', 'E', 'x', 't', 'r', 'a', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'R', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'T', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'S', 0,
    'A', 'l', 'p', 'h', 'a', 'V', 'a', 'l', 'u', 'e', 0,
    'G', 'r', 'e', 'e', 'n', 'V', 'a', 'l', 'u', 'e', 0,
    'S', 'w', 'i', 'z', 'z', 'l', 'e', 'R', 'e', 'd', 0,
    'h', 'a', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'F', 'l', 'o', 'a', 't', '1', '6', 'O', 'E', 'S', 0,
    'R', 'G', '_', 'I', 'n', 't', 'e', 'g', 'e', 'r', 0,
    'S', 'R', 'G', 'B', '8', '_', 'E', 'T', 'C', '2', 0,
    'R', 'G', 'B', 'A', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'R', 'G', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', 'B', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'g', 'e', 'n', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    'i', 's', 'C', 'o', 'm', 'p', 'i', 'l', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'C', 'o', 'd', 'e', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'k', 'i', 'p', 'P', 'i', 'x', 'e', 'l', 's', 0,
    's', 'k', 'i', 'p', 'I', 'm', 'a', 'g', 'e', 's', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 's', 0,
    'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 0,
    'l', 'o', 'g', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    's', 'e', 'v', 'e', 'r', 'i', 't', 'i', 'e', 's', 0,
    's', 'e', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'i', 's', 'O', 'p', 'e', 'n', 'G', 'L', 'E', 'S', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'a', 'r', 'e', 'S', 'h', 'a', 'r', 'i', 'n', 'g', 0,
    's', 'h', 'a', 'r', 'e', 'G', 'r', 'o', 'u', 'p', 0,
    'R', 'a', 'n', 'g', 'e', 'W', 'r', 'i', 't', 'e', 0,
    'S', 't', 'a', 't', 'i', 'c', 'C', 'o', 'p', 'y', 0,
    'S', 't', 'a', 't', 'i', 'c', 'R', 'e', 'a', 'd', 0,
    'S', 't', 'a', 't', 'i', 'c', 'D', 'r', 'a', 'w', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'C', 'o', 'p', 'y', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'R', 'e', 'a', 'd', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'D', 'r', 'a', 'w', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'o', 'u', 'n', 't', 0,
    '_', '_', 'm', 'a', 't', 'm', 'u', 'l', '_', '_', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'K', 'e', 'y', 0,
    'E', 'x', 'a', 'c', 't', 'M', 'a', 't', 'c', 'h', 0,
    'N', 'a', 't', 'i', 'v', 'e', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'S', 'u', 'b', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    's', 'c', 'a', 'l', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'E', 'n', 'd', 'i', 'a', 'n', 'n', 'e', 's', 's', 0,
    'p', 'i', 'x', 'e', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'o', 'u', 'n', 't', 0,
    't', 'r', 'u', 'e', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'r', 'g', 'b', 'S', 'w', 'a', 'p', 'p', 'e', 'd', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 0,
    'p', 'i', 'x', 'e', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    'I', 'n', 'v', 'e', 'r', 't', 'R', 'g', 'b', 'a', 0,
    'I', 's', 'N', 'u', 'l', 'l', 'H', 'o', 'o', 'k', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'I', 'c', 'o', 'n', 0,
    's', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'P', 'a', 'l', 'e', 't', 't', 'e', 0,
    't', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 'A', 't', 0,
    'a', 'l', 'l', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    's', 'e', 't', 'R', 'a', 'w', 'F', 'o', 'n', 't', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '2', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '3', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '2', 'x', '4', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '2', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '3', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '3', 'x', '4', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '2', 0,
    'i', 's', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    'c', 'o', 'p', 'y', 'D', 'a', 't', 'a', 'T', 'o', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '3', 0,
    'i', 'n', 'F', 'o', 'n', 't', 'U', 'c', 's', '4', 0,
    'e', 'l', 'i', 'd', 'e', 'd', 'T', 'e', 'x', 't', 0,
    's', 'y', 's', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    'i', 's', 'S', 'c', 'a', 'l', 'a', 'b', 'l', 'e', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 's', 0,
    'D', 'e', 'v', 'a', 'n', 'a', 'g', 'a', 'r', 'i', 0,
    'C', 'a', 'p', 'i', 't', 'a', 'l', 'i', 'z', 'e', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 0,
    's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 0,
    's', 'e', 't', 'R', 'a', 'w', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'R', 'a', 'w', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    's', 'e', 't', 'K', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    'f', 'i', 'x', 'e', 'd', 'P', 'i', 't', 'c', 'h', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 'F', 0,
    'A', 'n', 'y', 'S', 't', 'r', 'e', 't', 'c', 'h', 0,
    'E', 'x', 't', 'r', 'a', 'L', 'i', 'g', 'h', 't', 0,
    'D', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'v', 'e', 0,
    'O', 'l', 'd', 'E', 'n', 'g', 'l', 'i', 's', 'h', 0,
    'T', 'y', 'p', 'e', 'W', 'r', 'i', 't', 'e', 'r', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'P', 'o', 's', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'R', 'e', 'c', 't', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 'I', 'd', 0,
    'Q', 'H', 'e', 'l', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'a', 'n', 's', 'w', 'e', 'r', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'H', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'F', 'o', 'u', 'r', 'D', 'M', 'o', 'u', 's', 'e', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'o', 's', 'F', 0,
    'a', 'n', 'g', 'l', 'e', 'D', 'e', 'l', 't', 'a', 0,
    'p', 'i', 'x', 'e', 'l', 'D', 'e', 'l', 't', 'a', 0,
    'd', 'r', 'a', 'g', 'C', 'u', 'r', 's', 'o', 'r', 0,
    's', 'e', 't', 'H', 'o', 't', 'S', 'p', 'o', 't', 0,
    'i', 'c', 'c', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'S', 'R', 'g', 'b', 'L', 'i', 'n', 'e', 'a', 'r', 0,
    'Q', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'f', 'o', 'c', 'a', 'l', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'A', 't', 0,
    'N', 'u', 'm', 'P', 'r', 'e', 's', 'e', 't', 's', 0,
    'F', 'r', 'o', 'z', 'e', 'n', 'H', 'e', 'a', 't', 0,
    'L', 'i', 'l', 'y', 'M', 'e', 'a', 'd', 'o', 'w', 0,
    'S', 'u', 'p', 'r', 'e', 'm', 'e', 'S', 'k', 'y', 0,
    'D', 'e', 'e', 'p', 'R', 'e', 'l', 'i', 'e', 'f', 0,
    'F', 'r', 'e', 's', 'h', 'O', 'a', 's', 'i', 's', 0,
    'W', 'i', 't', 'c', 'h', 'D', 'a', 'n', 'c', 'e', 0,
    'S', 'a', 'n', 'd', 'S', 't', 'r', 'i', 'k', 'e', 0,
    'F', 'o', 'r', 'e', 's', 't', 'I', 'n', 'e', 'i', 0,
    'S', 'p', 'a', 'c', 'e', 'S', 'h', 'i', 'f', 't', 0,
    'H', 'i', 'g', 'h', 'F', 'l', 'i', 'g', 'h', 't', 0,
    'F', 'r', 'u', 'i', 't', 'B', 'l', 'e', 'n', 'd', 0,
    'G', 'l', 'a', 's', 's', 'W', 'a', 't', 'e', 'r', 0,
    'S', 'o', 'l', 'i', 'd', 'S', 't', 'o', 'n', 'e', 0,
    'G', 'e', 'n', 't', 'l', 'e', 'C', 'a', 'r', 'e', 0,
    'Y', 'o', 'u', 'n', 'g', 'G', 'r', 'a', 's', 's', 0,
    'M', 'a', 'r', 'b', 'l', 'e', 'W', 'a', 'l', 'l', 0,
    'D', 'e', 'n', 's', 'e', 'W', 'a', 't', 'e', 'r', 0,
    'L', 'e', 'C', 'o', 'c', 'k', 't', 'a', 'i', 'l', 0,
    'P', 'a', 'r', 't', 'y', 'B', 'l', 'i', 's', 's', 0,
    'A', 'm', 'o', 'u', 'r', 'A', 'm', 'o', 'u', 'r', 0,
    'J', 'a', 'p', 'a', 'n', 'B', 'l', 'u', 's', 'h', 0,
    'D', 'e', 's', 'e', 'r', 't', 'H', 'u', 'm', 'p', 0,
    'A', 'q', 'u', 'a', 'S', 'p', 'l', 'a', 's', 'h', 0,
    'N', 'i', 'g', 'h', 't', 'P', 'a', 'r', 't', 'y', 0,
    'W', 'i', 'd', 'e', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'G', 'r', 'e', 'a', 't', 'W', 'h', 'a', 'l', 'e', 0,
    'S', 'h', 'a', 'd', 'y', 'W', 'a', 't', 'e', 'r', 0,
    'S', 'h', 'a', 'r', 'p', 'B', 'l', 'u', 'e', 's', 0,
    'G', 'r', 'o', 'w', 'n', 'E', 'a', 'r', 'l', 'y', 0,
    'M', 'i', 'x', 'e', 'd', 'H', 'o', 'p', 'e', 's', 0,
    'S', 'h', 'y', 'R', 'a', 'i', 'n', 'b', 'o', 'w', 0,
    'T', 'r', 'u', 'e', 'S', 'u', 'n', 's', 'e', 't', 0,
    'D', 'u', 's', 't', 'y', 'G', 'r', 'a', 's', 's', 0,
    'W', 'i', 'n', 't', 'e', 'r', 'N', 'e', 'v', 'a', 0,
    'J', 'u', 'i', 'c', 'y', 'P', 'e', 'a', 'c', 'h', 0,
    'N', 'o', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'O', 'b', 'j', 'e', 'c', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'w', 'h', 'i', 't', 'e', 's', 'm', 'o', 'k', 'e', 0,
    's', 'a', 'n', 'd', 'y', 'b', 'r', 'o', 'w', 'n', 0,
    'p', 'o', 'w', 'd', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'p', 'a', 'p', 'a', 'y', 'a', 'w', 'h', 'i', 'p', 0,
    'm', 'e', 'd', 'i', 'u', 'm', 'b', 'l', 'u', 'e', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'c', 'o', 'r', 'a', 'l', 0,
    'g', 'h', 'o', 's', 't', 'w', 'h', 'i', 't', 'e', 0,
    'd', 'o', 'd', 'g', 'e', 'r', 'b', 'l', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 'v', 'i', 'o', 'l', 'e', 't', 0,
    'd', 'a', 'r', 'k', 's', 'a', 'l', 'm', 'o', 'n', 0,
    'd', 'a', 'r', 'k', 'o', 'r', 'c', 'h', 'i', 'd', 0,
    'd', 'a', 'r', 'k', 'o', 'r', 'a', 'n', 'g', 'e', 0,
    'c', 'h', 'a', 'r', 't', 'r', 'e', 'u', 's', 'e', 0,
    'b', 'l', 'u', 'e', 'v', 'i', 'o', 'l', 'e', 't', 0,
    'D', 'a', 'r', 'k', 'Y', 'e', 'l', 'l', 'o', 'w', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'a', '6', '4', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'F', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'l', 'o', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'P', 'a', 'i', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'l', 'i', 'n', 'e', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'e', 'x', 'a', 'c', 't', 'M', 'a', 't', 'c', 'h', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'N', 'o', 't', 'R', 'u', 'n', 'n', 'i', 'n', 'g', 0,
    't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'e', 'd', 0,
    'd', 'o', 't', 'P', 'r', 'o', 'd', 'u', 'c', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'M', 'a', 't', 'r', 'i', 'x', '4', 'x', '4', 0,
    'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'V', 'i', 'e', 't', 'n', 'a', 'm', 'e', 's', 'e', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', 0,
    'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 's', 0,
    'f', 'r', 'o', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    's', 'e', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', 0,
    '_', '_', 'r', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'i', 's', 'D', 'e', 't', 'a', 'c', 'h', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'f', 'r', 'o', 'm', 'W', 'i', 'n', 'I', 'd', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'E', 'x', 'p', 'o', 's', 'e', 'd', 0,
    'u', 'n', 'p', 'r', 'o', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'R', 'e', 'g', 'E', 'x', 'p', 0,
    'f', 'r', 'o', 'm', 'S', 'c', 'a', 'l', 'e', 0,
    'i', 's', 'S', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    's', 'e', 't', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'T', 'x', 'P', 'r', 'o', 'j', 'e', 'c', 't', 0,
    's', 'p', 'l', 'i', 't', 'C', 'e', 'l', 'l', 0,
    'd', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 0,
    'C', 'e', 'n', 't', 'e', 'r', 'T', 'a', 'b', 0,
    'u', 's', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'b', 'l', 'o', 'c', 'k', 'L', 'i', 's', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 's', 't', 0,
    't', 'e', 'x', 't', 'S', 't', 'a', 'r', 't', 0,
    'x', 'T', 'o', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'T', 'o', 'X', 0,
    'Q', 'T', 'e', 'x', 't', 'L', 'i', 'n', 'e', 0,
    'g', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 's', 0,
    'S', 'k', 'i', 'p', 'W', 'o', 'r', 'd', 's', 0,
    'e', 'n', 'd', 'L', 'a', 'y', 'o', 'u', 't', 0,
    's', 'e', 't', 'A', 's', 'c', 'e', 'n', 't', 0,
    't', 'o', 'p', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 0,
    'F', 'l', 'o', 'a', 't', 'L', 'e', 'f', 't', 0,
    's', 'e', 't', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'I', 'm', 'a', 'g', 'e', 'N', 'a', 'm', 'e', 0,
    'L', 'i', 's', 't', 'S', 't', 'y', 'l', 'e', 0,
    't', 'o', 'R', 'a', 'w', 'T', 'e', 'x', 't', 0,
    'R', 'e', 'd', 'o', 'S', 't', 'a', 'c', 'k', 0,
    'U', 'n', 'd', 'o', 'S', 't', 'a', 'c', 'k', 0,
    'l', 'a', 's', 't', 'B', 'l', 'o', 'c', 'k', 0,
    'f', 'i', 'n', 'd', 'B', 'l', 'o', 'c', 'k', 0,
    'r', 'o', 'o', 't', 'F', 'r', 'a', 'm', 'e', 0,
    'W', 'o', 'r', 'd', 'R', 'i', 'g', 'h', 't', 0,
    'N', 'e', 'x', 't', 'B', 'l', 'o', 'c', 'k', 0,
    's', 'e', 't', 'S', 't', 'e', 'r', 'e', 'o', 0,
    'N', 'o', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'O', 'f', 'f', 's', 'c', 'r', 'e', 'e', 'n', 0,
    't', 'e', 'x', 't', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'l', 'e', 'a', 'r', 'D', 'a', 't', 'a', 0,
    't', 'a', 'k', 'e', 'C', 'h', 'i', 'l', 'd', 0,
    'w', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    's', 't', 'a', 't', 'u', 's', 'T', 'i', 'p', 0,
    'f', 'i', 'n', 'd', 'I', 't', 'e', 'm', 's', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'R', 'o', 'w', 0,
    'f', 'o', 'n', 't', 'T', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'V', 'e', 'c', 't', 'o', 'r', 0,
    'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'a', 'r', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 0,
    't', 'o', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'p', 'u', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'i', 's', 'Q', 'B', 'i', 't', 'm', 'a', 'p', 0,
    'y', 'u', 'v', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'a', 'l', 'p', 'h', 'a', 'S', 'i', 'z', 'e', 0,
    'b', 'l', 'a', 'c', 'k', 'S', 'i', 'z', 'e', 0,
    'g', 'r', 'e', 'e', 'n', 'S', 'i', 'z', 'e', 0,
    'U', 's', 'e', 's', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 'F', 0,
    'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 0,
    'j', 'o', 'i', 'n', 'S', 't', 'y', 'l', 'e', 0,
    'e', 'l', 'e', 'm', 'e', 'n', 't', 'A', 't', 0,
    'a', 'r', 'c', 'M', 'o', 'v', 'e', 'T', 'o', 0,
    'a', 'd', 'd', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'i', 's', 'C', 'u', 'r', 'v', 'e', 'T', 'o', 0,
    'Q', 'u', 'i', 'c', 'k', 'D', 'r', 'a', 'w', 0,
    'l', 'i', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 'c', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'D', 'i', 'r', 't', 'y', 'F', 'o', 'n', 't', 0,
    'Q', 'T', 'e', 'x', 't', 'I', 't', 'e', 'm', 0,
    'P', 'd', 'm', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'T', 'o', 'p', 0,
    'd', 'r', 'a', 'w', 'I', 'm', 'a', 'g', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'o', 'i', 'n', 't', 0,
    'e', 'r', 'a', 's', 'e', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'C', 'h', 'o', 'r', 'd', 0,
    'd', 'r', 'a', 'w', 'R', 'e', 'c', 't', 's', 0,
    'd', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 's', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'N', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    't', 'o', 'p', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '9', 0,
    'F', 'a', 'n', 'F', 'o', 'l', 'd', 'U', 'S', 0,
    'P', 'r', 'c', '3', '2', 'K', 'B', 'i', 'g', 0,
    'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'E', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', 0,
    'D', 'e', 'p', 't', 'h', 'M', 'o', 'd', 'e', 0,
    'Z', 'e', 'r', 'o', 'V', 'a', 'l', 'u', 'e', 0,
    'B', 'l', 'u', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', '1', 'D', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', '3', 'D', 0,
    'L', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'L', 'a', 'y', 'e', 'r', 's', 0,
    'm', 'i', 'p', 'L', 'e', 'v', 'e', 'l', 's', 0,
    'R', 'G', 'B', '8', '_', 'E', 'T', 'C', '1', 0,
    'R', 'G', 'B', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'S', 'R', 'G', 'B', '_', 'D', 'X', 'T', '1', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '5', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '3', 0,
    'R', 'G', 'B', 'A', '_', 'D', 'X', 'T', '1', 0,
    'D', '3', '2', 'F', 'S', '8', 'X', '2', '4', 0,
    'R', '1', '6', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '1', '6', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'R', 'G', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 'I', 'd', 0,
    'a', 'd', 'd', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    'r', 'o', 'w', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'M', 'i', 'p', 'm', 'a', 'p', 0,
    'p', 'u', 's', 'h', 'G', 'r', 'o', 'u', 'p', 0,
    'i', 's', 'L', 'o', 'g', 'g', 'i', 'n', 'g', 0,
    'O', 't', 'h', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'E', 'r', 'r', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'A', 'n', 'y', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'A', 'P', 'I', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'R', 'a', 'n', 'g', 'e', 'R', 'e', 'a', 'd', 0,
    'i', 's', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    's', 'e', 't', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'c', 'a', 'c', 'h', 'e', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'R', 'e', 'c', 't', 0,
    'C', 'a', 'c', 'h', 'e', 'N', 'o', 'n', 'e', 0,
    'm', 'a', 'p', 'V', 'e', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'n', 'e', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'B', 'a', 'c', 'k', 's', 'p', 'a', 'c', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    'N', 'e', 'x', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'y', 't', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'O', 'f', 'f', 's', 'e', 't', 0,
    'c', 'l', 'i', 'p', 'T', 'i', 'g', 'h', 't', 0,
    'c', 'o', 'n', 's', 't', 'B', 'i', 't', 's', 0,
    'I', 'n', 'v', 'e', 'r', 't', 'R', 'g', 'b', 0,
    's', 'e', 't', 'I', 's', 'M', 'a', 's', 'k', 0,
    't', 'h', 'e', 'm', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'r', 'o', 'm', 'T', 'h', 'e', 'm', 'e', 0,
    'a', 'd', 'd', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'c', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'G', 'l', 'y', 'p', 'h', 'R', 'u', 'n', 0,
    'c', 'a', 'p', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'w', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'r', 0,
    'Q', 'F', 'o', 'n', 't', 'I', 'n', 'f', 'o', 0,
    'T', 'i', 't', 'l', 'e', 'F', 'o', 'n', 't', 0,
    'F', 'i', 'x', 'e', 'd', 'F', 'o', 'n', 't', 0,
    's', 't', 'y', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'S', 'm', 'a', 'l', 'l', 'C', 'a', 'p', 's', 0,
    'M', 'i', 'x', 'e', 'd', 'C', 'a', 's', 'e', 0,
    's', 'e', 't', 'I', 't', 'a', 'l', 'i', 'c', 0,
    's', 't', 'y', 'l', 'e', 'H', 'i', 'n', 't', 0,
    's', 't', 'r', 'i', 'k', 'e', 'O', 'u', 't', 0,
    'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    's', 'e', 't', 'W', 'e', 'i', 'g', 'h', 't', 0,
    'p', 'i', 'x', 'e', 'l', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'p', 'o', 'i', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'E', 'x', 't', 'r', 'a', 'B', 'o', 'l', 'd', 0,
    'M', 'o', 'n', 'o', 's', 'p', 'a', 'c', 'e', 0,
    'S', 'a', 'n', 's', 'S', 'e', 'r', 'i', 'f', 0,
    'H', 'e', 'l', 'v', 'e', 't', 'i', 'c', 'a', 0,
    'n', 'u', 'm', 'e', 'r', 'i', 'c', 'I', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'R', 'e', 'c', 't', 0,
    'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'c', 't', 0,
    'l', 'o', 's', 't', 'F', 'o', 'c', 'u', 's', 0,
    'Q', 'K', 'e', 'y', 'E', 'v', 'e', 'n', 't', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'P', 'o', 's', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'P', 'o', 's', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'P', 'o', 's', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', 0,
    'D', 'i', 's', 'p', 'l', 'a', 'y', 'P', '3', 0,
    's', 'e', 't', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    's', 'e', 't', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'f', 'i', 'n', 'a', 'l', 'S', 't', 'o', 'p', 0,
    's', 'e', 't', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'T', 'e', 'e', 'n', 'P', 'a', 'r', 't', 'y', 0,
    'M', 'i', 'n', 'd', 'C', 'r', 'a', 'w', 'l', 0,
    'L', 'i', 'g', 'h', 't', 'B', 'l', 'u', 'e', 0,
    'N', 'i', 'g', 'h', 't', 'C', 'a', 'l', 'l', 0,
    'S', 'e', 'a', 'S', 't', 'r', 'i', 'k', 'e', 0,
    'A', 'n', 'g', 'e', 'l', 'C', 'a', 'r', 'e', 0,
    'S', 'u', 'n', 'V', 'e', 'g', 'g', 'i', 'e', 0,
    'J', 'u', 'i', 'c', 'y', 'C', 'a', 'k', 'e', 0,
    'R', 'i', 'c', 'h', 'M', 'e', 't', 'a', 'l', 0,
    'M', 'a', 'g', 'i', 'c', 'L', 'a', 'k', 'e', 0,
    'C', 'h', 'i', 'l', 'd', 'C', 'a', 'r', 'e', 0,
    'R', 'i', 'v', 'e', 'r', 'C', 'i', 't', 'y', 0,
    'M', 'a', 'r', 's', 'P', 'a', 'r', 't', 'y', 0,
    'J', 'u', 'n', 'g', 'l', 'e', 'D', 'a', 'y', 0,
    'S', 'p', 'i', 'k', 'y', 'N', 'a', 'g', 'a', 0,
    'S', 'k', 'y', 'G', 'l', 'i', 'd', 'e', 'r', 0,
    'S', 'o', 'f', 't', 'G', 'r', 'a', 's', 's', 0,
    'K', 'i', 'n', 'd', 'S', 't', 'e', 'e', 'l', 0,
    'S', 'n', 'o', 'w', 'A', 'g', 'a', 'i', 'n', 0,
    'F', 'r', 'e', 's', 'h', 'M', 'i', 'l', 'k', 0,
    'H', 'a', 'p', 'p', 'y', 'A', 'c', 'i', 'd', 0,
    'L', 'e', 'm', 'o', 'n', 'G', 'a', 't', 'e', 0,
    'P', 'l', 'u', 'm', 'P', 'l', 'a', 't', 'e', 0,
    'W', 'i', 'l', 'd', 'A', 'p', 'p', 'l', 'e', 0,
    'M', 'e', 'a', 'n', 'F', 'r', 'u', 'i', 't', 0,
    'H', 'e', 'a', 'v', 'y', 'R', 'a', 'i', 'n', 0,
    'N', 'i', 'g', 'h', 't', 'F', 'a', 'd', 'e', 0,
    'W', 'a', 'r', 'm', 'F', 'l', 'a', 'm', 'e', 0,
    'P', 'a', 'd', 'S', 'p', 'r', 'e', 'a', 'd', 0,
    'Q', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'r', 'o', 'y', 'a', 'l', 'b', 'l', 'u', 'e', 0,
    'r', 'o', 's', 'y', 'b', 'r', 'o', 'w', 'n', 0,
    'p', 'e', 'a', 'c', 'h', 'p', 'u', 'f', 'f', 0,
    'p', 'a', 'l', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'o', 'r', 'a', 'n', 'g', 'e', 'r', 'e', 'd', 0,
    'o', 'l', 'i', 'v', 'e', 'd', 'r', 'a', 'b', 0,
    'm', 'i', 's', 't', 'y', 'r', 'o', 's', 'e', 0,
    'm', 'i', 'n', 't', 'c', 'r', 'e', 'a', 'm', 0,
    'l', 'i', 'm', 'e', 'g', 'r', 'e', 'e', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'p', 'i', 'n', 'k', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'e', 'y', 0,
    'l', 'i', 'g', 'h', 't', 'g', 'r', 'a', 'y', 0,
    'l', 'i', 'g', 'h', 't', 'c', 'y', 'a', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'b', 'l', 'u', 'e', 0,
    'l', 'a', 'w', 'n', 'g', 'r', 'e', 'e', 'n', 0,
    'i', 'n', 'd', 'i', 'a', 'n', 'r', 'e', 'd', 0,
    'g', 'a', 'i', 'n', 's', 'b', 'o', 'r', 'o', 0,
    'f', 'i', 'r', 'e', 'b', 'r', 'i', 'c', 'k', 0,
    'd', 'a', 'r', 'k', 'k', 'h', 'a', 'k', 'i', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'e', 'e', 'n', 0,
    'c', 'h', 'o', 'c', 'o', 'l', 'a', 't', 'e', 0,
    'c', 'a', 'd', 'e', 't', 'b', 'l', 'u', 'e', 0,
    'b', 'u', 'r', 'l', 'y', 'w', 'o', 'o', 'd', 0,
    'a', 'l', 'i', 'c', 'e', 'b', 'l', 'u', 'e', 0,
    'D', 'a', 'r', 'k', 'G', 'r', 'e', 'e', 'n', 0,
    'L', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'y', 0,
    's', 'e', 't', 'R', 'g', 'b', 'a', '6', '4', 0,
    'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 0,
    'f', 'r', 'o', 'm', 'C', 'm', 'y', 'k', 'F', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 'F', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'F', 0,
    'f', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 's', 'I', 'd', 0,
    'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 'F', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '4', 'D', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '3', 'D', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '2', 'D', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'M', 'a', 'l', 'a', 'y', 'a', 'l', 'a', 'm', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 's', 0,
    'R', 'e', 'a', 'd', 'W', 'r', 'i', 't', 'e', 0,
    'W', 'r', 'i', 't', 'e', 'O', 'n', 'l', 'y', 0,
    'b', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'u', 's', 0,
    'B', 'i', 'g', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    '_', '_', 'e', 'n', 't', 'e', 'r', '_', '_', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 0,
    'f', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'P', 'a', 'u', 's', 'e', 'd', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    'U', 'n', 'c', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'W', 'i', 'n', 'd', 'o', 'w', 'e', 'd', 0,
    'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'S', 'i', 'z', 'e', 0,
    'm', 'o', 'd', 'a', 'l', 'i', 't', 'y', 0,
    't', 'o', 'P', 'o', 'i', 'n', 't', 'F', 0,
    'd', 'e', 'c', 'i', 'm', 'a', 'l', 's', 0,
    's', 'e', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'T', 'x', 'R', 'o', 't', 'a', 't', 'e', 0,
    'T', 'o', 'u', 'c', 'h', 'P', 'a', 'd', 0,
    'r', 'o', 'w', 'S', 't', 'a', 'r', 't', 0,
    'R', 'i', 'g', 'h', 't', 'T', 'a', 'b', 0,
    'W', 'o', 'r', 'd', 'W', 'r', 'a', 'p', 0,
    'u', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    't', 'e', 'x', 't', 'L', 'i', 's', 't', 0,
    'i', 't', 'e', 'm', 'T', 'e', 'x', 't', 0,
    'T', 'r', 'a', 'i', 'l', 'i', 'n', 'g', 0,
    'L', 'i', 's', 't', 'D', 'i', 's', 'c', 0,
    'N', 'o', 'M', 'a', 'r', 'k', 'e', 'r', 0,
    'i', 's', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'I', 's', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'C', 's', 's', 'F', 'l', 'o', 'a', 't', 0,
    'N', 'o', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'r', 'a', 'w', 'V', 'a', 'l', 'u', 'e', 0,
    'f', 'r', 'o', 'm', 'H', 't', 'm', 'l', 0,
    'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'N', 'e', 'x', 't', 'C', 'e', 'l', 'l', 0,
    'W', 'o', 'r', 'd', 'L', 'e', 'f', 't', 0,
    's', 'e', 't', 'C', 'h', 'i', 'l', 'd', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    't', 'a', 'k', 'e', 'I', 't', 'e', 'm', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    '_', '_', 'l', 'o', 'n', 'g', '_', '_', 0,
    't', 'o', 'A', 'r', 'g', 'b', '3', '2', 0,
    's', 'e', 't', 'R', 'e', 'c', 't', 's', 0,
    'f', 'r', 'o', 'm', 'F', 'o', 'n', 't', 0,
    'Q', 'R', 'a', 'w', 'F', 'o', 'n', 't', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'e', 's', 0,
    'i', 's', 'C', 'l', 'o', 's', 'e', 'd', 0,
    's', 'e', 't', 'P', 'o', 'i', 'n', 't', 0,
    'h', 'a', 's', 'A', 'l', 'p', 'h', 'a', 0,
    'c', 'y', 'a', 'n', 'S', 'i', 'z', 'e', 0,
    'b', 'l', 'u', 'e', 'S', 'i', 'z', 'e', 0,
    'Y', 'U', 'V', '4', '2', '0', 'S', 'P', 0,
    'i', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'Q', 'P', 'i', 'c', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 0,
    'm', 'i', 'd', 'l', 'i', 'g', 'h', 't', 0,
    'M', 'i', 'd', 'l', 'i', 'g', 'h', 't', 0,
    'I', 'n', 'a', 'c', 't', 'i', 'v', 'e', 0,
    'c', 'a', 'p', 'S', 't', 'y', 'l', 'e', 0,
    'i', 's', 'L', 'i', 'n', 'e', 'T', 'o', 0,
    'i', 's', 'M', 'o', 'v', 'e', 'T', 'o', 0,
    'D', 'i', 'r', 'e', 'c', 't', '2', 'D', 0,
    'D', 'i', 'r', 'e', 'c', 't', '3', 'D', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'A', 'l', 'l', 'D', 'i', 'r', 't', 'y', 0,
    'D', 'i', 'r', 't', 'y', 'P', 'e', 'n', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'M', 0,
    'P', 'd', 'm', 'D', 'e', 'p', 't', 'h', 0,
    'P', 'd', 'm', 'W', 'i', 'd', 't', 'h', 0,
    'd', 'r', 'a', 'w', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 0,
    'f', 'i', 'l', 'l', 'R', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 'T', 'e', 'x', 't', 0,
    'f', 'i', 'l', 'l', 'R', 'u', 'l', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'a', 't', 'h', 0,
    'f', 'i', 'l', 'l', 'P', 'a', 't', 'h', 0,
    'c', 'l', 'i', 'p', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'B', 'r', 'u', 's', 'h', 0,
    'Q', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'f', 'u', 'l', 'l', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'U', 'n', 'i', 't', 's', 0,
    'p', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'G', 'L', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'I', 'd', 0,
    'w', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'O', 'n', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'R', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'R', '8', '_', 'S', 'N', 'o', 'r', 'm', 0,
    'R', '8', '_', 'U', 'N', 'o', 'r', 'm', 0,
    'N', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 's', 'L', 'i', 'n', 'k', 'e', 'd', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'I', 'd', 0,
    's', 'k', 'i', 'p', 'R', 'o', 'w', 's', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 's', 0,
    'p', 'o', 'p', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 'v', 'e', 'r', 'i', 't', 'y', 0,
    'm', 'a', 'p', 'R', 'a', 'n', 'g', 'e', 0,
    'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'I', 'd', 0,
    'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'S', 'p', 'e', 'e', 'd', 0,
    'C', 'a', 'c', 'h', 'e', 'A', 'l', 'l', 0,
    'i', 's', 'A', 'f', 'f', 'i', 'n', 'e', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'f', 'a', 'r', 'P', 'l', 'a', 'n', 'e', 0,
    'F', 'i', 'n', 'd', 'N', 'e', 'x', 't', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'G', 'a', 'm', 'm', 'a', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    't', 'e', 'x', 't', 'K', 'e', 'y', 's', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 0,
    's', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 0,
    'c', 'a', 'c', 'h', 'e', 'K', 'e', 'y', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    'D', 'i', 's', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'c', 'r', 'e', 'e', 'n', 'A', 't', 0,
    't', 'a', 'b', 'A', 'r', 'r', 'a', 'y', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 's', 0,
    'm', 'a', 'x', 'W', 'i', 'd', 't', 'h', 0,
    'f', 'o', 'n', 't', 'I', 'n', 'f', 'o', 0,
    'G', 'u', 'r', 'm', 'u', 'k', 'h', 'i', 0,
    'C', 'y', 'r', 'i', 'l', 'l', 'i', 'c', 0,
    'f', 'a', 'm', 'i', 'l', 'i', 'e', 's', 0,
    'i', 's', 'C', 'o', 'p', 'y', 'O', 'f', 0,
    's', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'o', 'v', 'e', 'r', 'l', 'i', 'n', 'e', 0,
    'D', 'e', 'm', 'i', 'B', 'o', 'l', 'd', 0,
    'A', 'n', 'y', 'S', 't', 'y', 'l', 'e', 0,
    'v', 'e', 'l', 'o', 'c', 'i', 't', 'y', 0,
    's', 'c', 'e', 'n', 'e', 'P', 'o', 's', 0,
    's', 't', 'a', 'r', 't', 'P', 'o', 's', 0,
    'o', 'p', 'e', 'n', 'F', 'i', 'l', 'e', 0,
    'K', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 0,
    'g', 'o', 't', 'F', 'o', 'c', 'u', 's', 0,
    'u', 'n', 'i', 'q', 'u', 'e', 'I', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    'A', 'i', 'r', 'b', 'r', 'u', 's', 'h', 0,
    'N', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'i', 'n', 'v', 'e', 'r', 't', 'e', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'P', 'o', 's', 0,
    's', 'e', 't', 'S', 'h', 'a', 'p', 'e', 0,
    'D', 'c', 'i', 'P', '3', 'D', '6', '5', 0,
    'A', 'd', 'o', 'b', 'e', 'R', 'g', 'b', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 0,
    's', 'e', 't', 'S', 't', 'o', 'p', 's', 0,
    'M', 'a', 'g', 'i', 'c', 'R', 'a', 'y', 0,
    'B', 'l', 'a', 'c', 'k', 'S', 'e', 'a', 0,
    'M', 'o', 'l', 'e', 'H', 'a', 'l', 'l', 0,
    'P', 'l', 'u', 'm', 'B', 'a', 't', 'h', 0,
    'N', 'i', 'g', 'h', 't', 'S', 'k', 'y', 0,
    'S', 'e', 'a', 's', 'h', 'o', 'r', 'e', 0,
    'P', 'a', 'l', 'o', 'A', 'l', 't', 'o', 0,
    'B', 'i', 'g', 'M', 'a', 'n', 'g', 'o', 0,
    'L', 'o', 'v', 'e', 'K', 'i', 's', 's', 0,
    'S', 't', 'a', 'r', 'W', 'i', 'n', 'e', 0,
    'B', 'l', 'e', 's', 's', 'i', 'n', 'g', 0,
    'N', 'e', 'a', 'r', 'M', 'o', 'o', 'n', 0,
    'R', 'a', 'r', 'e', 'W', 'i', 'n', 'd', 0,
    'D', 'e', 'e', 'p', 'B', 'l', 'u', 'e', 0,
    'A', 'm', 'y', 'C', 'r', 'i', 's', 'p', 0,
    'L', 'a', 'd', 'y', 'L', 'i', 'p', 's', 0,
    'i', 's', 'O', 'p', 'a', 'q', 'u', 'e', 0,
    'g', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 'a', 's', 'h', 'e', 'l', 'l', 0,
    'm', 'o', 'c', 'c', 'a', 's', 'i', 'n', 0,
    'l', 'a', 'v', 'e', 'n', 'd', 'e', 'r', 0,
    'h', 'o', 'n', 'e', 'y', 'd', 'e', 'w', 0,
    'd', 'e', 'e', 'p', 'p', 'i', 'n', 'k', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'e', 'y', 0,
    'd', 'a', 'r', 'k', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 'c', 'y', 'a', 'n', 0,
    'd', 'a', 'r', 'k', 'b', 'l', 'u', 'e', 0,
    'c', 'o', 'r', 'n', 's', 'i', 'l', 'k', 0,
    'D', 'a', 'r', 'k', 'C', 'y', 'a', 'n', 0,
    'D', 'a', 'r', 'k', 'B', 'l', 'u', 'e', 0,
    'D', 'a', 'r', 'k', 'G', 'r', 'a', 'y', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'l', 'F', 0,
    'f', 'r', 'o', 'm', 'C', 'm', 'y', 'k', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'v', 'F', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'F', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 'a', 0,
    's', 'e', 't', 'C', 'm', 'y', 'k', 'F', 0,
    'g', 'e', 't', 'C', 'm', 'y', 'k', 'F', 0,
    'm', 'a', 'g', 'e', 'n', 't', 'a', 'F', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 'F', 0,
    's', 'e', 't', 'G', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'f', 'r', 'o', 'm', 'D', 'a', 't', 'a', 0,
    'e', 'n', 'd', 'P', 'a', 'i', 'n', 't', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'A', 't', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 'A', 't', 0,
    'U', 's', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 0,
    'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'd', 'e', 'c', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'o', 'r', 't', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'e', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'i', 'c', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    'Q', 'P', 'o', 'l', 'y', 'g', 'o', 'n', 0,
    'Q', 'P', 'a', 'l', 'e', 't', 't', 'e', 0,
    '_', '_', 'i', 'd', 'i', 'v', '_', '_', 0,
    'J', 'a', 'p', 'a', 'n', 'e', 's', 'e', 0,
    'G', 'u', 'j', 'a', 'r', 'a', 't', 'i', 0,
    'G', 'e', 'o', 'r', 'g', 'i', 'a', 'n', 0,
    'A', 'r', 'm', 'e', 'n', 'i', 'a', 'n', 0,
    's', 'e', 't', 'A', 'n', 'g', 'l', 'e', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'D', 'e', 's', 'e', 'l', 'e', 'c', 't', 0,
    'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'f', 'i', 'l', 'e', 'P', 'a', 't', 'h', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    '_', '_', 'i', 's', 'u', 'b', '_', '_', 0,
    '_', '_', 'e', 'x', 'i', 't', '_', '_', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 's', 0,
    't', 'o', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'c', 'a', 'p', 'a', 'c', 'i', 't', 'y', 0,
    '_', '_', 'i', 'm', 'u', 'l', '_', '_', 0,
    '_', '_', 'r', 'e', 'p', 'r', '_', '_', 0,
    '_', '_', 'i', 'a', 'd', 'd', '_', '_', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'm', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'i', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'o', 'l', 'd', 'S', 't', 'a', 't', 'e', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'A', 'l', 'i', 'g', 'n', 'T', 'o', 'p', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    'i', 's', 'M', 'o', 'd', 'a', 'l', 0,
    'a', 'd', 'j', 'o', 'i', 'n', 't', 0,
    'T', 'x', 'S', 'h', 'e', 'a', 'r', 0,
    'T', 'x', 'S', 'c', 'a', 'l', 'e', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 's', 0,
    'r', 'o', 'w', 'S', 'p', 'a', 'n', 0,
    's', 'e', 't', 'T', 'a', 'b', 's', 0,
    'L', 'e', 'f', 't', 'T', 'a', 'b', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 0,
    'L', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'p', 'a', 'd', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    'b', 'a', 's', 'e', 'U', 'r', 'l', 0,
    'a', 't', 'S', 't', 'a', 'r', 't', 0,
    'N', 'e', 'x', 't', 'R', 'o', 'w', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    't', 'a', 'k', 'e', 'R', 'o', 'w', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'Q', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'q', 'I', 's', 'G', 'r', 'a', 'y', 0,
    'q', 'R', 'g', 'b', 'a', '6', '4', 0,
    't', 'o', 'R', 'g', 'b', '1', '6', 0,
    'Q', 'R', 'g', 'b', 'a', '6', '4', 0,
    'g', 'e', 't', 'A', 'x', 'e', 's', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 's', 'k', 0,
    'h', 'u', 'e', 'S', 'i', 'z', 'e', 0,
    'r', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    's', 'u', 'b', 'E', 'n', 'u', 'm', 0,
    'Y', 'U', 'V', '4', '2', '0', 'P', 0,
    'I', 'n', 'd', 'e', 'x', 'e', 'd', 0,
    'i', 's', 'S', 'o', 'l', 'i', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'i', 's', 'E', 'q', 'u', 'a', 'l', 0,
    'a', 'd', 'd', 'T', 'e', 'x', 't', 0,
    'a', 'd', 'd', 'R', 'e', 'c', 't', 0,
    'c', 'u', 'b', 'i', 'c', 'T', 'o', 0,
    'O', 'p', 'e', 'n', 'G', 'L', '2', 0,
    'Q', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'w', 'i', 'd', 't', 'h', 'M', 'M', 0,
    'P', 'd', 'm', 'D', 'p', 'i', 'Y', 0,
    'P', 'd', 'm', 'D', 'p', 'i', 'X', 0,
    'c', 'o', 'm', 'b', 'i', 'n', 'e', 0,
    'p', 'i', 'c', 't', 'u', 'r', 'e', 0,
    'd', 'r', 'a', 'w', 'P', 'i', 'e', 0,
    'd', 'r', 'a', 'w', 'A', 'r', 'c', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 0,
    'B', '5', 'E', 'x', 't', 'r', 'a', 0,
    'A', '5', 'E', 'x', 't', 'r', 'a', 0,
    'A', '4', 'S', 'm', 'a', 'l', 'l', 0,
    'A', '4', 'E', 'x', 't', 'r', 'a', 0,
    'A', '3', 'E', 'x', 't', 'r', 'a', 0,
    'T', 'a', 'b', 'l', 'o', 'i', 'd', 0,
    'C', 'o', 'm', 'm', '1', '0', 'E', 0,
    'n', 'e', 'w', 'P', 'a', 'g', 'e', 0,
    'p', 'a', 'i', 'n', 't', 'G', 'L', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'F', 'l', 'o', 'a', 't', '3', '2', 0,
    'R', 'G', 'B', 'A', '3', '2', 'F', 0,
    'R', 'G', 'B', 'A', '1', '6', 'F', 0,
    'R', 'G', 'B', 'A', '3', '2', 'I', 0,
    'R', 'G', 'B', 'A', '1', '6', 'I', 0,
    'R', 'G', 'B', 'A', '3', '2', 'U', 0,
    'R', 'G', 'B', 'A', '1', '6', 'U', 0,
    's', 'h', 'a', 'd', 'e', 'r', 's', 0,
    'C', 'o', 'm', 'p', 'u', 't', 'e', 0,
    's', 'a', 'm', 'p', 'l', 'e', 's', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 0,
    't', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    'i', 's', 'B', 'o', 'u', 'n', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'A', 'n', 'y', 'T', 'y', 'p', 'e', 0,
    'p', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'L', 'i', 'b', 'G', 'L', 'E', 'S', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'd', 'e', 's', 't', 'r', 'o', 'y', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'd', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 0,
    'f', 'r', 'u', 's', 't', 'u', 'm', 0,
    'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'Z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    'R', 'e', 'f', 'r', 'e', 's', 'h', 0,
    's', 'u', 'b', 'T', 'y', 'p', 'e', 0,
    'c', 'a', 'n', 'R', 'e', 'a', 'd', 0,
    'q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'a', 'l', 'l', 'G', 'r', 'a', 'y', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 0,
    's', 'c', 'r', 'e', 'e', 'n', 's', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 0,
    'r', 'a', 'w', 'F', 'o', 'n', 't', 0,
    'f', 'o', 'n', 't', 'D', 'p', 'i', 0,
    'x', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'd', 'e', 's', 'c', 'e', 'n', 't', 0,
    's', 'e', 't', 'B', 'o', 'l', 'd', 0,
    'c', 'l', 'e', 'a', 'n', 'u', 'p', 0,
    'r', 'a', 'w', 'N', 'a', 'm', 'e', 0,
    's', 't', 'r', 'e', 't', 'c', 'h', 0,
    'k', 'e', 'r', 'n', 'i', 'n', 'g', 0,
    'F', 'a', 'n', 't', 'a', 's', 'y', 0,
    'C', 'u', 'r', 's', 'i', 'v', 'e', 0,
    'C', 'o', 'u', 'r', 'i', 'e', 'r', 0,
    'Q', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'l', 'a', 's', 't', 'P', 'o', 's', 0,
    'q', 'u', 'e', 'r', 'i', 'e', 's', 0,
    'o', 'l', 'd', 'S', 'i', 'z', 'e', 0,
    'a', 'u', 't', 'o', 'r', 'e', 'p', 0,
    'o', 'l', 'd', 'P', 'o', 's', 'F', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'Y', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'X', 0,
    'b', 'u', 't', 't', 'o', 'n', 's', 0,
    'o', 'p', 'e', 'n', 'U', 'r', 'l', 0,
    'h', 'o', 't', 'S', 'p', 'o', 't', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'S', 'e', 'a', 'L', 'o', 'r', 'd', 0,
    'O', 'v', 'e', 'r', 'S', 'u', 'n', 0,
    'F', 'l', 'y', 'H', 'i', 'g', 'h', 0,
    'N', 'e', 'w', 'Y', 'o', 'r', 'k', 0,
    'N', 'e', 'w', 'L', 'i', 'f', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    't', 'h', 'i', 's', 't', 'l', 'e', 0,
    'o', 'l', 'd', 'l', 'a', 'c', 'e', 0,
    'h', 'o', 't', 'p', 'i', 'n', 'k', 0,
    'f', 'u', 'c', 'h', 's', 'i', 'a', 0,
    'd', 'i', 'm', 'g', 'r', 'e', 'y', 0,
    'd', 'i', 'm', 'g', 'r', 'a', 'y', 0,
    'd', 'a', 'r', 'k', 'r', 'e', 'd', 0,
    'c', 'r', 'i', 'm', 's', 'o', 'n', 0,
    'D', 'a', 'r', 'k', 'R', 'e', 'd', 0,
    'H', 'e', 'x', 'A', 'r', 'g', 'b', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'l', 0,
    's', 'e', 't', 'H', 's', 'l', 'F', 0,
    'g', 'e', 't', 'H', 's', 'l', 'F', 0,
    'h', 's', 'l', 'H', 'u', 'e', 'F', 0,
    'h', 's', 'v', 'H', 'u', 'e', 'F', 0,
    'f', 'r', 'o', 'm', 'H', 's', 'v', 0,
    'f', 'r', 'o', 'm', 'R', 'g', 'b', 0,
    's', 'e', 't', 'C', 'm', 'y', 'k', 0,
    'g', 'e', 't', 'C', 'm', 'y', 'k', 0,
    'y', 'e', 'l', 'l', 'o', 'w', 'F', 0,
    's', 'e', 't', 'H', 's', 'v', 'F', 0,
    'g', 'e', 't', 'H', 's', 'v', 'F', 0,
    's', 'e', 't', 'R', 'g', 'b', 'a', 0,
    's', 'e', 't', 'R', 'g', 'b', 'F', 0,
    'g', 'e', 't', 'R', 'g', 'b', 'F', 0,
    's', 'e', 't', 'R', 'e', 'd', 'F', 0,
    's', 'e', 't', 'B', 'l', 'u', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'A', 't', 0,
    'h', 'i', 't', 'T', 'e', 's', 't', 0,
    'p', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'p', 'a', 'l', 'e', 't', 't', 'e', 0,
    'm', 'a', 't', 'c', 'h', 'e', 's', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 0,
    'N', 'o', 'M', 'a', 't', 'c', 'h', 0,
    's', 'e', 't', 'S', 'i', 'z', 'e', 0,
    's', 't', 'a', 'r', 't', 'e', 'd', 0,
    't', 'o', 'P', 'o', 'i', 'n', 't', 0,
    'f', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'e', 't', 'H', 't', 'm', 'l', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    'Q', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'Q', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    '_', '_', 'n', 'e', 'g', '_', '_', 0,
    '_', '_', 'd', 'i', 'v', '_', '_', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'M', 'y', 'a', 'n', 'm', 'a', 'r', 0,
    'S', 'i', 'n', 'h', 'a', 'l', 'a', 0,
    'T', 'i', 'b', 'e', 't', 'a', 'n', 0,
    'K', 'a', 'n', 'n', 'a', 'd', 'a', 0,
    'B', 'e', 'n', 'g', 'a', 'l', 'i', 0,
    'r', 'e', 's', 'o', 'l', 'v', 'e', 0,
    'a', 'd', 'd', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    '_', '_', 's', 'u', 'b', '_', '_', 0,
    'M', 'a', 'x', 'U', 's', 'e', 'r', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'v', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 0,
    'F', 'l', 'o', 'a', 't', '1', '6', 0,
    '_', '_', 'a', 'd', 'd', '_', '_', 0,
    'r', 'e', 's', 'e', 'r', 'v', 'e', 0,
    '_', '_', 'm', 'u', 'l', '_', '_', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'p', 'r', 'e', 'p', 'e', 'n', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'e', 's', 's', 'a', 'g', 'e', 0,
    'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'C', 'h', 'e', 'c', 'k', 'e', 'd', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    'r', 'a', 'i', 's', 'e', '_', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 0,
    'T', 'x', 'N', 'o', 'n', 'e', 0,
    'r', 'o', 'w', 'E', 'n', 'd', 0,
    'c', 'e', 'l', 'l', 'A', 't', 0,
    'N', 'o', 'W', 'r', 'a', 'p', 0,
    'l', 'i', 'n', 'e', 'A', 't', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 0,
    'I', 'n', 'F', 'l', 'o', 'w', 0,
    'm', 'a', 'r', 'k', 'e', 'r', 0,
    'i', 'n', 'd', 'e', 'n', 't', 0,
    's', 't', 'a', 'c', 'k', 's', 0,
    'p', 'r', 'i', 'n', 't', '_', 0,
    't', 'o', 'H', 't', 'm', 'l', 0,
    'N', 'o', 'M', 'o', 'v', 'e', 0,
    'a', 'n', 'c', 'h', 'o', 'r', 0,
    's', 't', 'e', 'r', 'e', 'o', 0,
    'q', 'A', 'l', 'p', 'h', 'a', 0,
    'q', 'G', 'r', 'e', 'e', 'n', 0,
    'a', 'l', 'p', 'h', 'a', '8', 0,
    'g', 'r', 'e', 'e', 'n', '8', 0,
    's', 'c', 'a', 'l', 'a', 'r', 0,
    'c', 'l', 'o', 's', 'e', 'd', 0,
    'l', 'a', 'y', 'o', 'u', 't', 0,
    'Y', 'U', 'V', '4', '1', '1', 0,
    'Y', 'U', 'V', '4', '2', '2', 0,
    'Y', 'U', 'V', '4', '4', '4', 0,
    'w', 'i', 'd', 't', 'h', 'F', 0,
    's', 'h', 'a', 'd', 'o', 'w', 0,
    'N', 'o', 'R', 'o', 'l', 'e', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 0,
    'B', 'u', 't', 't', 'o', 'n', 0,
    'q', 'u', 'a', 'd', 'T', 'o', 0,
    'l', 'i', 'n', 'e', 'T', 'o', 0,
    'O', 'p', 'e', 'n', 'V', 'G', 0,
    'R', 'a', 's', 't', 'e', 'r', 0,
    's', 'c', 'a', 'l', 'e', 'Y', 0,
    's', 'c', 'a', 'l', 'e', 'X', 0,
    's', 'e', 't', 'P', 'e', 'n', 0,
    'C', 'i', 'c', 'e', 'r', 'o', 0,
    'P', 'r', 'c', '3', '2', 'K', 0,
    'P', 'r', 'c', '1', '6', 'K', 0,
    'S', 'u', 'p', 'e', 'r', 'B', 0,
    'S', 'u', 'p', 'e', 'r', 'A', 0,
    'Q', 'u', 'a', 'r', 't', 'o', 0,
    'J', 'i', 's', 'B', '1', '0', 0,
    'A', '4', 'P', 'l', 'u', 's', 0,
    'L', 'e', 'd', 'g', 'e', 'r', 0,
    'L', 'e', 't', 't', 'e', 'r', 0,
    'r', 'e', 'b', 'i', 'n', 'd', 0,
    'U', 'I', 'n', 't', '3', '2', 0,
    'U', 'I', 'n', 't', '1', '6', 0,
    'l', 'a', 'y', 'e', 'r', 's', 0,
    'R', 'G', 'B', '9', 'E', '5', 0,
    'R', 'G', 'B', '3', '2', 'F', 0,
    'R', 'G', 'B', '1', '6', 'F', 0,
    'R', 'G', 'B', '3', '2', 'I', 0,
    'R', 'G', 'B', '1', '6', 'I', 0,
    'R', 'G', 'B', 'A', '8', 'I', 0,
    'R', 'G', 'B', '3', '2', 'U', 0,
    'R', 'G', 'B', '1', '6', 'U', 0,
    'R', 'G', 'B', 'A', '8', 'U', 0,
    's', 't', 'r', 'i', 'd', 'e', 0,
    'V', 'e', 'r', 't', 'e', 'x', 0,
    'm', 'i', 'p', 'm', 'a', 'p', 0,
    's', 'h', 'a', 'r', 'e', 's', 0,
    'Q', 'M', 'o', 'v', 'i', 'e', 0,
    's', 'e', 't', 'R', 'o', 'w', 0,
    'l', 'o', 'o', 'k', 'A', 't', 0,
    'r', 'o', 't', 'a', 't', 'e', 0,
    'v', 'e', 'c', 't', 'o', 'r', 0,
    'C', 'a', 'n', 'c', 'e', 'l', 0,
    'S', 'a', 'v', 'e', 'A', 's', 0,
    'A', 'd', 'd', 'T', 'a', 'b', 0,
    'Z', 'o', 'o', 'm', 'I', 'n', 0,
    'D', 'e', 'l', 'e', 't', 'e', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'i', 's', 'M', 'a', 's', 'k', 0,
    'i', 'n', 'F', 'o', 'n', 't', 0,
    'a', 's', 'c', 'e', 'n', 't', 0,
    's', 't', 'y', 'l', 'e', 's', 0,
    'S', 'y', 'm', 'b', 'o', 'l', 0,
    'T', 'h', 'a', 'a', 'n', 'a', 0,
    'i', 't', 'a', 'l', 'i', 'c', 0,
    'w', 'e', 'i', 'g', 'h', 't', 0,
    'f', 'a', 'm', 'i', 'l', 'y', 0,
    'M', 'e', 'd', 'i', 'u', 'm', 0,
    'r', 'e', 'a', 's', 'o', 'n', 0,
    'o', 'l', 'd', 'P', 'o', 's', 0,
    'b', 'u', 't', 't', 'o', 'n', 0,
    's', 'e', 't', 'P', 'o', 's', 0,
    'b', 'i', 't', 'm', 'a', 'p', 0,
    'r', 'a', 'd', 'i', 'u', 's', 0,
    's', 'p', 'r', 'e', 'a', 'd', 0,
    'O', 'l', 'd', 'H', 'a', 't', 0,
    'p', 'i', 'x', 'm', 'a', 'p', 0,
    't', 'o', 'm', 'a', 't', 'o', 0,
    's', 'i', 'l', 'v', 'e', 'r', 0,
    's', 'i', 'e', 'n', 'n', 'a', 0,
    'm', 'a', 'r', 'o', 'o', 'n', 0,
    'i', 'n', 'd', 'i', 'g', 'o', 0,
    'b', 'i', 's', 'q', 'u', 'e', 0,
    'C', 'o', 'l', 'o', 'r', '1', 0,
    'C', 'o', 'l', 'o', 'r', '0', 0,
    'H', 'e', 'x', 'R', 'g', 'b', 0,
    's', 'e', 't', 'H', 's', 'l', 0,
    'g', 'e', 't', 'H', 's', 'l', 0,
    'h', 's', 'l', 'H', 'u', 'e', 0,
    'h', 's', 'v', 'H', 'u', 'e', 0,
    'd', 'a', 'r', 'k', 'e', 'r', 0,
    't', 'o', 'C', 'm', 'y', 'k', 0,
    'b', 'l', 'a', 'c', 'k', 'F', 0,
    's', 'e', 't', 'H', 's', 'v', 0,
    'g', 'e', 't', 'H', 's', 'v', 0,
    'v', 'a', 'l', 'u', 'e', 'F', 0,
    's', 'e', 't', 'R', 'g', 'b', 0,
    'g', 'e', 't', 'R', 'g', 'b', 0,
    'g', 'r', 'e', 'e', 'n', 'F', 0,
    's', 'e', 't', 'R', 'e', 'd', 0,
    'a', 'l', 'p', 'h', 'a', 'F', 0,
    'r', 'g', 'b', 'a', '6', '4', 0,
    'm', 'a', 't', 'r', 'i', 'x', 0,
    's', 'c', 'r', 'o', 'l', 'l', 0,
    'r', 'e', 'g', 'i', 'o', 'n', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 0,
    's', 'c', 'a', 'l', 'e', 'd', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 0,
    'c', 'o', 'm', 'm', 'i', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'u', 'n', 'i', 't', 'e', 'd', 0,
    'm', 'o', 'v', 'e', 'T', 'o', 0,
    'r', 'e', 'g', 'E', 'x', 'p', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'C', 'o', 'l', 'o', 'r', 0,
    'Q', 'B', 'r', 'u', 's', 'h', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 0,
    'f', 'a', 'c', 't', 'o', 'r', 0,
    's', 'e', 't', 'T', 'o', 'p', 0,
    'S', 'y', 'r', 'i', 'a', 'c', 0,
    'T', 'e', 'l', 'u', 'g', 'u', 0,
    'K', 'o', 'r', 'e', 'a', 'n', 0,
    'H', 'e', 'b', 'r', 'e', 'w', 0,
    'A', 'r', 'a', 'b', 'i', 'c', 0,
    'c', 'e', 'n', 't', 'e', 'r', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'b', 'o', 't', 't', 'o', 'm', 0,
    'o', 'f', 'f', 's', 'e', 't', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'C', 'u', 's', 't', 'o', 'm', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'H', 'i', 'd', 'd', 'e', 'n', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    'i', 'g', 'n', 'o', 'r', 'e', 0,
    'a', 'c', 'c', 'e', 'p', 't', 0,
    'n', 'o', 't', 'i', 'f', 'y', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'l', 'e', '_', '_', 0,
    '_', '_', 'g', 't', '_', '_', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'd', 'e', 't', 'a', 'c', 'h', 0,
    'r', 'e', 's', 'i', 'z', 'e', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    'r', 'e', 'v', 'e', 'r', 't', 0,
    's', 'u', 'b', 'm', 'i', 't', 0,
    'a', 'c', 't', 'i', 'o', 'n', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'l', 'e', 'r', 't', 0,
    'l', 'o', 'w', 'e', 'r', 0,
    'w', 'i', 'n', 'I', 'd', 0,
    'f', 'i', 'x', 'u', 'p', 0,
    'd', 'e', 'l', 'i', 'm', 0,
    'p', 'r', 'i', 'n', 't', 0,
    'q', 'G', 'r', 'a', 'y', 0,
    'q', 'R', 'g', 'b', 'a', 0,
    'q', 'B', 'l', 'u', 'e', 0,
    'b', 'l', 'u', 'e', '8', 0,
    'x', 'o', 'r', 'e', 'd', 0,
    'n', 'l', 'e', 'r', 'p', 0,
    's', 'l', 'e', 'r', 'p', 0,
    'A', 't', 'E', 'n', 'd', 0,
    't', 'i', 't', 'l', 'e', 0,
    'a', 'r', 'c', 'T', 'o', 0,
    'r', 'e', 'c', 't', 's', 0,
    's', 'h', 'e', 'a', 'r', 0,
    'b', 'e', 'g', 'i', 'n', 0,
    'D', 'i', 'd', 'o', 't', 0,
    'u', 'n', 'i', 't', 's', 0,
    'A', 'n', 's', 'i', 'B', 0,
    'A', 'n', 's', 'i', 'A', 0,
    'A', 'r', 'c', 'h', 'E', 0,
    'A', 'r', 'c', 'h', 'D', 0,
    'A', 'r', 'c', 'h', 'C', 0,
    'A', 'r', 'c', 'h', 'B', 0,
    'A', 'r', 'c', 'h', 'A', 0,
    'A', 'n', 's', 'i', 'E', 0,
    'A', 'n', 's', 'i', 'D', 0,
    'A', 'n', 's', 'i', 'C', 0,
    'J', 'i', 's', 'B', '9', 0,
    'J', 'i', 's', 'B', '8', 0,
    'J', 'i', 's', 'B', '7', 0,
    'J', 'i', 's', 'B', '6', 0,
    'J', 'i', 's', 'B', '5', 0,
    'J', 'i', 's', 'B', '4', 0,
    'J', 'i', 's', 'B', '3', 0,
    'J', 'i', 's', 'B', '2', 0,
    'J', 'i', 's', 'B', '1', 0,
    'J', 'i', 's', 'B', '0', 0,
    'F', 'o', 'l', 'i', 'o', 0,
    'U', 'I', 'n', 't', '8', 0,
    'f', 'a', 'c', 'e', 's', 0,
    'S', 'R', 'G', 'B', '8', 0,
    'R', 'G', '3', '2', 'F', 0,
    'R', 'G', '1', '6', 'F', 0,
    'R', 'G', '3', '2', 'I', 0,
    'R', 'G', '1', '6', 'I', 0,
    'R', 'G', 'B', '8', 'I', 0,
    'R', 'G', '3', '2', 'U', 0,
    'R', 'G', '1', '6', 'U', 0,
    'R', 'G', 'B', '8', 'U', 0,
    'L', 'i', 'b', 'G', 'L', 0,
    's', 'p', 'e', 'e', 'd', 0,
    'o', 'r', 't', 'h', 'o', 0,
    'P', 'r', 'i', 'n', 't', 0,
    'P', 'a', 's', 't', 'e', 0,
    'C', 'l', 'i', 'c', 'k', 0,
    'p', 'i', 'x', 'e', 'l', 0,
    'd', 'e', 'p', 't', 'h', 0,
    's', 'i', 'z', 'e', 's', 0,
    'c', 'l', 'o', 'n', 'e', 0,
    'p', 'a', 'i', 'n', 't', 0,
    'R', 'u', 'n', 'i', 'c', 0,
    'O', 'g', 'h', 'a', 'm', 0,
    'T', 'i', 'm', 'e', 's', 0,
    'T', 'o', 'k', 'e', 'n', 0,
    'O', 't', 'h', 'e', 'r', 0,
    'y', 'T', 'i', 'l', 't', 0,
    'x', 'T', 'i', 'l', 't', 0,
    'p', 'h', 'a', 's', 'e', 0,
    'Q', 'D', 'r', 'a', 'g', 0,
    'g', 'a', 'm', 'm', 'a', 0,
    's', 't', 'o', 'p', 's', 0,
    'w', 'h', 'e', 'a', 't', 0,
    'o', 'l', 'i', 'v', 'e', 0,
    'l', 'i', 'n', 'e', 'n', 0,
    'i', 'v', 'o', 'r', 'y', 0,
    'b', 'e', 'i', 'g', 'e', 0,
    'a', 'z', 'u', 'r', 'e', 0,
    'B', 'l', 'a', 'c', 'k', 0,
    't', 'o', 'H', 's', 'l', 0,
    't', 'o', 'H', 's', 'v', 0,
    'c', 'y', 'a', 'n', 'F', 0,
    'b', 'l', 'u', 'e', 'F', 0,
    'a', 'l', 'p', 'h', 'a', 0,
    'b', 'l', 'o', 'c', 'k', 0,
    's', 'h', 'a', 'p', 'e', 0,
    'c', 'o', 'd', 'e', 'c', 0,
    't', 'y', 'p', 'e', 's', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'i', 'm', 'a', 'g', 'e', 0,
    'Q', 'I', 'c', 'o', 'n', 0,
    'Q', 'F', 'o', 'n', 't', 0,
    's', 't', 'y', 'l', 'e', 0,
    'K', 'h', 'm', 'e', 'r', 0,
    'T', 'a', 'm', 'i', 'l', 0,
    'O', 'r', 'i', 'y', 'a', 0,
    'L', 'a', 't', 'i', 'n', 0,
    'G', 'r', 'e', 'e', 'k', 0,
    'p', 'o', 'i', 'n', 't', 0,
    'h', 'i', 'n', 't', 's', 0,
    'm', 'e', 'r', 'g', 'e', 0,
    'w', 'r', 'i', 't', 'e', 0,
    'u', 'n', 'm', 'a', 'p', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'C', 'l', 'o', 's', 'e', 0,
    'e', 'x', 'e', 'c', '_', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'r', 'i', 'g', 'h', 't', 0,
    'a', 't', 'E', 'n', 'd', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'f', 'i', 'r', 's', 't', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'b', 'u', 'd', 'd', 'y', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'm', 'o', 'd', 'e', 'l', 0,
    'c', 'h', 'i', 'l', 'd', 0,
    'f', 'l', 'u', 's', 'h', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'e', 'v', 'e', 'n', 't', 0,
    's', 't', 'a', 'r', 't', 0,
    'b', 'l', 'a', 'c', 'k', 0,
    's', 'e', 't', 'W', 0,
    'e', 'd', 'g', 'e', 0,
    't', 'a', 'b', 's', 0,
    'r', 'e', 'd', 'o', 0,
    'u', 'n', 'd', 'o', 0,
    'D', 'o', 'w', 'n', 0,
    'r', 'o', 'w', 's', 0,
    'q', 'R', 'g', 'b', 0,
    'q', 'R', 'e', 'd', 0,
    'r', 'e', 'd', '8', 0,
    's', 'e', 't', 'Z', 0,
    'a', 'x', 'i', 's', 0,
    'f', 'i', 'n', 'd', 0,
    'I', 'M', 'C', '4', 0,
    'I', 'M', 'C', '3', 0,
    'I', 'M', 'C', '2', 0,
    'I', 'M', 'C', '1', 0,
    'N', 'V', '2', '1', 0,
    'N', 'V', '1', '2', 0,
    'Y', 'U', 'Y', 'V', 0,
    'U', 'Y', 'V', 'Y', 0,
    'Y', 'V', '1', '2', 0,
    'C', 'M', 'Y', 'K', 0,
    'p', 'l', 'a', 'y', 0,
    'j', 'o', 'i', 'n', 0,
    'L', 'i', 'n', 'k', 0,
    'd', 'a', 'r', 'k', 0,
    'P', 'i', 'c', 'a', 0,
    'N', 'o', 't', 'e', 0,
    'b', 'l', 'i', 't', 0,
    'B', 'G', 'R', 'A', 0,
    'R', 'G', 'B', 'A', 0,
    'D', '3', '2', 'F', 0,
    'R', '3', '2', 'F', 0,
    'R', '1', '6', 'F', 0,
    'R', '3', '2', 'I', 0,
    'R', '1', '6', 'I', 0,
    'R', 'G', '8', 'I', 0,
    'R', '3', '2', 'U', 0,
    'R', '1', '6', 'U', 0,
    'R', 'G', '8', 'U', 0,
    'k', 'e', 'y', '4', 0,
    'k', 'e', 'y', '3', 0,
    'k', 'e', 'y', '2', 0,
    'Q', 'u', 'i', 't', 0,
    'F', 'i', 'n', 'd', 0,
    'B', 'a', 'c', 'k', 0,
    'R', 'e', 'd', 'o', 0,
    'U', 'n', 'd', 'o', 0,
    'S', 'a', 'v', 'e', 0,
    'h', 'i', 'd', 'e', 0,
    's', 'h', 'o', 'w', 0,
    'i', 'c', 'o', 'n', 0,
    'f', 'o', 'n', 't', 0,
    'b', 'o', 'l', 'd', 0,
    'T', 'h', 'i', 'n', 0,
    'h', 'r', 'e', 'f', 0,
    'R', 'u', 'b', 'y', 0,
    'P', 'u', 'c', 'k', 0,
    'p', 'o', 's', 'F', 0,
    'h', 'o', 't', 'Y', 0,
    'h', 'o', 't', 'X', 0,
    'S', 'R', 'g', 'b', 0,
    'N', 'e', 'g', 'a', 0,
    't', 'e', 'a', 'l', 0,
    's', 'n', 'o', 'w', 0,
    'p', 'l', 'u', 'm', 0,
    'p', 'e', 'r', 'u', 0,
    'n', 'a', 'v', 'y', 0,
    'l', 'i', 'm', 'e', 0,
    'g', 'o', 'l', 'd', 0,
    'a', 'q', 'u', 'a', 0,
    'h', 'u', 'e', 'F', 0,
    'r', 'g', 'b', 'a', 0,
    'r', 'e', 'd', 'F', 0,
    'i', 't', 'e', 'm', 0,
    'r', 'e', 'c', 't', 0,
    'd', 'r', 'a', 'w', 0,
    'c', 'l', 'i', 'p', 0,
    's', 'a', 'v', 'e', 0,
    'm', 'a', 's', 'k', 0,
    'O', 'p', 'e', 'n', 0,
    's', 'y', 'n', 'c', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'X', 0,
    'Q', 'P', 'e', 'n', 0,
    'T', 'h', 'a', 'i', 0,
    'l', 'o', 'a', 'd', 0,
    'c', 'o', 'p', 'y', 0,
    'l', 'i', 'n', 'k', 0,
    's', 'p', 'e', 'c', 0,
    'e', 'x', 'e', 'c', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'e', 'x', 't', 0,
    'n', 'a', 'm', 'e', 0,
    'l', 'e', 'f', 't', 0,
    'b', 'i', 't', 's', 0,
    'f', 'i', 'l', 'l', 0,
    'f', 'r', 'o', 'm', 0,
    'l', 'a', 's', 't', 0,
    's', 'p', 'a', 'n', 0,
    's', 'o', 'r', 't', 0,
    's', 'w', 'a', 'p', 0,
    'r', 'o', 'l', 'e', 0,
    's', 't', 'o', 'p', 0,
    'Y', '1', '6', 0,
    'Y', 'U', 'V', 0,
    'H', 'S', 'V', 0,
    'H', 'S', 'L', 0,
    'M', 'i', 'd', 0,
    'P', 'd', 'f', 0,
    'S', 'V', 'G', 0,
    'X', '1', '1', 0,
    'A', '1', '0', 0,
    'D', 'L', 'E', 0,
    'C', '5', 'E', 0,
    'B', 'G', 'R', 0,
    'R', 'G', 'B', 0,
    'D', '3', '2', 0,
    'D', '2', '4', 0,
    'D', '1', '6', 0,
    'R', '8', 'I', 0,
    'R', '8', 'U', 0,
    'l', 'o', 'g', 0,
    'm', '3', '3', 0,
    'm', '3', '2', 0,
    'm', '3', '1', 0,
    'm', '2', '3', 0,
    'm', '2', '2', 0,
    'm', '2', '1', 0,
    'm', '1', '3', 0,
    'm', '1', '2', 0,
    'm', '1', '1', 0,
    'C', 'u', 't', 0,
    'N', 'e', 'w', 0,
    'O', 'f', 'f', 0,
    'A', 'n', 'y', 0,
    't', 'i', 'p', 0,
    'h', 'u', 'e', 0,
    'c', 'a', 'p', 0,
    'a', 'd', 'd', 0,
    'u', 'r', 'l', 0,
    'N', 'k', 'o', 0,
    'L', 'a', 'o', 0,
    'k', 'e', 'y', 0,
    'm', 'i', 'd', 0,
    'p', 'o', 's', 0,
    'r', 'o', 'w', 0,
    'U', 'p', 0,
    'Y', '8', 0,
    's', 'w', 0,
    's', 'x', 0,
    'A', '9', 0,
    'A', '7', 0,
    'A', '6', 0,
    'A', '5', 0,
    'A', '3', 0,
    'A', '0', 0,
    'R', 'G', 0,
    'O', 'n', 0,
    'd', 'x', 0,
    'Q', 't', 0,
    'z', 0,
};
#line 178 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfontmetrics.sip"
// Convert an optional Python list to a 0 terminated array of integers on the
// heap.
int *qtgui_tabarray(PyObject *l)
{
    if (!l || l == Py_None)
        return 0;

    int *arr = new int[PyList_Size(l) + 1];
    Py_ssize_t i;

    for (i = 0; i < PyList_Size(l); ++i)
        arr[i] = SIPLong_AsLong(PyList_GetItem(l, i));

    arr[i] = 0;

    return arr;
}
#line 333 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
pyqt5_qtgui_cleanup_qobjects_t pyqt5_qtgui_cleanup_qobjects;
pyqt5_qtgui_from_argv_list_t pyqt5_qtgui_from_argv_list;
pyqt5_qtgui_update_argv_list_t pyqt5_qtgui_update_argv_list;

// Forward declarations not in any header files but are part of the API.
void qt_set_sequence_auto_mnemonic(bool enable);
#line 272 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qimage.sip"
// Convert a list of strings to an array of ASCII strings on the heap.  Used by
// QImage and QPixmap.
const char **QtGui_ListToArray(PyObject *lst)
{
    Py_ssize_t nstr = PyList_Size(lst);
    const char **arr = new const char *[nstr + 1];

    for (Py_ssize_t i = 0; i < nstr; ++i)
    {
        PyObject *ascii_obj = PyList_GetItem(lst, i);
        const char *ascii = sipString_AsASCIIString(&ascii_obj);

        if (!ascii)
        {
            while (i-- > 0)
                delete[] arr[i];

            delete[] arr;

            return 0;
        }

        // Copy the string.
        arr[i] = qstrdup(ascii);

        Py_DECREF(ascii_obj);
    }

    // The sentinal.
    arr[nstr] = 0;

    return arr;
}


// Return a string array created by QtGui_ListToArray() to the heap.
void QtGui_DeleteArray(const char **arr)
{
    for (Py_ssize_t i = 0; arr[i]; ++i)
        delete[] arr[i];

    delete[] arr;
}
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 228 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qmatrix4x4.sip"
// Convert a Python object to a row and column.
sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column)
{
    sipErrorState es = sipErrorContinue;

    if (PyTuple_Check(tup) && PyArg_ParseTuple(tup, "ii", row, column))
        if (*row >= 0 && *row < nr_rows && *column >= 0 && *column < nr_columns)
            es = sipErrorNone;

    if (es == sipErrorContinue)
        PyErr_Format(PyExc_IndexError, "an index must be a row in the range 0 to %d and a column in the range 0 to %d", nr_rows - 1, nr_columns - 1);

    return es;
}


// Convert a Python object to an array of qreals.
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values)
{
    sipErrorState es;

    if (PySequence_Size(seq) == nr_values)
    {
        es = sipErrorNone;

        for (int i = 0; i < nr_values; ++i)
        {
            PyObject *value = PySequence_GetItem(seq, i);

            if (!value)
            {
                es = sipErrorFail;
                break;
            }

            PyErr_Clear();

            double d = PyFloat_AsDouble(value);

            if (PyErr_Occurred())
            {
                Py_DECREF(value);
                es = sipErrorContinue;
                break;
            }

            Py_DECREF(value);

            *values++ = d;
        }
    }
    else
    {
        es = sipErrorContinue;
    }

    if (es == sipErrorContinue)
        PyErr_Format(PyExc_TypeError, "a sequence of %d floats is expected",
                nr_values);

    return es;
}


// Convert an array of qreals to a Python list.
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list)
{
    PyObject *l = PyList_New(nr_values);

    if (!l)
        return sipErrorFail;

    for (int i = 0; i < nr_values; ++i)
    {
        PyObject *value = PyFloat_FromDouble(*values++);

        if (!value)
        {
            Py_DECREF(l);
            return sipErrorFail;
        }

        PyList_SetItem(l, i, value);
    }

    *list = l;

    return sipErrorNone;
}
#line 25 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpixelformat.sip"
#include <qpixelformat.h>
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 25 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qrgba64.sip"
#include <qrgba64.h>
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qrgb.sip"
#include <qrgb.h>
#line 260 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtextobject.sip"
// Wrap a QObject and ensure that it's ancestors are all wrapped with the
// correct ownerships.
static PyObject *qtgui_wrap_ancestors_worker(QObject *obj)
{
    if (!obj)
    {
        Py_INCREF(Py_None);
        return Py_None;
    }

    PyObject *py_parent = qtgui_wrap_ancestors_worker(obj->parent());

    if (!py_parent)
        return 0;

    PyObject *py_obj = sipConvertFromType(obj, sipType_QObject,
            (py_parent != Py_None ? py_parent : 0));

    Py_DECREF(py_parent);
    return py_obj;
}

PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td)
{
    PyObject *py_parent = qtgui_wrap_ancestors_worker(obj->parent());

    if (!py_parent)
        return 0;

    PyObject *py_obj = sipConvertFromType(obj, td,
            (py_parent != Py_None ? py_parent : 0));

    Py_DECREF(py_parent);

    return py_obj;
}
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector2d.sip"
#include <qvector2d.h>
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 24 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qvector4d.sip"
#include <qvector4d.h>
#line 4770 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

void sipVH_QtGui_109(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, double a0,double a1,int a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ddi", a0, a1, a2);
}

void sipVH_QtGui_108(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QString& a0)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", &a0, sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &a0);
}

 ::QValidator::State sipVH_QtGui_107(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QString& a0,int& a1)
{
     ::QValidator::State sipRes =  ::QValidator::Invalid;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Di", &a0, sipType_QString, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(FH5i)", sipType_QValidator_State, &sipRes, sipType_QString, &a0, &a1);

    return sipRes;
}

void sipVH_QtGui_106(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QTextBlock& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QTextBlock(a0), sipType_QTextBlock, SIP_NULLPTR);
}

 ::QVariant sipVH_QtGui_105(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,const  ::QUrl& a1)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iN", a0, new  ::QUrl(a1), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

 ::QTextObject* sipVH_QtGui_104(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QTextFormat& a0)
{
     ::QTextObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QTextFormat(a0), sipType_QTextFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QTextObject, &sipRes);

    return sipRes;
}

void sipVH_QtGui_103(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QString(a0), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtGui_102(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QStandardItem& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QStandardItem *>(&a0), sipType_QStandardItem, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_101(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDataStream& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", &a0, sipType_QDataStream, SIP_NULLPTR);
}

 ::QStandardItem* sipVH_QtGui_100(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QStandardItem* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QStandardItem, &sipRes);

    return sipRes;
}

void sipVH_QtGui_99(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QVariant& a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "Ni", new  ::QVariant(a0), sipType_QVariant, SIP_NULLPTR, a1);
}

 ::QVariant sipVH_QtGui_98(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

 ::QModelIndex sipVH_QtGui_97(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,int a1,const  ::QModelIndex& a2)
{
     ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new  ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

int sipVH_QtGui_96(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

 ::QVariant sipVH_QtGui_95(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0,int a1)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Ni", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_94(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0,const  ::QVariant& a1,int a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNi", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new  ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QVariant sipVH_QtGui_93(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1,int a2)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFi", a0, a1, sipType_Qt_Orientation, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_92(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1,const  ::QVariant& a2,int a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFNi", a0, a1, sipType_Qt_Orientation, new  ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QMap<int, ::QVariant> sipVH_QtGui_91(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
    QMap<int, ::QVariant> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMap_1800_0100QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_90(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0,const QMap<int, ::QVariant>& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new QMap<int, ::QVariant>(a1), sipType_QMap_1800_0100QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QStringList sipVH_QtGui_89(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

 ::QMimeData* sipVH_QtGui_88(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndexList& a0)
{
     ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMimeData, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_87(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,int a1,const  ::QModelIndex& a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new  ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);
}

bool sipVH_QtGui_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::Qt::ItemFlags sipVH_QtGui_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
     ::Qt::ItemFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_Qt_ItemFlags, &sipRes);

    return sipRes;
}

void sipVH_QtGui_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::SortOrder a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_Qt_SortOrder);
}

 ::QModelIndex sipVH_QtGui_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
     ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

 ::QModelIndexList sipVH_QtGui_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0,int a1,const  ::QVariant& a2,int a3, ::Qt::MatchFlags a4)
{
     ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiNiN", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, new  ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3, new  ::Qt::MatchFlags(a4), sipType_Qt_MatchFlags, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

 ::QSize sipVH_QtGui_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0)
{
     ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

 ::Qt::DropActions sipVH_QtGui_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::Qt::DropActions sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_Qt_DropActions, &sipRes);

    return sipRes;
}

QHash<int, ::QByteArray> sipVH_QtGui_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QHash<int, ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QHash_1800_0100QByteArray, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMimeData*a0, ::Qt::DropAction a1,int a2,int a3,const  ::QModelIndex& a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DFiiN", const_cast< ::QMimeData *>(a0), sipType_QMimeData, SIP_NULLPTR, a1, sipType_Qt_DropAction, a2, a3, new  ::QModelIndex(a4), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QModelIndex& a0,int a1,int a2,const  ::QModelIndex& a3,int a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiNi", new  ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2, new  ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR, a4);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0,uint a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "g", a0, (SIP_SSIZE_T)a1);
}

 ::QPaintEngine::Type sipVH_QtGui_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QPaintEngine::Type sipRes =  ::QPaintEngine::X11;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QPaintEngine_Type, &sipRes);

    return sipRes;
}

void sipVH_QtGui_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0,const  ::QImage& a1,const  ::QRectF& a2, ::Qt::ImageConversionFlags a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNNN", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new  ::QImage(a1), sipType_QImage, SIP_NULLPTR, new  ::QRectF(a2), sipType_QRectF, SIP_NULLPTR, new  ::Qt::ImageConversionFlags(a3), sipType_Qt_ImageConversionFlags, SIP_NULLPTR);
}

void sipVH_QtGui_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0,const  ::QPixmap& a1,const  ::QPointF& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new  ::QPixmap(a1), sipType_QPixmap, SIP_NULLPTR, new  ::QPointF(a2), sipType_QPointF, SIP_NULLPTR);
}

void sipVH_QtGui_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPointF& a0,const  ::QTextItem& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ND", new  ::QPointF(a0), sipType_QPointF, SIP_NULLPTR, const_cast< ::QTextItem *>(&a1), sipType_QTextItem, SIP_NULLPTR);
}

void sipVH_QtGui_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0,const  ::QPixmap& a1,const  ::QRectF& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new  ::QPixmap(a1), sipType_QPixmap, SIP_NULLPTR, new  ::QRectF(a2), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtGui_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPoint*a0,int a1, ::QPaintEngine::PolygonDrawMode a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "rF", const_cast< ::QPoint *>(a0), (SIP_SSIZE_T)a1, sipType_QPoint, a2, sipType_QPaintEngine_PolygonDrawMode);
}

void sipVH_QtGui_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPointF*a0,int a1, ::QPaintEngine::PolygonDrawMode a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "rF", const_cast< ::QPointF *>(a0), (SIP_SSIZE_T)a1, sipType_QPointF, a2, sipType_QPaintEngine_PolygonDrawMode);
}

void sipVH_QtGui_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPoint*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QPoint *>(a0), (SIP_SSIZE_T)a1, sipType_QPoint);
}

void sipVH_QtGui_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPointF*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QPointF *>(a0), (SIP_SSIZE_T)a1, sipType_QPointF);
}

void sipVH_QtGui_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPainterPath& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QPainterPath(a0), sipType_QPainterPath, SIP_NULLPTR);
}

void sipVH_QtGui_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRect& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QRect(a0), sipType_QRect, SIP_NULLPTR);
}

void sipVH_QtGui_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR);
}

void sipVH_QtGui_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QLineF*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QLineF *>(a0), (SIP_SSIZE_T)a1, sipType_QLineF);
}

void sipVH_QtGui_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QLine*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QLine *>(a0), (SIP_SSIZE_T)a1, sipType_QLine);
}

void sipVH_QtGui_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QRectF *>(a0), (SIP_SSIZE_T)a1, sipType_QRectF);
}

void sipVH_QtGui_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRect*a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "r", const_cast< ::QRect *>(a0), (SIP_SSIZE_T)a1, sipType_QRect);
}

void sipVH_QtGui_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPaintEngineState& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", const_cast< ::QPaintEngineState *>(&a0), sipType_QPaintEngineState, SIP_NULLPTR);
}

bool sipVH_QtGui_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPaintDevice*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QPaintDevice, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPagedPaintDevice::Margins& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QPagedPaintDevice::Margins(a0), sipType_QPagedPaintDevice_Margins, SIP_NULLPTR);
}

void sipVH_QtGui_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSizeF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QSizeF(a0), sipType_QSizeF, SIP_NULLPTR);
}

void sipVH_QtGui_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPagedPaintDevice::PageSize a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QPagedPaintDevice_PageSize);
}

void sipVH_QtGui_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ii", a0, a1);
}

void sipVH_QtGui_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtGui_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtGui_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTouchEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTouchEvent, SIP_NULLPTR);
}

void sipVH_QtGui_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtGui_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtGui_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtGui_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtGui_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtGui_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtGui_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtGui_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtGui_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QExposeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QExposeEvent, SIP_NULLPTR);
}

 ::QObject* sipVH_QtGui_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_QtGui_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

 ::QSize sipVH_QtGui_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

 ::QSurface::SurfaceType sipVH_QtGui_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSurface::SurfaceType sipRes =  ::QSurface::RasterSurface;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSurface_SurfaceType, &sipRes);

    return sipRes;
}

 ::QSurfaceFormat sipVH_QtGui_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSurfaceFormat, &sipRes);

    return sipRes;
}

 ::QRect sipVH_QtGui_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QRect sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRect, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QImageIOHandler::ImageOption a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QImageIOHandler_ImageOption);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QImageIOHandler::ImageOption a0,const  ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QImageIOHandler_ImageOption, new  ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

 ::QVariant sipVH_QtGui_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QImageIOHandler::ImageOption a0)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QImageIOHandler_ImageOption);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QImage& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QImage(a0), sipType_QImage, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QImage*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QImage, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QList< ::QSize> sipVH_QtGui_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QIcon::Mode a0, ::QIcon::State a1)
{
    QList< ::QSize> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FF", a0, sipType_QIcon_Mode, a1, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QSize, &sipRes);

    return sipRes;
}

bool sipVH_QtGui_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDataStream& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", &a0, sipType_QDataStream, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QIconEngine* sipVH_QtGui_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QIconEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QIconEngine, &sipRes);

    return sipRes;
}

 ::QString sipVH_QtGui_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

void sipVH_QtGui_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0,const  ::QSize& a1, ::QIcon::Mode a2, ::QIcon::State a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNFF", new  ::QString(a0), sipType_QString, SIP_NULLPTR, new  ::QSize(a1), sipType_QSize, SIP_NULLPTR, a2, sipType_QIcon_Mode, a3, sipType_QIcon_State);
}

void sipVH_QtGui_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPixmap& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NFF", new  ::QPixmap(a0), sipType_QPixmap, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);
}

 ::QPixmap sipVH_QtGui_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSize& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
     ::QPixmap sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFF", new  ::QSize(a0), sipType_QSize, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPixmap, &sipRes);

    return sipRes;
}

 ::QSize sipVH_QtGui_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSize& a0, ::QIcon::Mode a1, ::QIcon::State a2)
{
     ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NFF", new  ::QSize(a0), sipType_QSize, SIP_NULLPTR, a1, sipType_QIcon_Mode, a2, sipType_QIcon_State);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtGui_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPainter*a0,const  ::QRect& a1, ::QIcon::Mode a2, ::QIcon::State a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNFF", a0, sipType_QPainter, SIP_NULLPTR, new  ::QRect(a1), sipType_QRect, SIP_NULLPTR, a2, sipType_QIcon_Mode, a3, sipType_QIcon_State);
}

int sipVH_QtGui_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

 ::QPaintEngine* sipVH_QtGui_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

void sipVH_QtGui_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPainter*a0,const  ::QRectF& a1, ::QTextDocument*a2,int a3,const  ::QTextFormat& a4)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNDiN", a0, sipType_QPainter, SIP_NULLPTR, new  ::QRectF(a1), sipType_QRectF, SIP_NULLPTR, a2, sipType_QTextDocument, SIP_NULLPTR, a3, new  ::QTextFormat(a4), sipType_QTextFormat, SIP_NULLPTR);
}

 ::QSizeF sipVH_QtGui_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTextDocument*a0,int a1,const  ::QTextFormat& a2)
{
     ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DiN", a0, sipType_QTextDocument, SIP_NULLPTR, a1, new  ::QTextFormat(a2), sipType_QTextFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

void sipVH_QtGui_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPainter*a0,const  ::QRectF& a1, ::QTextInlineObject a2,int a3,const  ::QTextFormat& a4)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNNiN", a0, sipType_QPainter, SIP_NULLPTR, new  ::QRectF(a1), sipType_QRectF, SIP_NULLPTR, new  ::QTextInlineObject(a2), sipType_QTextInlineObject, SIP_NULLPTR, a3, new  ::QTextFormat(a4), sipType_QTextFormat, SIP_NULLPTR);
}

void sipVH_QtGui_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTextInlineObject a0,int a1,const  ::QTextFormat& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NiN", new  ::QTextInlineObject(a0), sipType_QTextInlineObject, SIP_NULLPTR, a1, new  ::QTextFormat(a2), sipType_QTextFormat, SIP_NULLPTR);
}

void sipVH_QtGui_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,int a1,int a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iii", a0, a1, a2);
}

 ::QRectF sipVH_QtGui_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QTextBlock& a0)
{
     ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QTextBlock(a0), sipType_QTextBlock, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

 ::QRectF sipVH_QtGui_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTextFrame*a0)
{
     ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QTextFrame, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

 ::QSizeF sipVH_QtGui_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSizeF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSizeF, &sipRes);

    return sipRes;
}

int sipVH_QtGui_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

int sipVH_QtGui_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPointF& a0, ::Qt::HitTestAccuracy a1)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new  ::QPointF(a0), sipType_QPointF, SIP_NULLPTR, a1, sipType_Qt_HitTestAccuracy);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtGui_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPainter*a0,const  ::QAbstractTextDocumentLayout::PaintContext& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QPainter, SIP_NULLPTR, new  ::QAbstractTextDocumentLayout::PaintContext(a1), sipType_QAbstractTextDocumentLayout_PaintContext, SIP_NULLPTR);
}

bool sipVH_QtGui_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtGui_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtGui_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtGui_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtGui_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtGui_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


PyDoc_STRVAR(doc_qIsGray, "qIsGray(int) -> bool");

extern "C" {static PyObject *func_qIsGray(PyObject *,PyObject *);}
static PyObject *func_qIsGray(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            bool sipRes;

            sipRes = qIsGray(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qIsGray, doc_qIsGray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qGray, "qGray(int, int, int) -> int\n"
"qGray(int) -> int");

extern "C" {static PyObject *func_qGray(PyObject *,PyObject *);}
static PyObject *func_qGray(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "iii", &a0, &a1, &a2))
        {
            int sipRes;

            sipRes = qGray(a0,a1,a2);

            return SIPLong_FromLong(sipRes);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qGray(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qGray, doc_qGray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgba, "qRgba(int, int, int, int) -> int");

extern "C" {static PyObject *func_qRgba(PyObject *,PyObject *);}
static PyObject *func_qRgba(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;

        if (sipParseArgs(&sipParseErr, sipArgs, "iiii", &a0, &a1, &a2, &a3))
        {
             ::QRgb sipRes;

            sipRes = qRgba(a0,a1,a2,a3);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgba, doc_qRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgb, "qRgb(int, int, int) -> int");

extern "C" {static PyObject *func_qRgb(PyObject *,PyObject *);}
static PyObject *func_qRgb(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "iii", &a0, &a1, &a2))
        {
             ::QRgb sipRes;

            sipRes = qRgb(a0,a1,a2);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgb, doc_qRgb);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qAlpha, "qAlpha(QRgba64) -> int\n"
"qAlpha(int) -> int");

extern "C" {static PyObject *func_qAlpha(PyObject *,PyObject *);}
static PyObject *func_qAlpha(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::uint sipRes;

            sipRes = qAlpha(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qAlpha(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qAlpha, doc_qAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qBlue, "qBlue(QRgba64) -> int\n"
"qBlue(int) -> int");

extern "C" {static PyObject *func_qBlue(PyObject *,PyObject *);}
static PyObject *func_qBlue(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::uint sipRes;

            sipRes = qBlue(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qBlue(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qBlue, doc_qBlue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qGreen, "qGreen(QRgba64) -> int\n"
"qGreen(int) -> int");

extern "C" {static PyObject *func_qGreen(PyObject *,PyObject *);}
static PyObject *func_qGreen(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::uint sipRes;

            sipRes = qGreen(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qGreen(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qGreen, doc_qGreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRed, "qRed(QRgba64) -> int\n"
"qRed(int) -> int");

extern "C" {static PyObject *func_qRed(PyObject *,PyObject *);}
static PyObject *func_qRed(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::uint sipRes;

            sipRes = qRed(*a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
            int sipRes;

            sipRes = qRed(a0);

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRed, doc_qRed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qUnpremultiply, "qUnpremultiply(QRgba64) -> QRgba64\n"
"qUnpremultiply(int) -> int");

extern "C" {static PyObject *func_qUnpremultiply(PyObject *,PyObject *);}
static PyObject *func_qUnpremultiply(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::QRgba64*sipRes;

            sipRes = new  ::QRgba64(qUnpremultiply(*a0));

            return sipConvertFromNewType(sipRes,sipType_QRgba64,SIP_NULLPTR);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
             ::QRgb sipRes;

            sipRes = qUnpremultiply(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qUnpremultiply, doc_qUnpremultiply);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPremultiply, "qPremultiply(QRgba64) -> QRgba64\n"
"qPremultiply(int) -> int");

extern "C" {static PyObject *func_qPremultiply(PyObject *,PyObject *);}
static PyObject *func_qPremultiply(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRgba64* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QRgba64, &a0))
        {
             ::QRgba64*sipRes;

            sipRes = new  ::QRgba64(qPremultiply(*a0));

            return sipConvertFromNewType(sipRes,sipType_QRgba64,SIP_NULLPTR);
        }
    }

    {
         ::QRgb a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "u", &a0))
        {
             ::QRgb sipRes;

            sipRes = qPremultiply(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPremultiply, doc_qPremultiply);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qRgba64, "qRgba64(int, int, int, int) -> QRgba64\n"
"qRgba64(int) -> QRgba64");

extern "C" {static PyObject *func_qRgba64(PyObject *,PyObject *);}
static PyObject *func_qRgba64(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::quint16 a0;
         ::quint16 a1;
         ::quint16 a2;
         ::quint16 a3;

        if (sipParseArgs(&sipParseErr, sipArgs, "tttt", &a0, &a1, &a2, &a3))
        {
             ::QRgba64*sipRes;

            sipRes = new  ::QRgba64(qRgba64(a0,a1,a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QRgba64,SIP_NULLPTR);
        }
    }

    {
         ::quint64 a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "o", &a0))
        {
             ::QRgba64*sipRes;

            sipRes = new  ::QRgba64(qRgba64(a0));

            return sipConvertFromNewType(sipRes,sipType_QRgba64,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qRgba64, doc_qRgba64);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatAlpha, "qPixelFormatAlpha(int, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatAlpha(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatAlpha(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::QPixelFormat::TypeInterpretation a1 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|E", &a0, sipType_QPixelFormat_TypeInterpretation, &a1))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatAlpha(a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatAlpha, doc_qPixelFormatAlpha);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatYuv, "qPixelFormatYuv(QPixelFormat.YUVLayout, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, premultiplied: QPixelFormat.AlphaPremultiplied = QPixelFormat.NotPremultiplied, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedByte, byteOrder: QPixelFormat.ByteOrder = QPixelFormat.LittleEndian) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatYuv(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatYuv(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPixelFormat::YUVLayout a0;
         ::uchar a1 = 0;
         ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
         ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
         ::QPixelFormat::AlphaPremultiplied a4 = QPixelFormat::NotPremultiplied;
         ::QPixelFormat::TypeInterpretation a5 = QPixelFormat::UnsignedByte;
         ::QPixelFormat::ByteOrder a6 = QPixelFormat::LittleEndian;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_premultiplied,
            sipName_typeInterpretation,
            sipName_byteOrder,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "E|MEEEEE", sipType_QPixelFormat_YUVLayout, &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_AlphaPremultiplied, &a4, sipType_QPixelFormat_TypeInterpretation, &a5, sipType_QPixelFormat_ByteOrder, &a6))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatYuv(a0,a1,a2,a3,a4,a5,a6));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatYuv, doc_qPixelFormatYuv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatHsv, "qPixelFormatHsv(int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.FloatingPoint) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatHsv(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatHsv(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::uchar a1 = 0;
         ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
         ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
         ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::FloatingPoint;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatHsv(a0,a1,a2,a3,a4));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatHsv, doc_qPixelFormatHsv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatHsl, "qPixelFormatHsl(int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.FloatingPoint) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatHsl(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatHsl(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::uchar a1 = 0;
         ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
         ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
         ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::FloatingPoint;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatHsl(a0,a1,a2,a3,a4));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatHsl, doc_qPixelFormatHsl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatCmyk, "qPixelFormatCmyk(int, alphaSize: int = 0, alphaUsage: QPixelFormat.AlphaUsage = QPixelFormat.IgnoresAlpha, alphaPosition: QPixelFormat.AlphaPosition = QPixelFormat.AtBeginning, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatCmyk(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatCmyk(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::uchar a1 = 0;
         ::QPixelFormat::AlphaUsage a2 = QPixelFormat::IgnoresAlpha;
         ::QPixelFormat::AlphaPosition a3 = QPixelFormat::AtBeginning;
         ::QPixelFormat::TypeInterpretation a4 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_alphaSize,
            sipName_alphaUsage,
            sipName_alphaPosition,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|MEEE", &a0, &a1, sipType_QPixelFormat_AlphaUsage, &a2, sipType_QPixelFormat_AlphaPosition, &a3, sipType_QPixelFormat_TypeInterpretation, &a4))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatCmyk(a0,a1,a2,a3,a4));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatCmyk, doc_qPixelFormatCmyk);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatGrayscale, "qPixelFormatGrayscale(int, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatGrayscale(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatGrayscale(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::QPixelFormat::TypeInterpretation a1 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "M|E", &a0, sipType_QPixelFormat_TypeInterpretation, &a1))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatGrayscale(a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatGrayscale, doc_qPixelFormatGrayscale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qPixelFormatRgba, "qPixelFormatRgba(int, int, int, int, QPixelFormat.AlphaUsage, QPixelFormat.AlphaPosition, premultiplied: QPixelFormat.AlphaPremultiplied = QPixelFormat.NotPremultiplied, typeInterpretation: QPixelFormat.TypeInterpretation = QPixelFormat.UnsignedInteger) -> QPixelFormat");

extern "C" {static PyObject *func_qPixelFormatRgba(PyObject *,PyObject *, PyObject *);}
static PyObject *func_qPixelFormatRgba(PyObject *,PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::uchar a0;
         ::uchar a1;
         ::uchar a2;
         ::uchar a3;
         ::QPixelFormat::AlphaUsage a4;
         ::QPixelFormat::AlphaPosition a5;
         ::QPixelFormat::AlphaPremultiplied a6 = QPixelFormat::NotPremultiplied;
         ::QPixelFormat::TypeInterpretation a7 = QPixelFormat::UnsignedInteger;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_premultiplied,
            sipName_typeInterpretation,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "MMMMEE|EE", &a0, &a1, &a2, &a3, sipType_QPixelFormat_AlphaUsage, &a4, sipType_QPixelFormat_AlphaPosition, &a5, sipType_QPixelFormat_AlphaPremultiplied, &a6, sipType_QPixelFormat_TypeInterpretation, &a7))
        {
             ::QPixelFormat*sipRes;

            sipRes = new  ::QPixelFormat(qPixelFormatRgba(a0,a1,a2,a3,a4,a5,a6,a7));

            return sipConvertFromNewType(sipRes,sipType_QPixelFormat,SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qPixelFormatRgba, doc_qPixelFormatRgba);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qFuzzyCompare, "qFuzzyCompare(QMatrix4x4, QMatrix4x4) -> bool\n"
"qFuzzyCompare(QQuaternion, QQuaternion) -> bool\n"
"qFuzzyCompare(QTransform, QTransform) -> bool\n"
"qFuzzyCompare(QVector2D, QVector2D) -> bool\n"
"qFuzzyCompare(QVector3D, QVector3D) -> bool\n"
"qFuzzyCompare(QVector4D, QVector4D) -> bool");

extern "C" {static PyObject *func_qFuzzyCompare(PyObject *,PyObject *);}
static PyObject *func_qFuzzyCompare(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QMatrix4x4* a0;
        const  ::QMatrix4x4* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QMatrix4x4, &a0, sipType_QMatrix4x4, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QQuaternion* a0;
        const  ::QQuaternion* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QQuaternion, &a0, sipType_QQuaternion, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QTransform* a0;
        const  ::QTransform* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QTransform, &a0, sipType_QTransform, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QVector2D* a0;
        const  ::QVector2D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector2D, &a0, sipType_QVector2D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QVector3D* a0;
        const  ::QVector3D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector3D, &a0, sipType_QVector3D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QVector4D* a0;
        const  ::QVector4D* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9J9", sipType_QVector4D, &a0, sipType_QVector4D, &a1))
        {
            bool sipRes;

            sipRes = qFuzzyCompare(*a0,*a1);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qFuzzyCompare, doc_qFuzzyCompare);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot___mul__(PyObject *,PyObject *);}
static PyObject *slot___mul__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPoint, &a0, sipType_QMatrix4x4, &a1))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1J9", sipType_QPointF, &a0, &a0State, sipType_QMatrix4x4, &a1))
        {
             ::QPointF*sipRes;

            sipRes = new  ::QPointF((*a0 * *a1));
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return sipConvertFromNewType(sipRes,sipType_QPointF,SIP_NULLPTR);
        }
    }

    {
        const  ::QPoint* a0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPoint, &a0, sipType_QTransform, &a1))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1J9", sipType_QPointF, &a0, &a0State, sipType_QTransform, &a1))
        {
             ::QPointF*sipRes;

            sipRes = new  ::QPointF((*a0 * *a1));
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return sipConvertFromNewType(sipRes,sipType_QPointF,SIP_NULLPTR);
        }
    }

    {
        const  ::QLineF* a0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QLineF, &a0, sipType_QTransform, &a1))
        {
             ::QLineF*sipRes;

            sipRes = new  ::QLineF((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QLineF,SIP_NULLPTR);
        }
    }

    {
        const  ::QLine* a0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QLine, &a0, sipType_QTransform, &a1))
        {
             ::QLine*sipRes;

            sipRes = new  ::QLine((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QLine,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


PyDoc_STRVAR(doc_qt_set_sequence_auto_mnemonic, "qt_set_sequence_auto_mnemonic(bool)");

extern "C" {static PyObject *func_qt_set_sequence_auto_mnemonic(PyObject *,PyObject *);}
static PyObject *func_qt_set_sequence_auto_mnemonic(PyObject *,PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "b", &a0))
        {
            qt_set_sequence_auto_mnemonic(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qt_set_sequence_auto_mnemonic, doc_qt_set_sequence_auto_mnemonic);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot___rshift__(PyObject *,PyObject *);}
static PyObject *slot___rshift__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDataStream* a0;
         ::QColor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColor, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QBrush* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QBrush, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QColorSpace* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColorSpace, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QCursor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QCursor, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QFont* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QIcon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QIcon, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QImage* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QImage, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QKeySequence* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QKeySequence, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x4, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPainterPath, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPalette* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPalette, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPen* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPen, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPicture* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPicture, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPixmap* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPixmap, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPolygonF* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygonF, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QPolygon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygon, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QQuaternion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QQuaternion, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QRegion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QRegion, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QStandardItem* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QStandardItem, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QTextLength* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextLength, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QTextFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFormat, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTransform, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector2D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QVector3D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector3D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
         ::QVector4D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector4D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot___lshift__(PyObject *,PyObject *);}
static PyObject *slot___lshift__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QDataStream* a0;
        const  ::QColor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColor, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QBrush* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QBrush, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QColorSpace* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QColorSpace, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QCursor* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QCursor, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QFont* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QFont, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QIcon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QIcon, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QImage* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QImage, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QKeySequence* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QKeySequence, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QMatrix4x4* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QMatrix4x4, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPainterPath, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPalette* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPalette, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPen* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPen, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPicture* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPicture, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPixmap* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPixmap, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPolygonF* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygonF, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QPolygon* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QPolygon, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QQuaternion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QQuaternion, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QRegion* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QRegion, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QStandardItem* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QStandardItem, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QTextLength* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextLength, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QTextFormat* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTextFormat, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QTransform, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QVector2D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector2D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QVector3D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector3D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    {
         ::QDataStream* a0;
        const  ::QVector4D* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QVector4D, &a1))
        {
             ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes,sipType_QDataStream,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static void *init_type_QPointF(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPointF(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QPointF *sipCpp = SIP_NULLPTR;

    {
         ::QPainterPath::Element* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPainterPath_Element, &a0))
        {
            sipCpp = new  ::QPointF(a0->operator  ::QPointF());

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}

static sipInitExtenderDef initExtenders[] = {
    {-1, init_type_QPointF, {28, 0, 0}, SIP_NULLPTR},
    {-1, SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};

static sipPySlotExtenderDef slotExtenders[] = {
    {(void *)slot___mul__, mul_slot, {0, 0, 0}},
    {(void *)slot___rshift__, rshift_slot, {0, 0, 0}},
    {(void *)slot___lshift__, lshift_slot, {0, 0, 0}},
    {SIP_NULLPTR, (sipPySlotType)0, {0, 0, 0}}
};


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QGradient(void **);}
static const sipTypeDef *sipSubClass_QGradient(void **sipCppRet)
{
     ::QGradient *sipCpp = reinterpret_cast< ::QGradient *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 127 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qbrush.sip"
    switch (sipCpp->type())
    {
    case QGradient::ConicalGradient:
        sipType = sipType_QConicalGradient;
        break;
    
    case QGradient::LinearGradient:
        sipType = sipType_QLinearGradient;
        break;
    
    case QGradient::RadialGradient:
        sipType = sipType_QRadialGradient;
        break;
    
    default:
        sipType = 0;
    }
#line 7442 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QInputEvent(void **);}
static const sipTypeDef *sipSubClass_QInputEvent(void **sipCppRet)
{
     ::QEvent *sipCpp = reinterpret_cast< ::QEvent *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qevent.sip"
    switch (sipCpp->type())
    {
    case QEvent::ActionAdded:
    case QEvent::ActionChanged:
    case QEvent::ActionRemoved:
        sipType = sipType_QActionEvent;
        break;
    
    case QEvent::Close:
        sipType = sipType_QCloseEvent;
        break;
    
    case QEvent::ContextMenu:
        sipType = sipType_QContextMenuEvent;
        break;
    
    case QEvent::DragEnter:
        sipType = sipType_QDragEnterEvent;
        break;
    
    case QEvent::DragLeave:
        sipType = sipType_QDragLeaveEvent;
        break;
    
    case QEvent::DragMove:
        sipType = sipType_QDragMoveEvent;
        break;
    
    case QEvent::Drop:
        sipType = sipType_QDropEvent;
        break;
    
    case QEvent::Enter:
        sipType = sipType_QEnterEvent;
        break;
    
    case QEvent::FileOpen:
        sipType = sipType_QFileOpenEvent;
        break;
    
    case QEvent::FocusIn:
    case QEvent::FocusOut:
        sipType = sipType_QFocusEvent;
        break;
    
    case QEvent::Hide:
        sipType = sipType_QHideEvent;
        break;
    
    case QEvent::HoverEnter:
    case QEvent::HoverLeave:
    case QEvent::HoverMove:
        sipType = sipType_QHoverEvent;
        break;
    
    case QEvent::IconDrag:
        sipType = sipType_QIconDragEvent;
        break;
    
    case QEvent::InputMethod:
        sipType = sipType_QInputMethodEvent;
        break;
    
    case QEvent::KeyPress:
    case QEvent::KeyRelease:
    case QEvent::ShortcutOverride:
        sipType = sipType_QKeyEvent;
        break;
    
    case QEvent::MouseButtonDblClick:
    case QEvent::MouseButtonPress:
    case QEvent::MouseButtonRelease:
    case QEvent::MouseMove:
        sipType = sipType_QMouseEvent;
        break;
    
    case QEvent::Move:
        sipType = sipType_QMoveEvent;
        break;
    
    case QEvent::Paint:
        sipType = sipType_QPaintEvent;
        break;
    
    case QEvent::Resize:
        sipType = sipType_QResizeEvent;
        break;
    
    case QEvent::Shortcut:
        sipType = sipType_QShortcutEvent;
        break;
    
    case QEvent::Show:
        sipType = sipType_QShowEvent;
        break;
    
    case QEvent::StatusTip:
        sipType = sipType_QStatusTipEvent;
        break;
    
    case QEvent::TabletMove:
    case QEvent::TabletPress:
    case QEvent::TabletRelease:
    case QEvent::TabletEnterProximity:
    case QEvent::TabletLeaveProximity:
        sipType = sipType_QTabletEvent;
        break;
    
    case QEvent::ToolTip:
    case QEvent::WhatsThis:
        sipType = sipType_QHelpEvent;
        break;
    
    case QEvent::WhatsThisClicked:
        sipType = sipType_QWhatsThisClickedEvent;
        break;
    
    case QEvent::Wheel:
        sipType = sipType_QWheelEvent;
        break;
    
    case QEvent::WindowStateChange:
        sipType = sipType_QWindowStateChangeEvent;
        break;
    
    case QEvent::TouchBegin:
    case QEvent::TouchUpdate:
    case QEvent::TouchEnd:
    case QEvent::TouchCancel:
        sipType = sipType_QTouchEvent;
        break;
    
    case QEvent::InputMethodQuery:
        sipType = sipType_QInputMethodQueryEvent;
        break;
    
    case QEvent::Expose:
        sipType = sipType_QExposeEvent;
        break;
    
    case QEvent::ScrollPrepare:
        sipType = sipType_QScrollPrepareEvent;
        break;
    
    case QEvent::Scroll:
        sipType = sipType_QScrollEvent;
        break;
    
    #if QT_VERSION >= 0x050200
    case QEvent::NativeGesture:
        sipType = sipType_QNativeGestureEvent;
        break;
    #endif
    
    #if QT_VERSION >= 0x050500
    case QEvent::PlatformSurface:
        sipType = sipType_QPlatformSurfaceEvent;
        break;
    #endif
    
    default:
        sipType = 0;
    }
#line 7619 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QGuiApplication(void **);}
static const sipTypeDef *sipSubClass_QGuiApplication(void **sipCppRet)
{
     ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qguiapplication.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_Desktop_OpenGL)
        {sipName_QOpenGLTimeMonitor, &sipType_QOpenGLTimeMonitor, -1, 1},
    #else
        {0, 0, -1, 1},
    #endif
        {sipName_QSyntaxHighlighter, &sipType_QSyntaxHighlighter, -1, 2},
        {sipName_QWindow, &sipType_QWindow, 25, 3},
        {sipName_QPdfWriter, &sipType_QPdfWriter, -1, 4},
        {sipName_QMovie, &sipType_QMovie, -1, 5},
    #if defined(SIP_FEATURE_PyQt_SessionManager)
        {sipName_QSessionManager, &sipType_QSessionManager, -1, 6},
    #else
        {0, 0, -1, 6},
    #endif
        {sipName_QAbstractTextDocumentLayout, &sipType_QAbstractTextDocumentLayout, -1, 7},
        {sipName_QScreen, &sipType_QScreen, -1, 8},
        {sipName_QTextObject, &sipType_QTextObject, 28, 9},
        {sipName_QStandardItemModel, &sipType_QStandardItemModel, -1, 10},
        {sipName_QDrag, &sipType_QDrag, -1, 11},
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLContextGroup, &sipType_QOpenGLContextGroup, -1, 12},
    #else
        {0, 0, -1, 12},
    #endif
        {sipName_QValidator, &sipType_QValidator, 32, 13},
        {sipName_QTextDocument, &sipType_QTextDocument, -1, 14},
    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLVertexArrayObject, &sipType_QOpenGLVertexArrayObject, -1, 15},
    #else
        {0, 0, -1, 15},
    #endif
    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLDebugLogger, &sipType_QOpenGLDebugLogger, -1, 16},
    #else
        {0, 0, -1, 16},
    #endif
        {sipName_QGuiApplication, &sipType_QGuiApplication, -1, 17},
    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_Desktop_OpenGL)
        {sipName_QOpenGLTimerQuery, &sipType_QOpenGLTimerQuery, -1, 18},
    #else
        {0, 0, -1, 18},
    #endif
    #if QT_VERSION >= 0x050100
        {sipName_QOffscreenSurface, &sipType_QOffscreenSurface, -1, 19},
    #else
        {0, 0, -1, 19},
    #endif
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLShaderProgram, &sipType_QOpenGLShaderProgram, -1, 20},
    #else
        {0, 0, -1, 20},
    #endif
        {sipName_QStyleHints, &sipType_QStyleHints, -1, 21},
        {sipName_QClipboard, &sipType_QClipboard, -1, 22},
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLShader, &sipType_QOpenGLShader, -1, 23},
    #else
        {0, 0, -1, 23},
    #endif
    #if defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLContext, &sipType_QOpenGLContext, -1, 24},
    #else
        {0, 0, -1, 24},
    #endif
        {sipName_QInputMethod, &sipType_QInputMethod, -1, -1},
    #if QT_VERSION >= 0x050400
        {sipName_QPaintDeviceWindow, &sipType_QPaintDeviceWindow, 26, -1},
    #else
        {0, 0, 26, -1},
    #endif
    #if QT_VERSION >= 0x050400 && defined(SIP_FEATURE_PyQt_OpenGL)
        {sipName_QOpenGLWindow, &sipType_QOpenGLWindow, -1, 27},
    #else
        {0, 0, -1, 27},
    #endif
    #if QT_VERSION >= 0x050400
        {sipName_QRasterWindow, &sipType_QRasterWindow, -1, -1},
    #else
        {0, 0, -1, -1},
    #endif
        {sipName_QTextBlockGroup, &sipType_QTextBlockGroup, 30, 29},
        {sipName_QTextFrame, &sipType_QTextFrame, 31, -1},
        {sipName_QTextList, &sipType_QTextList, -1, -1},
        {sipName_QTextTable, &sipType_QTextTable, -1, -1},
    #if QT_VERSION >= 0x050100
        {sipName_QRegularExpressionValidator, &sipType_QRegularExpressionValidator, -1, 33},
    #else
        {0, 0, -1, 33},
    #endif
        {sipName_QIntValidator, &sipType_QIntValidator, -1, 34},
        {sipName_QDoubleValidator, &sipType_QDoubleValidator, -1, 35},
        {sipName_QRegExpValidator, &sipType_QRegExpValidator, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 7749 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

    return sipType;
}


/* This defines each external type declared in this module, */
static sipExternalTypeDef externalTypesTable[] = {
    {4, "QAction"},
    {-1, SIP_NULLPTR}
};


extern "C" {static PyObject *slot_QTouchDevice_CapabilityFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTouchDevice_CapabilityFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTouchDevice::CapabilityFlag a0;
         ::QTouchDevice::Capabilities* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTouchDevice_CapabilityFlag, &a0, sipType_QTouchDevice_Capabilities, &a1, &a1State))
        {
             ::QTouchDevice::Capabilities*sipRes;

            sipRes = new  ::QTouchDevice::Capabilities((a0 | *a1));
            sipReleaseType(a1,sipType_QTouchDevice_Capabilities,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTouchDevice_Capabilities,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTouchDevice_CapabilityFlag[] = {
    {(void *)slot_QTouchDevice_CapabilityFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QTextOption_Flag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTextOption_Flag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextOption::Flag a0;
         ::QTextOption::Flags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTextOption_Flag, &a0, sipType_QTextOption_Flags, &a1, &a1State))
        {
             ::QTextOption::Flags*sipRes;

            sipRes = new  ::QTextOption::Flags((a0 | *a1));
            sipReleaseType(a1,sipType_QTextOption_Flags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTextOption_Flags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTextOption_Flag[] = {
    {(void *)slot_QTextOption_Flag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QTextFormat_PageBreakFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTextFormat_PageBreakFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextFormat::PageBreakFlag a0;
         ::QTextFormat::PageBreakFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTextFormat_PageBreakFlag, &a0, sipType_QTextFormat_PageBreakFlags, &a1, &a1State))
        {
             ::QTextFormat::PageBreakFlags*sipRes;

            sipRes = new  ::QTextFormat::PageBreakFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QTextFormat_PageBreakFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTextFormat_PageBreakFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTextFormat_PageBreakFlag[] = {
    {(void *)slot_QTextFormat_PageBreakFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QTextDocument_FindFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTextDocument_FindFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextDocument::FindFlag a0;
         ::QTextDocument::FindFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTextDocument_FindFlag, &a0, sipType_QTextDocument_FindFlags, &a1, &a1State))
        {
             ::QTextDocument::FindFlags*sipRes;

            sipRes = new  ::QTextDocument::FindFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QTextDocument_FindFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTextDocument_FindFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTextDocument_FindFlag[] = {
    {(void *)slot_QTextDocument_FindFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSurfaceFormat_FormatOption___or__(PyObject *,PyObject *);}
static PyObject *slot_QSurfaceFormat_FormatOption___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSurfaceFormat::FormatOption a0;
         ::QSurfaceFormat::FormatOptions* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSurfaceFormat_FormatOption, &a0, sipType_QSurfaceFormat_FormatOptions, &a1, &a1State))
        {
             ::QSurfaceFormat::FormatOptions*sipRes;

            sipRes = new  ::QSurfaceFormat::FormatOptions((a0 | *a1));
            sipReleaseType(a1,sipType_QSurfaceFormat_FormatOptions,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSurfaceFormat_FormatOptions,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSurfaceFormat_FormatOption[] = {
    {(void *)slot_QSurfaceFormat_FormatOption___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QRawFont_LayoutFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QRawFont_LayoutFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QRawFont::LayoutFlag a0;
         ::QRawFont::LayoutFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QRawFont_LayoutFlag, &a0, sipType_QRawFont_LayoutFlags, &a1, &a1State))
        {
             ::QRawFont::LayoutFlags*sipRes;

            sipRes = new  ::QRawFont::LayoutFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QRawFont_LayoutFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QRawFont_LayoutFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QRawFont_LayoutFlag[] = {
    {(void *)slot_QRawFont_LayoutFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QPaintEngine_PaintEngineFeature___or__(PyObject *,PyObject *);}
static PyObject *slot_QPaintEngine_PaintEngineFeature___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPaintEngine::PaintEngineFeature a0;
         ::QPaintEngine::PaintEngineFeatures* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QPaintEngine_PaintEngineFeature, &a0, sipType_QPaintEngine_PaintEngineFeatures, &a1, &a1State))
        {
             ::QPaintEngine::PaintEngineFeatures*sipRes;

            sipRes = new  ::QPaintEngine::PaintEngineFeatures((a0 | *a1));
            sipReleaseType(a1,sipType_QPaintEngine_PaintEngineFeatures,a1State);

            return sipConvertFromNewType(sipRes,sipType_QPaintEngine_PaintEngineFeatures,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QPaintEngine_PaintEngineFeature[] = {
    {(void *)slot_QPaintEngine_PaintEngineFeature___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QTextItem_RenderFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTextItem_RenderFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTextItem::RenderFlag a0;
         ::QTextItem::RenderFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTextItem_RenderFlag, &a0, sipType_QTextItem_RenderFlags, &a1, &a1State))
        {
             ::QTextItem::RenderFlags*sipRes;

            sipRes = new  ::QTextItem::RenderFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QTextItem_RenderFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTextItem_RenderFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTextItem_RenderFlag[] = {
    {(void *)slot_QTextItem_RenderFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QPainter_RenderHint___or__(PyObject *,PyObject *);}
static PyObject *slot_QPainter_RenderHint___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainter::RenderHint a0;
         ::QPainter::RenderHints* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QPainter_RenderHint, &a0, sipType_QPainter_RenderHints, &a1, &a1State))
        {
             ::QPainter::RenderHints*sipRes;

            sipRes = new  ::QPainter::RenderHints((a0 | *a1));
            sipReleaseType(a1,sipType_QPainter_RenderHints,a1State);

            return sipConvertFromNewType(sipRes,sipType_QPainter_RenderHints,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QPainter_RenderHint[] = {
    {(void *)slot_QPainter_RenderHint___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLTexture_Feature___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLTexture_Feature___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLTexture::Feature a0;
         ::QOpenGLTexture::Features* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLTexture_Feature, &a0, sipType_QOpenGLTexture_Features, &a1, &a1State))
        {
             ::QOpenGLTexture::Features*sipRes;

            sipRes = new  ::QOpenGLTexture::Features((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLTexture_Features,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLTexture_Features,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLTexture_Feature[] = {
    {(void *)slot_QOpenGLTexture_Feature___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLShader_ShaderTypeBit___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLShader_ShaderTypeBit___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLShader::ShaderTypeBit a0;
         ::QOpenGLShader::ShaderType* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLShader_ShaderTypeBit, &a0, sipType_QOpenGLShader_ShaderType, &a1, &a1State))
        {
             ::QOpenGLShader::ShaderType*sipRes;

            sipRes = new  ::QOpenGLShader::ShaderType((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLShader_ShaderType,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLShader_ShaderType,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLShader_ShaderTypeBit[] = {
    {(void *)slot_QOpenGLShader_ShaderTypeBit___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLDebugMessage_Severity___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLDebugMessage_Severity___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugMessage::Severity a0;
         ::QOpenGLDebugMessage::Severities* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLDebugMessage_Severity, &a0, sipType_QOpenGLDebugMessage_Severities, &a1, &a1State))
        {
             ::QOpenGLDebugMessage::Severities*sipRes;

            sipRes = new  ::QOpenGLDebugMessage::Severities((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Severities,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLDebugMessage_Severities,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLDebugMessage_Severity[] = {
    {(void *)slot_QOpenGLDebugMessage_Severity___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLDebugMessage_Type___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLDebugMessage_Type___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugMessage::Type a0;
         ::QOpenGLDebugMessage::Types* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLDebugMessage_Type, &a0, sipType_QOpenGLDebugMessage_Types, &a1, &a1State))
        {
             ::QOpenGLDebugMessage::Types*sipRes;

            sipRes = new  ::QOpenGLDebugMessage::Types((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Types,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLDebugMessage_Types,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLDebugMessage_Type[] = {
    {(void *)slot_QOpenGLDebugMessage_Type___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLDebugMessage_Source___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLDebugMessage_Source___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLDebugMessage::Source a0;
         ::QOpenGLDebugMessage::Sources* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLDebugMessage_Source, &a0, sipType_QOpenGLDebugMessage_Sources, &a1, &a1State))
        {
             ::QOpenGLDebugMessage::Sources*sipRes;

            sipRes = new  ::QOpenGLDebugMessage::Sources((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLDebugMessage_Sources,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLDebugMessage_Sources,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLDebugMessage_Source[] = {
    {(void *)slot_QOpenGLDebugMessage_Source___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QOpenGLBuffer_RangeAccessFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QOpenGLBuffer_RangeAccessFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QOpenGLBuffer::RangeAccessFlag a0;
         ::QOpenGLBuffer::RangeAccessFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QOpenGLBuffer_RangeAccessFlag, &a0, sipType_QOpenGLBuffer_RangeAccessFlags, &a1, &a1State))
        {
             ::QOpenGLBuffer::RangeAccessFlags*sipRes;

            sipRes = new  ::QOpenGLBuffer::RangeAccessFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QOpenGLBuffer_RangeAccessFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QOpenGLBuffer_RangeAccessFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QOpenGLBuffer_RangeAccessFlag[] = {
    {(void *)slot_QOpenGLBuffer_RangeAccessFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QKeySequence_StandardKey___eq__(PyObject *,PyObject *);}
static PyObject *slot_QKeySequence_StandardKey___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QKeySequence::StandardKey sipCpp = static_cast< ::QKeySequence::StandardKey>(sipConvertToEnum(sipSelf, sipType_QKeySequence_StandardKey));

    if (PyErr_Occurred())
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QKeyEvent* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J8", sipType_QKeyEvent, &a0))
        {
            bool sipRes;

            sipRes = operator==(sipCpp, a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QKeySequence_StandardKey[] = {
    {(void *)slot_QKeySequence_StandardKey___eq__, eq_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QTouchEvent_TouchPoint_InfoFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QTouchEvent_TouchPoint_InfoFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QTouchEvent::TouchPoint::InfoFlag a0;
         ::QTouchEvent::TouchPoint::InfoFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QTouchEvent_TouchPoint_InfoFlag, &a0, sipType_QTouchEvent_TouchPoint_InfoFlags, &a1, &a1State))
        {
             ::QTouchEvent::TouchPoint::InfoFlags*sipRes;

            sipRes = new  ::QTouchEvent::TouchPoint::InfoFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QTouchEvent_TouchPoint_InfoFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QTouchEvent_TouchPoint_InfoFlags,SIP_NULLPTR);
        }
    }

    {
         ::QTouchEvent::TouchPoint::InfoFlag a0;
         ::QTouchEvent::TouchPoint::InfoFlag a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EE", sipType_QTouchEvent_TouchPoint_InfoFlag, &a0, sipType_QTouchEvent_TouchPoint_InfoFlag, &a1))
        {
             ::QTouchEvent::TouchPoint::InfoFlags*sipRes;

            sipRes = new  ::QTouchEvent::TouchPoint::InfoFlags((a0 | a1));

            return sipConvertFromNewType(sipRes,sipType_QTouchEvent_TouchPoint_InfoFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QTouchEvent_TouchPoint_InfoFlag[] = {
    {(void *)slot_QTouchEvent_TouchPoint_InfoFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QWindow__Visibility, {0}, 0}, sipNameNr_Visibility, 383, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QWindow__AncestorMode, {0}, 0}, sipNameNr_AncestorMode, 383, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QDoubleValidator__Notation, {0}, 0}, sipNameNr_Notation, 27, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QValidator__State, {0}, 0}, sipNameNr_State, 362, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTransform__TransformationType, {0}, 0}, sipNameNr_TransformationType, 360, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTouchDevice__CapabilityFlag, {0}, 0}, sipNameNr_CapabilityFlag, 352, slots_QTouchDevice_CapabilityFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTouchDevice__DeviceType, {0}, 0}, sipNameNr_DeviceType, 352, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextOption__TabType, {0}, 0}, sipNameNr_TabType, 342, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextOption__Flag, {0}, 0}, sipNameNr_Flag, 342, slots_QTextOption_Flag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextOption__WrapMode, {0}, 0}, sipNameNr_WrapMode, 342, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextLine__CursorPosition, {0}, 0}, sipNameNr_CursorPosition, 334, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextLine__Edge, {0}, 0}, sipNameNr_Edge, 334, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextLayout__CursorMode, {0}, 0}, sipNameNr_CursorMode, 329, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFrameFormat__BorderStyle, {0}, 0}, sipNameNr_BorderStyle, 321, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFrameFormat__Position, {0}, 0}, sipNameNr_Position, 321, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextListFormat__Style, {0}, 0}, sipNameNr_Style, 338, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QTextBlockFormat__MarkerType, {0}, 0}, sipNameNr_MarkerType, 289, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextBlockFormat__LineHeightTypes, {0}, 0}, sipNameNr_LineHeightTypes, 289, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior, {0}, 0}, sipNameNr_FontPropertiesInheritanceBehavior, 294, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__UnderlineStyle, {0}, 0}, sipNameNr_UnderlineStyle, 294, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCharFormat__VerticalAlignment, {0}, 0}, sipNameNr_VerticalAlignment, 294, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFormat__Property, {0}, 0}, sipNameNr_Property, 312, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFormat__PageBreakFlag, {0}, 0}, sipNameNr_PageBreakFlag, 312, slots_QTextFormat_PageBreakFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFormat__ObjectTypes, {0}, 0}, sipNameNr_ObjectTypes, 312, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextFormat__FormatType, {0}, 0}, sipNameNr_FormatType, 312, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextLength__Type, {0}, 0}, sipNameNr_Type, 332, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextDocument__MarkdownFeature, {0}, 0}, sipNameNr_MarkdownFeature, 302, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextDocument__Stacks, {0}, 0}, sipNameNr_Stacks, 302, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextDocument__ResourceType, {0}, 0}, sipNameNr_ResourceType, 302, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextDocument__FindFlag, {0}, 0}, sipNameNr_FindFlag, 302, slots_QTextDocument_FindFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextDocument__MetaInformation, {0}, 0}, sipNameNr_MetaInformation, 302, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCursor__SelectionType, {0}, 0}, sipNameNr_SelectionType, 298, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCursor__MoveOperation, {0}, 0}, sipNameNr_MoveOperation, 298, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextCursor__MoveMode, {0}, 0}, sipNameNr_MoveMode, 298, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__ColorSpace, {0}, 0}, sipNameNr_ColorSpace, 276, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__OpenGLContextProfile, {0}, 0}, sipNameNr_OpenGLContextProfile, 276, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__RenderableType, {0}, 0}, sipNameNr_RenderableType, 276, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__SwapBehavior, {0}, 0}, sipNameNr_SwapBehavior, 276, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurfaceFormat__FormatOption, {0}, 0}, sipNameNr_FormatOption, 276, slots_QSurfaceFormat_FormatOption},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurface__SurfaceType, {0}, 0}, sipNameNr_SurfaceType, 273, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSurface__SurfaceClass, {0}, 0}, sipNameNr_SurfaceClass, 273, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QStaticText__PerformanceHint, {0}, 0}, sipNameNr_PerformanceHint, 269, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QStandardItem__ItemType, {0}, 0}, sipNameNr_ItemType, 266, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QRegion__RegionType, {0}, 0}, sipNameNr_RegionType, 254, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QRawFont__LayoutFlag, {0}, 0}, sipNameNr_LayoutFlag, 249, slots_QRawFont_LayoutFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QRawFont__AntialiasingType, {0}, 0}, sipNameNr_AntialiasingType, 249, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__ByteOrder, {0}, 0}, sipNameNr_ByteOrder, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__YUVLayout, {0}, 0}, sipNameNr_YUVLayout, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__TypeInterpretation, {0}, 0}, sipNameNr_TypeInterpretation, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaPremultiplied, {0}, 0}, sipNameNr_AlphaPremultiplied, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaPosition, {0}, 0}, sipNameNr_AlphaPosition, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__AlphaUsage, {0}, 0}, sipNameNr_AlphaUsage, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPixelFormat__ColorModel, {0}, 0}, sipNameNr_ColorModel, 230, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPalette__ColorRole, {0}, 0}, sipNameNr_ColorRole, 223, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPalette__ColorGroup, {0}, 0}, sipNameNr_ColorGroup, 223, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPainterPath__ElementType, {0}, 0}, sipNameNr_ElementType, 217, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__Type, {0}, 0}, sipNameNr_Type, 201, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__PolygonDrawMode, {0}, 0}, sipNameNr_PolygonDrawMode, 201, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__DirtyFlag, {0}, 0}, sipNameNr_DirtyFlag, 201, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPaintEngine__PaintEngineFeature, {0}, 0}, sipNameNr_PaintEngineFeature, 201, slots_QPaintEngine_PaintEngineFeature},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTextItem__RenderFlag, {0}, 0}, sipNameNr_RenderFlag, 326, slots_QTextItem_RenderFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPaintDevice__PaintDeviceMetric, {0}, 0}, sipNameNr_PaintDeviceMetric, 198, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPainter__PixmapFragmentHint, {0}, 0}, sipNameNr_PixmapFragmentHint, 210, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPainter__CompositionMode, {0}, 0}, sipNameNr_CompositionMode, 210, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPainter__RenderHint, {0}, 0}, sipNameNr_RenderHint, 210, slots_QPainter_RenderHint},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageSize__SizeMatchPolicy, {0}, 0}, sipNameNr_SizeMatchPolicy, 190, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageSize__Unit, {0}, 0}, sipNameNr_Unit, 190, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageSize__PageSizeId, {0}, 0}, sipNameNr_PageSizeId, 190, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Mode, {0}, 0}, sipNameNr_Mode, 186, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Orientation, {0}, 0}, sipNameNr_Orientation, 186, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPageLayout__Unit, {0}, 0}, sipNameNr_Unit, 186, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPagedPaintDevice__PdfVersion, {0}, 0}, sipNameNr_PdfVersion, 194, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPagedPaintDevice__PageSize, {0}, 0}, sipNameNr_PageSize, 194, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLWindow__UpdateBehavior, {0}, 0}, sipNameNr_UpdateBehavior, 184, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTextureBlitter__Origin, {0}, 0}, sipNameNr_Origin, 179, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__ComparisonMode, {0}, 0}, sipNameNr_ComparisonMode, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__ComparisonFunction, {0}, 0}, sipNameNr_ComparisonFunction, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__CoordinateDirection, {0}, 0}, sipNameNr_CoordinateDirection, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__WrapMode, {0}, 0}, sipNameNr_WrapMode, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__Filter, {0}, 0}, sipNameNr_Filter, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__DepthStencilMode, {0}, 0}, sipNameNr_DepthStencilMode, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__SwizzleValue, {0}, 0}, sipNameNr_SwizzleValue, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__SwizzleComponent, {0}, 0}, sipNameNr_SwizzleComponent, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__Feature, {0}, 0}, sipNameNr_Feature, 160, slots_QOpenGLTexture_Feature},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__PixelType, {0}, 0}, sipNameNr_PixelType, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__PixelFormat, {0}, 0}, sipNameNr_PixelFormat, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__CubeMapFace, {0}, 0}, sipNameNr_CubeMapFace, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__TextureFormat, {0}, 0}, sipNameNr_TextureFormat, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__TextureUnitReset, {0}, 0}, sipNameNr_TextureUnitReset, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__MipMapGeneration, {0}, 0}, sipNameNr_MipMapGeneration, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__BindingTarget, {0}, 0}, sipNameNr_BindingTarget, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLTexture__Target, {0}, 0}, sipNameNr_Target, 160, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLShader__ShaderTypeBit, {0}, 0}, sipNameNr_ShaderTypeBit, 156, slots_QOpenGLShader_ShaderTypeBit},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLFramebufferObject__FramebufferRestorePolicy, {0}, 0}, sipNameNr_FramebufferRestorePolicy, 150, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLFramebufferObject__Attachment, {0}, 0}, sipNameNr_Attachment, 150, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLDebugLogger__LoggingMode, {0}, 0}, sipNameNr_LoggingMode, 141, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLDebugMessage__Severity, {0}, 0}, sipNameNr_Severity, 143, slots_QOpenGLDebugMessage_Severity},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLDebugMessage__Type, {0}, 0}, sipNameNr_Type, 143, slots_QOpenGLDebugMessage_Type},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLDebugMessage__Source, {0}, 0}, sipNameNr_Source, 143, slots_QOpenGLDebugMessage_Source},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLContext__OpenGLModuleType, {0}, 0}, sipNameNr_OpenGLModuleType, 138, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLBuffer__RangeAccessFlag, {0}, 0}, sipNameNr_RangeAccessFlag, 132, slots_QOpenGLBuffer_RangeAccessFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLBuffer__Access, {0}, 0}, sipNameNr_Access, 132, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLBuffer__UsagePattern, {0}, 0}, sipNameNr_UsagePattern, 132, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QOpenGLBuffer__Type, {0}, 0}, sipNameNr_Type, 132, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QMovie__CacheMode, {0}, 0}, sipNameNr_CacheMode, 127, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QMovie__MovieState, {0}, 0}, sipNameNr_MovieState, 127, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QKeySequence__StandardKey, {0}, 0}, sipNameNr_StandardKey, 93, slots_QKeySequence_StandardKey},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QKeySequence__SequenceMatch, {0}, 0}, sipNameNr_SequenceMatch, 93, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QKeySequence__SequenceFormat, {0}, 0}, sipNameNr_SequenceFormat, 93, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QInputMethod__Action, {0}, 0}, sipNameNr_Action, 85, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImageWriter__ImageWriterError, {0}, 0}, sipNameNr_ImageWriterError, 82, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImageReader__ImageReaderError, {0}, 0}, sipNameNr_ImageReaderError, 80, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImageIOHandler__Transformation, {0}, 0}, sipNameNr_Transformation, 76, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImageIOHandler__ImageOption, {0}, 0}, sipNameNr_ImageOption, 76, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImage__Format, {0}, 0}, sipNameNr_Format, 73, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QImage__InvertMode, {0}, 0}, sipNameNr_InvertMode, 73, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QIconEngine__IconEngineHook, {0}, 0}, sipNameNr_IconEngineHook, 69, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QIcon__State, {0}, 0}, sipNameNr_State, 65, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QIcon__Mode, {0}, 0}, sipNameNr_Mode, 65, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QGlyphRun__GlyphRunFlag, {0}, 0}, sipNameNr_GlyphRunFlag, 53, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFontDatabase__SystemFont, {0}, 0}, sipNameNr_SystemFont, 47, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFontDatabase__WritingSystem, {0}, 0}, sipNameNr_WritingSystem, 47, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__HintingPreference, {0}, 0}, sipNameNr_HintingPreference, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__SpacingType, {0}, 0}, sipNameNr_SpacingType, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__Capitalization, {0}, 0}, sipNameNr_Capitalization, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__Stretch, {0}, 0}, sipNameNr_Stretch, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__Style, {0}, 0}, sipNameNr_Style, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__Weight, {0}, 0}, sipNameNr_Weight, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__StyleStrategy, {0}, 0}, sipNameNr_StyleStrategy, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QFont__StyleHint, {0}, 0}, sipNameNr_StyleHint, 38, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QPlatformSurfaceEvent__SurfaceEventType, {0}, 0}, sipNameNr_SurfaceEventType, 241, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QScrollEvent__ScrollState, {0}, 0}, sipNameNr_ScrollState, 260, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTouchEvent__TouchPoint__InfoFlag, {0}, 0}, sipNameNr_InfoFlag, 357, slots_QTouchEvent_TouchPoint_InfoFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QInputMethodEvent__AttributeType, {0}, 0}, sipNameNr_AttributeType, 87, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QContextMenuEvent__Reason, {0}, 0}, sipNameNr_Reason, 23, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTabletEvent__PointerType, {0}, 0}, sipNameNr_PointerType, 284, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QTabletEvent__TabletDevice, {0}, 0}, sipNameNr_TabletDevice, 284, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QColorSpace__TransferFunction, {0}, 0}, sipNameNr_TransferFunction, 17, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_SCOPED_ENUM, sipNameNr_QColorSpace__Primaries, {0}, 0}, sipNameNr_Primaries, 17, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QColorSpace__NamedColorSpace, {0}, 0}, sipNameNr_NamedColorSpace, 17, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QClipboard__Mode, {0}, 0}, sipNameNr_Mode, 9, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QGradient__Preset, {0}, 0}, sipNameNr_Preset, 56, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QGradient__Spread, {0}, 0}, sipNameNr_Spread, 56, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QGradient__Type, {0}, 0}, sipNameNr_Type, 56, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QGradient__CoordinateMode, {0}, 0}, sipNameNr_CoordinateMode, 56, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QColor__NameFormat, {0}, 0}, sipNameNr_NameFormat, 12, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QColor__Spec, {0}, 0}, sipNameNr_Spec, 12, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtGui[] = {
    &sipTypeDef_QtGui_QAbstractOpenGLFunctions.ctd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout.ctd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext.ctd_base,
    &sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection.ctd_base,
    0,
    &sipTypeDef_QtGui_QActionEvent.ctd_base,
    &sipTypeDef_QtGui_QBackingStore.ctd_base,
    &sipTypeDef_QtGui_QBitmap.ctd_base,
    &sipTypeDef_QtGui_QBrush.ctd_base,
    &sipTypeDef_QtGui_QClipboard.ctd_base,
    &enumTypes[140].etd_base,
    &sipTypeDef_QtGui_QCloseEvent.ctd_base,
    &sipTypeDef_QtGui_QColor.ctd_base,
    &enumTypes[145].etd_base,
    &enumTypes[146].etd_base,
    &sipTypeDef_QtGui_QColorConstants.ctd_base,
    &sipTypeDef_QtGui_QColorConstants_Svg.ctd_base,
    &sipTypeDef_QtGui_QColorSpace.ctd_base,
    &enumTypes[139].etd_base,
    &enumTypes[138].etd_base,
    &enumTypes[137].etd_base,
    &sipTypeDef_QtGui_QColorTransform.ctd_base,
    &sipTypeDef_QtGui_QConicalGradient.ctd_base,
    &sipTypeDef_QtGui_QContextMenuEvent.ctd_base,
    &enumTypes[134].etd_base,
    &sipTypeDef_QtGui_QCursor.ctd_base,
    &sipTypeDef_QtGui_QDesktopServices.ctd_base,
    &sipTypeDef_QtGui_QDoubleValidator.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtGui_QDrag.ctd_base,
    &sipTypeDef_QtGui_QDragEnterEvent.ctd_base,
    &sipTypeDef_QtGui_QDragLeaveEvent.ctd_base,
    &sipTypeDef_QtGui_QDragMoveEvent.ctd_base,
    &sipTypeDef_QtGui_QDropEvent.ctd_base,
    &sipTypeDef_QtGui_QEnterEvent.ctd_base,
    &sipTypeDef_QtGui_QExposeEvent.ctd_base,
    &sipTypeDef_QtGui_QFileOpenEvent.ctd_base,
    &sipTypeDef_QtGui_QFocusEvent.ctd_base,
    &sipTypeDef_QtGui_QFont.ctd_base,
    &enumTypes[124].etd_base,
    &enumTypes[122].etd_base,
    &enumTypes[123].etd_base,
    &enumTypes[125].etd_base,
    &enumTypes[126].etd_base,
    &enumTypes[129].etd_base,
    &enumTypes[128].etd_base,
    &enumTypes[127].etd_base,
    &sipTypeDef_QtGui_QFontDatabase.ctd_base,
    &enumTypes[120].etd_base,
    &enumTypes[121].etd_base,
    &sipTypeDef_QtGui_QFontInfo.ctd_base,
    &sipTypeDef_QtGui_QFontMetrics.ctd_base,
    &sipTypeDef_QtGui_QFontMetricsF.ctd_base,
    &sipTypeDef_QtGui_QGlyphRun.ctd_base,
    &enumTypes[119].etd_base,
    &sipTypeDef_QtGui_QGlyphRun_GlyphRunFlags.ctd_base,
    &sipTypeDef_QtGui_QGradient.ctd_base,
    &enumTypes[144].etd_base,
    &enumTypes[141].etd_base,
    &enumTypes[142].etd_base,
    &enumTypes[143].etd_base,
    &sipTypeDef_QtGui_QGuiApplication.ctd_base,
    &sipTypeDef_QtGui_QHelpEvent.ctd_base,
    &sipTypeDef_QtGui_QHideEvent.ctd_base,
    &sipTypeDef_QtGui_QHoverEvent.ctd_base,
    &sipTypeDef_QtGui_QIcon.ctd_base,
    &enumTypes[118].etd_base,
    &enumTypes[117].etd_base,
    &sipTypeDef_QtGui_QIconDragEvent.ctd_base,
    &sipTypeDef_QtGui_QIconEngine.ctd_base,
    &sipTypeDef_QtGui_QIconEngine_AvailableSizesArgument.ctd_base,
    &enumTypes[116].etd_base,
    &sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument.ctd_base,
    &sipTypeDef_QtGui_QImage.ctd_base,
    &enumTypes[114].etd_base,
    &enumTypes[115].etd_base,
    &sipTypeDef_QtGui_QImageIOHandler.ctd_base,
    &enumTypes[113].etd_base,
    &enumTypes[112].etd_base,
    &sipTypeDef_QtGui_QImageIOHandler_Transformations.ctd_base,
    &sipTypeDef_QtGui_QImageReader.ctd_base,
    &enumTypes[111].etd_base,
    &sipTypeDef_QtGui_QImageWriter.ctd_base,
    &enumTypes[110].etd_base,
    &sipTypeDef_QtGui_QInputEvent.ctd_base,
    &sipTypeDef_QtGui_QInputMethod.ctd_base,
    &enumTypes[109].etd_base,
    &sipTypeDef_QtGui_QInputMethodEvent.ctd_base,
    &sipTypeDef_QtGui_QInputMethodEvent_Attribute.ctd_base,
    &enumTypes[133].etd_base,
    &sipTypeDef_QtGui_QInputMethodQueryEvent.ctd_base,
    &sipTypeDef_QtGui_QIntValidator.ctd_base,
    &sipTypeDef_QtGui_QKeyEvent.ctd_base,
    &sipTypeDef_QtGui_QKeySequence.ctd_base,
    &enumTypes[108].etd_base,
    &enumTypes[107].etd_base,
    &enumTypes[106].etd_base,
    &sipTypeDef_QtGui_QLinearGradient.ctd_base,
    &sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem.mtd_base,
    &sipTypeDef_QtGui_QList_0100QGlyphRun.mtd_base,
    &sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute.mtd_base,
    &sipTypeDef_QtGui_QList_0100QKeySequence.mtd_base,
    &sipTypeDef_QtGui_QList_0101QOpenGLContext.mtd_base,
    &sipTypeDef_QtGui_QList_0100QOpenGLDebugMessage.mtd_base,
    &sipTypeDef_QtGui_QList_0101QOpenGLShader.mtd_base,
    &sipTypeDef_QtGui_QList_0100QPolygonF.mtd_base,
    &sipTypeDef_QtGui_QList_0101QScreen.mtd_base,
    &sipTypeDef_QtGui_QList_0100QSize.mtd_base,
    &sipTypeDef_QtGui_QList_0101QStandardItem.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextBlock.mtd_base,
    &sipTypeDef_QtGui_QList_0101QTextFrame.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTextOption_Tab.mtd_base,
    &sipTypeDef_QtGui_QList_0111QTouchDevice.mtd_base,
    &sipTypeDef_QtGui_QList_0100QTouchEvent_TouchPoint.mtd_base,
    &sipTypeDef_QtGui_QList_0101QWindow.mtd_base,
    &sipTypeDef_QtGui_QMatrix2x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix2x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix2x4.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix3x4.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x2.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x3.ctd_base,
    &sipTypeDef_QtGui_QMatrix4x4.ctd_base,
    &sipTypeDef_QtGui_QMouseEvent.ctd_base,
    &sipTypeDef_QtGui_QMoveEvent.ctd_base,
    &sipTypeDef_QtGui_QMovie.ctd_base,
    &enumTypes[104].etd_base,
    &enumTypes[105].etd_base,
    &sipTypeDef_QtGui_QNativeGestureEvent.ctd_base,
    &sipTypeDef_QtGui_QOffscreenSurface.ctd_base,
    &sipTypeDef_QtGui_QOpenGLBuffer.ctd_base,
    &enumTypes[101].etd_base,
    &enumTypes[100].etd_base,
    &sipTypeDef_QtGui_QOpenGLBuffer_RangeAccessFlags.ctd_base,
    &enumTypes[103].etd_base,
    &enumTypes[102].etd_base,
    &sipTypeDef_QtGui_QOpenGLContext.ctd_base,
    &enumTypes[99].etd_base,
    &sipTypeDef_QtGui_QOpenGLContextGroup.ctd_base,
    &sipTypeDef_QtGui_QOpenGLDebugLogger.ctd_base,
    &enumTypes[95].etd_base,
    &sipTypeDef_QtGui_QOpenGLDebugMessage.ctd_base,
    &sipTypeDef_QtGui_QOpenGLDebugMessage_Severities.ctd_base,
    &enumTypes[96].etd_base,
    &enumTypes[98].etd_base,
    &sipTypeDef_QtGui_QOpenGLDebugMessage_Sources.ctd_base,
    &enumTypes[97].etd_base,
    &sipTypeDef_QtGui_QOpenGLDebugMessage_Types.ctd_base,
    &sipTypeDef_QtGui_QOpenGLFramebufferObject.ctd_base,
    &enumTypes[94].etd_base,
    &enumTypes[93].etd_base,
    &sipTypeDef_QtGui_QOpenGLFramebufferObjectFormat.ctd_base,
    &sipTypeDef_QtGui_QOpenGLPaintDevice.ctd_base,
    &sipTypeDef_QtGui_QOpenGLPixelTransferOptions.ctd_base,
    &sipTypeDef_QtGui_QOpenGLShader.ctd_base,
    &sipTypeDef_QtGui_QOpenGLShader_ShaderType.ctd_base,
    &enumTypes[92].etd_base,
    &sipTypeDef_QtGui_QOpenGLShaderProgram.ctd_base,
    &sipTypeDef_QtGui_QOpenGLTexture.ctd_base,
    &enumTypes[90].etd_base,
    &enumTypes[76].etd_base,
    &enumTypes[75].etd_base,
    &enumTypes[77].etd_base,
    &enumTypes[86].etd_base,
    &enumTypes[80].etd_base,
    &enumTypes[83].etd_base,
    &sipTypeDef_QtGui_QOpenGLTexture_Features.ctd_base,
    &enumTypes[79].etd_base,
    &enumTypes[89].etd_base,
    &enumTypes[85].etd_base,
    &enumTypes[84].etd_base,
    &enumTypes[82].etd_base,
    &enumTypes[81].etd_base,
    &enumTypes[91].etd_base,
    &enumTypes[87].etd_base,
    &enumTypes[88].etd_base,
    &enumTypes[78].etd_base,
    &sipTypeDef_QtGui_QOpenGLTextureBlitter.ctd_base,
    &enumTypes[74].etd_base,
    &sipTypeDef_QtGui_QOpenGLVersionProfile.ctd_base,
    &sipTypeDef_QtGui_QOpenGLVertexArrayObject.ctd_base,
    &sipTypeDef_QtGui_QOpenGLVertexArrayObject_Binder.ctd_base,
    &sipTypeDef_QtGui_QOpenGLWindow.ctd_base,
    &enumTypes[73].etd_base,
    &sipTypeDef_QtGui_QPageLayout.ctd_base,
    &enumTypes[68].etd_base,
    &enumTypes[69].etd_base,
    &enumTypes[70].etd_base,
    &sipTypeDef_QtGui_QPageSize.ctd_base,
    &enumTypes[67].etd_base,
    &enumTypes[65].etd_base,
    &enumTypes[66].etd_base,
    &sipTypeDef_QtGui_QPagedPaintDevice.ctd_base,
    &sipTypeDef_QtGui_QPagedPaintDevice_Margins.ctd_base,
    &enumTypes[72].etd_base,
    &enumTypes[71].etd_base,
    &sipTypeDef_QtGui_QPaintDevice.ctd_base,
    &enumTypes[61].etd_base,
    &sipTypeDef_QtGui_QPaintDeviceWindow.ctd_base,
    &sipTypeDef_QtGui_QPaintEngine.ctd_base,
    &enumTypes[58].etd_base,
    &sipTypeDef_QtGui_QPaintEngine_DirtyFlags.ctd_base,
    &enumTypes[59].etd_base,
    &sipTypeDef_QtGui_QPaintEngine_PaintEngineFeatures.ctd_base,
    &enumTypes[57].etd_base,
    &enumTypes[56].etd_base,
    &sipTypeDef_QtGui_QPaintEngineState.ctd_base,
    &sipTypeDef_QtGui_QPaintEvent.ctd_base,
    &sipTypeDef_QtGui_QPainter.ctd_base,
    &enumTypes[63].etd_base,
    &sipTypeDef_QtGui_QPainter_PixmapFragment.ctd_base,
    &enumTypes[62].etd_base,
    &sipTypeDef_QtGui_QPainter_PixmapFragmentHints.ctd_base,
    &enumTypes[64].etd_base,
    &sipTypeDef_QtGui_QPainter_RenderHints.ctd_base,
    &sipTypeDef_QtGui_QPainterPath.ctd_base,
    &sipTypeDef_QtGui_QPainterPath_Element.ctd_base,
    &enumTypes[55].etd_base,
    &sipTypeDef_QtGui_QPainterPathStroker.ctd_base,
    &sipTypeDef_QtGui_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter.mtd_base,
    &sipTypeDef_QtGui_QPair_2200_2200.mtd_base,
    &sipTypeDef_QtGui_QPalette.ctd_base,
    &enumTypes[54].etd_base,
    &enumTypes[53].etd_base,
    &sipTypeDef_QtGui_QPdfWriter.ctd_base,
    &sipTypeDef_QtGui_QPen.ctd_base,
    &sipTypeDef_QtGui_QPicture.ctd_base,
    &sipTypeDef_QtGui_QPictureIO.ctd_base,
    &sipTypeDef_QtGui_QPixelFormat.ctd_base,
    &enumTypes[50].etd_base,
    &enumTypes[49].etd_base,
    &enumTypes[51].etd_base,
    &enumTypes[46].etd_base,
    &enumTypes[52].etd_base,
    &enumTypes[48].etd_base,
    &enumTypes[47].etd_base,
    &sipTypeDef_QtGui_QPixmap.ctd_base,
    &sipTypeDef_QtGui_QPixmapCache.ctd_base,
    &sipTypeDef_QtGui_QPixmapCache_Key.ctd_base,
    &sipTypeDef_QtGui_QPlatformSurfaceEvent.ctd_base,
    &enumTypes[130].etd_base,
    &sipTypeDef_QtGui_QPointingDeviceUniqueId.ctd_base,
    &sipTypeDef_QtGui_QPolygon.ctd_base,
    &sipTypeDef_QtGui_QPolygonF.ctd_base,
    &sipTypeDef_QtGui_QQuaternion.ctd_base,
    &sipTypeDef_QtGui_QRadialGradient.ctd_base,
    &sipTypeDef_QtGui_QRasterWindow.ctd_base,
    &sipTypeDef_QtGui_QRawFont.ctd_base,
    &enumTypes[45].etd_base,
    &enumTypes[44].etd_base,
    &sipTypeDef_QtGui_QRawFont_LayoutFlags.ctd_base,
    &sipTypeDef_QtGui_QRegExpValidator.ctd_base,
    &sipTypeDef_QtGui_QRegion.ctd_base,
    &enumTypes[43].etd_base,
    &sipTypeDef_QtGui_QRegularExpressionValidator.ctd_base,
    &sipTypeDef_QtGui_QResizeEvent.ctd_base,
    &sipTypeDef_QtGui_QRgba64.ctd_base,
    &sipTypeDef_QtGui_QScreen.ctd_base,
    &sipTypeDef_QtGui_QScrollEvent.ctd_base,
    &enumTypes[131].etd_base,
    &sipTypeDef_QtGui_QScrollPrepareEvent.ctd_base,
    &sipTypeDef_QtGui_QSet_0100QByteArray.mtd_base,
    &sipTypeDef_QtGui_QShortcutEvent.ctd_base,
    &sipTypeDef_QtGui_QShowEvent.ctd_base,
    &sipTypeDef_QtGui_QStandardItem.ctd_base,
    &enumTypes[42].etd_base,
    &sipTypeDef_QtGui_QStandardItemModel.ctd_base,
    &sipTypeDef_QtGui_QStaticText.ctd_base,
    &enumTypes[41].etd_base,
    &sipTypeDef_QtGui_QStatusTipEvent.ctd_base,
    &sipTypeDef_QtGui_QStyleHints.ctd_base,
    &sipTypeDef_QtGui_QSurface.ctd_base,
    &enumTypes[40].etd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_QtGui_QSurfaceFormat.ctd_base,
    &enumTypes[34].etd_base,
    &enumTypes[38].etd_base,
    &sipTypeDef_QtGui_QSurfaceFormat_FormatOptions.ctd_base,
    &enumTypes[35].etd_base,
    &enumTypes[36].etd_base,
    &enumTypes[37].etd_base,
    &sipTypeDef_QtGui_QSyntaxHighlighter.ctd_base,
    &sipTypeDef_QtGui_QTabletEvent.ctd_base,
    &enumTypes[135].etd_base,
    &enumTypes[136].etd_base,
    &sipTypeDef_QtGui_QTextBlock.ctd_base,
    &sipTypeDef_QtGui_QTextBlock_iterator.ctd_base,
    &sipTypeDef_QtGui_QTextBlockFormat.ctd_base,
    &enumTypes[17].etd_base,
    &enumTypes[16].etd_base,
    &sipTypeDef_QtGui_QTextBlockGroup.ctd_base,
    &sipTypeDef_QtGui_QTextBlockUserData.ctd_base,
    &sipTypeDef_QtGui_QTextCharFormat.ctd_base,
    &enumTypes[18].etd_base,
    &enumTypes[19].etd_base,
    &enumTypes[20].etd_base,
    &sipTypeDef_QtGui_QTextCursor.ctd_base,
    &enumTypes[33].etd_base,
    &enumTypes[32].etd_base,
    &enumTypes[31].etd_base,
    &sipTypeDef_QtGui_QTextDocument.ctd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_QtGui_QTextDocument_FindFlags.ctd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_QtGui_QTextDocument_MarkdownFeatures.ctd_base,
    &enumTypes[30].etd_base,
    &enumTypes[28].etd_base,
    &enumTypes[27].etd_base,
    &sipTypeDef_QtGui_QTextDocumentFragment.ctd_base,
    &sipTypeDef_QtGui_QTextDocumentWriter.ctd_base,
    &sipTypeDef_QtGui_QTextFormat.ctd_base,
    &enumTypes[24].etd_base,
    &enumTypes[23].etd_base,
    &enumTypes[22].etd_base,
    &sipTypeDef_QtGui_QTextFormat_PageBreakFlags.ctd_base,
    &enumTypes[21].etd_base,
    &sipTypeDef_QtGui_QTextFragment.ctd_base,
    &sipTypeDef_QtGui_QTextFrame.ctd_base,
    &sipTypeDef_QtGui_QTextFrame_iterator.ctd_base,
    &sipTypeDef_QtGui_QTextFrameFormat.ctd_base,
    &enumTypes[13].etd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtGui_QTextImageFormat.ctd_base,
    &sipTypeDef_QtGui_QTextInlineObject.ctd_base,
    &sipTypeDef_QtGui_QTextItem.ctd_base,
    &enumTypes[60].etd_base,
    &sipTypeDef_QtGui_QTextItem_RenderFlags.ctd_base,
    &sipTypeDef_QtGui_QTextLayout.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtGui_QTextLayout_FormatRange.ctd_base,
    &sipTypeDef_QtGui_QTextLength.ctd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_QtGui_QTextLine.ctd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtGui_QTextList.ctd_base,
    &sipTypeDef_QtGui_QTextListFormat.ctd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtGui_QTextObject.ctd_base,
    &sipTypeDef_QtGui_QTextObjectInterface.ctd_base,
    &sipTypeDef_QtGui_QTextOption.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtGui_QTextOption_Flags.ctd_base,
    &sipTypeDef_QtGui_QTextOption_Tab.ctd_base,
    &enumTypes[7].etd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtGui_QTextTable.ctd_base,
    &sipTypeDef_QtGui_QTextTableCell.ctd_base,
    &sipTypeDef_QtGui_QTextTableCellFormat.ctd_base,
    &sipTypeDef_QtGui_QTextTableFormat.ctd_base,
    &sipTypeDef_QtGui_QTouchDevice.ctd_base,
    &sipTypeDef_QtGui_QTouchDevice_Capabilities.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtGui_QTouchEvent.ctd_base,
    &sipTypeDef_QtGui_QTouchEvent_TouchPoint.ctd_base,
    &enumTypes[132].etd_base,
    &sipTypeDef_QtGui_QTouchEvent_TouchPoint_InfoFlags.ctd_base,
    &sipTypeDef_QtGui_QTransform.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtGui_QValidator.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtGui_QVector2D.ctd_base,
    &sipTypeDef_QtGui_QVector3D.ctd_base,
    &sipTypeDef_QtGui_QVector4D.ctd_base,
    &sipTypeDef_QtGui_QVector_0100QAbstractTextDocumentLayout_Selection.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QLine.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QLineF.mtd_base,
    &sipTypeDef_QtGui_QVector_0600QPair_2400_0100QColor.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QPoint.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QRect.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QRectF.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QSize.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QTextFormat.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QTextLayout_FormatRange.mtd_base,
    &sipTypeDef_QtGui_QVector_0100QTextLength.mtd_base,
    &sipTypeDef_QtGui_QVector_2200.mtd_base,
    &sipTypeDef_QtGui_QVector_2400.mtd_base,
    &sipTypeDef_QtGui_QVector_1900.mtd_base,
    &sipTypeDef_QtGui_QWhatsThisClickedEvent.ctd_base,
    &sipTypeDef_QtGui_QWheelEvent.ctd_base,
    &sipTypeDef_QtGui_QWindow.ctd_base,
    &enumTypes[1].etd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtGui_QWindowStateChangeEvent.ctd_base,
    &sipTypeDef_QtGui_Qt.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"GLbitfield", "uint"},
    {"GLboolean", "unsigned char"},
    {"GLbyte", "signed char"},
    {"GLchar", "char"},
    {"GLclampf", "float"},
    {"GLenum", "uint"},
    {"GLfloat", "float"},
    {"GLint", "int"},
    {"GLintptr", "long"},
    {"GLshort", "short"},
    {"GLsizei", "int"},
    {"GLsizeiptr", "long"},
    {"GLubyte", "unsigned char"},
    {"GLuint", "uint"},
    {"GLushort", "unsigned short"},
    {"QGradientStops", "QVector<QPair<qreal,QColor> >"},
    {"QRgb", "uint"},
    {"QTextBlock::Iterator", "QTextBlock::iterator"},
    {"QTextFrame::Iterator", "QTextFrame::iterator"},
    {"QWindowList", "QList<QWindow*>"},
    {"WId", "quintptr"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtGui_QtCore[] = {
    {"QAbstractItemModel"},
    {"QByteArray"},
    {"QChar"},
    {"QChildEvent"},
    {"QCoreApplication"},
    {"QDataStream"},
    {"QEvent"},
    {"QEvent::Type"},
    {"QFile"},
    {"QHash<int,QByteArray>"},
    {"QIODevice"},
    {"QIODevice::OpenMode"},
    {"QLine"},
    {"QLineF"},
    {"QList<QByteArray>"},
    {"QList<QModelIndex>"},
    {"QList<int>"},
    {"QList<qreal>"},
    {"QLocale"},
    {"QMap<int,QVariant>"},
    {"QMargins"},
    {"QMarginsF"},
    {"QMetaMethod"},
    {"QMimeData"},
    {"QModelIndex"},
    {"QObject"},
    {"QPair<int,int>"},
    {"QPoint"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QRegExp"},
    {"QRegularExpression"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTextCodec"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVector<QPointF>"},
    {"Qt"},
    {"Qt::Alignment"},
    {"Qt::ApplicationState"},
    {"Qt::AspectRatioMode"},
    {"Qt::Axis"},
    {"Qt::BGMode"},
    {"Qt::BrushStyle"},
    {"Qt::CheckState"},
    {"Qt::ClipOperation"},
    {"Qt::CursorMoveStyle"},
    {"Qt::CursorShape"},
    {"Qt::DropAction"},
    {"Qt::DropActions"},
    {"Qt::Edges"},
    {"Qt::FillRule"},
    {"Qt::FocusReason"},
    {"Qt::GlobalColor"},
    {"Qt::HighDpiScaleFactorRoundingPolicy"},
    {"Qt::HitTestAccuracy"},
    {"Qt::ImageConversionFlags"},
    {"Qt::InputMethodQueries"},
    {"Qt::InputMethodQuery"},
    {"Qt::ItemFlags"},
    {"Qt::KeyboardModifiers"},
    {"Qt::LayoutDirection"},
    {"Qt::MaskMode"},
    {"Qt::MatchFlags"},
    {"Qt::MouseButton"},
    {"Qt::MouseButtons"},
    {"Qt::MouseEventFlags"},
    {"Qt::MouseEventSource"},
    {"Qt::NativeGestureType"},
    {"Qt::Orientation"},
    {"Qt::PenCapStyle"},
    {"Qt::PenJoinStyle"},
    {"Qt::PenStyle"},
    {"Qt::ScreenOrientation"},
    {"Qt::ScreenOrientations"},
    {"Qt::ScrollPhase"},
    {"Qt::SizeMode"},
    {"Qt::SortOrder"},
    {"Qt::TabFocusBehavior"},
    {"Qt::TextElideMode"},
    {"Qt::TextFormat"},
    {"Qt::TouchPointState"},
    {"Qt::TouchPointStates"},
    {"Qt::TransformationMode"},
    {"Qt::WhiteSpaceMode"},
    {"Qt::WindowFlags"},
    {"Qt::WindowModality"},
    {"Qt::WindowState"},
    {"Qt::WindowStates"},
    {"Qt::WindowType"},
    {"quintptr"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtGui_QtCore, sipImportedVirtErrorHandlers_QtGui_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QGradient, {56, 255, 0}, SIP_NULLPTR},
    {sipSubClass_QInputEvent, {6, 0, 0}, SIP_NULLPTR},
    {sipSubClass_QGuiApplication, {25, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtGui = {
    0,
    SIP_API_MINOR_NR,
    sipNameNr_PyQt5_QtGui,
    0,
    sipStrings_QtGui,
    importsTable,
    SIP_NULLPTR,
    388,
    sipExportedTypes_QtGui,
    externalTypesTable,
    0,
    SIP_NULLPTR,
    21,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    slotExtenders,
    initExtenders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtGui;

sip_qt_metaobject_func sip_QtGui_qt_metaobject;
sip_qt_metacall_func sip_QtGui_qt_metacall;
sip_qt_metacast_func sip_QtGui_qt_metacast;


/* The Python module initialisation function. */
#if PY_MAJOR_VERSION >= 3
#define SIP_MODULE_ENTRY        PyInit_QtGui
#define SIP_MODULE_TYPE         PyObject *
#define SIP_MODULE_DISCARD(r)   Py_DECREF(r)
#define SIP_MODULE_RETURN(r)    return (r)
#else
#define SIP_MODULE_ENTRY        initQtGui
#define SIP_MODULE_TYPE         void
#define SIP_MODULE_DISCARD(r)
#define SIP_MODULE_RETURN(r)    return
#endif

#if defined(SIP_STATIC_MODULE)
extern "C" SIP_MODULE_TYPE SIP_MODULE_ENTRY()
#else
PyMODINIT_FUNC SIP_MODULE_ENTRY()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_MLNAME_CAST(sipName_qIsGray), func_qIsGray, METH_VARARGS, SIP_MLDOC_CAST(doc_qIsGray)},
        {SIP_MLNAME_CAST(sipName_qGray), func_qGray, METH_VARARGS, SIP_MLDOC_CAST(doc_qGray)},
        {SIP_MLNAME_CAST(sipName_qRgba), func_qRgba, METH_VARARGS, SIP_MLDOC_CAST(doc_qRgba)},
        {SIP_MLNAME_CAST(sipName_qRgb), func_qRgb, METH_VARARGS, SIP_MLDOC_CAST(doc_qRgb)},
        {SIP_MLNAME_CAST(sipName_qAlpha), func_qAlpha, METH_VARARGS, SIP_MLDOC_CAST(doc_qAlpha)},
        {SIP_MLNAME_CAST(sipName_qBlue), func_qBlue, METH_VARARGS, SIP_MLDOC_CAST(doc_qBlue)},
        {SIP_MLNAME_CAST(sipName_qGreen), func_qGreen, METH_VARARGS, SIP_MLDOC_CAST(doc_qGreen)},
        {SIP_MLNAME_CAST(sipName_qRed), func_qRed, METH_VARARGS, SIP_MLDOC_CAST(doc_qRed)},
        {SIP_MLNAME_CAST(sipName_qUnpremultiply), func_qUnpremultiply, METH_VARARGS, SIP_MLDOC_CAST(doc_qUnpremultiply)},
        {SIP_MLNAME_CAST(sipName_qPremultiply), func_qPremultiply, METH_VARARGS, SIP_MLDOC_CAST(doc_qPremultiply)},
        {SIP_MLNAME_CAST(sipName_qRgba64), func_qRgba64, METH_VARARGS, SIP_MLDOC_CAST(doc_qRgba64)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatAlpha), SIP_MLMETH_CAST(func_qPixelFormatAlpha), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatAlpha)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatYuv), SIP_MLMETH_CAST(func_qPixelFormatYuv), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatYuv)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatHsv), SIP_MLMETH_CAST(func_qPixelFormatHsv), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatHsv)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatHsl), SIP_MLMETH_CAST(func_qPixelFormatHsl), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatHsl)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatCmyk), SIP_MLMETH_CAST(func_qPixelFormatCmyk), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatCmyk)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatGrayscale), SIP_MLMETH_CAST(func_qPixelFormatGrayscale), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatGrayscale)},
        {SIP_MLNAME_CAST(sipName_qPixelFormatRgba), SIP_MLMETH_CAST(func_qPixelFormatRgba), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_qPixelFormatRgba)},
        {SIP_MLNAME_CAST(sipName_qFuzzyCompare), func_qFuzzyCompare, METH_VARARGS, SIP_MLDOC_CAST(doc_qFuzzyCompare)},
        {SIP_MLNAME_CAST(sipName_qt_set_sequence_auto_mnemonic), func_qt_set_sequence_auto_mnemonic, METH_VARARGS, SIP_MLDOC_CAST(doc_qt_set_sequence_auto_mnemonic)},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };

#if PY_MAJOR_VERSION >= 3
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtGui",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };
#endif

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
#if PY_MAJOR_VERSION >= 3
    sipModule = PyModule_Create(&sip_module_def);
#elif PY_VERSION_HEX >= 0x02050000
    sipModule = Py_InitModule(sipName_PyQt5_QtGui, sip_methods);
#else
    sipModule = Py_InitModule(const_cast<char *>(sipName_PyQt5_QtGui), sip_methods);
#endif

    if (sipModule == SIP_NULLPTR)
        SIP_MODULE_RETURN(SIP_NULLPTR);

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
#if PY_VERSION_HEX >= 0x02050000
    sip_sipmod = PyImport_ImportModule("PyQt5.sip");
#else
    sip_sipmod = PyImport_ImportModule(const_cast<char *>("PyQt5.sip"));
#endif

    if (sip_sipmod == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

#if defined(SIP_USE_PYCAPSULE)
    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
#else
    if (sip_capiobj == SIP_NULLPTR || !PyCObject_Check(sip_capiobj))
#endif
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

#if defined(SIP_USE_PYCAPSULE)
    sipAPI_QtGui = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));
#else
    sipAPI_QtGui = reinterpret_cast<const sipAPIDef *>(PyCObject_AsVoidPtr(sip_capiobj));
#endif

#if defined(SIP_USE_PYCAPSULE)
    if (sipAPI_QtGui == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#endif

#line 343 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qguiapplication.sip"
// Export our own helpers.
sipExportSymbol("qtgui_wrap_ancestors", (void *)qtgui_wrap_ancestors);
#line 339 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qopenglshaderprogram.sip"
#if defined(SIP_FEATURE_PyQt_OpenGL)
qpyopengl_init();
#endif
#line 9266 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"
    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtGui,SIP_API_MAJOR_NR,SIP_API_MINOR_NR,0) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_QtGui_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtGui_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtGui_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtGui_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtGui,sipModuleDict) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#line 348 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
pyqt5_qtgui_cleanup_qobjects = (pyqt5_qtgui_cleanup_qobjects_t)sipImportSymbol("pyqt5_cleanup_qobjects");
Q_ASSERT(pyqt5_qtgui_cleanup_qobjects);

pyqt5_qtgui_from_argv_list = (pyqt5_qtgui_from_argv_list_t)sipImportSymbol("pyqt5_from_argv_list");
Q_ASSERT(pyqt5_qtgui_from_argv_list);

pyqt5_qtgui_update_argv_list = (pyqt5_qtgui_update_argv_list_t)sipImportSymbol("pyqt5_update_argv_list");
Q_ASSERT(pyqt5_qtgui_update_argv_list);
#line 9297 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuicmodule.cpp"

    SIP_MODULE_RETURN(sipModule);
}
