/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"

#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 195 "sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qregion.sip"
#include <qregion.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 96 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 99 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 102 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qfont.sip"
#include <qfont.h>
#line 105 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 108 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 509 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 111 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 114 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 471 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 117 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 460 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 120 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 570 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 123 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 619 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 592 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 608 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 675 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 302 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 482 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 438 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 425 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 412 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 398 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 384 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 363 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 253 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 205 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 52 "sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 168 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 171 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 174 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 177 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 180 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 183 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 186 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 189 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 192 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 195 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 198 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 203 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 206 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 209 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 212 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 215 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 218 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 221 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 224 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 227 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 230 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 233 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 236 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
#line 32 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
// Transfer the ownership of a single widget to a parent.
static void qtgui_TransferWidget(QWidget *w, PyObject *py_parent)
{
    PyObject *py_w = sipGetPyObject(w, sipType_QWidget);

    if (py_w)
        sipTransferTo(py_w, py_parent);
}


// Transfer ownership of all widgets in a layout to their new parent.
static void qtwidgets_TransferLayoutWidgets(QLayout *lay, PyObject *pw)
{
    int n = lay->count();

    for (int i = 0; i < n; ++i)
    {
        QLayoutItem *item = lay->itemAt(i);
        QWidget *w = item->widget();

        if (w)
        {
            qtgui_TransferWidget(w, pw);
        }
        else
        {
            QLayout *l = item->layout();

            if (l)
                qtwidgets_TransferLayoutWidgets(l, pw);
        }
    }
    
    QWidget *mb = lay->menuBar();

    if (mb)
        qtgui_TransferWidget(mb, pw);
}
#line 276 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"


class sipQWidget : public  ::QWidget
{
public:
    sipQWidget( ::QWidget*, ::Qt::WindowFlags);
    virtual ~sipQWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initPainter( ::QPainter*) const SIP_OVERRIDE;
     ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const  ::QByteArray&,void*,long*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
     ::QVariant inputMethodQuery( ::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent( ::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent( ::QEvent*) SIP_OVERRIDE;
    void hideEvent( ::QHideEvent*) SIP_OVERRIDE;
    void showEvent( ::QShowEvent*) SIP_OVERRIDE;
    void dropEvent( ::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent( ::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent( ::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent( ::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent( ::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent( ::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent( ::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent( ::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent( ::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent( ::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent( ::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent( ::QEvent*) SIP_OVERRIDE;
    void enterEvent( ::QEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
     ::QSize minimumSizeHint() const SIP_OVERRIDE;
     ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
     ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric( ::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWidget(const sipQWidget &);
    sipQWidget &operator = (const sipQWidget &);

    char sipPyMethods[46];
};

sipQWidget::sipQWidget( ::QWidget*a0, ::Qt::WindowFlags a1):  ::QWidget(a0,a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWidget::~sipQWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf,sipType_QWidget);

    return  ::QWidget::metaObject();
}

int sipQWidget::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QWidget::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf,sipType_QWidget,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QWidget, _clname, &sipCpp) ? sipCpp :  ::QWidget::qt_metacast(_clname));
}

void sipQWidget::initPainter( ::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,SIP_NULLPTR,sipName_initPainter);

    if (!sipMeth)
    {
         ::QWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QPainter* sipQWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,SIP_NULLPTR,sipName_sharedPainter);

    if (!sipMeth)
        return  ::QWidget::sharedPainter();

    extern  ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWidget::nativeEvent(const  ::QByteArray& a0,void*a1,long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,SIP_NULLPTR,sipName_nativeEvent);

    if (!sipMeth)
        return  ::QWidget::nativeEvent(a0,a1,a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QByteArray&,void*,long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,SIP_NULLPTR,sipName_hasHeightForWidth);

    if (!sipMeth)
        return  ::QWidget::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,SIP_NULLPTR,sipName_focusNextPrevChild);

    if (!sipMeth)
        return  ::QWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QVariant sipQWidget::inputMethodQuery( ::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,SIP_NULLPTR,sipName_inputMethodQuery);

    if (!sipMeth)
        return  ::QWidget::inputMethodQuery(a0);

    extern  ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::inputMethodEvent( ::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,SIP_NULLPTR,sipName_inputMethodEvent);

    if (!sipMeth)
    {
         ::QWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::changeEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,SIP_NULLPTR,sipName_changeEvent);

    if (!sipMeth)
    {
         ::QWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::hideEvent( ::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,SIP_NULLPTR,sipName_hideEvent);

    if (!sipMeth)
    {
         ::QWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::showEvent( ::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,SIP_NULLPTR,sipName_showEvent);

    if (!sipMeth)
    {
         ::QWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::dropEvent( ::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,SIP_NULLPTR,sipName_dropEvent);

    if (!sipMeth)
    {
         ::QWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::dragLeaveEvent( ::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,SIP_NULLPTR,sipName_dragLeaveEvent);

    if (!sipMeth)
    {
         ::QWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::dragMoveEvent( ::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,SIP_NULLPTR,sipName_dragMoveEvent);

    if (!sipMeth)
    {
         ::QWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::dragEnterEvent( ::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,SIP_NULLPTR,sipName_dragEnterEvent);

    if (!sipMeth)
    {
         ::QWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::actionEvent( ::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,SIP_NULLPTR,sipName_actionEvent);

    if (!sipMeth)
    {
         ::QWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::tabletEvent( ::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[15],sipPySelf,SIP_NULLPTR,sipName_tabletEvent);

    if (!sipMeth)
    {
         ::QWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::contextMenuEvent( ::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[16],sipPySelf,SIP_NULLPTR,sipName_contextMenuEvent);

    if (!sipMeth)
    {
         ::QWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::closeEvent( ::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[17],sipPySelf,SIP_NULLPTR,sipName_closeEvent);

    if (!sipMeth)
    {
         ::QWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::resizeEvent( ::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_resizeEvent);

    if (!sipMeth)
    {
         ::QWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::moveEvent( ::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[19],sipPySelf,SIP_NULLPTR,sipName_moveEvent);

    if (!sipMeth)
    {
         ::QWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::paintEvent( ::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_paintEvent);

    if (!sipMeth)
    {
         ::QWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::leaveEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[21],sipPySelf,SIP_NULLPTR,sipName_leaveEvent);

    if (!sipMeth)
    {
         ::QWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::enterEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[22],sipPySelf,SIP_NULLPTR,sipName_enterEvent);

    if (!sipMeth)
    {
         ::QWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::focusOutEvent( ::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_focusOutEvent);

    if (!sipMeth)
    {
         ::QWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::focusInEvent( ::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_focusInEvent);

    if (!sipMeth)
    {
         ::QWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::keyReleaseEvent( ::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_keyReleaseEvent);

    if (!sipMeth)
    {
         ::QWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::keyPressEvent( ::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,SIP_NULLPTR,sipName_keyPressEvent);

    if (!sipMeth)
    {
         ::QWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::wheelEvent( ::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[27],sipPySelf,SIP_NULLPTR,sipName_wheelEvent);

    if (!sipMeth)
    {
         ::QWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::mouseMoveEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[28],sipPySelf,SIP_NULLPTR,sipName_mouseMoveEvent);

    if (!sipMeth)
    {
         ::QWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::mouseDoubleClickEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[29],sipPySelf,SIP_NULLPTR,sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
         ::QWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::mouseReleaseEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[30],sipPySelf,SIP_NULLPTR,sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
         ::QWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::mousePressEvent( ::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[31],sipPySelf,SIP_NULLPTR,sipName_mousePressEvent);

    if (!sipMeth)
    {
         ::QWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[32]),sipPySelf,SIP_NULLPTR,sipName_heightForWidth);

    if (!sipMeth)
        return  ::QWidget::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QSize sipQWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[33]),sipPySelf,SIP_NULLPTR,sipName_minimumSizeHint);

    if (!sipMeth)
        return  ::QWidget::minimumSizeHint();

    extern  ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QSize sipQWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[34]),sipPySelf,SIP_NULLPTR,sipName_sizeHint);

    if (!sipMeth)
        return  ::QWidget::sizeHint();

    extern  ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[35],sipPySelf,SIP_NULLPTR,sipName_setVisible);

    if (!sipMeth)
    {
         ::QWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[36]),sipPySelf,SIP_NULLPTR,sipName_devType);

    if (!sipMeth)
        return  ::QWidget::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QPaintEngine* sipQWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[37]),sipPySelf,SIP_NULLPTR,sipName_paintEngine);

    if (!sipMeth)
        return  ::QWidget::paintEngine();

    extern  ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQWidget::metric( ::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[38]),sipPySelf,SIP_NULLPTR,sipName_metric);

    if (!sipMeth)
        return  ::QWidget::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWidget::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[39],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QWidget::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWidget::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[40],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QWidget::eventFilter(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWidget::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[41],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[42],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[43],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[44],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWidget::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[45],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWidget_devType, "devType(self) -> int");

extern "C" {static PyObject *meth_QWidget_devType(PyObject *, PyObject *);}
static PyObject *meth_QWidget_devType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::devType() : sipCpp->devType());

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_devType, doc_QWidget_devType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_style, "style(self) -> QStyle");

extern "C" {static PyObject *meth_QWidget_style(PyObject *, PyObject *);}
static PyObject *meth_QWidget_style(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QStyle*sipRes;

            sipRes = sipCpp->style();

            return sipConvertFromType(sipRes,sipType_QStyle,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_style, doc_QWidget_style);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setStyle, "setStyle(self, QStyle)");

extern "C" {static PyObject *meth_QWidget_setStyle(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QStyle* a0;
        PyObject *a0Keep;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWidget, &sipCpp, &a0Keep, sipType_QStyle, &a0))
        {
            sipCpp->setStyle(a0);

            sipKeepReference(sipSelf, -57, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setStyle, doc_QWidget_setStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isEnabledTo, "isEnabledTo(self, QWidget) -> bool");

extern "C" {static PyObject *meth_QWidget_isEnabledTo(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isEnabledTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabledTo(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isEnabledTo, doc_QWidget_isEnabledTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setEnabled, "setEnabled(self, bool)");

extern "C" {static PyObject *meth_QWidget_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setEnabled, doc_QWidget_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setDisabled, "setDisabled(self, bool)");

extern "C" {static PyObject *meth_QWidget_setDisabled(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setDisabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setDisabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setDisabled, doc_QWidget_setDisabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowModified, "setWindowModified(self, bool)");

extern "C" {static PyObject *meth_QWidget_setWindowModified(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setWindowModified(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowModified, doc_QWidget_setWindowModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_frameGeometry, "frameGeometry(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_frameGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_frameGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->frameGeometry());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_frameGeometry, doc_QWidget_frameGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_normalGeometry, "normalGeometry(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_normalGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_normalGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->normalGeometry());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_normalGeometry, doc_QWidget_normalGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_x, "x(self) -> int");

extern "C" {static PyObject *meth_QWidget_x(PyObject *, PyObject *);}
static PyObject *meth_QWidget_x(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->x();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_x, doc_QWidget_x);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_y, "y(self) -> int");

extern "C" {static PyObject *meth_QWidget_y(PyObject *, PyObject *);}
static PyObject *meth_QWidget_y(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->y();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_y, doc_QWidget_y);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_pos, "pos(self) -> QPoint");

extern "C" {static PyObject *meth_QWidget_pos(PyObject *, PyObject *);}
static PyObject *meth_QWidget_pos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->pos());

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_pos, doc_QWidget_pos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_frameSize, "frameSize(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_frameSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_frameSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->frameSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_frameSize, doc_QWidget_frameSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_childrenRect, "childrenRect(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_childrenRect(PyObject *, PyObject *);}
static PyObject *meth_QWidget_childrenRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->childrenRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_childrenRect, doc_QWidget_childrenRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_childrenRegion, "childrenRegion(self) -> QRegion");

extern "C" {static PyObject *meth_QWidget_childrenRegion(PyObject *, PyObject *);}
static PyObject *meth_QWidget_childrenRegion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRegion*sipRes;

            sipRes = new  ::QRegion(sipCpp->childrenRegion());

            return sipConvertFromNewType(sipRes,sipType_QRegion,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_childrenRegion, doc_QWidget_childrenRegion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_minimumSize, "minimumSize(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_minimumSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_minimumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->minimumSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_minimumSize, doc_QWidget_minimumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_maximumSize, "maximumSize(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_maximumSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_maximumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->maximumSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_maximumSize, doc_QWidget_maximumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMinimumSize, "setMinimumSize(self, int, int)\n"
"setMinimumSize(self, QSize)");

extern "C" {static PyObject *meth_QWidget_setMinimumSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMinimumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setMinimumSize(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setMinimumSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMinimumSize, doc_QWidget_setMinimumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMaximumSize, "setMaximumSize(self, int, int)\n"
"setMaximumSize(self, QSize)");

extern "C" {static PyObject *meth_QWidget_setMaximumSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMaximumSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setMaximumSize(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setMaximumSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMaximumSize, doc_QWidget_setMaximumSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMinimumWidth, "setMinimumWidth(self, int)");

extern "C" {static PyObject *meth_QWidget_setMinimumWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMinimumWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setMinimumWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMinimumWidth, doc_QWidget_setMinimumWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMinimumHeight, "setMinimumHeight(self, int)");

extern "C" {static PyObject *meth_QWidget_setMinimumHeight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMinimumHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setMinimumHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMinimumHeight, doc_QWidget_setMinimumHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMaximumWidth, "setMaximumWidth(self, int)");

extern "C" {static PyObject *meth_QWidget_setMaximumWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMaximumWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setMaximumWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMaximumWidth, doc_QWidget_setMaximumWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMaximumHeight, "setMaximumHeight(self, int)");

extern "C" {static PyObject *meth_QWidget_setMaximumHeight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMaximumHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setMaximumHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMaximumHeight, doc_QWidget_setMaximumHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_sizeIncrement, "sizeIncrement(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_sizeIncrement(PyObject *, PyObject *);}
static PyObject *meth_QWidget_sizeIncrement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->sizeIncrement());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_sizeIncrement, doc_QWidget_sizeIncrement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setSizeIncrement, "setSizeIncrement(self, int, int)\n"
"setSizeIncrement(self, QSize)");

extern "C" {static PyObject *meth_QWidget_setSizeIncrement(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setSizeIncrement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setSizeIncrement(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSizeIncrement(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setSizeIncrement, doc_QWidget_setSizeIncrement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_baseSize, "baseSize(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_baseSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_baseSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->baseSize());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_baseSize, doc_QWidget_baseSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setBaseSize, "setBaseSize(self, int, int)\n"
"setBaseSize(self, QSize)");

extern "C" {static PyObject *meth_QWidget_setBaseSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setBaseSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setBaseSize(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setBaseSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setBaseSize, doc_QWidget_setBaseSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFixedSize, "setFixedSize(self, QSize)\n"
"setFixedSize(self, int, int)");

extern "C" {static PyObject *meth_QWidget_setFixedSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFixedSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setFixedSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setFixedSize(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFixedSize, doc_QWidget_setFixedSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFixedWidth, "setFixedWidth(self, int)");

extern "C" {static PyObject *meth_QWidget_setFixedWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFixedWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setFixedWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFixedWidth, doc_QWidget_setFixedWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFixedHeight, "setFixedHeight(self, int)");

extern "C" {static PyObject *meth_QWidget_setFixedHeight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFixedHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setFixedHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFixedHeight, doc_QWidget_setFixedHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapToGlobal, "mapToGlobal(self, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapToGlobal(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapToGlobal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapToGlobal(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapToGlobal, doc_QWidget_mapToGlobal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapFromGlobal, "mapFromGlobal(self, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapFromGlobal(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapFromGlobal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapFromGlobal(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapFromGlobal, doc_QWidget_mapFromGlobal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapToParent, "mapToParent(self, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapToParent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapToParent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapToParent(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapToParent, doc_QWidget_mapToParent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapFromParent, "mapFromParent(self, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapFromParent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapFromParent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapFromParent(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapFromParent, doc_QWidget_mapFromParent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapTo, "mapTo(self, QWidget, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapTo(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QPoint* a1;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0, sipType_QPoint, &a1))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapTo(a0,*a1));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapTo, doc_QWidget_mapTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mapFrom, "mapFrom(self, QWidget, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QWidget_mapFrom(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mapFrom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QPoint* a1;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0, sipType_QPoint, &a1))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint(sipCpp->mapFrom(a0,*a1));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mapFrom, doc_QWidget_mapFrom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_window, "window(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_window(PyObject *, PyObject *);}
static PyObject *meth_QWidget_window(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->window();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_window, doc_QWidget_window);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_palette, "palette(self) -> QPalette");

extern "C" {static PyObject *meth_QWidget_palette(PyObject *, PyObject *);}
static PyObject *meth_QWidget_palette(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPalette*sipRes;

            sipRes = new  ::QPalette(sipCpp->palette());

            return sipConvertFromNewType(sipRes,sipType_QPalette,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_palette, doc_QWidget_palette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setPalette, "setPalette(self, QPalette)");

extern "C" {static PyObject *meth_QWidget_setPalette(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setPalette(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPalette* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPalette, &a0))
        {
            sipCpp->setPalette(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setPalette, doc_QWidget_setPalette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setBackgroundRole, "setBackgroundRole(self, QPalette.ColorRole)");

extern "C" {static PyObject *meth_QWidget_setBackgroundRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setBackgroundRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPalette::ColorRole a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPalette_ColorRole, &a0))
        {
            sipCpp->setBackgroundRole(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setBackgroundRole, doc_QWidget_setBackgroundRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_backgroundRole, "backgroundRole(self) -> QPalette.ColorRole");

extern "C" {static PyObject *meth_QWidget_backgroundRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_backgroundRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPalette::ColorRole sipRes;

            sipRes = sipCpp->backgroundRole();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPalette_ColorRole);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_backgroundRole, doc_QWidget_backgroundRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setForegroundRole, "setForegroundRole(self, QPalette.ColorRole)");

extern "C" {static PyObject *meth_QWidget_setForegroundRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setForegroundRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPalette::ColorRole a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPalette_ColorRole, &a0))
        {
            sipCpp->setForegroundRole(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setForegroundRole, doc_QWidget_setForegroundRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_foregroundRole, "foregroundRole(self) -> QPalette.ColorRole");

extern "C" {static PyObject *meth_QWidget_foregroundRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_foregroundRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPalette::ColorRole sipRes;

            sipRes = sipCpp->foregroundRole();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPalette_ColorRole);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_foregroundRole, doc_QWidget_foregroundRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFont, "setFont(self, QFont)");

extern "C" {static PyObject *meth_QWidget_setFont(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QFont* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFont, doc_QWidget_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_cursor, "cursor(self) -> QCursor");

extern "C" {static PyObject *meth_QWidget_cursor(PyObject *, PyObject *);}
static PyObject *meth_QWidget_cursor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QCursor*sipRes;

            sipRes = new  ::QCursor(sipCpp->cursor());

            return sipConvertFromNewType(sipRes,sipType_QCursor,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_cursor, doc_QWidget_cursor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setCursor, "setCursor(self, Union[QCursor, Qt.CursorShape])");

extern "C" {static PyObject *meth_QWidget_setCursor(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setCursor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QCursor* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QCursor, &a0, &a0State))
        {
            sipCpp->setCursor(*a0);
            sipReleaseType(const_cast< ::QCursor *>(a0),sipType_QCursor,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setCursor, doc_QWidget_setCursor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_unsetCursor, "unsetCursor(self)");

extern "C" {static PyObject *meth_QWidget_unsetCursor(PyObject *, PyObject *);}
static PyObject *meth_QWidget_unsetCursor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->unsetCursor();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_unsetCursor, doc_QWidget_unsetCursor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMask, "setMask(self, QBitmap)\n"
"setMask(self, QRegion)");

extern "C" {static PyObject *meth_QWidget_setMask(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QBitmap* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QBitmap, &a0))
        {
            sipCpp->setMask(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRegion* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRegion, &a0))
        {
            sipCpp->setMask(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMask, doc_QWidget_setMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mask, "mask(self) -> QRegion");

extern "C" {static PyObject *meth_QWidget_mask(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRegion*sipRes;

            sipRes = new  ::QRegion(sipCpp->mask());

            return sipConvertFromNewType(sipRes,sipType_QRegion,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mask, doc_QWidget_mask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_clearMask, "clearMask(self)");

extern "C" {static PyObject *meth_QWidget_clearMask(PyObject *, PyObject *);}
static PyObject *meth_QWidget_clearMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->clearMask();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_clearMask, doc_QWidget_clearMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowTitle, "setWindowTitle(self, str)");

extern "C" {static PyObject *meth_QWidget_setWindowTitle(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWindowTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowTitle, doc_QWidget_setWindowTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowTitle, "windowTitle(self) -> str");

extern "C" {static PyObject *meth_QWidget_windowTitle(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->windowTitle());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowTitle, doc_QWidget_windowTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowIcon, "setWindowIcon(self, QIcon)");

extern "C" {static PyObject *meth_QWidget_setWindowIcon(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QIcon* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->setWindowIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowIcon, doc_QWidget_setWindowIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowIcon, "windowIcon(self) -> QIcon");

extern "C" {static PyObject *meth_QWidget_windowIcon(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QIcon*sipRes;

            sipRes = new  ::QIcon(sipCpp->windowIcon());

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowIcon, doc_QWidget_windowIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowIconText, "setWindowIconText(self, str)");

extern "C" {static PyObject *meth_QWidget_setWindowIconText(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowIconText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWindowIconText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowIconText, doc_QWidget_setWindowIconText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowIconText, "windowIconText(self) -> str");

extern "C" {static PyObject *meth_QWidget_windowIconText(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowIconText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->windowIconText());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowIconText, doc_QWidget_windowIconText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowRole, "setWindowRole(self, str)");

extern "C" {static PyObject *meth_QWidget_setWindowRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWindowRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowRole, doc_QWidget_setWindowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowRole, "windowRole(self) -> str");

extern "C" {static PyObject *meth_QWidget_windowRole(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->windowRole());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowRole, doc_QWidget_windowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowOpacity, "setWindowOpacity(self, float)");

extern "C" {static PyObject *meth_QWidget_setWindowOpacity(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setWindowOpacity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowOpacity, doc_QWidget_setWindowOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowOpacity, "windowOpacity(self) -> float");

extern "C" {static PyObject *meth_QWidget_windowOpacity(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->windowOpacity();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowOpacity, doc_QWidget_windowOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isWindowModified, "isWindowModified(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isWindowModified(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isWindowModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isWindowModified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isWindowModified, doc_QWidget_isWindowModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setToolTip, "setToolTip(self, str)");

extern "C" {static PyObject *meth_QWidget_setToolTip(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setToolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setToolTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setToolTip, doc_QWidget_setToolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_toolTip, "toolTip(self) -> str");

extern "C" {static PyObject *meth_QWidget_toolTip(PyObject *, PyObject *);}
static PyObject *meth_QWidget_toolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toolTip());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_toolTip, doc_QWidget_toolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setStatusTip, "setStatusTip(self, str)");

extern "C" {static PyObject *meth_QWidget_setStatusTip(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setStatusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setStatusTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setStatusTip, doc_QWidget_setStatusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_statusTip, "statusTip(self) -> str");

extern "C" {static PyObject *meth_QWidget_statusTip(PyObject *, PyObject *);}
static PyObject *meth_QWidget_statusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->statusTip());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_statusTip, doc_QWidget_statusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWhatsThis, "setWhatsThis(self, str)");

extern "C" {static PyObject *meth_QWidget_setWhatsThis(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWhatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWhatsThis(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWhatsThis, doc_QWidget_setWhatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_whatsThis, "whatsThis(self) -> str");

extern "C" {static PyObject *meth_QWidget_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_QWidget_whatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->whatsThis());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_whatsThis, doc_QWidget_whatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setLayoutDirection, "setLayoutDirection(self, Qt.LayoutDirection)");

extern "C" {static PyObject *meth_QWidget_setLayoutDirection(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setLayoutDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::LayoutDirection a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_LayoutDirection, &a0))
        {
            sipCpp->setLayoutDirection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setLayoutDirection, doc_QWidget_setLayoutDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_layoutDirection, "layoutDirection(self) -> Qt.LayoutDirection");

extern "C" {static PyObject *meth_QWidget_layoutDirection(PyObject *, PyObject *);}
static PyObject *meth_QWidget_layoutDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::LayoutDirection sipRes;

            sipRes = sipCpp->layoutDirection();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_LayoutDirection);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_layoutDirection, doc_QWidget_layoutDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_unsetLayoutDirection, "unsetLayoutDirection(self)");

extern "C" {static PyObject *meth_QWidget_unsetLayoutDirection(PyObject *, PyObject *);}
static PyObject *meth_QWidget_unsetLayoutDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->unsetLayoutDirection();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_unsetLayoutDirection, doc_QWidget_unsetLayoutDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isRightToLeft, "isRightToLeft(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isRightToLeft(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isRightToLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRightToLeft();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isRightToLeft, doc_QWidget_isRightToLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isLeftToRight, "isLeftToRight(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isLeftToRight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isLeftToRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLeftToRight();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isLeftToRight, doc_QWidget_isLeftToRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFocus, "setFocus(self)\n"
"setFocus(self, Qt.FocusReason)");

extern "C" {static PyObject *meth_QWidget_setFocus(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->setFocus();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::Qt::FocusReason a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_FocusReason, &a0))
        {
            sipCpp->setFocus(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFocus, doc_QWidget_setFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isActiveWindow, "isActiveWindow(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isActiveWindow(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isActiveWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isActiveWindow();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isActiveWindow, doc_QWidget_isActiveWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_activateWindow, "activateWindow(self)");

extern "C" {static PyObject *meth_QWidget_activateWindow(PyObject *, PyObject *);}
static PyObject *meth_QWidget_activateWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->activateWindow();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_activateWindow, doc_QWidget_activateWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_clearFocus, "clearFocus(self)");

extern "C" {static PyObject *meth_QWidget_clearFocus(PyObject *, PyObject *);}
static PyObject *meth_QWidget_clearFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->clearFocus();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_clearFocus, doc_QWidget_clearFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusPolicy, "focusPolicy(self) -> Qt.FocusPolicy");

extern "C" {static PyObject *meth_QWidget_focusPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::FocusPolicy sipRes;

            sipRes = sipCpp->focusPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_FocusPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusPolicy, doc_QWidget_focusPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFocusPolicy, "setFocusPolicy(self, Qt.FocusPolicy)");

extern "C" {static PyObject *meth_QWidget_setFocusPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFocusPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::FocusPolicy a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_FocusPolicy, &a0))
        {
            sipCpp->setFocusPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFocusPolicy, doc_QWidget_setFocusPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hasFocus, "hasFocus(self) -> bool");

extern "C" {static PyObject *meth_QWidget_hasFocus(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hasFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFocus();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hasFocus, doc_QWidget_hasFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setTabOrder, "setTabOrder(QWidget, QWidget)");

extern "C" {static PyObject *meth_QWidget_setTabOrder(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setTabOrder(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
         ::QWidget* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J8", sipType_QWidget, &a0, sipType_QWidget, &a1))
        {
             ::QWidget::setTabOrder(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setTabOrder, doc_QWidget_setTabOrder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setFocusProxy, "setFocusProxy(self, QWidget)");

extern "C" {static PyObject *meth_QWidget_setFocusProxy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setFocusProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        PyObject *a0Keep;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWidget, &sipCpp, &a0Keep, sipType_QWidget, &a0))
        {
            sipCpp->setFocusProxy(a0);

            sipKeepReference(sipSelf, -58, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setFocusProxy, doc_QWidget_setFocusProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusProxy, "focusProxy(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_focusProxy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->focusProxy();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusProxy, doc_QWidget_focusProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_contextMenuPolicy, "contextMenuPolicy(self) -> Qt.ContextMenuPolicy");

extern "C" {static PyObject *meth_QWidget_contextMenuPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_contextMenuPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::ContextMenuPolicy sipRes;

            sipRes = sipCpp->contextMenuPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ContextMenuPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_contextMenuPolicy, doc_QWidget_contextMenuPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setContextMenuPolicy, "setContextMenuPolicy(self, Qt.ContextMenuPolicy)");

extern "C" {static PyObject *meth_QWidget_setContextMenuPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setContextMenuPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::ContextMenuPolicy a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_ContextMenuPolicy, &a0))
        {
            sipCpp->setContextMenuPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setContextMenuPolicy, doc_QWidget_setContextMenuPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_grabMouse, "grabMouse(self)\n"
"grabMouse(self, Union[QCursor, Qt.CursorShape])");

extern "C" {static PyObject *meth_QWidget_grabMouse(PyObject *, PyObject *);}
static PyObject *meth_QWidget_grabMouse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->grabMouse();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QCursor* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QCursor, &a0, &a0State))
        {
            sipCpp->grabMouse(*a0);
            sipReleaseType(const_cast< ::QCursor *>(a0),sipType_QCursor,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_grabMouse, doc_QWidget_grabMouse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_releaseMouse, "releaseMouse(self)");

extern "C" {static PyObject *meth_QWidget_releaseMouse(PyObject *, PyObject *);}
static PyObject *meth_QWidget_releaseMouse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->releaseMouse();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_releaseMouse, doc_QWidget_releaseMouse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_grabKeyboard, "grabKeyboard(self)");

extern "C" {static PyObject *meth_QWidget_grabKeyboard(PyObject *, PyObject *);}
static PyObject *meth_QWidget_grabKeyboard(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->grabKeyboard();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_grabKeyboard, doc_QWidget_grabKeyboard);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_releaseKeyboard, "releaseKeyboard(self)");

extern "C" {static PyObject *meth_QWidget_releaseKeyboard(PyObject *, PyObject *);}
static PyObject *meth_QWidget_releaseKeyboard(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->releaseKeyboard();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_releaseKeyboard, doc_QWidget_releaseKeyboard);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_grabShortcut, "grabShortcut(self, Union[QKeySequence, QKeySequence.StandardKey, str, int], context: Qt.ShortcutContext = Qt.WindowShortcut) -> int");

extern "C" {static PyObject *meth_QWidget_grabShortcut(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_grabShortcut(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QKeySequence* a0;
        int a0State = 0;
         ::Qt::ShortcutContext a1 = Qt::WindowShortcut;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_context,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QWidget, &sipCpp, sipType_QKeySequence, &a0, &a0State, sipType_Qt_ShortcutContext, &a1))
        {
            int sipRes;

            sipRes = sipCpp->grabShortcut(*a0,a1);
            sipReleaseType(const_cast< ::QKeySequence *>(a0),sipType_QKeySequence,a0State);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_grabShortcut, doc_QWidget_grabShortcut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_releaseShortcut, "releaseShortcut(self, int)");

extern "C" {static PyObject *meth_QWidget_releaseShortcut(PyObject *, PyObject *);}
static PyObject *meth_QWidget_releaseShortcut(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->releaseShortcut(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_releaseShortcut, doc_QWidget_releaseShortcut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setShortcutEnabled, "setShortcutEnabled(self, int, enabled: bool = True)");

extern "C" {static PyObject *meth_QWidget_setShortcutEnabled(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_setShortcutEnabled(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        bool a1 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|b", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setShortcutEnabled(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setShortcutEnabled, doc_QWidget_setShortcutEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mouseGrabber, "mouseGrabber() -> QWidget");

extern "C" {static PyObject *meth_QWidget_mouseGrabber(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mouseGrabber(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QWidget::mouseGrabber();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mouseGrabber, doc_QWidget_mouseGrabber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_keyboardGrabber, "keyboardGrabber() -> QWidget");

extern "C" {static PyObject *meth_QWidget_keyboardGrabber(PyObject *, PyObject *);}
static PyObject *meth_QWidget_keyboardGrabber(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QWidget*sipRes;

            sipRes =  ::QWidget::keyboardGrabber();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_keyboardGrabber, doc_QWidget_keyboardGrabber);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setUpdatesEnabled, "setUpdatesEnabled(self, bool)");

extern "C" {static PyObject *meth_QWidget_setUpdatesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setUpdatesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setUpdatesEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setUpdatesEnabled, doc_QWidget_setUpdatesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_update, "update(self)\n"
"update(self, QRect)\n"
"update(self, QRegion)\n"
"update(self, int, int, int, int)");

extern "C" {static PyObject *meth_QWidget_update(PyObject *, PyObject *);}
static PyObject *meth_QWidget_update(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->update();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRect* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->update(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRegion* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRegion, &a0))
        {
            sipCpp->update(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        int a2;
        int a3;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->update(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_update, doc_QWidget_update);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_repaint, "repaint(self)\n"
"repaint(self, int, int, int, int)\n"
"repaint(self, QRect)\n"
"repaint(self, QRegion)");

extern "C" {static PyObject *meth_QWidget_repaint(PyObject *, PyObject *);}
static PyObject *meth_QWidget_repaint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->repaint();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        int a2;
        int a3;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->repaint(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRect* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->repaint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QRegion* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRegion, &a0))
        {
            sipCpp->repaint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_repaint, doc_QWidget_repaint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setVisible, "setVisible(self, bool)");

extern "C" {static PyObject *meth_QWidget_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::setVisible(a0) : sipCpp->setVisible(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setVisible, doc_QWidget_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setHidden, "setHidden(self, bool)");

extern "C" {static PyObject *meth_QWidget_setHidden(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setHidden(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setHidden(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setHidden, doc_QWidget_setHidden);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_show, "show(self)");

extern "C" {static PyObject *meth_QWidget_show(PyObject *, PyObject *);}
static PyObject *meth_QWidget_show(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->show();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_show, doc_QWidget_show);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hide, "hide(self)");

extern "C" {static PyObject *meth_QWidget_hide(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hide(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->hide();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hide, doc_QWidget_hide);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_showMinimized, "showMinimized(self)");

extern "C" {static PyObject *meth_QWidget_showMinimized(PyObject *, PyObject *);}
static PyObject *meth_QWidget_showMinimized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->showMinimized();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_showMinimized, doc_QWidget_showMinimized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_showMaximized, "showMaximized(self)");

extern "C" {static PyObject *meth_QWidget_showMaximized(PyObject *, PyObject *);}
static PyObject *meth_QWidget_showMaximized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->showMaximized();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_showMaximized, doc_QWidget_showMaximized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_showFullScreen, "showFullScreen(self)");

extern "C" {static PyObject *meth_QWidget_showFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QWidget_showFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->showFullScreen();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_showFullScreen, doc_QWidget_showFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_showNormal, "showNormal(self)");

extern "C" {static PyObject *meth_QWidget_showNormal(PyObject *, PyObject *);}
static PyObject *meth_QWidget_showNormal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->showNormal();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_showNormal, doc_QWidget_showNormal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_close, "close(self) -> bool");

extern "C" {static PyObject *meth_QWidget_close(PyObject *, PyObject *);}
static PyObject *meth_QWidget_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->close();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_close, doc_QWidget_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_raise_, "raise_(self)");

extern "C" {static PyObject *meth_QWidget_raise_(PyObject *, PyObject *);}
static PyObject *meth_QWidget_raise_(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->raise();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_raise_, doc_QWidget_raise_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_lower, "lower(self)");

extern "C" {static PyObject *meth_QWidget_lower(PyObject *, PyObject *);}
static PyObject *meth_QWidget_lower(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->lower();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_lower, doc_QWidget_lower);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_stackUnder, "stackUnder(self, QWidget)");

extern "C" {static PyObject *meth_QWidget_stackUnder(PyObject *, PyObject *);}
static PyObject *meth_QWidget_stackUnder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0))
        {
            sipCpp->stackUnder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_stackUnder, doc_QWidget_stackUnder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_move, "move(self, QPoint)\n"
"move(self, int, int)");

extern "C" {static PyObject *meth_QWidget_move(PyObject *, PyObject *);}
static PyObject *meth_QWidget_move(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->move(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->move(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_move, doc_QWidget_move);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_resize, "resize(self, QSize)\n"
"resize(self, int, int)");

extern "C" {static PyObject *meth_QWidget_resize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_resize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QSize* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->resize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->resize(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_resize, doc_QWidget_resize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setGeometry, "setGeometry(self, QRect)\n"
"setGeometry(self, int, int, int, int)");

extern "C" {static PyObject *meth_QWidget_setGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setGeometry(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        int a2;
        int a3;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setGeometry(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setGeometry, doc_QWidget_setGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_adjustSize, "adjustSize(self)");

extern "C" {static PyObject *meth_QWidget_adjustSize(PyObject *, PyObject *);}
static PyObject *meth_QWidget_adjustSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->adjustSize();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_adjustSize, doc_QWidget_adjustSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isVisibleTo, "isVisibleTo(self, QWidget) -> bool");

extern "C" {static PyObject *meth_QWidget_isVisibleTo(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isVisibleTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isVisibleTo(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isVisibleTo, doc_QWidget_isVisibleTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isMinimized, "isMinimized(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isMinimized(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isMinimized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMinimized();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isMinimized, doc_QWidget_isMinimized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isMaximized, "isMaximized(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isMaximized(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isMaximized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMaximized();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isMaximized, doc_QWidget_isMaximized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isFullScreen, "isFullScreen(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFullScreen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isFullScreen, doc_QWidget_isFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowState, "windowState(self) -> Qt.WindowStates");

extern "C" {static PyObject *meth_QWidget_windowState(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::WindowStates*sipRes;

            sipRes = new  ::Qt::WindowStates(sipCpp->windowState());

            return sipConvertFromNewType(sipRes,sipType_Qt_WindowStates,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowState, doc_QWidget_windowState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowState, "setWindowState(self, Union[Qt.WindowStates, Qt.WindowState])");

extern "C" {static PyObject *meth_QWidget_setWindowState(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowStates* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowStates, &a0, &a0State))
        {
            sipCpp->setWindowState(*a0);
            sipReleaseType(a0,sipType_Qt_WindowStates,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowState, doc_QWidget_setWindowState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_overrideWindowState, "overrideWindowState(self, Union[Qt.WindowStates, Qt.WindowState])");

extern "C" {static PyObject *meth_QWidget_overrideWindowState(PyObject *, PyObject *);}
static PyObject *meth_QWidget_overrideWindowState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowStates* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowStates, &a0, &a0State))
        {
            sipCpp->overrideWindowState(*a0);
            sipReleaseType(a0,sipType_Qt_WindowStates,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_overrideWindowState, doc_QWidget_overrideWindowState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QWidget_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize((sipSelfWasArg ? sipCpp-> ::QWidget::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_sizeHint, doc_QWidget_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QWidget_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize((sipSelfWasArg ? sipCpp-> ::QWidget::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_minimumSizeHint, doc_QWidget_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_sizePolicy, "sizePolicy(self) -> QSizePolicy");

extern "C" {static PyObject *meth_QWidget_sizePolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_sizePolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSizePolicy*sipRes;

            sipRes = new  ::QSizePolicy(sipCpp->sizePolicy());

            return sipConvertFromNewType(sipRes,sipType_QSizePolicy,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_sizePolicy, doc_QWidget_sizePolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setSizePolicy, "setSizePolicy(self, QSizePolicy)\n"
"setSizePolicy(self, QSizePolicy.Policy, QSizePolicy.Policy)");

extern "C" {static PyObject *meth_QWidget_setSizePolicy(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setSizePolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSizePolicy* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSizePolicy, &a0))
        {
            sipCpp->setSizePolicy(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QSizePolicy::Policy a0;
         ::QSizePolicy::Policy a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEE", &sipSelf, sipType_QWidget, &sipCpp, sipType_QSizePolicy_Policy, &a0, sipType_QSizePolicy_Policy, &a1))
        {
            sipCpp->setSizePolicy(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setSizePolicy, doc_QWidget_setSizePolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_heightForWidth, "heightForWidth(self, int) -> int");

extern "C" {static PyObject *meth_QWidget_heightForWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_heightForWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::heightForWidth(a0) : sipCpp->heightForWidth(a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_heightForWidth, doc_QWidget_heightForWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_visibleRegion, "visibleRegion(self) -> QRegion");

extern "C" {static PyObject *meth_QWidget_visibleRegion(PyObject *, PyObject *);}
static PyObject *meth_QWidget_visibleRegion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRegion*sipRes;

            sipRes = new  ::QRegion(sipCpp->visibleRegion());

            return sipConvertFromNewType(sipRes,sipType_QRegion,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_visibleRegion, doc_QWidget_visibleRegion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setContentsMargins, "setContentsMargins(self, int, int, int, int)\n"
"setContentsMargins(self, QMargins)");

extern "C" {static PyObject *meth_QWidget_setContentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setContentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setContentsMargins(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QMargins* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMargins, &a0))
        {
            sipCpp->setContentsMargins(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setContentsMargins, doc_QWidget_setContentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_getContentsMargins, "getContentsMargins(self) -> Tuple[int, int, int, int]");

extern "C" {static PyObject *meth_QWidget_getContentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QWidget_getContentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->getContentsMargins(&a0,&a1,&a2,&a3);

            return sipBuildResult(0,"(iiii)",a0,a1,a2,a3);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_getContentsMargins, doc_QWidget_getContentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_contentsRect, "contentsRect(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_contentsRect(PyObject *, PyObject *);}
static PyObject *meth_QWidget_contentsRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->contentsRect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_contentsRect, doc_QWidget_contentsRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_layout, "layout(self) -> QLayout");

extern "C" {static PyObject *meth_QWidget_layout(PyObject *, PyObject *);}
static PyObject *meth_QWidget_layout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QLayout*sipRes;

            sipRes = sipCpp->layout();

            return sipConvertFromType(sipRes,sipType_QLayout,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_layout, doc_QWidget_layout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setLayout, "setLayout(self, QLayout)");

extern "C" {static PyObject *meth_QWidget_setLayout(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setLayout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QLayout* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QWidget, &sipCpp, sipType_QLayout, &a0))
        {
#line 243 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
        Py_BEGIN_ALLOW_THREADS
        sipCpp->setLayout(a0);
        Py_END_ALLOW_THREADS
        
        // Internally Qt has reparented all of the widgets in the layout, so we need
        // to update the ownership hierachy.
        qtwidgets_TransferLayoutWidgets(a0, sipSelf);
#line 5024 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setLayout, doc_QWidget_setLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_updateGeometry, "updateGeometry(self)");

extern "C" {static PyObject *meth_QWidget_updateGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_updateGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->updateGeometry();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_updateGeometry, doc_QWidget_updateGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setParent, "setParent(self, QWidget)\n"
"setParent(self, QWidget, Union[Qt.WindowFlags, Qt.WindowType])");

extern "C" {static PyObject *meth_QWidget_setParent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setParent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget* a0;
        sipWrapper *sipOwner = SIP_NULLPTR;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJH", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0, &sipOwner))
        {
            sipCpp->setParent(a0);

            if (sipOwner)
                sipTransferTo(sipSelf, (PyObject *)sipOwner);
            else
                sipTransferBack(sipSelf);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QWidget* a0;
         ::Qt::WindowFlags* a1;
        int a1State = 0;
        sipWrapper *sipOwner = SIP_NULLPTR;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJHJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0, &sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp->setParent(a0,*a1);

            if (sipOwner)
                sipTransferTo(sipSelf, (PyObject *)sipOwner);
            else
                sipTransferBack(sipSelf);
            sipReleaseType(a1,sipType_Qt_WindowFlags,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setParent, doc_QWidget_setParent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_scroll, "scroll(self, int, int)\n"
"scroll(self, int, int, QRect)");

extern "C" {static PyObject *meth_QWidget_scroll(PyObject *, PyObject *);}
static PyObject *meth_QWidget_scroll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->scroll(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        const  ::QRect* a2;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1, sipType_QRect, &a2))
        {
            sipCpp->scroll(a0,a1,*a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_scroll, doc_QWidget_scroll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusWidget, "focusWidget(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_focusWidget(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->focusWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusWidget, doc_QWidget_focusWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_nextInFocusChain, "nextInFocusChain(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_nextInFocusChain(PyObject *, PyObject *);}
static PyObject *meth_QWidget_nextInFocusChain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->nextInFocusChain();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_nextInFocusChain, doc_QWidget_nextInFocusChain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_acceptDrops, "acceptDrops(self) -> bool");

extern "C" {static PyObject *meth_QWidget_acceptDrops(PyObject *, PyObject *);}
static PyObject *meth_QWidget_acceptDrops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->acceptDrops();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_acceptDrops, doc_QWidget_acceptDrops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setAcceptDrops, "setAcceptDrops(self, bool)");

extern "C" {static PyObject *meth_QWidget_setAcceptDrops(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setAcceptDrops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setAcceptDrops(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setAcceptDrops, doc_QWidget_setAcceptDrops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_addAction, "addAction(self, QAction)");

extern "C" {static PyObject *meth_QWidget_addAction(PyObject *, PyObject *);}
static PyObject *meth_QWidget_addAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QAction, &a0))
        {
            sipCpp->addAction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_addAction, doc_QWidget_addAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_addActions, "addActions(self, Iterable[QAction])");

extern "C" {static PyObject *meth_QWidget_addActions(PyObject *, PyObject *);}
static PyObject *meth_QWidget_addActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        QList< ::QAction*>* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QList_0101QAction,&a0, &a0State))
        {
            sipCpp->addActions(*a0);
            sipReleaseType(a0,sipType_QList_0101QAction,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_addActions, doc_QWidget_addActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_insertAction, "insertAction(self, QAction, QAction)");

extern "C" {static PyObject *meth_QWidget_insertAction(PyObject *, PyObject *);}
static PyObject *meth_QWidget_insertAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
         ::QAction* a1;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QAction, &a0, sipType_QAction, &a1))
        {
            sipCpp->insertAction(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_insertAction, doc_QWidget_insertAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_insertActions, "insertActions(self, QAction, Iterable[QAction])");

extern "C" {static PyObject *meth_QWidget_insertActions(PyObject *, PyObject *);}
static PyObject *meth_QWidget_insertActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
        QList< ::QAction*>* a1;
        int a1State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QAction, &a0, sipType_QList_0101QAction,&a1, &a1State))
        {
            sipCpp->insertActions(a0,*a1);
            sipReleaseType(a1,sipType_QList_0101QAction,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_insertActions, doc_QWidget_insertActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_removeAction, "removeAction(self, QAction)");

extern "C" {static PyObject *meth_QWidget_removeAction(PyObject *, PyObject *);}
static PyObject *meth_QWidget_removeAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QAction* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QAction, &a0))
        {
            sipCpp->removeAction(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_removeAction, doc_QWidget_removeAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_actions, "actions(self) -> List[QAction]");

extern "C" {static PyObject *meth_QWidget_actions(PyObject *, PyObject *);}
static PyObject *meth_QWidget_actions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            QList< ::QAction*>*sipRes;

            sipRes = new QList< ::QAction*>(sipCpp->actions());

            return sipConvertFromNewType(sipRes,sipType_QList_0101QAction,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_actions, doc_QWidget_actions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowFlags, "setWindowFlags(self, Union[Qt.WindowFlags, Qt.WindowType])");

extern "C" {static PyObject *meth_QWidget_setWindowFlags(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowFlags* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowFlags, &a0, &a0State))
        {
            sipCpp->setWindowFlags(*a0);
            sipReleaseType(a0,sipType_Qt_WindowFlags,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowFlags, doc_QWidget_setWindowFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_overrideWindowFlags, "overrideWindowFlags(self, Union[Qt.WindowFlags, Qt.WindowType])");

extern "C" {static PyObject *meth_QWidget_overrideWindowFlags(PyObject *, PyObject *);}
static PyObject *meth_QWidget_overrideWindowFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowFlags* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowFlags, &a0, &a0State))
        {
            sipCpp->overrideWindowFlags(*a0);
            sipReleaseType(a0,sipType_Qt_WindowFlags,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_overrideWindowFlags, doc_QWidget_overrideWindowFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_find, "find(sip.voidptr) -> QWidget");

extern "C" {static PyObject *meth_QWidget_find(PyObject *, PyObject *);}
static PyObject *meth_QWidget_find(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::WId* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_quintptr,&a0, &a0State))
        {
             ::QWidget*sipRes;

            sipRes =  ::QWidget::find(*a0);
            sipReleaseType(a0,sipType_quintptr,a0State);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_find, doc_QWidget_find);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_childAt, "childAt(self, QPoint) -> QWidget\n"
"childAt(self, int, int) -> QWidget");

extern "C" {static PyObject *meth_QWidget_childAt(PyObject *, PyObject *);}
static PyObject *meth_QWidget_childAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPoint* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPoint, &a0))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->childAt(*a0);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->childAt(a0,a1);

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_childAt, doc_QWidget_childAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setAttribute, "setAttribute(self, Qt.WidgetAttribute, on: bool = True)");

extern "C" {static PyObject *meth_QWidget_setAttribute(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_setAttribute(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WidgetAttribute a0;
        bool a1 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_on,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WidgetAttribute, &a0, &a1))
        {
            sipCpp->setAttribute(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setAttribute, doc_QWidget_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_paintEngine, "paintEngine(self) -> QPaintEngine");

extern "C" {static PyObject *meth_QWidget_paintEngine(PyObject *, PyObject *);}
static PyObject *meth_QWidget_paintEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPaintEngine*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::paintEngine() : sipCpp->paintEngine());

            return sipConvertFromType(sipRes,sipType_QPaintEngine,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_paintEngine, doc_QWidget_paintEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_ensurePolished, "ensurePolished(self)");

extern "C" {static PyObject *meth_QWidget_ensurePolished(PyObject *, PyObject *);}
static PyObject *meth_QWidget_ensurePolished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->ensurePolished();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_ensurePolished, doc_QWidget_ensurePolished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isAncestorOf, "isAncestorOf(self, QWidget) -> bool");

extern "C" {static PyObject *meth_QWidget_isAncestorOf(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isAncestorOf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isAncestorOf(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isAncestorOf, doc_QWidget_isAncestorOf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_event, "event(self, QEvent) -> bool");

extern "C" {static PyObject *meth_QWidget_event(PyObject *, PyObject *);}
static PyObject *meth_QWidget_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_event, doc_QWidget_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mousePressEvent, "mousePressEvent(self, QMouseEvent)");

extern "C" {static PyObject *meth_QWidget_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QMouseEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mousePressEvent, doc_QWidget_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mouseReleaseEvent, "mouseReleaseEvent(self, QMouseEvent)");

extern "C" {static PyObject *meth_QWidget_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QMouseEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mouseReleaseEvent, doc_QWidget_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, QMouseEvent)");

extern "C" {static PyObject *meth_QWidget_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QMouseEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mouseDoubleClickEvent, doc_QWidget_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_mouseMoveEvent, "mouseMoveEvent(self, QMouseEvent)");

extern "C" {static PyObject *meth_QWidget_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QMouseEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_mouseMoveEvent, doc_QWidget_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_wheelEvent, "wheelEvent(self, QWheelEvent)");

extern "C" {static PyObject *meth_QWidget_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QWheelEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_wheelEvent, doc_QWidget_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_keyPressEvent, "keyPressEvent(self, QKeyEvent)");

extern "C" {static PyObject *meth_QWidget_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QKeyEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_keyPressEvent, doc_QWidget_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_keyReleaseEvent, "keyReleaseEvent(self, QKeyEvent)");

extern "C" {static PyObject *meth_QWidget_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QKeyEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_keyReleaseEvent, doc_QWidget_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusInEvent, "focusInEvent(self, QFocusEvent)");

extern "C" {static PyObject *meth_QWidget_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QFocusEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusInEvent, doc_QWidget_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusOutEvent, "focusOutEvent(self, QFocusEvent)");

extern "C" {static PyObject *meth_QWidget_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QFocusEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusOutEvent, doc_QWidget_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_enterEvent, "enterEvent(self, QEvent)");

extern "C" {static PyObject *meth_QWidget_enterEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_enterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::enterEvent(a0) : sipCpp->enterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_enterEvent, doc_QWidget_enterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_leaveEvent, "leaveEvent(self, QEvent)");

extern "C" {static PyObject *meth_QWidget_leaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_leaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::leaveEvent(a0) : sipCpp->leaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_leaveEvent, doc_QWidget_leaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_paintEvent, "paintEvent(self, QPaintEvent)");

extern "C" {static PyObject *meth_QWidget_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QPaintEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_paintEvent, doc_QWidget_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_moveEvent, "moveEvent(self, QMoveEvent)");

extern "C" {static PyObject *meth_QWidget_moveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_moveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QMoveEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QMoveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::moveEvent(a0) : sipCpp->moveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_moveEvent, doc_QWidget_moveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_resizeEvent, "resizeEvent(self, QResizeEvent)");

extern "C" {static PyObject *meth_QWidget_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QResizeEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_resizeEvent, doc_QWidget_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_closeEvent, "closeEvent(self, QCloseEvent)");

extern "C" {static PyObject *meth_QWidget_closeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_closeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QCloseEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QCloseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::closeEvent(a0) : sipCpp->closeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_closeEvent, doc_QWidget_closeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_contextMenuEvent, "contextMenuEvent(self, QContextMenuEvent)");

extern "C" {static PyObject *meth_QWidget_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QContextMenuEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_contextMenuEvent, doc_QWidget_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_tabletEvent, "tabletEvent(self, QTabletEvent)");

extern "C" {static PyObject *meth_QWidget_tabletEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_tabletEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QTabletEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QTabletEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::tabletEvent(a0) : sipCpp->tabletEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_tabletEvent, doc_QWidget_tabletEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_actionEvent, "actionEvent(self, QActionEvent)");

extern "C" {static PyObject *meth_QWidget_actionEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_actionEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QActionEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QActionEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::actionEvent(a0) : sipCpp->actionEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_actionEvent, doc_QWidget_actionEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_dragEnterEvent, "dragEnterEvent(self, QDragEnterEvent)");

extern "C" {static PyObject *meth_QWidget_dragEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_dragEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDragEnterEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QDragEnterEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::dragEnterEvent(a0) : sipCpp->dragEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_dragEnterEvent, doc_QWidget_dragEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_dragMoveEvent, "dragMoveEvent(self, QDragMoveEvent)");

extern "C" {static PyObject *meth_QWidget_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDragMoveEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QDragMoveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_dragMoveEvent, doc_QWidget_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_dragLeaveEvent, "dragLeaveEvent(self, QDragLeaveEvent)");

extern "C" {static PyObject *meth_QWidget_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDragLeaveEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QDragLeaveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_dragLeaveEvent, doc_QWidget_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_dropEvent, "dropEvent(self, QDropEvent)");

extern "C" {static PyObject *meth_QWidget_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QDropEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_dropEvent, doc_QWidget_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_showEvent, "showEvent(self, QShowEvent)");

extern "C" {static PyObject *meth_QWidget_showEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QShowEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_showEvent, doc_QWidget_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hideEvent, "hideEvent(self, QHideEvent)");

extern "C" {static PyObject *meth_QWidget_hideEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hideEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QHideEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QHideEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::hideEvent(a0) : sipCpp->hideEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hideEvent, doc_QWidget_hideEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_changeEvent, "changeEvent(self, QEvent)");

extern "C" {static PyObject *meth_QWidget_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_changeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::changeEvent(a0) : sipCpp->changeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_changeEvent, doc_QWidget_changeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_metric, "metric(self, QPaintDevice.PaintDeviceMetric) -> int");

extern "C" {static PyObject *meth_QWidget_metric(PyObject *, PyObject *);}
static PyObject *meth_QWidget_metric(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QPaintDevice::PaintDeviceMetric a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPaintDevice_PaintDeviceMetric, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::metric(a0) : sipCpp->metric(a0));

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_metric, doc_QWidget_metric);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_inputMethodEvent, "inputMethodEvent(self, QInputMethodEvent)");

extern "C" {static PyObject *meth_QWidget_inputMethodEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_inputMethodEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QInputMethodEvent* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QInputMethodEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::inputMethodEvent(a0) : sipCpp->inputMethodEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_inputMethodEvent, doc_QWidget_inputMethodEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_inputMethodQuery, "inputMethodQuery(self, Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QWidget_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QWidget_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::Qt::InputMethodQuery a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::QWidget::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes,sipType_QVariant,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_inputMethodQuery, doc_QWidget_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_updateMicroFocus, "updateMicroFocus(self)");

extern "C" {static PyObject *meth_QWidget_updateMicroFocus(PyObject *, PyObject *);}
static PyObject *meth_QWidget_updateMicroFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->updateMicroFocus();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_updateMicroFocus, doc_QWidget_updateMicroFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_create, "create(self, window: sip.voidptr = 0, initializeWindow: bool = True, destroyOldWindow: bool = True)");

extern "C" {static PyObject *meth_QWidget_create(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_create(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::WId a0def = 0;
         ::WId* a0 = &a0def;
        int a0State = 0;
        bool a1 = 1;
        bool a2 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            sipName_window,
            sipName_initializeWindow,
            sipName_destroyOldWindow,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "p|J1bb", &sipSelf, sipType_QWidget, &sipCpp, sipType_quintptr,&a0, &a0State, &a1, &a2))
        {
            sipCpp->create(*a0,a1,a2);
            sipReleaseType(a0,sipType_quintptr,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_create, doc_QWidget_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_destroy, "destroy(self, destroyWindow: bool = True, destroySubWindows: bool = True)");

extern "C" {static PyObject *meth_QWidget_destroy(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_destroy(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        bool a1 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            sipName_destroyWindow,
            sipName_destroySubWindows,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "p|bb", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->destroy(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_destroy, doc_QWidget_destroy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusNextPrevChild, "focusNextPrevChild(self, bool) -> bool");

extern "C" {static PyObject *meth_QWidget_focusNextPrevChild(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusNextPrevChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::focusNextPrevChild(a0) : sipCpp->focusNextPrevChild(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusNextPrevChild, doc_QWidget_focusNextPrevChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusNextChild, "focusNextChild(self) -> bool");

extern "C" {static PyObject *meth_QWidget_focusNextChild(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusNextChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->focusNextChild();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusNextChild, doc_QWidget_focusNextChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_focusPreviousChild, "focusPreviousChild(self) -> bool");

extern "C" {static PyObject *meth_QWidget_focusPreviousChild(PyObject *, PyObject *);}
static PyObject *meth_QWidget_focusPreviousChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->focusPreviousChild();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_focusPreviousChild, doc_QWidget_focusPreviousChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowType, "windowType(self) -> Qt.WindowType");

extern "C" {static PyObject *meth_QWidget_windowType(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::WindowType sipRes;

            sipRes = sipCpp->windowType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_WindowType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowType, doc_QWidget_windowType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowFlags, "windowFlags(self) -> Qt.WindowFlags");

extern "C" {static PyObject *meth_QWidget_windowFlags(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::WindowFlags*sipRes;

            sipRes = new  ::Qt::WindowFlags(sipCpp->windowFlags());

            return sipConvertFromNewType(sipRes,sipType_Qt_WindowFlags,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowFlags, doc_QWidget_windowFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_winId, "winId(self) -> sip.voidptr");

extern "C" {static PyObject *meth_QWidget_winId(PyObject *, PyObject *);}
static PyObject *meth_QWidget_winId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::WId*sipRes;

            sipRes = new  ::WId(sipCpp->winId());

            return sipConvertFromNewType(sipRes,sipType_quintptr,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_winId, doc_QWidget_winId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isWindow, "isWindow(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isWindow(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isWindow();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isWindow, doc_QWidget_isWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isEnabled, doc_QWidget_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isModal, "isModal(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isModal(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isModal(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isModal();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isModal, doc_QWidget_isModal);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_minimumWidth, "minimumWidth(self) -> int");

extern "C" {static PyObject *meth_QWidget_minimumWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_minimumWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumWidth();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_minimumWidth, doc_QWidget_minimumWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_minimumHeight, "minimumHeight(self) -> int");

extern "C" {static PyObject *meth_QWidget_minimumHeight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_minimumHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumHeight();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_minimumHeight, doc_QWidget_minimumHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_maximumWidth, "maximumWidth(self) -> int");

extern "C" {static PyObject *meth_QWidget_maximumWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_maximumWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumWidth();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_maximumWidth, doc_QWidget_maximumWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_maximumHeight, "maximumHeight(self) -> int");

extern "C" {static PyObject *meth_QWidget_maximumHeight(PyObject *, PyObject *);}
static PyObject *meth_QWidget_maximumHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumHeight();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_maximumHeight, doc_QWidget_maximumHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QWidget_font(PyObject *, PyObject *);}
static PyObject *meth_QWidget_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QFont*sipRes;

            sipRes = new  ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes,sipType_QFont,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_font, doc_QWidget_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_fontMetrics, "fontMetrics(self) -> QFontMetrics");

extern "C" {static PyObject *meth_QWidget_fontMetrics(PyObject *, PyObject *);}
static PyObject *meth_QWidget_fontMetrics(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QFontMetrics*sipRes;

            sipRes = new  ::QFontMetrics(sipCpp->fontMetrics());

            return sipConvertFromNewType(sipRes,sipType_QFontMetrics,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_fontMetrics, doc_QWidget_fontMetrics);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_fontInfo, "fontInfo(self) -> QFontInfo");

extern "C" {static PyObject *meth_QWidget_fontInfo(PyObject *, PyObject *);}
static PyObject *meth_QWidget_fontInfo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QFontInfo*sipRes;

            sipRes = new  ::QFontInfo(sipCpp->fontInfo());

            return sipConvertFromNewType(sipRes,sipType_QFontInfo,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_fontInfo, doc_QWidget_fontInfo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setMouseTracking, "setMouseTracking(self, bool)");

extern "C" {static PyObject *meth_QWidget_setMouseTracking(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setMouseTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setMouseTracking(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setMouseTracking, doc_QWidget_setMouseTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hasMouseTracking, "hasMouseTracking(self) -> bool");

extern "C" {static PyObject *meth_QWidget_hasMouseTracking(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hasMouseTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasMouseTracking();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hasMouseTracking, doc_QWidget_hasMouseTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_underMouse, "underMouse(self) -> bool");

extern "C" {static PyObject *meth_QWidget_underMouse(PyObject *, PyObject *);}
static PyObject *meth_QWidget_underMouse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->underMouse();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_underMouse, doc_QWidget_underMouse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_updatesEnabled, "updatesEnabled(self) -> bool");

extern "C" {static PyObject *meth_QWidget_updatesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QWidget_updatesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->updatesEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_updatesEnabled, doc_QWidget_updatesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isVisible, doc_QWidget_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_isHidden, "isHidden(self) -> bool");

extern "C" {static PyObject *meth_QWidget_isHidden(PyObject *, PyObject *);}
static PyObject *meth_QWidget_isHidden(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isHidden();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_isHidden, doc_QWidget_isHidden);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_rect, "rect(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_rect(PyObject *, PyObject *);}
static PyObject *meth_QWidget_rect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->rect());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_rect, doc_QWidget_rect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_geometry, "geometry(self) -> QRect");

extern "C" {static PyObject *meth_QWidget_geometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_geometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect(sipCpp->geometry());

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_geometry, doc_QWidget_geometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_size, "size(self) -> QSize");

extern "C" {static PyObject *meth_QWidget_size(PyObject *, PyObject *);}
static PyObject *meth_QWidget_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QSize*sipRes;

            sipRes = new  ::QSize(sipCpp->size());

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_size, doc_QWidget_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_width, "width(self) -> int");

extern "C" {static PyObject *meth_QWidget_width(PyObject *, PyObject *);}
static PyObject *meth_QWidget_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->width();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_width, doc_QWidget_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_height, "height(self) -> int");

extern "C" {static PyObject *meth_QWidget_height(PyObject *, PyObject *);}
static PyObject *meth_QWidget_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->height();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_height, doc_QWidget_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_parentWidget, "parentWidget(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_parentWidget(PyObject *, PyObject *);}
static PyObject *meth_QWidget_parentWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->parentWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_parentWidget, doc_QWidget_parentWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_testAttribute, "testAttribute(self, Qt.WidgetAttribute) -> bool");

extern "C" {static PyObject *meth_QWidget_testAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWidget_testAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WidgetAttribute a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WidgetAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->testAttribute(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_testAttribute, doc_QWidget_testAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowModality, "windowModality(self) -> Qt.WindowModality");

extern "C" {static PyObject *meth_QWidget_windowModality(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowModality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::WindowModality sipRes;

            sipRes = sipCpp->windowModality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_WindowModality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowModality, doc_QWidget_windowModality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowModality, "setWindowModality(self, Qt.WindowModality)");

extern "C" {static PyObject *meth_QWidget_setWindowModality(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowModality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowModality a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowModality, &a0))
        {
            sipCpp->setWindowModality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowModality, doc_QWidget_setWindowModality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_autoFillBackground, "autoFillBackground(self) -> bool");

extern "C" {static PyObject *meth_QWidget_autoFillBackground(PyObject *, PyObject *);}
static PyObject *meth_QWidget_autoFillBackground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoFillBackground();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_autoFillBackground, doc_QWidget_autoFillBackground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setAutoFillBackground, "setAutoFillBackground(self, bool)");

extern "C" {static PyObject *meth_QWidget_setAutoFillBackground(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setAutoFillBackground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setAutoFillBackground(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setAutoFillBackground, doc_QWidget_setAutoFillBackground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setStyleSheet, "setStyleSheet(self, str)");

extern "C" {static PyObject *meth_QWidget_setStyleSheet(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setStyleSheet(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setStyleSheet(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setStyleSheet, doc_QWidget_setStyleSheet);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_styleSheet, "styleSheet(self) -> str");

extern "C" {static PyObject *meth_QWidget_styleSheet(PyObject *, PyObject *);}
static PyObject *meth_QWidget_styleSheet(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->styleSheet());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_styleSheet, doc_QWidget_styleSheet);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setShortcutAutoRepeat, "setShortcutAutoRepeat(self, int, enabled: bool = True)");

extern "C" {static PyObject *meth_QWidget_setShortcutAutoRepeat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_setShortcutAutoRepeat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        bool a1 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|b", &sipSelf, sipType_QWidget, &sipCpp, &a0, &a1))
        {
            sipCpp->setShortcutAutoRepeat(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setShortcutAutoRepeat, doc_QWidget_setShortcutAutoRepeat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_saveGeometry, "saveGeometry(self) -> QByteArray");

extern "C" {static PyObject *meth_QWidget_saveGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_saveGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QByteArray*sipRes;

            sipRes = new  ::QByteArray(sipCpp->saveGeometry());

            return sipConvertFromNewType(sipRes,sipType_QByteArray,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_saveGeometry, doc_QWidget_saveGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_restoreGeometry, "restoreGeometry(self, Union[QByteArray, bytes, bytearray]) -> bool");

extern "C" {static PyObject *meth_QWidget_restoreGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWidget_restoreGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QByteArray* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->restoreGeometry(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_restoreGeometry, doc_QWidget_restoreGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_render, "render(self, QPaintDevice, targetOffset: QPoint = QPoint(), sourceRegion: QRegion = QRegion(), flags: Union[QWidget.RenderFlags, QWidget.RenderFlag] = QWidget.RenderFlags(QWidget.RenderFlag.DrawWindowBackground|QWidget.RenderFlag.DrawChildren))\n"
"render(self, QPainter, targetOffset: QPoint = QPoint(), sourceRegion: QRegion = QRegion(), flags: Union[QWidget.RenderFlags, QWidget.RenderFlag] = QWidget.RenderFlags(QWidget.RenderFlag.DrawWindowBackground|QWidget.RenderFlag.DrawChildren))");

extern "C" {static PyObject *meth_QWidget_render(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_render(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPaintDevice* a0;
        const  ::QPoint& a1def = QPoint();
        const  ::QPoint* a1 = &a1def;
        const  ::QRegion& a2def = QRegion();
        const  ::QRegion* a2 = &a2def;
         ::QWidget::RenderFlags a3def = QWidget::RenderFlags(QWidget::RenderFlag::DrawWindowBackground|QWidget::RenderFlag::DrawChildren);
         ::QWidget::RenderFlags* a3 = &a3def;
        int a3State = 0;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_targetOffset,
            sipName_sourceRegion,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J9J9J1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPaintDevice, &a0, sipType_QPoint, &a1, sipType_QRegion, &a2, sipType_QWidget_RenderFlags, &a3, &a3State))
        {
            sipCpp->render(a0,*a1,*a2,*a3);
            sipReleaseType(a3,sipType_QWidget_RenderFlags,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QPainter* a0;
        const  ::QPoint& a1def = QPoint();
        const  ::QPoint* a1 = &a1def;
        const  ::QRegion& a2def = QRegion();
        const  ::QRegion* a2 = &a2def;
         ::QWidget::RenderFlags a3def = QWidget::RenderFlags(QWidget::RenderFlag::DrawWindowBackground|QWidget::RenderFlag::DrawChildren);
         ::QWidget::RenderFlags* a3 = &a3def;
        int a3State = 0;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_targetOffset,
            sipName_sourceRegion,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J9J9J1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPainter, &a0, sipType_QPoint, &a1, sipType_QRegion, &a2, sipType_QWidget_RenderFlags, &a3, &a3State))
        {
            sipCpp->render(a0,*a1,*a2,*a3);
            sipReleaseType(a3,sipType_QWidget_RenderFlags,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_render, doc_QWidget_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setLocale, "setLocale(self, QLocale)");

extern "C" {static PyObject *meth_QWidget_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QLocale* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setLocale, doc_QWidget_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QWidget_locale(PyObject *, PyObject *);}
static PyObject *meth_QWidget_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QLocale*sipRes;

            sipRes = new  ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes,sipType_QLocale,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_locale, doc_QWidget_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_unsetLocale, "unsetLocale(self)");

extern "C" {static PyObject *meth_QWidget_unsetLocale(PyObject *, PyObject *);}
static PyObject *meth_QWidget_unsetLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            sipCpp->unsetLocale();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_unsetLocale, doc_QWidget_unsetLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_effectiveWinId, "effectiveWinId(self) -> sip.voidptr");

extern "C" {static PyObject *meth_QWidget_effectiveWinId(PyObject *, PyObject *);}
static PyObject *meth_QWidget_effectiveWinId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::WId*sipRes;

            sipRes = new  ::WId(sipCpp->effectiveWinId());

            return sipConvertFromNewType(sipRes,sipType_quintptr,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_effectiveWinId, doc_QWidget_effectiveWinId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_nativeParentWidget, "nativeParentWidget(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_nativeParentWidget(PyObject *, PyObject *);}
static PyObject *meth_QWidget_nativeParentWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->nativeParentWidget();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_nativeParentWidget, doc_QWidget_nativeParentWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowFilePath, "setWindowFilePath(self, str)");

extern "C" {static PyObject *meth_QWidget_setWindowFilePath(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowFilePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWindowFilePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowFilePath, doc_QWidget_setWindowFilePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowFilePath, "windowFilePath(self) -> str");

extern "C" {static PyObject *meth_QWidget_windowFilePath(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowFilePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->windowFilePath());

            return sipConvertFromNewType(sipRes,sipType_QString,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowFilePath, doc_QWidget_windowFilePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_graphicsProxyWidget, "graphicsProxyWidget(self) -> QGraphicsProxyWidget");

extern "C" {static PyObject *meth_QWidget_graphicsProxyWidget(PyObject *, PyObject *);}
static PyObject *meth_QWidget_graphicsProxyWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QGraphicsProxyWidget*sipRes;

            sipRes = sipCpp->graphicsProxyWidget();

            return sipConvertFromType(sipRes,sipType_QGraphicsProxyWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_graphicsProxyWidget, doc_QWidget_graphicsProxyWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_graphicsEffect, "graphicsEffect(self) -> QGraphicsEffect");

extern "C" {static PyObject *meth_QWidget_graphicsEffect(PyObject *, PyObject *);}
static PyObject *meth_QWidget_graphicsEffect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QGraphicsEffect*sipRes;

            sipRes = sipCpp->graphicsEffect();

            return sipConvertFromType(sipRes,sipType_QGraphicsEffect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_graphicsEffect, doc_QWidget_graphicsEffect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setGraphicsEffect, "setGraphicsEffect(self, QGraphicsEffect)");

extern "C" {static PyObject *meth_QWidget_setGraphicsEffect(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setGraphicsEffect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QGraphicsEffect* a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QWidget, &sipCpp, sipType_QGraphicsEffect, &a0))
        {
            sipCpp->setGraphicsEffect(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setGraphicsEffect, doc_QWidget_setGraphicsEffect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_grabGesture, "grabGesture(self, Qt.GestureType, flags: Union[Qt.GestureFlags, Qt.GestureFlag] = Qt.GestureFlags())");

extern "C" {static PyObject *meth_QWidget_grabGesture(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_grabGesture(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::GestureType a0;
         ::Qt::GestureFlags a1def = Qt::GestureFlags();
         ::Qt::GestureFlags* a1 = &a1def;
        int a1State = 0;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_GestureType, &a0, sipType_Qt_GestureFlags, &a1, &a1State))
        {
            sipCpp->grabGesture(a0,*a1);
            sipReleaseType(a1,sipType_Qt_GestureFlags,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_grabGesture, doc_QWidget_grabGesture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_ungrabGesture, "ungrabGesture(self, Qt.GestureType)");

extern "C" {static PyObject *meth_QWidget_ungrabGesture(PyObject *, PyObject *);}
static PyObject *meth_QWidget_ungrabGesture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::GestureType a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_GestureType, &a0))
        {
            sipCpp->ungrabGesture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_ungrabGesture, doc_QWidget_ungrabGesture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_contentsMargins, "contentsMargins(self) -> QMargins");

extern "C" {static PyObject *meth_QWidget_contentsMargins(PyObject *, PyObject *);}
static PyObject *meth_QWidget_contentsMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QMargins*sipRes;

            sipRes = new  ::QMargins(sipCpp->contentsMargins());

            return sipConvertFromNewType(sipRes,sipType_QMargins,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_contentsMargins, doc_QWidget_contentsMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_previousInFocusChain, "previousInFocusChain(self) -> QWidget");

extern "C" {static PyObject *meth_QWidget_previousInFocusChain(PyObject *, PyObject *);}
static PyObject *meth_QWidget_previousInFocusChain(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWidget*sipRes;

            sipRes = sipCpp->previousInFocusChain();

            return sipConvertFromType(sipRes,sipType_QWidget,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_previousInFocusChain, doc_QWidget_previousInFocusChain);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_inputMethodHints, "inputMethodHints(self) -> Qt.InputMethodHints");

extern "C" {static PyObject *meth_QWidget_inputMethodHints(PyObject *, PyObject *);}
static PyObject *meth_QWidget_inputMethodHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::Qt::InputMethodHints*sipRes;

            sipRes = new  ::Qt::InputMethodHints(sipCpp->inputMethodHints());

            return sipConvertFromNewType(sipRes,sipType_Qt_InputMethodHints,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_inputMethodHints, doc_QWidget_inputMethodHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setInputMethodHints, "setInputMethodHints(self, Union[Qt.InputMethodHints, Qt.InputMethodHint])");

extern "C" {static PyObject *meth_QWidget_setInputMethodHints(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setInputMethodHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::InputMethodHints* a0;
        int a0State = 0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_InputMethodHints, &a0, &a0State))
        {
            sipCpp->setInputMethodHints(*a0);
            sipReleaseType(a0,sipType_Qt_InputMethodHints,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setInputMethodHints, doc_QWidget_setInputMethodHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hasHeightForWidth, "hasHeightForWidth(self) -> bool");

extern "C" {static PyObject *meth_QWidget_hasHeightForWidth(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hasHeightForWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::hasHeightForWidth() : sipCpp->hasHeightForWidth());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hasHeightForWidth, doc_QWidget_hasHeightForWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_grab, "grab(self, rectangle: QRect = QRect(QPoint(0,0),QSize(-1,-1))) -> QPixmap");

extern "C" {static PyObject *meth_QWidget_grab(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_grab(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRect& a0def = QRect(QPoint(0,0),QSize(-1,-1));
        const  ::QRect* a0 = &a0def;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            sipName_rectangle,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QWidget, &sipCpp, sipType_QRect, &a0))
        {
             ::QPixmap*sipRes;

            sipRes = new  ::QPixmap(sipCpp->grab(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_grab, doc_QWidget_grab);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_createWindowContainer, "createWindowContainer(QWindow, parent: QWidget = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = 0) -> QWidget");

extern "C" {static PyObject *meth_QWidget_createWindowContainer(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_createWindowContainer(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QWindow* a0;
        PyObject *a0Wrapper;
         ::QWidget* a1 = 0;
        PyObject *a1Wrapper = 0;
         ::Qt::WindowFlags a2def = 0;
         ::Qt::WindowFlags* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "@J8|@J8J1", &a0Wrapper, sipType_QWindow, &a0, &a1Wrapper, sipType_QWidget, &a1, sipType_Qt_WindowFlags, &a2, &a2State))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 399 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
        // Ownersip issues are complicated so we handle them explicitly.
        
        QWidget *w = QWidget::createWindowContainer(a0, a1, *a2);
        
        sipRes = sipConvertFromNewType(w, sipType_QWidget, a1Wrapper);
        
        if (sipRes)
            sipTransferTo(a0Wrapper, sipRes);
#line 8253 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQWidget.cpp"
            sipReleaseType(a2,sipType_Qt_WindowFlags,a2State);

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_createWindowContainer, doc_QWidget_createWindowContainer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_windowHandle, "windowHandle(self) -> QWindow");

extern "C" {static PyObject *meth_QWidget_windowHandle(PyObject *, PyObject *);}
static PyObject *meth_QWidget_windowHandle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QWindow*sipRes;

            sipRes = sipCpp->windowHandle();

            return sipConvertFromType(sipRes,sipType_QWindow,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_windowHandle, doc_QWidget_windowHandle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_nativeEvent, "nativeEvent(self, Union[QByteArray, bytes, bytearray], sip.voidptr) -> Tuple[bool, int]");

extern "C" {static PyObject *meth_QWidget_nativeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWidget_nativeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        void* a1;
        long a2;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1v", &sipSelf, sipType_QWidget, &sipCpp, sipType_QByteArray, &a0, &a0State, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::nativeEvent(*a0,a1,&a2) : sipCpp->nativeEvent(*a0,a1,&a2));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipBuildResult(0,"(bl)",sipRes,a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_nativeEvent, doc_QWidget_nativeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_sharedPainter, "sharedPainter(self) -> QPainter");

extern "C" {static PyObject *meth_QWidget_sharedPainter(PyObject *, PyObject *);}
static PyObject *meth_QWidget_sharedPainter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QPainter*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::QWidget::sharedPainter() : sipCpp->sharedPainter());

            return sipConvertFromType(sipRes,sipType_QPainter,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_sharedPainter, doc_QWidget_sharedPainter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_initPainter, "initPainter(self, QPainter)");

extern "C" {static PyObject *meth_QWidget_initPainter(PyObject *, PyObject *);}
static PyObject *meth_QWidget_initPainter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QPainter* a0;
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWidget, &sipCpp, sipType_QPainter, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QWidget::initPainter(a0) : sipCpp->initPainter(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_initPainter, doc_QWidget_initPainter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setToolTipDuration, "setToolTipDuration(self, int)");

extern "C" {static PyObject *meth_QWidget_setToolTipDuration(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setToolTipDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setToolTipDuration(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setToolTipDuration, doc_QWidget_setToolTipDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_toolTipDuration, "toolTipDuration(self) -> int");

extern "C" {static PyObject *meth_QWidget_toolTipDuration(PyObject *, PyObject *);}
static PyObject *meth_QWidget_toolTipDuration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->toolTipDuration();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_toolTipDuration, doc_QWidget_toolTipDuration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setTabletTracking, "setTabletTracking(self, bool)");

extern "C" {static PyObject *meth_QWidget_setTabletTracking(PyObject *, PyObject *);}
static PyObject *meth_QWidget_setTabletTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
         ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWidget, &sipCpp, &a0))
        {
            sipCpp->setTabletTracking(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setTabletTracking, doc_QWidget_setTabletTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_hasTabletTracking, "hasTabletTracking(self) -> bool");

extern "C" {static PyObject *meth_QWidget_hasTabletTracking(PyObject *, PyObject *);}
static PyObject *meth_QWidget_hasTabletTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasTabletTracking();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_hasTabletTracking, doc_QWidget_hasTabletTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_setWindowFlag, "setWindowFlag(self, Qt.WindowType, on: bool = True)");

extern "C" {static PyObject *meth_QWidget_setWindowFlag(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWidget_setWindowFlag(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::WindowType a0;
        bool a1 = 1;
         ::QWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_on,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWidget, &sipCpp, sipType_Qt_WindowType, &a0, &a1))
        {
            sipCpp->setWindowFlag(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_setWindowFlag, doc_QWidget_setWindowFlag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWidget_screen, "screen(self) -> QScreen");

extern "C" {static PyObject *meth_QWidget_screen(PyObject *, PyObject *);}
static PyObject *meth_QWidget_screen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWidget, &sipCpp))
        {
             ::QScreen*sipRes;

            sipRes = sipCpp->screen();

            return sipConvertFromType(sipRes,sipType_QScreen,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWidget, sipName_screen, doc_QWidget_screen);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWidget(void *, const sipTypeDef *);}
static void *cast_QWidget(void *sipCppV, const sipTypeDef *targetType)
{
     ::QWidget *sipCpp = reinterpret_cast< ::QWidget *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QPaintDevice)
        return static_cast< ::QPaintDevice *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWidget(void *, int);}
static void release_QWidget(void *sipCppV, int)
{
     ::QWidget *sipCpp = reinterpret_cast< ::QWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWidget(Py_ssize_t);}
static void *array_QWidget(Py_ssize_t sipNrElem)
{
    return new  ::QWidget[sipNrElem];
}


extern "C" {static void dealloc_QWidget(sipSimpleWrapper *);}
static void dealloc_QWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWidget *sipCpp = SIP_NULLPTR;

    {
         ::QWidget* a0 = 0;
         ::Qt::WindowFlags a1def = Qt::WindowFlags();
         ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QWidget, &a0, sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp = new sipQWidget(a0,*a1);
            sipReleaseType(a1,sipType_Qt_WindowFlags,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWidget[] = {{34, 0, 0}, {35, 1, 1}};


static PyMethodDef methods_QWidget[] = {
    {SIP_MLNAME_CAST(sipName_acceptDrops), meth_QWidget_acceptDrops, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_acceptDrops)},
    {SIP_MLNAME_CAST(sipName_actionEvent), meth_QWidget_actionEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_actionEvent)},
    {SIP_MLNAME_CAST(sipName_actions), meth_QWidget_actions, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_actions)},
    {SIP_MLNAME_CAST(sipName_activateWindow), meth_QWidget_activateWindow, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_activateWindow)},
    {SIP_MLNAME_CAST(sipName_addAction), meth_QWidget_addAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_addAction)},
    {SIP_MLNAME_CAST(sipName_addActions), meth_QWidget_addActions, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_addActions)},
    {SIP_MLNAME_CAST(sipName_adjustSize), meth_QWidget_adjustSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_adjustSize)},
    {SIP_MLNAME_CAST(sipName_autoFillBackground), meth_QWidget_autoFillBackground, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_autoFillBackground)},
    {SIP_MLNAME_CAST(sipName_backgroundRole), meth_QWidget_backgroundRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_backgroundRole)},
    {SIP_MLNAME_CAST(sipName_baseSize), meth_QWidget_baseSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_baseSize)},
    {SIP_MLNAME_CAST(sipName_changeEvent), meth_QWidget_changeEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_changeEvent)},
    {SIP_MLNAME_CAST(sipName_childAt), meth_QWidget_childAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_childAt)},
    {SIP_MLNAME_CAST(sipName_childrenRect), meth_QWidget_childrenRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_childrenRect)},
    {SIP_MLNAME_CAST(sipName_childrenRegion), meth_QWidget_childrenRegion, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_childrenRegion)},
    {SIP_MLNAME_CAST(sipName_clearFocus), meth_QWidget_clearFocus, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_clearFocus)},
    {SIP_MLNAME_CAST(sipName_clearMask), meth_QWidget_clearMask, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_clearMask)},
    {SIP_MLNAME_CAST(sipName_close), meth_QWidget_close, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_close)},
    {SIP_MLNAME_CAST(sipName_closeEvent), meth_QWidget_closeEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_closeEvent)},
    {SIP_MLNAME_CAST(sipName_contentsMargins), meth_QWidget_contentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_contentsMargins)},
    {SIP_MLNAME_CAST(sipName_contentsRect), meth_QWidget_contentsRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_contentsRect)},
    {SIP_MLNAME_CAST(sipName_contextMenuEvent), meth_QWidget_contextMenuEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_contextMenuEvent)},
    {SIP_MLNAME_CAST(sipName_contextMenuPolicy), meth_QWidget_contextMenuPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_contextMenuPolicy)},
    {SIP_MLNAME_CAST(sipName_create), SIP_MLMETH_CAST(meth_QWidget_create), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_create)},
    {SIP_MLNAME_CAST(sipName_createWindowContainer), SIP_MLMETH_CAST(meth_QWidget_createWindowContainer), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_createWindowContainer)},
    {SIP_MLNAME_CAST(sipName_cursor), meth_QWidget_cursor, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_cursor)},
    {SIP_MLNAME_CAST(sipName_destroy), SIP_MLMETH_CAST(meth_QWidget_destroy), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_destroy)},
    {SIP_MLNAME_CAST(sipName_devType), meth_QWidget_devType, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_devType)},
    {SIP_MLNAME_CAST(sipName_dragEnterEvent), meth_QWidget_dragEnterEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_dragEnterEvent)},
    {SIP_MLNAME_CAST(sipName_dragLeaveEvent), meth_QWidget_dragLeaveEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_dragLeaveEvent)},
    {SIP_MLNAME_CAST(sipName_dragMoveEvent), meth_QWidget_dragMoveEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_dragMoveEvent)},
    {SIP_MLNAME_CAST(sipName_dropEvent), meth_QWidget_dropEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_dropEvent)},
    {SIP_MLNAME_CAST(sipName_effectiveWinId), meth_QWidget_effectiveWinId, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_effectiveWinId)},
    {SIP_MLNAME_CAST(sipName_ensurePolished), meth_QWidget_ensurePolished, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_ensurePolished)},
    {SIP_MLNAME_CAST(sipName_enterEvent), meth_QWidget_enterEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_enterEvent)},
    {SIP_MLNAME_CAST(sipName_event), meth_QWidget_event, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_event)},
    {SIP_MLNAME_CAST(sipName_find), meth_QWidget_find, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_find)},
    {SIP_MLNAME_CAST(sipName_focusInEvent), meth_QWidget_focusInEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusInEvent)},
    {SIP_MLNAME_CAST(sipName_focusNextChild), meth_QWidget_focusNextChild, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusNextChild)},
    {SIP_MLNAME_CAST(sipName_focusNextPrevChild), meth_QWidget_focusNextPrevChild, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusNextPrevChild)},
    {SIP_MLNAME_CAST(sipName_focusOutEvent), meth_QWidget_focusOutEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusOutEvent)},
    {SIP_MLNAME_CAST(sipName_focusPolicy), meth_QWidget_focusPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusPolicy)},
    {SIP_MLNAME_CAST(sipName_focusPreviousChild), meth_QWidget_focusPreviousChild, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusPreviousChild)},
    {SIP_MLNAME_CAST(sipName_focusProxy), meth_QWidget_focusProxy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusProxy)},
    {SIP_MLNAME_CAST(sipName_focusWidget), meth_QWidget_focusWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_focusWidget)},
    {SIP_MLNAME_CAST(sipName_font), meth_QWidget_font, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_font)},
    {SIP_MLNAME_CAST(sipName_fontInfo), meth_QWidget_fontInfo, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_fontInfo)},
    {SIP_MLNAME_CAST(sipName_fontMetrics), meth_QWidget_fontMetrics, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_fontMetrics)},
    {SIP_MLNAME_CAST(sipName_foregroundRole), meth_QWidget_foregroundRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_foregroundRole)},
    {SIP_MLNAME_CAST(sipName_frameGeometry), meth_QWidget_frameGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_frameGeometry)},
    {SIP_MLNAME_CAST(sipName_frameSize), meth_QWidget_frameSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_frameSize)},
    {SIP_MLNAME_CAST(sipName_geometry), meth_QWidget_geometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_geometry)},
    {SIP_MLNAME_CAST(sipName_getContentsMargins), meth_QWidget_getContentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_getContentsMargins)},
    {SIP_MLNAME_CAST(sipName_grab), SIP_MLMETH_CAST(meth_QWidget_grab), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_grab)},
    {SIP_MLNAME_CAST(sipName_grabGesture), SIP_MLMETH_CAST(meth_QWidget_grabGesture), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_grabGesture)},
    {SIP_MLNAME_CAST(sipName_grabKeyboard), meth_QWidget_grabKeyboard, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_grabKeyboard)},
    {SIP_MLNAME_CAST(sipName_grabMouse), meth_QWidget_grabMouse, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_grabMouse)},
    {SIP_MLNAME_CAST(sipName_grabShortcut), SIP_MLMETH_CAST(meth_QWidget_grabShortcut), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_grabShortcut)},
    {SIP_MLNAME_CAST(sipName_graphicsEffect), meth_QWidget_graphicsEffect, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_graphicsEffect)},
    {SIP_MLNAME_CAST(sipName_graphicsProxyWidget), meth_QWidget_graphicsProxyWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_graphicsProxyWidget)},
    {SIP_MLNAME_CAST(sipName_hasFocus), meth_QWidget_hasFocus, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hasFocus)},
    {SIP_MLNAME_CAST(sipName_hasHeightForWidth), meth_QWidget_hasHeightForWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hasHeightForWidth)},
    {SIP_MLNAME_CAST(sipName_hasMouseTracking), meth_QWidget_hasMouseTracking, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hasMouseTracking)},
    {SIP_MLNAME_CAST(sipName_hasTabletTracking), meth_QWidget_hasTabletTracking, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hasTabletTracking)},
    {SIP_MLNAME_CAST(sipName_height), meth_QWidget_height, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_height)},
    {SIP_MLNAME_CAST(sipName_heightForWidth), meth_QWidget_heightForWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_heightForWidth)},
    {SIP_MLNAME_CAST(sipName_hide), meth_QWidget_hide, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hide)},
    {SIP_MLNAME_CAST(sipName_hideEvent), meth_QWidget_hideEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_hideEvent)},
    {SIP_MLNAME_CAST(sipName_initPainter), meth_QWidget_initPainter, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_initPainter)},
    {SIP_MLNAME_CAST(sipName_inputMethodEvent), meth_QWidget_inputMethodEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_inputMethodEvent)},
    {SIP_MLNAME_CAST(sipName_inputMethodHints), meth_QWidget_inputMethodHints, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_inputMethodHints)},
    {SIP_MLNAME_CAST(sipName_inputMethodQuery), meth_QWidget_inputMethodQuery, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_inputMethodQuery)},
    {SIP_MLNAME_CAST(sipName_insertAction), meth_QWidget_insertAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_insertAction)},
    {SIP_MLNAME_CAST(sipName_insertActions), meth_QWidget_insertActions, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_insertActions)},
    {SIP_MLNAME_CAST(sipName_isActiveWindow), meth_QWidget_isActiveWindow, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isActiveWindow)},
    {SIP_MLNAME_CAST(sipName_isAncestorOf), meth_QWidget_isAncestorOf, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isAncestorOf)},
    {SIP_MLNAME_CAST(sipName_isEnabled), meth_QWidget_isEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isEnabled)},
    {SIP_MLNAME_CAST(sipName_isEnabledTo), meth_QWidget_isEnabledTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isEnabledTo)},
    {SIP_MLNAME_CAST(sipName_isFullScreen), meth_QWidget_isFullScreen, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isFullScreen)},
    {SIP_MLNAME_CAST(sipName_isHidden), meth_QWidget_isHidden, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isHidden)},
    {SIP_MLNAME_CAST(sipName_isLeftToRight), meth_QWidget_isLeftToRight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isLeftToRight)},
    {SIP_MLNAME_CAST(sipName_isMaximized), meth_QWidget_isMaximized, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isMaximized)},
    {SIP_MLNAME_CAST(sipName_isMinimized), meth_QWidget_isMinimized, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isMinimized)},
    {SIP_MLNAME_CAST(sipName_isModal), meth_QWidget_isModal, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isModal)},
    {SIP_MLNAME_CAST(sipName_isRightToLeft), meth_QWidget_isRightToLeft, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isRightToLeft)},
    {SIP_MLNAME_CAST(sipName_isVisible), meth_QWidget_isVisible, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isVisible)},
    {SIP_MLNAME_CAST(sipName_isVisibleTo), meth_QWidget_isVisibleTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isVisibleTo)},
    {SIP_MLNAME_CAST(sipName_isWindow), meth_QWidget_isWindow, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isWindow)},
    {SIP_MLNAME_CAST(sipName_isWindowModified), meth_QWidget_isWindowModified, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_isWindowModified)},
    {SIP_MLNAME_CAST(sipName_keyPressEvent), meth_QWidget_keyPressEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_keyPressEvent)},
    {SIP_MLNAME_CAST(sipName_keyReleaseEvent), meth_QWidget_keyReleaseEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_keyReleaseEvent)},
    {SIP_MLNAME_CAST(sipName_keyboardGrabber), meth_QWidget_keyboardGrabber, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_keyboardGrabber)},
    {SIP_MLNAME_CAST(sipName_layout), meth_QWidget_layout, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_layout)},
    {SIP_MLNAME_CAST(sipName_layoutDirection), meth_QWidget_layoutDirection, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_layoutDirection)},
    {SIP_MLNAME_CAST(sipName_leaveEvent), meth_QWidget_leaveEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_leaveEvent)},
    {SIP_MLNAME_CAST(sipName_locale), meth_QWidget_locale, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_locale)},
    {SIP_MLNAME_CAST(sipName_lower), meth_QWidget_lower, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_lower)},
    {SIP_MLNAME_CAST(sipName_mapFrom), meth_QWidget_mapFrom, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapFrom)},
    {SIP_MLNAME_CAST(sipName_mapFromGlobal), meth_QWidget_mapFromGlobal, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapFromGlobal)},
    {SIP_MLNAME_CAST(sipName_mapFromParent), meth_QWidget_mapFromParent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapFromParent)},
    {SIP_MLNAME_CAST(sipName_mapTo), meth_QWidget_mapTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapTo)},
    {SIP_MLNAME_CAST(sipName_mapToGlobal), meth_QWidget_mapToGlobal, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapToGlobal)},
    {SIP_MLNAME_CAST(sipName_mapToParent), meth_QWidget_mapToParent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mapToParent)},
    {SIP_MLNAME_CAST(sipName_mask), meth_QWidget_mask, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mask)},
    {SIP_MLNAME_CAST(sipName_maximumHeight), meth_QWidget_maximumHeight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_maximumHeight)},
    {SIP_MLNAME_CAST(sipName_maximumSize), meth_QWidget_maximumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_maximumSize)},
    {SIP_MLNAME_CAST(sipName_maximumWidth), meth_QWidget_maximumWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_maximumWidth)},
    {SIP_MLNAME_CAST(sipName_metric), meth_QWidget_metric, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_metric)},
    {SIP_MLNAME_CAST(sipName_minimumHeight), meth_QWidget_minimumHeight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_minimumHeight)},
    {SIP_MLNAME_CAST(sipName_minimumSize), meth_QWidget_minimumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_minimumSize)},
    {SIP_MLNAME_CAST(sipName_minimumSizeHint), meth_QWidget_minimumSizeHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_minimumSizeHint)},
    {SIP_MLNAME_CAST(sipName_minimumWidth), meth_QWidget_minimumWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_minimumWidth)},
    {SIP_MLNAME_CAST(sipName_mouseDoubleClickEvent), meth_QWidget_mouseDoubleClickEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mouseDoubleClickEvent)},
    {SIP_MLNAME_CAST(sipName_mouseGrabber), meth_QWidget_mouseGrabber, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mouseGrabber)},
    {SIP_MLNAME_CAST(sipName_mouseMoveEvent), meth_QWidget_mouseMoveEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mouseMoveEvent)},
    {SIP_MLNAME_CAST(sipName_mousePressEvent), meth_QWidget_mousePressEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mousePressEvent)},
    {SIP_MLNAME_CAST(sipName_mouseReleaseEvent), meth_QWidget_mouseReleaseEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_mouseReleaseEvent)},
    {SIP_MLNAME_CAST(sipName_move), meth_QWidget_move, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_move)},
    {SIP_MLNAME_CAST(sipName_moveEvent), meth_QWidget_moveEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_moveEvent)},
    {SIP_MLNAME_CAST(sipName_nativeEvent), meth_QWidget_nativeEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_nativeEvent)},
    {SIP_MLNAME_CAST(sipName_nativeParentWidget), meth_QWidget_nativeParentWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_nativeParentWidget)},
    {SIP_MLNAME_CAST(sipName_nextInFocusChain), meth_QWidget_nextInFocusChain, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_nextInFocusChain)},
    {SIP_MLNAME_CAST(sipName_normalGeometry), meth_QWidget_normalGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_normalGeometry)},
    {SIP_MLNAME_CAST(sipName_overrideWindowFlags), meth_QWidget_overrideWindowFlags, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_overrideWindowFlags)},
    {SIP_MLNAME_CAST(sipName_overrideWindowState), meth_QWidget_overrideWindowState, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_overrideWindowState)},
    {SIP_MLNAME_CAST(sipName_paintEngine), meth_QWidget_paintEngine, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_paintEngine)},
    {SIP_MLNAME_CAST(sipName_paintEvent), meth_QWidget_paintEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_paintEvent)},
    {SIP_MLNAME_CAST(sipName_palette), meth_QWidget_palette, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_palette)},
    {SIP_MLNAME_CAST(sipName_parentWidget), meth_QWidget_parentWidget, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_parentWidget)},
    {SIP_MLNAME_CAST(sipName_pos), meth_QWidget_pos, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_pos)},
    {SIP_MLNAME_CAST(sipName_previousInFocusChain), meth_QWidget_previousInFocusChain, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_previousInFocusChain)},
    {SIP_MLNAME_CAST(sipName_raise_), meth_QWidget_raise_, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_raise_)},
    {SIP_MLNAME_CAST(sipName_rect), meth_QWidget_rect, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_rect)},
    {SIP_MLNAME_CAST(sipName_releaseKeyboard), meth_QWidget_releaseKeyboard, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_releaseKeyboard)},
    {SIP_MLNAME_CAST(sipName_releaseMouse), meth_QWidget_releaseMouse, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_releaseMouse)},
    {SIP_MLNAME_CAST(sipName_releaseShortcut), meth_QWidget_releaseShortcut, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_releaseShortcut)},
    {SIP_MLNAME_CAST(sipName_removeAction), meth_QWidget_removeAction, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_removeAction)},
    {SIP_MLNAME_CAST(sipName_render), SIP_MLMETH_CAST(meth_QWidget_render), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_render)},
    {SIP_MLNAME_CAST(sipName_repaint), meth_QWidget_repaint, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_repaint)},
    {SIP_MLNAME_CAST(sipName_resize), meth_QWidget_resize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_resize)},
    {SIP_MLNAME_CAST(sipName_resizeEvent), meth_QWidget_resizeEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_resizeEvent)},
    {SIP_MLNAME_CAST(sipName_restoreGeometry), meth_QWidget_restoreGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_restoreGeometry)},
    {SIP_MLNAME_CAST(sipName_saveGeometry), meth_QWidget_saveGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_saveGeometry)},
    {SIP_MLNAME_CAST(sipName_screen), meth_QWidget_screen, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_screen)},
    {SIP_MLNAME_CAST(sipName_scroll), meth_QWidget_scroll, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_scroll)},
    {SIP_MLNAME_CAST(sipName_setAcceptDrops), meth_QWidget_setAcceptDrops, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setAcceptDrops)},
    {SIP_MLNAME_CAST(sipName_setAttribute), SIP_MLMETH_CAST(meth_QWidget_setAttribute), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_setAttribute)},
    {SIP_MLNAME_CAST(sipName_setAutoFillBackground), meth_QWidget_setAutoFillBackground, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setAutoFillBackground)},
    {SIP_MLNAME_CAST(sipName_setBackgroundRole), meth_QWidget_setBackgroundRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setBackgroundRole)},
    {SIP_MLNAME_CAST(sipName_setBaseSize), meth_QWidget_setBaseSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setBaseSize)},
    {SIP_MLNAME_CAST(sipName_setContentsMargins), meth_QWidget_setContentsMargins, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setContentsMargins)},
    {SIP_MLNAME_CAST(sipName_setContextMenuPolicy), meth_QWidget_setContextMenuPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setContextMenuPolicy)},
    {SIP_MLNAME_CAST(sipName_setCursor), meth_QWidget_setCursor, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setCursor)},
    {SIP_MLNAME_CAST(sipName_setDisabled), meth_QWidget_setDisabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setDisabled)},
    {SIP_MLNAME_CAST(sipName_setEnabled), meth_QWidget_setEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setEnabled)},
    {SIP_MLNAME_CAST(sipName_setFixedHeight), meth_QWidget_setFixedHeight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFixedHeight)},
    {SIP_MLNAME_CAST(sipName_setFixedSize), meth_QWidget_setFixedSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFixedSize)},
    {SIP_MLNAME_CAST(sipName_setFixedWidth), meth_QWidget_setFixedWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFixedWidth)},
    {SIP_MLNAME_CAST(sipName_setFocus), meth_QWidget_setFocus, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFocus)},
    {SIP_MLNAME_CAST(sipName_setFocusPolicy), meth_QWidget_setFocusPolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFocusPolicy)},
    {SIP_MLNAME_CAST(sipName_setFocusProxy), meth_QWidget_setFocusProxy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFocusProxy)},
    {SIP_MLNAME_CAST(sipName_setFont), meth_QWidget_setFont, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setFont)},
    {SIP_MLNAME_CAST(sipName_setForegroundRole), meth_QWidget_setForegroundRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setForegroundRole)},
    {SIP_MLNAME_CAST(sipName_setGeometry), meth_QWidget_setGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setGeometry)},
    {SIP_MLNAME_CAST(sipName_setGraphicsEffect), meth_QWidget_setGraphicsEffect, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setGraphicsEffect)},
    {SIP_MLNAME_CAST(sipName_setHidden), meth_QWidget_setHidden, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setHidden)},
    {SIP_MLNAME_CAST(sipName_setInputMethodHints), meth_QWidget_setInputMethodHints, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setInputMethodHints)},
    {SIP_MLNAME_CAST(sipName_setLayout), meth_QWidget_setLayout, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setLayout)},
    {SIP_MLNAME_CAST(sipName_setLayoutDirection), meth_QWidget_setLayoutDirection, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setLayoutDirection)},
    {SIP_MLNAME_CAST(sipName_setLocale), meth_QWidget_setLocale, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setLocale)},
    {SIP_MLNAME_CAST(sipName_setMask), meth_QWidget_setMask, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMask)},
    {SIP_MLNAME_CAST(sipName_setMaximumHeight), meth_QWidget_setMaximumHeight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMaximumHeight)},
    {SIP_MLNAME_CAST(sipName_setMaximumSize), meth_QWidget_setMaximumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMaximumSize)},
    {SIP_MLNAME_CAST(sipName_setMaximumWidth), meth_QWidget_setMaximumWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMaximumWidth)},
    {SIP_MLNAME_CAST(sipName_setMinimumHeight), meth_QWidget_setMinimumHeight, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMinimumHeight)},
    {SIP_MLNAME_CAST(sipName_setMinimumSize), meth_QWidget_setMinimumSize, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMinimumSize)},
    {SIP_MLNAME_CAST(sipName_setMinimumWidth), meth_QWidget_setMinimumWidth, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMinimumWidth)},
    {SIP_MLNAME_CAST(sipName_setMouseTracking), meth_QWidget_setMouseTracking, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setMouseTracking)},
    {SIP_MLNAME_CAST(sipName_setPalette), meth_QWidget_setPalette, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setPalette)},
    {SIP_MLNAME_CAST(sipName_setParent), meth_QWidget_setParent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setParent)},
    {SIP_MLNAME_CAST(sipName_setShortcutAutoRepeat), SIP_MLMETH_CAST(meth_QWidget_setShortcutAutoRepeat), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_setShortcutAutoRepeat)},
    {SIP_MLNAME_CAST(sipName_setShortcutEnabled), SIP_MLMETH_CAST(meth_QWidget_setShortcutEnabled), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_setShortcutEnabled)},
    {SIP_MLNAME_CAST(sipName_setSizeIncrement), meth_QWidget_setSizeIncrement, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setSizeIncrement)},
    {SIP_MLNAME_CAST(sipName_setSizePolicy), meth_QWidget_setSizePolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setSizePolicy)},
    {SIP_MLNAME_CAST(sipName_setStatusTip), meth_QWidget_setStatusTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setStatusTip)},
    {SIP_MLNAME_CAST(sipName_setStyle), meth_QWidget_setStyle, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setStyle)},
    {SIP_MLNAME_CAST(sipName_setStyleSheet), meth_QWidget_setStyleSheet, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setStyleSheet)},
    {SIP_MLNAME_CAST(sipName_setTabOrder), meth_QWidget_setTabOrder, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setTabOrder)},
    {SIP_MLNAME_CAST(sipName_setTabletTracking), meth_QWidget_setTabletTracking, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setTabletTracking)},
    {SIP_MLNAME_CAST(sipName_setToolTip), meth_QWidget_setToolTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setToolTip)},
    {SIP_MLNAME_CAST(sipName_setToolTipDuration), meth_QWidget_setToolTipDuration, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setToolTipDuration)},
    {SIP_MLNAME_CAST(sipName_setUpdatesEnabled), meth_QWidget_setUpdatesEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setUpdatesEnabled)},
    {SIP_MLNAME_CAST(sipName_setVisible), meth_QWidget_setVisible, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setVisible)},
    {SIP_MLNAME_CAST(sipName_setWhatsThis), meth_QWidget_setWhatsThis, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWhatsThis)},
    {SIP_MLNAME_CAST(sipName_setWindowFilePath), meth_QWidget_setWindowFilePath, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowFilePath)},
    {SIP_MLNAME_CAST(sipName_setWindowFlag), SIP_MLMETH_CAST(meth_QWidget_setWindowFlag), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QWidget_setWindowFlag)},
    {SIP_MLNAME_CAST(sipName_setWindowFlags), meth_QWidget_setWindowFlags, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowFlags)},
    {SIP_MLNAME_CAST(sipName_setWindowIcon), meth_QWidget_setWindowIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowIcon)},
    {SIP_MLNAME_CAST(sipName_setWindowIconText), meth_QWidget_setWindowIconText, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowIconText)},
    {SIP_MLNAME_CAST(sipName_setWindowModality), meth_QWidget_setWindowModality, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowModality)},
    {SIP_MLNAME_CAST(sipName_setWindowModified), meth_QWidget_setWindowModified, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowModified)},
    {SIP_MLNAME_CAST(sipName_setWindowOpacity), meth_QWidget_setWindowOpacity, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowOpacity)},
    {SIP_MLNAME_CAST(sipName_setWindowRole), meth_QWidget_setWindowRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowRole)},
    {SIP_MLNAME_CAST(sipName_setWindowState), meth_QWidget_setWindowState, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowState)},
    {SIP_MLNAME_CAST(sipName_setWindowTitle), meth_QWidget_setWindowTitle, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_setWindowTitle)},
    {SIP_MLNAME_CAST(sipName_sharedPainter), meth_QWidget_sharedPainter, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_sharedPainter)},
    {SIP_MLNAME_CAST(sipName_show), meth_QWidget_show, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_show)},
    {SIP_MLNAME_CAST(sipName_showEvent), meth_QWidget_showEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_showEvent)},
    {SIP_MLNAME_CAST(sipName_showFullScreen), meth_QWidget_showFullScreen, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_showFullScreen)},
    {SIP_MLNAME_CAST(sipName_showMaximized), meth_QWidget_showMaximized, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_showMaximized)},
    {SIP_MLNAME_CAST(sipName_showMinimized), meth_QWidget_showMinimized, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_showMinimized)},
    {SIP_MLNAME_CAST(sipName_showNormal), meth_QWidget_showNormal, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_showNormal)},
    {SIP_MLNAME_CAST(sipName_size), meth_QWidget_size, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_size)},
    {SIP_MLNAME_CAST(sipName_sizeHint), meth_QWidget_sizeHint, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_sizeHint)},
    {SIP_MLNAME_CAST(sipName_sizeIncrement), meth_QWidget_sizeIncrement, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_sizeIncrement)},
    {SIP_MLNAME_CAST(sipName_sizePolicy), meth_QWidget_sizePolicy, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_sizePolicy)},
    {SIP_MLNAME_CAST(sipName_stackUnder), meth_QWidget_stackUnder, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_stackUnder)},
    {SIP_MLNAME_CAST(sipName_statusTip), meth_QWidget_statusTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_statusTip)},
    {SIP_MLNAME_CAST(sipName_style), meth_QWidget_style, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_style)},
    {SIP_MLNAME_CAST(sipName_styleSheet), meth_QWidget_styleSheet, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_styleSheet)},
    {SIP_MLNAME_CAST(sipName_tabletEvent), meth_QWidget_tabletEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_tabletEvent)},
    {SIP_MLNAME_CAST(sipName_testAttribute), meth_QWidget_testAttribute, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_testAttribute)},
    {SIP_MLNAME_CAST(sipName_toolTip), meth_QWidget_toolTip, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_toolTip)},
    {SIP_MLNAME_CAST(sipName_toolTipDuration), meth_QWidget_toolTipDuration, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_toolTipDuration)},
    {SIP_MLNAME_CAST(sipName_underMouse), meth_QWidget_underMouse, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_underMouse)},
    {SIP_MLNAME_CAST(sipName_ungrabGesture), meth_QWidget_ungrabGesture, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_ungrabGesture)},
    {SIP_MLNAME_CAST(sipName_unsetCursor), meth_QWidget_unsetCursor, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_unsetCursor)},
    {SIP_MLNAME_CAST(sipName_unsetLayoutDirection), meth_QWidget_unsetLayoutDirection, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_unsetLayoutDirection)},
    {SIP_MLNAME_CAST(sipName_unsetLocale), meth_QWidget_unsetLocale, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_unsetLocale)},
    {SIP_MLNAME_CAST(sipName_update), meth_QWidget_update, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_update)},
    {SIP_MLNAME_CAST(sipName_updateGeometry), meth_QWidget_updateGeometry, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_updateGeometry)},
    {SIP_MLNAME_CAST(sipName_updateMicroFocus), meth_QWidget_updateMicroFocus, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_updateMicroFocus)},
    {SIP_MLNAME_CAST(sipName_updatesEnabled), meth_QWidget_updatesEnabled, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_updatesEnabled)},
    {SIP_MLNAME_CAST(sipName_visibleRegion), meth_QWidget_visibleRegion, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_visibleRegion)},
    {SIP_MLNAME_CAST(sipName_whatsThis), meth_QWidget_whatsThis, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_whatsThis)},
    {SIP_MLNAME_CAST(sipName_wheelEvent), meth_QWidget_wheelEvent, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_wheelEvent)},
    {SIP_MLNAME_CAST(sipName_width), meth_QWidget_width, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_width)},
    {SIP_MLNAME_CAST(sipName_winId), meth_QWidget_winId, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_winId)},
    {SIP_MLNAME_CAST(sipName_window), meth_QWidget_window, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_window)},
    {SIP_MLNAME_CAST(sipName_windowFilePath), meth_QWidget_windowFilePath, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowFilePath)},
    {SIP_MLNAME_CAST(sipName_windowFlags), meth_QWidget_windowFlags, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowFlags)},
    {SIP_MLNAME_CAST(sipName_windowHandle), meth_QWidget_windowHandle, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowHandle)},
    {SIP_MLNAME_CAST(sipName_windowIcon), meth_QWidget_windowIcon, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowIcon)},
    {SIP_MLNAME_CAST(sipName_windowIconText), meth_QWidget_windowIconText, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowIconText)},
    {SIP_MLNAME_CAST(sipName_windowModality), meth_QWidget_windowModality, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowModality)},
    {SIP_MLNAME_CAST(sipName_windowOpacity), meth_QWidget_windowOpacity, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowOpacity)},
    {SIP_MLNAME_CAST(sipName_windowRole), meth_QWidget_windowRole, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowRole)},
    {SIP_MLNAME_CAST(sipName_windowState), meth_QWidget_windowState, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowState)},
    {SIP_MLNAME_CAST(sipName_windowTitle), meth_QWidget_windowTitle, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowTitle)},
    {SIP_MLNAME_CAST(sipName_windowType), meth_QWidget_windowType, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_windowType)},
    {SIP_MLNAME_CAST(sipName_x), meth_QWidget_x, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_x)},
    {SIP_MLNAME_CAST(sipName_y), meth_QWidget_y, METH_VARARGS, SIP_MLDOC_CAST(doc_QWidget_y)}
};

static sipEnumMemberDef enummembers_QWidget[] = {
    {sipName_DrawChildren, static_cast<int>( ::QWidget::DrawChildren), 464},
    {sipName_DrawWindowBackground, static_cast<int>( ::QWidget::DrawWindowBackground), 464},
    {sipName_IgnoreMask, static_cast<int>( ::QWidget::IgnoreMask), 464},
};

PyDoc_STRVAR(doc_QWidget, "\1QWidget(parent: QWidget = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags())");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QWidget[] = {
    {"windowIconTextChanged(QString)", "\1windowIconTextChanged(self, str)", SIP_NULLPTR, SIP_NULLPTR},
    {"windowIconChanged(QIcon)", "\1windowIconChanged(self, QIcon)", SIP_NULLPTR, SIP_NULLPTR},
    {"windowTitleChanged(QString)", "\1windowTitleChanged(self, str)", SIP_NULLPTR, SIP_NULLPTR},
    {"customContextMenuRequested(QPoint)", "\1customContextMenuRequested(self, QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QWidget = {
    & ::QWidget::staticMetaObject,
    0,
    signals_QWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWidget,
        {SIP_NULLPTR},
        &plugin_QWidget
    },
    {
        sipNameNr_QWidget,
        {0, 0, 1},
        251, methods_QWidget,
        3, enummembers_QWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWidget,
    -1,
    -1,
    supers_QWidget,
    SIP_NULLPTR,
    init_type_QWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QWidget,
    SIP_NULLPTR,
    array_QWidget,
    SIP_NULLPTR,
    release_QWidget,
    cast_QWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
